@@ -1,3 +1,4 @@
+# sage.doctest: optional - sage.graphs, sage.combinat
 r"""
 Classical Crystals
 """
@@ -107,7 +108,6 @@ class ClassicalCrystals(Category_singleton):
         """
         return None
 
-
     class ParentMethods:
 
         def demazure_character(self, w, f=None):
@@ -181,7 +181,7 @@ class ClassicalCrystals(Category_singleton):
             u = self.algebra(ZZ).sum_of_monomials(self.module_generators)
             u = self.demazure_operator(u, word)
             if f is None:
-                from sage.symbolic.all import SR as P
+                from sage.symbolic.ring import SR as P
                 x = [P.var('x%s' % (i+1)) for i in range(n)]
                 # TODO: use P.linear_combination when PolynomialRing will be a ModulesWithBasis
                 return sum((coeff*prod((x[i]**(c.weight()[i]) for i in range(n)), P.one()) for c, coeff in u), P.zero())
