@@ -46,8 +46,8 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: F = CombinatorialFreeModule(ZZ, ['a', 'b', 'c'])
-                sage: F.gens()
+                sage: F = CombinatorialFreeModule(ZZ, ['a', 'b', 'c'])                  # optional - sage.modules
+                sage: F.gens()                                                          # optional - sage.modules
                 (B['a'], B['b'], B['c'])
             """
             return tuple(self.basis())
@@ -91,35 +91,35 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: F = FiniteDimensionalAlgebrasWithBasis(QQ).example(); F
+                sage: F = FiniteDimensionalAlgebrasWithBasis(QQ).example(); F           # optional - sage.modules
                 An example of a finite dimensional algebra with basis:
                 the path algebra of the Kronecker quiver
                 (containing the arrows a:x->y and b:x->y) over Rational Field
-                sage: x,y,a,b = F.basis()
-                sage: A = F.annihilator([a + 3*b + 2*y]); A
+                sage: x, y, a, b = F.basis()                                            # optional - sage.modules
+                sage: A = F.annihilator([a + 3*b + 2*y]); A                             # optional - sage.modules
                 Free module generated by {0} over Rational Field
-                sage: [b.lift() for b in A.basis()]
+                sage: [b.lift() for b in A.basis()]                                     # optional - sage.modules
                 [-1/2*a - 3/2*b + x]
 
             The category can be used to specify other properties of
             this subspace, like that this is a subalgebra::
 
-                sage: center = F.annihilator(F.basis(), F.bracket,
+                sage: center = F.annihilator(F.basis(), F.bracket,                      # optional - sage.modules
                 ....:                        category=Algebras(QQ).Subobjects())
-                sage: (e,) = center.basis()
-                sage: e.lift()
+                sage: (e,) = center.basis()                                             # optional - sage.modules
+                sage: e.lift()                                                          # optional - sage.modules
                 x + y
-                sage: e * e == e
+                sage: e * e == e                                                        # optional - sage.modules
                 True
 
             Taking annihilator is order reversing for inclusion::
 
-                sage: A   = F.annihilator([]);    A  .rename("A")
-                sage: Ax  = F.annihilator([x]);   Ax .rename("Ax")
-                sage: Ay  = F.annihilator([y]);   Ay .rename("Ay")
-                sage: Axy = F.annihilator([x,y]); Axy.rename("Axy")
-                sage: P = Poset(([A, Ax, Ay, Axy], attrcall("is_submodule")))
-                sage: sorted(P.cover_relations(), key=str)
+                sage: A   = F.annihilator([]);    A  .rename("A")                       # optional - sage.modules
+                sage: Ax  = F.annihilator([x]);   Ax .rename("Ax")                      # optional - sage.modules
+                sage: Ay  = F.annihilator([y]);   Ay .rename("Ay")                      # optional - sage.modules
+                sage: Axy = F.annihilator([x,y]); Axy.rename("Axy")                     # optional - sage.modules
+                sage: P = Poset(([A, Ax, Ay, Axy], attrcall("is_submodule")))           # optional - sage.combinat sage.graphs sage.modules
+                sage: sorted(P.cover_relations(), key=str)                              # optional - sage.combinat sage.graphs sage.modules
                 [[Ax, A], [Axy, Ax], [Axy, Ay], [Ay, A]]
             """
             return self.submodule(self.annihilator_basis(S, action, side),
@@ -204,7 +204,8 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
             compute the orthogonal of a subspace::
 
                 sage: x,y,a,b = F.basis()
-                sage: def scalar(u,v): return vector([sum(u[i]*v[i] for i in F.basis().keys())])
+                sage: def scalar(u,v):
+                ....:     return vector([sum(u[i]*v[i] for i in F.basis().keys())])
                 sage: F.annihilator_basis([x+y, a+b], scalar)
                 (x - y, a - b)
 
@@ -251,13 +252,13 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: C = CombinatorialFreeModule(QQ['x'], ['a','b','c']); C
+                sage: C = CombinatorialFreeModule(QQ['x'], ['a','b','c']); C            # optional - sage.modules
                 Free module generated by {'a', 'b', 'c'} over
                  Univariate Polynomial Ring in x over Rational Field
-                sage: C._dense_free_module()
+                sage: C._dense_free_module()                                            # optional - sage.modules
                 Ambient free module of rank 3 over the principal ideal domain
                  Univariate Polynomial Ring in x over Rational Field
-                sage: C._dense_free_module(QQ['x,y'])
+                sage: C._dense_free_module(QQ['x,y'])                                   # optional - sage.modules
                 Ambient free module of rank 3 over the integral domain
                  Multivariate Polynomial Ring in x, y over Rational Field
             """
@@ -272,11 +273,11 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: p_mult = matrix([[0,0,0],[0,0,-1],[0,0,0]])
-                sage: q_mult = matrix([[0,0,1],[0,0,0],[0,0,0]])
-                sage: A = algebras.FiniteDimensional(QQ, [p_mult, q_mult, matrix(QQ,3,3)],
-                ....:                                'p,q,z')
-                sage: A.from_vector(vector([1,0,2]))
+                sage: p_mult = matrix([[0,0,0], [0,0,-1], [0,0,0]])                     # optional - sage.modules
+                sage: q_mult = matrix([[0,0,1], [0,0,0], [0,0,0]])                      # optional - sage.modules
+                sage: A = algebras.FiniteDimensional(                                   # optional - sage.combinat sage.modules
+                ....:         QQ, [p_mult, q_mult, matrix(QQ, 3, 3)], 'p,q,z')
+                sage: A.from_vector(vector([1,0,2]))                                    # optional - sage.combinat sage.modules
                 p + 2*z
             """
             if order is None:
@@ -312,42 +313,42 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x")
-                sage: x = X.basis()
-                sage: V = X.echelon_form([x[0]-x[1], x[0]-x[2],x[1]-x[2]]); V
+                sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x")             # optional - sage.modules
+                sage: x = X.basis()                                                     # optional - sage.modules
+                sage: V = X.echelon_form([x[0]-x[1], x[0]-x[2], x[1]-x[2]]); V          # optional - sage.modules
                 [x[0] - x[2], x[1] - x[2]]
-                sage: matrix(list(map(vector, V)))
+                sage: matrix(list(map(vector, V)))                                      # optional - sage.modules
                 [ 1  0 -1]
                 [ 0  1 -1]
 
             ::
 
-                sage: F = CombinatorialFreeModule(ZZ, [1,2,3,4])
-                sage: B = F.basis()
-                sage: elements = [B[1]-17*B[2]+6*B[3], B[1]-17*B[2]+B[4]]
-                sage: F.echelon_form(elements)
+                sage: F = CombinatorialFreeModule(ZZ, [1,2,3,4])                        # optional - sage.modules
+                sage: B = F.basis()                                                     # optional - sage.modules
+                sage: elements = [B[1]-17*B[2]+6*B[3], B[1]-17*B[2]+B[4]]               # optional - sage.modules
+                sage: F.echelon_form(elements)                                          # optional - sage.modules
                 [B[1] - 17*B[2] + B[4], 6*B[3] - B[4]]
 
             ::
 
-                sage: F = CombinatorialFreeModule(QQ, ['a','b','c'])
-                sage: a,b,c = F.basis()
-                sage: F.echelon_form([8*a+b+10*c, -3*a+b-c, a-b-c])
+                sage: F = CombinatorialFreeModule(QQ, ['a','b','c'])                    # optional - sage.modules
+                sage: a,b,c = F.basis()                                                 # optional - sage.modules
+                sage: F.echelon_form([8*a+b+10*c, -3*a+b-c, a-b-c])                     # optional - sage.modules
                 [B['a'] + B['c'], B['b'] + 2*B['c']]
 
             ::
 
                 sage: R.<x,y> = QQ[]
-                sage: C = CombinatorialFreeModule(R, range(3), prefix='x')
-                sage: x = C.basis()
-                sage: C.echelon_form([x[0] - x[1], 2*x[1] - 2*x[2], x[0] - x[2]])
+                sage: C = CombinatorialFreeModule(R, range(3), prefix='x')              # optional - sage.modules
+                sage: x = C.basis()                                                     # optional - sage.modules
+                sage: C.echelon_form([x[0] - x[1], 2*x[1] - 2*x[2], x[0] - x[2]])       # optional - sage.modules
                 [x[0] - x[2], x[1] - x[2]]
 
             ::
 
-                sage: M = MatrixSpace(QQ, 3, 3)
-                sage: A = M([[0, 0, 2], [0, 0, 0], [0, 0, 0]])
-                sage: M.echelon_form([A, A])
+                sage: M = MatrixSpace(QQ, 3, 3)                                         # optional - sage.modules
+                sage: A = M([[0, 0, 2], [0, 0, 0], [0, 0, 0]])                          # optional - sage.modules
+                sage: M.echelon_form([A, A])                                            # optional - sage.modules
                 [
                 [0 0 1]
                 [0 0 0]
@@ -358,8 +359,8 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             We convert the input elements to ``self``::
 
-                sage: E.<x,y,z> = ExteriorAlgebra(QQ)
-                sage: E.echelon_form([1, x + 2])
+                sage: E.<x,y,z> = ExteriorAlgebra(QQ)                                   # optional - sage.modules sage.combinat
+                sage: E.echelon_form([1, x + 2])                                        # optional - sage.modules sage.combinat
                 [1, x]
             """
             # Make sure elements consists of elements of ``self``
@@ -410,35 +411,37 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
             We build the invariant module of the permutation representation
             of the symmetric group::
 
-                sage: G = SymmetricGroup(3); G.rename('S3')
-                sage: M = FreeModule(ZZ, [1,2,3], prefix='M'); M.rename('M')
+                sage: G = SymmetricGroup(3); G.rename('S3')                             # optional - sage.groups sage.modules
+                sage: M = FreeModule(ZZ, [1,2,3], prefix='M'); M.rename('M')            # optional - sage.groups sage.modules
                 sage: action = lambda g, x: M.term(g(x))
-                sage: I = M.invariant_module(G, action_on_basis=action); I
+                sage: I = M.invariant_module(G, action_on_basis=action); I              # optional - sage.groups sage.modules
                 (S3)-invariant submodule of M
-                sage: I.basis()
+                sage: I.basis()                                                         # optional - sage.groups sage.modules
                 Finite family {0: B[0]}
-                sage: [I.lift(b) for b in I.basis()]
+                sage: [I.lift(b) for b in I.basis()]                                    # optional - sage.groups sage.modules
                 [M[1] + M[2] + M[3]]
 
-                sage: G.rename(); M.rename()  # reset the names
+                sage: G.rename(); M.rename()  # reset the names                         # optional - sage.groups sage.modules
 
             We can construct the invariant module of any module that has
             an action of ``S``. In this example, we consider the dihedral
             group `G = D_4` and the subgroup `H < G` of all rotations. We
             construct the `H`-invariant module of the group algebra `\QQ[G]`::
 
-                sage: G = groups.permutation.Dihedral(4)
-                sage: H = G.subgroup(G.gen(0))
-                sage: H
-                Subgroup generated by [(1,2,3,4)] of (Dihedral group of order 8 as a permutation group)
-                sage: H.cardinality()
+                sage: G = groups.permutation.Dihedral(4)                                # optional - sage.groups
+                sage: H = G.subgroup(G.gen(0))                                          # optional - sage.groups
+                sage: H                                                                 # optional - sage.groups
+                Subgroup generated by [(1,2,3,4)]
+                 of (Dihedral group of order 8 as a permutation group)
+                sage: H.cardinality()                                                   # optional - sage.groups
                 4
-                sage: A = G.algebra(QQ)
-                sage: I = A.invariant_module(H)
-                sage: [I.lift(b) for b in I.basis()]
+                sage: A = G.algebra(QQ)                                                 # optional - sage.groups sage.modules
+                sage: I = A.invariant_module(H)                                         # optional - sage.groups sage.modules
+                sage: [I.lift(b) for b in I.basis()]                                    # optional - sage.groups sage.modules
                 [() + (1,2,3,4) + (1,3)(2,4) + (1,4,3,2),
                  (2,4) + (1,2)(3,4) + (1,3) + (1,4)(2,3)]
-                sage: all(h * I.lift(b) == I.lift(b) for b in I.basis() for h in H)
+                sage: all(h * I.lift(b) == I.lift(b)                                    # optional - sage.groups sage.modules
+                ....:     for b in I.basis() for h in H)
                 True
             """
             if action_on_basis is not None:
@@ -480,12 +483,13 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: M = CombinatorialFreeModule(QQ, [1,2,3])
-                sage: G = SymmetricGroup(3)
-                sage: def action(g,x): return(M.term(g(x))) # permute coordinates
-                sage: T = M.twisted_invariant_module(G, [2,0,-1], action_on_basis=action)
+                sage: M = CombinatorialFreeModule(QQ, [1,2,3])                          # optional - sage.groups sage.modules
+                sage: G = SymmetricGroup(3)                                             # optional - sage.groups
+                sage: def action(g,x): return(M.term(g(x)))  # permute coordinates
+                sage: T = M.twisted_invariant_module(G, [2,0,-1],                       # optional - sage.groups sage.modules
+                ....:                                action_on_basis=action)
                 sage: import __main__; __main__.action = action
-                sage: TestSuite(T).run()
+                sage: TestSuite(T).run()                                                # optional - sage.groups sage.modules
             """
 
             if action_on_basis is not None:
@@ -514,12 +518,12 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: v = vector([0, -1, -3])
-                sage: v.dense_coefficient_list()
+                sage: v = vector([0, -1, -3])                                           # optional - sage.modules
+                sage: v.dense_coefficient_list()                                        # optional - sage.modules
                 [0, -1, -3]
-                sage: v.dense_coefficient_list([2,1,0])
+                sage: v.dense_coefficient_list([2,1,0])                                 # optional - sage.modules
                 [-3, -1, 0]
-                sage: sorted(v.coefficients())
+                sage: sorted(v.coefficients())                                          # optional - sage.modules
                 [-3, -1]
             """
             if order is None:
@@ -535,11 +539,11 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: v = vector([0, -1, -3])
-                sage: v._vector_()
+                sage: v = vector([0, -1, -3])                                           # optional - sage.modules
+                sage: v._vector_()                                                      # optional - sage.modules
                 (0, -1, -3)
-                sage: C = CombinatorialFreeModule(QQ['x'], ['a','b','c'])
-                sage: C.an_element()._vector_()
+                sage: C = CombinatorialFreeModule(QQ['x'], ['a','b','c'])               # optional - sage.modules
+                sage: C.an_element()._vector_()                                         # optional - sage.modules
                 (2, 2, 3)
             """
             if order is None:
@@ -577,30 +581,31 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: X = CombinatorialFreeModule(ZZ, [1,2]); x = X.basis()
-                sage: Y = CombinatorialFreeModule(ZZ, [3,4]); y = Y.basis()
-                sage: phi = X.module_morphism(on_basis = {1: y[3] + 3*y[4], 2: 2*y[3] + 5*y[4]}.__getitem__,
-                ....:                         codomain = Y)
-                sage: phi.matrix()
+                sage: X = CombinatorialFreeModule(ZZ, [1,2]); x = X.basis()             # optional - sage.modules
+                sage: Y = CombinatorialFreeModule(ZZ, [3,4]); y = Y.basis()             # optional - sage.modules
+                sage: phi = X.module_morphism(on_basis={1: y[3] + 3*y[4],               # optional - sage.modules
+                ....:                                   2: 2*y[3] + 5*y[4]}.__getitem__,
+                ....:                         codomain=Y)
+                sage: phi.matrix()                                                      # optional - sage.modules
                 [1 2]
                 [3 5]
-                sage: phi.matrix(side="right")
+                sage: phi.matrix(side="right")                                          # optional - sage.modules
                 [1 3]
                 [2 5]
 
-                sage: phi.matrix().parent()
+                sage: phi.matrix().parent()                                             # optional - sage.modules
                 Full MatrixSpace of 2 by 2 dense matrices over Integer Ring
-                sage: phi.matrix(QQ).parent()
+                sage: phi.matrix(QQ).parent()                                           # optional - sage.modules
                 Full MatrixSpace of 2 by 2 dense matrices over Rational Field
 
             The resulting matrix is immutable::
 
-                sage: phi.matrix().is_mutable()
+                sage: phi.matrix().is_mutable()                                         # optional - sage.modules
                 False
 
             The zero morphism has a zero matrix::
 
-                sage: Hom(X,Y).zero().matrix()
+                sage: Hom(X, Y).zero().matrix()                                         # optional - sage.modules
                 [0 0]
                 [0 0]
 
@@ -609,10 +614,11 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 Add support for morphisms where the codomain has a
                 different base ring than the domain::
 
-                    sage: Y = CombinatorialFreeModule(QQ, [3,4]); y = Y.basis()
-                    sage: phi = X.module_morphism(on_basis = {1: y[3] + 3*y[4], 2: 2*y[3] + 5/2*y[4]}.__getitem__,
-                    ....:                         codomain = Y)
-                    sage: phi.matrix().parent()          # todo: not implemented
+                    sage: Y = CombinatorialFreeModule(QQ, [3,4]); y = Y.basis()         # optional - sage.modules
+                    sage: phi = X.module_morphism(on_basis={1: y[3] + 3*y[4],           # optional - sage.modules
+                    ....:                                   2: 2*y[3] + 5/2*y[4]}.__getitem__,
+                    ....:                         codomain=Y)
+                    sage: phi.matrix().parent()          # todo: not implemented        # optional - sage.modules
                     Full MatrixSpace of 2 by 2 dense matrices over Rational Field
 
                 This currently does not work because, in this case,
@@ -620,20 +626,20 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 additive groups (i.e. the intersection of the
                 categories of modules over `\ZZ` and over `\QQ`)::
 
-                    sage: phi.parent().homset_category()
+                    sage: phi.parent().homset_category()                                # optional - sage.modules
                     Category of commutative additive semigroups
-                    sage: phi.parent().homset_category() # todo: not implemented
+                    sage: phi.parent().homset_category() # todo: not implemented        # optional - sage.modules
                     Category of finite dimensional modules with basis over Integer Ring
 
             TESTS:
 
             Check that :trac:`23216` is fixed::
 
-                sage: X = CombinatorialFreeModule(QQ, [])
-                sage: Y = CombinatorialFreeModule(QQ, [1,2,3])
-                sage: Hom(X,Y).zero().matrix()
+                sage: X = CombinatorialFreeModule(QQ, [])                               # optional - sage.modules
+                sage: Y = CombinatorialFreeModule(QQ, [1,2,3])                          # optional - sage.modules
+                sage: Hom(X, Y).zero().matrix()                                         # optional - sage.modules
                 []
-                sage: Hom(X,Y).zero().matrix().parent()
+                sage: Hom(X, Y).zero().matrix().parent()                                # optional - sage.modules
                 Full MatrixSpace of 3 by 0 dense matrices over Rational Field
             """
             if base_ring is None:
@@ -663,41 +669,41 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
             EXAMPLES::
 
                 sage: category = FiniteDimensionalModulesWithBasis(ZZ)
-                sage: X = CombinatorialFreeModule(ZZ, [1,2], category = category); X.rename("X"); x = X.basis()
-                sage: Y = CombinatorialFreeModule(ZZ, [3,4], category = category); Y.rename("Y"); y = Y.basis()
-                sage: phi = X.module_morphism(on_basis = {1: y[3] + 3*y[4], 2: 2*y[3] + 5*y[4]}.__getitem__,
-                ....:                         codomain = Y, category = category)
-                sage: psi = ~phi
-                sage: psi
+                sage: X = CombinatorialFreeModule(ZZ, [1,2], category=category); X.rename("X"); x = X.basis()           # optional - sage.modules
+                sage: Y = CombinatorialFreeModule(ZZ, [3,4], category=category); Y.rename("Y"); y = Y.basis()           # optional - sage.modules
+                sage: phi = X.module_morphism(on_basis={1: y[3] + 3*y[4], 2: 2*y[3] + 5*y[4]}.__getitem__,              # optional - sage.modules
+                ....:                         codomain=Y, category=category)
+                sage: psi = ~phi                                                                                        # optional - sage.modules
+                sage: psi                                                                                               # optional - sage.modules
                 Generic morphism:
                   From: Y
                   To:   X
-                sage: psi.parent()
+                sage: psi.parent()                                                                                      # optional - sage.modules
                 Set of Morphisms from Y to X in Category of finite dimensional modules with basis over Integer Ring
-                sage: psi(y[3])
+                sage: psi(y[3])                                                                                         # optional - sage.modules
                 -5*B[1] + 3*B[2]
-                sage: psi(y[4])
+                sage: psi(y[4])                                                                                         # optional - sage.modules
                 2*B[1] - B[2]
-                sage: psi.matrix()
+                sage: psi.matrix()                                                                                      # optional - sage.modules
                 [-5  2]
                 [ 3 -1]
-                sage: psi(phi(x[1])), psi(phi(x[2]))
+                sage: psi(phi(x[1])), psi(phi(x[2]))                                                                    # optional - sage.modules
                 (B[1], B[2])
-                sage: phi(psi(y[3])), phi(psi(y[4]))
+                sage: phi(psi(y[3])), phi(psi(y[4]))                                                                    # optional - sage.modules
                 (B[3], B[4])
 
             We check that this function complains if the morphism is not invertible::
 
-                sage: phi = X.module_morphism(on_basis = {1: y[3] + y[4], 2: y[3] + y[4]}.__getitem__,
-                ....:                         codomain = Y, category = category)
-                sage: ~phi
+                sage: phi = X.module_morphism(on_basis={1: y[3] + y[4], 2: y[3] + y[4]}.__getitem__,                    # optional - sage.modules
+                ....:                         codomain=Y, category=category)
+                sage: ~phi                                                                                              # optional - sage.modules
                 Traceback (most recent call last):
                 ...
                 RuntimeError: morphism is not invertible
 
-                sage: phi = X.module_morphism(on_basis = {1: y[3] + y[4], 2: y[3] + 5*y[4]}.__getitem__,
-                ....:                         codomain = Y, category = category)
-                sage: ~phi
+                sage: phi = X.module_morphism(on_basis={1: y[3] + y[4], 2: y[3] + 5*y[4]}.__getitem__,                  # optional - sage.modules
+                ....:                         codomain=Y, category=category)
+                sage: ~phi                                                                                              # optional - sage.modules
                 Traceback (most recent call last):
                 ...
                 RuntimeError: morphism is not invertible
@@ -717,9 +723,9 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: SGA = SymmetricGroupAlgebra(QQ, 3)
-                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)
-                sage: f.kernel_basis()
+                sage: SGA = SymmetricGroupAlgebra(QQ, 3)                                # optional - sage.groups sage.modules
+                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)        # optional - sage.groups sage.modules
+                sage: f.kernel_basis()                                                  # optional - sage.groups sage.modules
                 ([1, 2, 3] - [3, 2, 1], [1, 3, 2] - [3, 2, 1], [2, 1, 3] - [3, 2, 1])
             """
             return tuple(map( self.domain().from_vector,
@@ -731,12 +737,12 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: SGA = SymmetricGroupAlgebra(QQ, 3)
-                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)
-                sage: K = f.kernel()
-                sage: K
+                sage: SGA = SymmetricGroupAlgebra(QQ, 3)                                # optional - sage.groups sage.modules
+                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)        # optional - sage.groups sage.modules
+                sage: K = f.kernel()                                                    # optional - sage.groups sage.modules
+                sage: K                                                                 # optional - sage.groups sage.modules
                 Free module generated by {0, 1, 2} over Rational Field
-                sage: K.ambient()
+                sage: K.ambient()                                                       # optional - sage.groups sage.modules
                 Symmetric group algebra of order 3 over Rational Field
             """
             D = self.domain()
@@ -749,9 +755,9 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: SGA = SymmetricGroupAlgebra(QQ, 3)
-                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)
-                sage: f.image_basis()
+                sage: SGA = SymmetricGroupAlgebra(QQ, 3)                                # optional - sage.groups sage.modules
+                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)        # optional - sage.groups sage.modules
+                sage: f.image_basis()                                                   # optional - sage.groups sage.modules
                 ([1, 2, 3], [2, 3, 1], [3, 1, 2])
             """
             C = self.codomain()
@@ -763,9 +769,9 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: SGA = SymmetricGroupAlgebra(QQ, 3)
-                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)
-                sage: f.image()
+                sage: SGA = SymmetricGroupAlgebra(QQ, 3)                                # optional - sage.groups sage.modules
+                sage: f = SGA.module_morphism(lambda x: SGA(x**2), codomain=SGA)        # optional - sage.groups sage.modules
+                sage: f.image()                                                         # optional - sage.groups sage.modules
                 Free module generated by {0, 1, 2} over Rational Field
             """
             C = self.codomain()
@@ -781,10 +787,12 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
 
             EXAMPLES::
 
-                sage: ModulesWithBasis(ZZ).FiniteDimensional().TensorProducts().extra_super_categories()
+                sage: C = ModulesWithBasis(ZZ).FiniteDimensional().TensorProducts()
+                sage: C.extra_super_categories()
                 [Category of finite dimensional modules with basis over Integer Ring]
-                sage: ModulesWithBasis(ZZ).FiniteDimensional().TensorProducts().FiniteDimensional()
-                Category of tensor products of finite dimensional modules with basis over Integer Ring
+                sage: C.FiniteDimensional()
+                Category of tensor products of
+                 finite dimensional modules with basis over Integer Ring
 
             """
             return [self.base_category()]
