@@ -35,7 +35,9 @@ class FiniteMonoids(CategoryWithAxiom):
             r"""
             The nerve (classifying space) of this monoid.
 
-            OUTPUT: the nerve `BG` (if `G` denotes this monoid), as a
+            OUTPUT:
+
+            the nerve `BG` (if `G` denotes this monoid), as a
             simplicial set.  The `k`-dimensional simplices of this
             object are indexed by products of `k` elements in the
             monoid:
@@ -70,9 +72,9 @@ class FiniteMonoids(CategoryWithAxiom):
             The nerve (classifying space) of the cyclic group of order
             2 is infinite-dimensional real projective space. ::
 
-                sage: Sigma2 = groups.permutation.Cyclic(2)
-                sage: BSigma2 = Sigma2.nerve()
-                sage: BSigma2.cohomology(4, base_ring=GF(2))
+                sage: Sigma2 = groups.permutation.Cyclic(2)                             # optional - sage.groups
+                sage: BSigma2 = Sigma2.nerve()                                          # optional - sage.groups
+                sage: BSigma2.cohomology(4, base_ring=GF(2))                            # optional - sage.groups sage.modules sage.rings.finite_rings
                 Vector space of dimension 1 over Finite Field of size 2
 
             The `k`-simplices of the nerve are named after the chains
@@ -81,45 +83,45 @@ class FiniteMonoids(CategoryWithAxiom):
             element) and ``(1,2)`` in Sage. So the 1-cells and 2-cells
             in `B\Sigma_2` are::
 
-                sage: BSigma2.n_cells(1)
+                sage: BSigma2.n_cells(1)                                                # optional - sage.groups
                 [(1,2)]
-                sage: BSigma2.n_cells(2)
+                sage: BSigma2.n_cells(2)                                                # optional - sage.groups
                 [(1,2) * (1,2)]
 
             Another construction of the group, with different names
             for its elements::
 
-                sage: C2 = groups.misc.MultiplicativeAbelian([2])
-                sage: BC2 = C2.nerve()
-                sage: BC2.n_cells(0)
+                sage: C2 = groups.misc.MultiplicativeAbelian([2])                       # optional - sage.groups
+                sage: BC2 = C2.nerve()                                                  # optional - sage.groups
+                sage: BC2.n_cells(0)                                                    # optional - sage.groups
                 [1]
-                sage: BC2.n_cells(1)
+                sage: BC2.n_cells(1)                                                    # optional - sage.groups
                 [f]
-                sage: BC2.n_cells(2)
+                sage: BC2.n_cells(2)                                                    # optional - sage.groups
                 [f * f]
 
             With mod `p` coefficients, `B \Sigma_p` should have its
             first nonvanishing homology group in dimension `p`::
 
-                sage: Sigma3 = groups.permutation.Symmetric(3)
-                sage: BSigma3 = Sigma3.nerve()
-                sage: BSigma3.homology(range(4), base_ring=GF(3))
+                sage: Sigma3 = groups.permutation.Symmetric(3)                          # optional - sage.groups
+                sage: BSigma3 = Sigma3.nerve()                                          # optional - sage.groups
+                sage: BSigma3.homology(range(4), base_ring=GF(3))                       # optional - sage.groups sage.rings.finite_rings
                 {0: Vector space of dimension 0 over Finite Field of size 3,
-                1: Vector space of dimension 0 over Finite Field of size 3,
-                2: Vector space of dimension 0 over Finite Field of size 3,
-                3: Vector space of dimension 1 over Finite Field of size 3}
+                 1: Vector space of dimension 0 over Finite Field of size 3,
+                 2: Vector space of dimension 0 over Finite Field of size 3,
+                 3: Vector space of dimension 1 over Finite Field of size 3}
 
             Note that we can construct the `n`-skeleton for
             `B\Sigma_2` for relatively large values of `n`, while for
             `B\Sigma_3`, the complexes get large pretty quickly::
 
-                sage: Sigma2.nerve().n_skeleton(14)
+                sage: Sigma2.nerve().n_skeleton(14)                                     # optional - sage.groups
                 Simplicial set with 15 non-degenerate simplices
 
-                sage: BSigma3 = Sigma3.nerve()
-                sage: BSigma3.n_skeleton(3)
+                sage: BSigma3 = Sigma3.nerve()                                          # optional - sage.groups
+                sage: BSigma3.n_skeleton(3)                                             # optional - sage.groups
                 Simplicial set with 156 non-degenerate simplices
-                sage: BSigma3.n_skeleton(4)
+                sage: BSigma3.n_skeleton(4)                                             # optional - sage.groups
                 Simplicial set with 781 non-degenerate simplices
 
             Finally, note that the classifying space of the order `p`
@@ -127,35 +129,33 @@ class FiniteMonoids(CategoryWithAxiom):
             on `p` letters, and its first homology group appears
             earlier::
 
-                sage: C3 = groups.misc.MultiplicativeAbelian([3])
-                sage: list(C3)
+                sage: C3 = groups.misc.MultiplicativeAbelian([3])                       # optional - sage.groups
+                sage: list(C3)                                                          # optional - sage.groups
                 [1, f, f^2]
-                sage: BC3 = C3.nerve()
-                sage: BC3.n_cells(1)
+                sage: BC3 = C3.nerve()                                                  # optional - sage.groups
+                sage: BC3.n_cells(1)                                                    # optional - sage.groups
                 [f, f^2]
-                sage: BC3.n_cells(2)
+                sage: BC3.n_cells(2)                                                    # optional - sage.groups
                 [f * f, f * f^2, f^2 * f, f^2 * f^2]
-                sage: len(BSigma3.n_cells(2))
+                sage: len(BSigma3.n_cells(2))                                           # optional - sage.groups
                 25
-                sage: len(BC3.n_cells(3))
+                sage: len(BC3.n_cells(3))                                               # optional - sage.groups
                 8
-                sage: len(BSigma3.n_cells(3))
+                sage: len(BSigma3.n_cells(3))                                           # optional - sage.groups
                 125
 
-                sage: BC3.homology(range(5), base_ring=GF(3))
+                sage: BC3.homology(range(4), base_ring=GF(3))                           # optional - sage.groups sage.rings.finite_rings
                 {0: Vector space of dimension 0 over Finite Field of size 3,
                  1: Vector space of dimension 1 over Finite Field of size 3,
                  2: Vector space of dimension 1 over Finite Field of size 3,
-                 3: Vector space of dimension 1 over Finite Field of size 3,
-                 4: Vector space of dimension 1 over Finite Field of size 3}
+                 3: Vector space of dimension 1 over Finite Field of size 3}
 
-                sage: BC5 = groups.permutation.Cyclic(5).nerve()
-                sage: BC5.homology(range(5), base_ring=GF(5))
+                sage: BC5 = groups.permutation.Cyclic(5).nerve()                        # optional - sage.groups
+                sage: BC5.homology(range(4), base_ring=GF(5))                           # optional - sage.groups sage.rings.finite_rings
                 {0: Vector space of dimension 0 over Finite Field of size 5,
-                1: Vector space of dimension 1 over Finite Field of size 5,
-                2: Vector space of dimension 1 over Finite Field of size 5,
-                3: Vector space of dimension 1 over Finite Field of size 5,
-                4: Vector space of dimension 1 over Finite Field of size 5}
+                 1: Vector space of dimension 1 over Finite Field of size 5,
+                 2: Vector space of dimension 1 over Finite Field of size 5,
+                 3: Vector space of dimension 1 over Finite Field of size 5}
             """
             from sage.topology.simplicial_set_examples import Nerve
             return Nerve(self)
@@ -179,20 +179,20 @@ class FiniteMonoids(CategoryWithAxiom):
             EXAMPLES::
 
                 sage: M = Monoids().Finite().example()
-                sage: M.rhodes_radical_congruence()
+                sage: M.rhodes_radical_congruence()                                     # optional - sage.groups sage.modules
                 [(0, 6), (2, 8), (4, 10)]
-                sage: from sage.monoids.hecke_monoid import HeckeMonoid
-                sage: H3 = HeckeMonoid(SymmetricGroup(3))
-                sage: H3.repr_element_method(style="reduced")
-                sage: H3.rhodes_radical_congruence()
+                sage: from sage.monoids.hecke_monoid import HeckeMonoid                 # optional - sage.groups sage.modules
+                sage: H3 = HeckeMonoid(SymmetricGroup(3))                               # optional - sage.groups sage.modules
+                sage: H3.repr_element_method(style="reduced")                           # optional - sage.groups sage.modules
+                sage: H3.rhodes_radical_congruence()                                    # optional - sage.groups sage.modules
                 [([1, 2], [2, 1]), ([1, 2], [1, 2, 1]), ([2, 1], [1, 2, 1])]
 
             By Maschke's theorem, every group algebra over `\QQ`
             is semisimple hence the Rhodes radical of a group must be trivial::
 
-                sage: SymmetricGroup(3).rhodes_radical_congruence()
+                sage: SymmetricGroup(3).rhodes_radical_congruence()                     # optional - sage.groups sage.modules
                 []
-                sage: DihedralGroup(10).rhodes_radical_congruence()
+                sage: DihedralGroup(10).rhodes_radical_congruence()                     # optional - sage.groups sage.modules
                 []
 
             REFERENCES:
@@ -207,7 +207,7 @@ class FiniteMonoids(CategoryWithAxiom):
             res = []
             for m in self:
                 for n in self:
-                    if (m == n) or ((n, m) in res):
+                    if m == n or (n, m) in res:
                         continue
                     try:
                         kSrad.retract(kS(m) - kS(n))
@@ -220,7 +220,7 @@ class FiniteMonoids(CategoryWithAxiom):
     class ElementMethods:
         def pseudo_order(self):
             r"""
-            Returns the pair `[k, j]` with `k` minimal and `0\leq j <k` such
+            Return the pair `[k, j]` with `k` minimal and `0\leq j <k` such
             that ``self^k == self^j``.
 
             Note that `j` is uniquely determined.
@@ -254,8 +254,10 @@ class FiniteMonoids(CategoryWithAxiom):
                 sage: x.pseudo_order()
                 [2, 0]
 
-            TODO: more appropriate name? see, for example, Jean-Eric Pin's
-            lecture notes on semigroups.
+            .. TODO::
+
+                more appropriate name? see, for example, Jean-Eric Pin's
+                lecture notes on semigroups.
             """
             self_powers = {self.parent().one(): 0}
             k = 1
