@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.modules sage.rings.finite_rings
 r"""
 Guruswami-Sudan decoder for (Generalized) Reed-Solomon codes
 
@@ -36,9 +37,9 @@ from sage.misc.functional import sqrt
 
 def n_k_params(C, n_k):
     r"""
-    Internal helper function for the GRSGuruswamiSudanDecoder class for allowing to
-    specify either a GRS code `C` or the length and dimensions `n, k` directly,
-    in all the static functions.
+    Internal helper function for the :class:`GRSGuruswamiSudanDecoder` class for
+    allowing to specify either a GRS code `C` or the length and dimensions `n,
+    k` directly, in all the static functions.
 
     If neither `C` or `n,k` were specified to those functions, an appropriate
     error should be raised. Otherwise, `n, k` of the code or the supplied tuple
@@ -46,9 +47,10 @@ def n_k_params(C, n_k):
 
     INPUT:
 
-    - ``C`` -- A GRS code or `None`
+    - ``C`` -- A GRS code or ``None``
 
-    - ``n_k`` -- A tuple `(n,k)` being length and dimension of a GRS code, or `None`.
+    - ``n_k`` -- A tuple `(n,k)` being length and dimension of a GRS code, or
+      ``None``.
 
     OUTPUT:
 
@@ -60,13 +62,13 @@ def n_k_params(C, n_k):
         sage: n_k_params(None, (10, 5))
         (10, 5)
         sage: C = codes.GeneralizedReedSolomonCode(GF(11).list()[:10], 5)
-        sage: n_k_params(C,None)
+        sage: n_k_params(C, None)
         (10, 5)
         sage: n_k_params(None,None)
         Traceback (most recent call last):
         ...
         ValueError: Please provide either the code or its length and dimension
-        sage: n_k_params(C,(12, 2))
+        sage: n_k_params(C, (12, 2))
         Traceback (most recent call last):
         ...
         ValueError: Please provide only the code or its length and dimension
@@ -85,7 +87,7 @@ def n_k_params(C, n_k):
 def roth_ruckenstein_root_finder(p, maxd=None, precision=None):
     """
     Wrapper for Roth-Ruckenstein algorithm to compute the roots of a polynomial
-    with coefficients in ``F[x]``.
+    with coefficients in `F[x]`.
 
     TESTS::
 
@@ -104,7 +106,7 @@ def roth_ruckenstein_root_finder(p, maxd=None, precision=None):
 def alekhnovich_root_finder(p, maxd=None, precision=None):
     """
     Wrapper for Alekhnovich's algorithm to compute the roots of a polynomial
-    with coefficients in ``F[x]``.
+    with coefficients in `F[x]`.
 
     TESTS::
 
@@ -155,16 +157,18 @@ class GRSGuruswamiSudanDecoder(Decoder):
       Guruswami-Sudan algorithm to correct.
 
     - ``parameters`` -- (default: ``None``) a pair of integers, where:
-        - the first integer is the multiplicity parameter, and
-        - the second integer is the list size parameter.
+
+      - the first integer is the multiplicity parameter, and
+      - the second integer is the list size parameter.
 
     - ``interpolation_alg`` -- (default: ``None``) the interpolation algorithm
       that will be used. The following possibilities are currently available:
 
-        * ``"LinearAlgebra"`` -- uses a linear system solver.
-        * ``"LeeOSullivan"`` -- uses Lee O'Sullivan method based on row reduction of a matrix
-        * ``None`` -- one of the above will be chosen based on the size of the
-          code and the parameters.
+      * ``"LinearAlgebra"`` -- uses a linear system solver.
+      * ``"LeeOSullivan"`` -- uses Lee O'Sullivan method based on row reduction
+        of a matrix
+      * ``None`` -- one of the above will be chosen based on the size of the
+        code and the parameters.
 
       You can also supply your own function to perform the interpolation. See
       NOTE section for details on the signature of this function.
@@ -172,12 +176,12 @@ class GRSGuruswamiSudanDecoder(Decoder):
     - ``root_finder`` -- (default: ``None``) the rootfinding algorithm that will
       be used. The following possibilities are currently available:
 
-        * ``"Alekhnovich"`` -- uses Alekhnovich's algorithm.
+      * ``"Alekhnovich"`` -- uses Alekhnovich's algorithm.
 
-        * ``"RothRuckenstein"`` -- uses Roth-Ruckenstein algorithm.
+      * ``"RothRuckenstein"`` -- uses Roth-Ruckenstein algorithm.
 
-        * ``None`` -- one of the above will be chosen based on the size of the
-          code and the parameters.
+      * ``None`` -- one of the above will be chosen based on the size of the
+        code and the parameters.
 
       You can also supply your own function to perform the interpolation. See
       NOTE section for details on the signature of this function.
@@ -201,46 +205,48 @@ class GRSGuruswamiSudanDecoder(Decoder):
     EXAMPLES::
 
         sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 97)
-        sage: D
-        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
+        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau=97); D
+        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
+         decoding 97 errors with parameters (1, 2)
 
     One can specify multiplicity and list size instead of ``tau``::
 
-        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters = (1,2))
-        sage: D
-        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
+        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters=(1,2)); D
+        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
+         decoding 97 errors with parameters (1, 2)
 
     One can pass a method as ``root_finder`` (works also for ``interpolation_alg``)::
 
         sage: from sage.coding.guruswami_sudan.gs_decoder import roth_ruckenstein_root_finder
         sage: rf = roth_ruckenstein_root_finder
-        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters = (1,2), root_finder = rf)
-        sage: D
-        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
+        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters=(1,2),
+        ....:                                             root_finder=rf);  D
+        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
+         decoding 97 errors with parameters (1, 2)
 
     If one wants to use the native Sage algorithms for the root finding step,
     one can directly pass the string given in the ``Input`` block of this class.
     This works for ``interpolation_alg`` as well::
 
 
-        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters = (1,2), root_finder="RothRuckenstein")
-        sage: D
-        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
+        sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, parameters=(1,2),
+        ....:                                             root_finder="RothRuckenstein"); D
+        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
+         decoding 97 errors with parameters (1, 2)
 
     Actually, we can construct the decoder from ``C`` directly::
 
-        sage: D = C.decoder("GuruswamiSudan", tau = 97)
-        sage: D
-        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
+        sage: D = C.decoder("GuruswamiSudan", tau=97); D
+        Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251)
+         decoding 97 errors with parameters (1, 2)
     """
 
     ####################### static methods ###############################
 
     @staticmethod
-    def parameters_given_tau(tau, C = None, n_k = None):
+    def parameters_given_tau(tau, C=None, n_k=None):
         r"""
-        Returns the smallest possible multiplicity and list size given the
+        Return the smallest possible multiplicity and list size given the
         given parameters of the code and decoding radius.
 
         INPUT:
@@ -254,8 +260,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         OUTPUT:
 
         - ``(s, l)`` -- a pair of integers, where:
-            - ``s`` is the multiplicity parameter, and
-            - ``l`` is the list size parameter.
+
+          - ``s`` is the multiplicity parameter, and
+          - ``l`` is the list size parameter.
 
         .. NOTE::
 
@@ -264,23 +271,25 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         EXAMPLES::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: tau, n, k = 97, 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD.parameters_given_tau(tau, n_k=(n, k))
             (1, 2)
 
         Another example with a bigger decoding radius::
 
             sage: tau, n, k = 118, 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD.parameters_given_tau(tau, n_k=(n, k))
             (47, 89)
 
         Choosing a decoding radius which is too large results in an errors::
 
             sage: tau = 200
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD.parameters_given_tau(tau, n_k=(n, k))
             Traceback (most recent call last):
             ...
-            ValueError: The decoding radius must be less than the Johnson radius (which is 118.66)
+            ValueError: The decoding radius must be less than
+            the Johnson radius (which is 118.66)
         """
         n,k = n_k_params(C, n_k)
 
@@ -307,9 +316,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         return (s, l)
 
     @staticmethod
-    def guruswami_sudan_decoding_radius(C = None, n_k = None, l = None, s = None):
+    def guruswami_sudan_decoding_radius(C=None, n_k=None, l=None, s=None):
         r"""
-        Returns the maximal decoding radius of the Guruswami-Sudan decoder and
+        Return the maximal decoding radius of the Guruswami-Sudan decoder and
         the parameter choices needed for this.
 
         If ``s`` is set but ``l`` is not it will return the best decoding radius using this ``s``
@@ -332,27 +341,30 @@ class GRSGuruswamiSudanDecoder(Decoder):
         OUTPUT:
 
         - ``(tau, (s, l))`` -- where
-            - ``tau`` is the obtained decoding radius, and
-            - ``s, ell`` are the multiplicity parameter, respectively list size
-              parameter giving this radius.
+
+          - ``tau`` is the obtained decoding radius, and
+
+          - ``s, ell`` are the multiplicity parameter, respectively list size
+            parameter giving this radius.
 
         EXAMPLES::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: n, k = 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(n_k = (n, k))
+            sage: GSD.guruswami_sudan_decoding_radius(n_k=(n, k))
             (118, (47, 89))
 
         One parameter can be restricted at a time::
 
             sage: n, k = 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(n_k = (n, k), s=3)
+            sage: GSD.guruswami_sudan_decoding_radius(n_k=(n, k), s=3)
             (109, (3, 5))
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(n_k = (n, k), l=7)
+            sage: GSD.guruswami_sudan_decoding_radius(n_k=(n, k), l=7)
             (111, (4, 7))
 
         The function can also just compute the decoding radius given the parameters::
 
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(n_k = (n, k), s=2, l=6)
+            sage: GSD.guruswami_sudan_decoding_radius(n_k=(n, k), s=2, l=6)
             (92, (2, 6))
         """
         n,k = n_k_params(C, n_k)
@@ -364,7 +376,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
             return gilt(n - n/2*(s+1)/(l+1) - (k-1)/2*l/s)
         if l is None and s is None:
             tau = gilt(johnson_radius(n, n - k + 1))
-            return (tau, GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k)))
+            return (tau, GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k=(n, k)))
         if l is not None and s is not None:
             return (get_tau(s,l), (s,l))
 
@@ -401,7 +413,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
             return (tau, (s,l))
 
     @staticmethod
-    def _suitable_parameters_given_tau(tau, C = None, n_k = None):
+    def _suitable_parameters_given_tau(tau, C=None, n_k=None):
         r"""
         Return quite good multiplicity and list size parameters for the code
         parameters and the decoding radius.
@@ -423,8 +435,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         OUTPUT:
 
         - ``(s, l)`` -- a pair of integers, where:
-            - ``s`` is the multiplicity parameter, and
-            - ``l`` is the list size parameter.
+
+          - ``s`` is the multiplicity parameter, and
+          - ``l`` is the list size parameter.
 
         .. NOTE::
 
@@ -436,31 +449,32 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         The following is an example where the parameters are optimal::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: tau = 98
             sage: n, k = 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder._suitable_parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD._suitable_parameters_given_tau(tau, n_k=(n, k))
             (2, 3)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD.parameters_given_tau(tau, n_k=(n, k))
             (2, 3)
 
         This is an example where they are not::
 
             sage: tau = 97
             sage: n, k = 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder._suitable_parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD._suitable_parameters_given_tau(tau, n_k=(n, k))
             (2, 3)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            sage: GSD.parameters_given_tau(tau, n_k=(n, k))
             (1, 2)
 
         We can provide a GRS code instead of `n` and `k` directly::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder._suitable_parameters_given_tau(tau, C = C)
+            sage: GSD._suitable_parameters_given_tau(tau, C=C)
             (2, 3)
 
         Another one with a bigger ``tau``::
 
-            sage: codes.decoders.GRSGuruswamiSudanDecoder._suitable_parameters_given_tau(118, C = C)
+            sage: GSD._suitable_parameters_given_tau(118, C=C)
             (47, 89)
         """
         n,k = n_k_params(C, n_k)
@@ -473,9 +487,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
         return (s, l)
 
     @staticmethod
-    def gs_satisfactory(tau, s, l, C = None, n_k = None):
+    def gs_satisfactory(tau, s, l, C=None, n_k=None):
         r"""
-        Returns whether input parameters satisfy the governing equation of
+        Return whether input parameters satisfy the governing equation of
         Guruswami-Sudan.
 
         See [Nie2013]_ page 49, definition 3.3 and proposition 3.4 for details.
@@ -497,21 +511,22 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         EXAMPLES::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: tau, s, l = 97, 1, 2
             sage: n, k = 250, 70
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.gs_satisfactory(tau, s, l, n_k = (n, k))
+            sage: GSD.gs_satisfactory(tau, s, l, n_k=(n, k))
             True
 
         One can also pass a GRS code::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.gs_satisfactory(tau, s, l, C = C)
+            sage: GSD.gs_satisfactory(tau, s, l, C=C)
             True
 
         Another example where ``s`` and ``l`` does not satisfy the equation::
 
             sage: tau, s, l = 118, 47, 80
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.gs_satisfactory(tau, s, l, n_k = (n, k))
+            sage: GSD.gs_satisfactory(tau, s, l, n_k=(n, k))
             False
 
         If one provides both ``C`` and ``n_k`` an exception is returned::
@@ -519,14 +534,14 @@ class GRSGuruswamiSudanDecoder(Decoder):
             sage: tau, s, l = 97, 1, 2
             sage: n, k = 250, 70
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.gs_satisfactory(tau, s, l, C = C, n_k = (n, k))
+            sage: GSD.gs_satisfactory(tau, s, l, C=C, n_k=(n, k))
             Traceback (most recent call last):
             ...
             ValueError: Please provide only the code or its length and dimension
 
         Same if one provides none of these::
 
-            sage: codes.decoders.GRSGuruswamiSudanDecoder.gs_satisfactory(tau, s, l)
+            sage: GSD.gs_satisfactory(tau, s, l)
             Traceback (most recent call last):
             ...
             ValueError: Please provide either the code or its length and dimension
@@ -534,17 +549,16 @@ class GRSGuruswamiSudanDecoder(Decoder):
         n,k = n_k_params(C, n_k)
         return l > 0 and s > 0 and n * s * (s+1) < (l+1) * (2*s*(n-tau) - (k-1) * l)
 
-
-
     ####################### decoder itself ###############################
-    def __init__(self, code, tau = None, parameters = None, interpolation_alg = None, root_finder = None):
+    def __init__(self, code, tau=None, parameters=None, interpolation_alg=None, root_finder=None):
         r"""
         TESTS:
 
         If neither ``tau`` nor ``parameters`` is given, an exception is returned::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C)
+            sage: D = GSD(C)
             Traceback (most recent call last):
             ...
             ValueError: Specify either tau or parameters
@@ -553,7 +567,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         an exception is returned::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 97, interpolation_alg = 42)
+            sage: D = GSD(C, tau=97, interpolation_alg=42)
             Traceback (most recent call last):
             ...
             ValueError: Please provide a method or one of the allowed strings for interpolation_alg
@@ -561,7 +575,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         Same thing for ``root_finder``::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 97, root_finder = "FortyTwo")
+            sage: D = GSD(C, tau=97, root_finder="FortyTwo")
             Traceback (most recent call last):
             ...
             ValueError: Please provide a method or one of the allowed strings for root_finder
@@ -570,7 +584,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         error message is returned::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 142, parameters=(1, 2))
+            sage: D = GSD(C, tau=142, parameters=(1, 2))
             Traceback (most recent call last):
             ...
             ValueError: Impossible parameters for the Guruswami-Sudan algorithm
@@ -578,7 +592,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         If ``code`` is not a GRS code, an error is raised::
 
             sage: C  = codes.random_linear_code(GF(11), 10, 4)
-            sage: codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 2)
+            sage: GSD(C, tau=2)
             Traceback (most recent call last):
             ...
             ValueError: code has to be a generalized Reed-Solomon code
@@ -587,16 +601,16 @@ class GRSGuruswamiSudanDecoder(Decoder):
             raise ValueError("code has to be a generalized Reed-Solomon code")
         n, k = code.length(), code.dimension()
         if tau and parameters:
-            if not GRSGuruswamiSudanDecoder.gs_satisfactory(tau, parameters[0], parameters[1], C = code):
+            if not GRSGuruswamiSudanDecoder.gs_satisfactory(tau, parameters[0], parameters[1], C=code):
                 raise ValueError("Impossible parameters for the Guruswami-Sudan algorithm")
             self._tau, self._s, self._ell = tau, parameters[0], parameters[1]
         elif tau:
             self._tau = tau
-            self._s, self._ell = GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k = (n, k))
+            self._s, self._ell = GRSGuruswamiSudanDecoder.parameters_given_tau(tau, n_k=(n, k))
         elif parameters:
             self._s = parameters[0]
             self._ell = parameters[1]
-            (self._tau,_) = GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(C = code, s=self._s, l=self._ell)
+            (self._tau,_) = GRSGuruswamiSudanDecoder.guruswami_sudan_decoding_radius(C=code, s=self._s, l=self._ell)
         else:
             raise ValueError("Specify either tau or parameters")
         if callable(interpolation_alg):
@@ -619,12 +633,12 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def _repr_(self):
         r"""
-        Returns a string representation of ``self``.
+        Return a string representation of ``self``.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D
             Guruswami-Sudan decoder for [250, 70, 181] Reed-Solomon Code over GF(251) decoding 97 errors with parameters (1, 2)
         """
@@ -632,12 +646,12 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def _latex_(self):
         r"""
-        Returns a string representation of ``self``.
+        Return a string representation of ``self``.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: latex(D)
             \textnormal{Guruswami-Sudan decoder for } [250, 70, 181] \textnormal{ Reed-Solomon Code over } \Bold{F}_{251}\textnormal{ decoding }97\textnormal{ errors with parameters }(1, 2)
         """
@@ -650,8 +664,8 @@ class GRSGuruswamiSudanDecoder(Decoder):
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D1 = C.decoder("GuruswamiSudan", tau = 97)
-            sage: D2 = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D1 = C.decoder("GuruswamiSudan", tau=97)
+            sage: D2 = C.decoder("GuruswamiSudan", tau=97)
             sage: D1.__eq__(D2)
             True
         """
@@ -665,7 +679,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def interpolation_algorithm(self):
         r"""
-        Returns the interpolation algorithm that will be used.
+        Return the interpolation algorithm that will be used.
 
         Remember that its signature has to be:
         ``my_inter(interpolation_points, tau, s_and_l, wy)``.
@@ -675,7 +689,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.interpolation_algorithm()
             <function gs_interpolation_lee_osullivan at 0x...>
         """
@@ -683,7 +697,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def rootfinding_algorithm(self):
         r"""
-        Returns the rootfinding algorithm that will be used.
+        Return the rootfinding algorithm that will be used.
 
         Remember that its signature has to be:
         ``my_rootfinder(Q, maxd=default_value, precision=default_value)``.
@@ -693,7 +707,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.rootfinding_algorithm()
             <function alekhnovich_root_finder at 0x...>
         """
@@ -701,26 +715,25 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def parameters(self):
         r"""
-        Returns the multiplicity and list size parameters of ``self``.
+        Return the multiplicity and list size parameters of ``self``.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.parameters()
             (1, 2)
         """
         return (self._s, self._ell)
 
-
     def multiplicity(self):
         r"""
-        Returns the multiplicity parameter of ``self``.
+        Return the multiplicity parameter of ``self``.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.multiplicity()
             1
         """
@@ -728,12 +741,12 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def list_size(self):
         r"""
-        Returns the list size parameter of ``self``.
+        Return the list size parameter of ``self``.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.list_size()
             2
         """
@@ -741,7 +754,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def decode_to_message(self, r):
         r"""
-        Decodes ``r`` to the list of polynomials whose encoding by
+        Decode ``r`` to the list of polynomials whose encoding by
         :meth:`self.code()` is within Hamming distance
         :meth:`self.decoding_radius` of ``r``.
 
@@ -752,8 +765,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         EXAMPLES::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: C = codes.GeneralizedReedSolomonCode(GF(17).list()[:15], 6)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau=5)
+            sage: D = GSD(C, tau=5)
             sage: F.<x> = GF(17)[]
             sage: m = 13*x^4 + 7*x^3 + 10*x^2 + 14*x + 3
             sage: c = D.connected_encoder().encode(m)
@@ -772,7 +786,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         does not fit the allowed signature, an exception will be raised::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(17).list()[:15], 6)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau=5, root_finder=next_prime)
+            sage: D = GSD(C, tau=5, root_finder=next_prime)
             sage: F.<x> = GF(17)[]
             sage: m = 9*x^5 + 10*x^4 + 9*x^3 + 7*x^2 + 15*x + 2
             sage: c = D.connected_encoder().encode(m)
@@ -780,7 +794,8 @@ class GRSGuruswamiSudanDecoder(Decoder):
             sage: m in D.decode_to_message(r)
             Traceback (most recent call last):
             ...
-            ValueError: The provided root-finding algorithm has a wrong signature. See the documentation of `codes.decoders.GRSGuruswamiSudanDecoder.rootfinding_algorithm()` for details
+            ValueError: The provided root-finding algorithm has a wrong signature.
+            See the documentation of `...rootfinding_algorithm()` for details
         """
         return [self.connected_encoder().unencode(c) for c in self.decode_to_code(r)]
 
@@ -795,8 +810,9 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
         EXAMPLES::
 
+            sage: GSD = codes.decoders.GRSGuruswamiSudanDecoder
             sage: C = codes.GeneralizedReedSolomonCode(GF(17).list()[:15], 6)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau=5)
+            sage: D = GSD(C, tau=5)
             sage: c = vector(GF(17), [3,13,12,0,0,7,5,1,8,11,1,9,4,12,14])
             sage: c in C
             True
@@ -814,7 +830,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         Check that :trac:`21347` is fixed::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(13).list()[:10], 3)
-            sage: D = codes.decoders.GRSGuruswamiSudanDecoder(C, tau = 4)
+            sage: D = GSD(C, tau=4)
             sage: c = vector(GF(13), [6, 8, 2, 1, 5, 1, 2, 8, 6, 9])
             sage: e = vector(GF(13), [1, 0, 0, 1, 1, 0, 0, 1, 0, 1])
             sage: D.decode_to_code(c+e)
@@ -837,7 +853,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
             raise ValueError("The provided interpolation algorithm has a wrong signature. See the documentation of `codes.decoders.GRSGuruswamiSudanDecoder.interpolation_algorithm()` for details")
         ## EXAMINE THE FACTORS AND CONVERT TO CODEWORDS
         try:
-            polynomials = self.rootfinding_algorithm()(Q, maxd = wy)
+            polynomials = self.rootfinding_algorithm()(Q, maxd=wy)
         except TypeError:
             raise ValueError("The provided root-finding algorithm has a wrong signature. See the documentation of `codes.decoders.GRSGuruswamiSudanDecoder.rootfinding_algorithm()` for details")
         if not polynomials:
@@ -850,19 +866,19 @@ class GRSGuruswamiSudanDecoder(Decoder):
 
     def decoding_radius(self):
         r"""
-        Returns the maximal number of errors that ``self`` is able to correct.
+        Return the maximal number of errors that ``self`` is able to correct.
 
         EXAMPLES::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", tau = 97)
+            sage: D = C.decoder("GuruswamiSudan", tau=97)
             sage: D.decoding_radius()
             97
 
         An example where tau is not one of the inputs to the constructor::
 
             sage: C = codes.GeneralizedReedSolomonCode(GF(251).list()[:250], 70)
-            sage: D = C.decoder("GuruswamiSudan", parameters = (2,4))
+            sage: D = C.decoder("GuruswamiSudan", parameters=(2,4))
             sage: D.decoding_radius()
             105
         """
