@@ -102,15 +102,15 @@ class Huffman(SageObject):
 
     - ``source`` -- can be either
 
-        - A string from which the Huffman encoding should be created.
+      - A string from which the Huffman encoding should be created.
 
-        - A dictionary that associates to each symbol of an alphabet a numeric
-          value. If we consider the frequency of each alphabetic symbol, then
-          ``source`` is considered as the frequency table of the alphabet with
-          each numeric (non-negative integer) value being the number of
-          occurrences of a symbol. The numeric values can also represent weights
-          of the symbols. In that case, the numeric values are not necessarily
-          integers, but can be real numbers.
+      - A dictionary that associates to each symbol of an alphabet a numeric
+        value. If we consider the frequency of each alphabetic symbol, then
+        ``source`` is considered as the frequency table of the alphabet with
+        each numeric (non-negative integer) value being the number of
+        occurrences of a symbol. The numeric values can also represent weights
+        of the symbols. In that case, the numeric values are not necessarily
+        integers, but can be real numbers.
 
     In order to construct a Huffman code for an alphabet, we use exactly one of
     the following methods:
@@ -235,7 +235,7 @@ class Huffman(SageObject):
 
         Feeding anything else than a string or a dictionary::
 
-            sage: Huffman(Graph())
+            sage: Huffman(Graph())                                                      # optional - sage.graphs
             Traceback (most recent call last):
             ...
             ValueError: Input must be either a string or a dictionary.
@@ -510,9 +510,9 @@ class Huffman(SageObject):
             sage: from sage.coding.source_coding.huffman import Huffman
             sage: str = "Sage is my most favorite general purpose computer algebra system"
             sage: h = Huffman(str)
-            sage: T = h.tree(); T
+            sage: T = h.tree(); T                                                       # optional - sage.graphs
             Digraph on 39 vertices
-            sage: T.show(figsize=[20,20])
+            sage: T.show(figsize=[20,20])                                               # optional - sage.graphs sage.plot
             <BLANKLINE>
         """
         from sage.graphs.digraph import DiGraph
@@ -543,8 +543,8 @@ class Huffman(SageObject):
 
             sage: from sage.coding.source_coding.huffman import Huffman
             sage: H = Huffman("Sage")
-            sage: T = H.tree()
-            sage: T.edges(sort=True, labels=None)  # indirect doctest
+            sage: T = H.tree()                                                          # optional - sage.graphs
+            sage: T.edges(sort=True, labels=None)  # indirect doctest                   # optional - sage.graphs
             [('0', 'S: 00'), ('0', 'a: 01'), ('1', 'e: 10'), ('1', 'g: 11'), ('root', '0'), ('root', '1')]
         """
         if parent == "":
