@@ -10,6 +10,7 @@ Affine Permutations
 #  the License, or (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
+from itertools import repeat
 from sage.misc.cachefunc import cached_method
 from sage.misc.misc_c import prod
 from sage.misc.constant_function import ConstantFunction
@@ -22,7 +23,7 @@ from sage.structure.parent import Parent
 from sage.rings.integer_ring import ZZ
 
 from sage.groups.perm_gps.permgroup_named import SymmetricGroup
-from sage.arith.all import binomial
+from sage.arith.misc import binomial
 from sage.combinat.root_system.cartan_type import CartanType
 from sage.combinat.root_system.weyl_group import WeylGroup
 from sage.combinat.composition import Composition
@@ -41,6 +42,7 @@ class AffinePermutation(ClonableArray):
         sage: p
         Type A affine permutation with window [3, -1, 0, 6, 5, 4, 10, 9]
     """
+
     def __init__(self, parent, lst, check=True):
         r"""
         Initialize ``self``
@@ -160,21 +162,19 @@ class AffinePermutation(ClonableArray):
         return self.__rmul__(q)
 
     @cached_method
-    def inverse(self):
+    def __invert__(self):
         r"""
         Return the inverse affine permutation.
 
         EXAMPLES::
 
             sage: p = AffinePermutationGroup(['A',7,1])([3, -1, 0, 6, 5, 4, 10, 9])
-            sage: p.inverse()
+            sage: p.inverse()  # indirect doctest
             Type A affine permutation with window [0, -1, 1, 6, 5, 4, 10, 11]
         """
-        inv = [self.position(i) for i in range(1,len(self)+1)]
+        inv = [self.position(i) for i in range(1, len(self) + 1)]
         return type(self)(self.parent(), inv, check=False)
 
-    __invert__=inverse
-
     def apply_simple_reflection(self, i, side='right'):
         r"""
         Apply a simple reflection.
@@ -217,7 +217,7 @@ class AffinePermutation(ClonableArray):
         """
         return self.value(i)
 
-    def is_i_grassmannian(self, i=0, side="right"):
+    def is_i_grassmannian(self, i=0, side="right") -> bool:
         r"""
         Test whether ``self`` is `i`-grassmannian, i.e., either is the
         identity or has ``i`` as the sole descent.
@@ -277,7 +277,7 @@ class AffinePermutation(ClonableArray):
         S = self.descents(side)
         return [self.apply_simple_reflection(i, side) for i in S]
 
-    def is_one(self):
+    def is_one(self) -> bool:
         r"""
         Tests whether the affine permutation is the identity.
 
@@ -408,7 +408,6 @@ class AffinePermutation(ClonableArray):
             return (fin, gr)
 
 
-
 class AffinePermutationTypeA(AffinePermutation):
     #----------------------
     #Type-specific methods.
@@ -449,7 +448,6 @@ class AffinePermutationTypeA(AffinePermutation):
         if l != list(range(k+1)):
             raise ValueError("entries must have distinct residues")
 
-
     def value(self, i, base_window=False):
         r"""
         Return the image of the integer ``i`` under this permutation.
@@ -731,7 +729,6 @@ class AffinePermutationTypeA(AffinePermutation):
             best_T.reverse()
         return best_T
 
-
     def maximal_cyclic_decomposition(self, typ='decreasing', side='right', verbose=False):
         r"""
         Find the unique maximal decomposition of ``self`` into cyclically
@@ -854,8 +851,8 @@ class AffinePermutationTypeA(AffinePermutation):
                 a=self(i)
                 for j in range(i-self.k, i):
                     b=self(j)
-                    #A small rotation is necessary for the reduced word from
-                    #the lehmer code to match the element.
+                    # A small rotation is necessary for the reduced word from
+                    # the Lehmer code to match the element.
                     if a < b:
                         code[i-1]+=((b-a)//(self.k+1)+1)
         elif typ[0] == 'i' and side[0] == 'l':
@@ -879,18 +876,21 @@ class AffinePermutationTypeA(AffinePermutation):
                         code[i] += (b-i) // (self.k+1) + 1
         return Composition(code)
 
-    def is_fully_commutative(self):
+    def is_fully_commutative(self) -> bool:
         r"""
-        Determine whether ``self`` is fully commutative, i.e., has no
-        reduced words with a braid.
+        Determine whether ``self`` is fully commutative.
+
+        This means that it has no reduced word with a braid.
+
+        This uses a specific algorithm.
 
         EXAMPLES::
 
             sage: A = AffinePermutationGroup(['A',7,1])
-            sage: p=A([3, -1, 0, 6, 5, 4, 10, 9])
+            sage: p = A([3, -1, 0, 6, 5, 4, 10, 9])
             sage: p.is_fully_commutative()
             False
-            sage: q=A([-3, -2, 0, 7, 9, 2, 11, 12])
+            sage: q = A([-3, -2, 0, 7, 9, 2, 11, 12])
             sage: q.is_fully_commutative()
             True
         """
@@ -903,14 +903,12 @@ class AffinePermutationTypeA(AffinePermutation):
             if c[i] > 0:
                 if firstnonzero is None:
                     firstnonzero = i
-                if m != -1 and c[i] - (i-m) >= c[m]:
+                if m != -1 and c[i] - (i - m) >= c[m]:
                     return False
                 m = i
-        #now check m (the last non-zero) against firstnonzero.
-        d = self.n-(m-firstnonzero)
-        if c[firstnonzero]-d >= c[m]:
-            return False
-        return True
+        # now check m (the last non-zero) against first non-zero.
+        d = self.n - (m - firstnonzero)
+        return not c[firstnonzero] - d >= c[m]
 
     def to_bounded_partition(self, typ='decreasing', side='right'):
         r"""
@@ -1038,7 +1036,7 @@ class AffinePermutationTypeA(AffinePermutation):
             alpha = Composition(alpha)
         # TODO: We should probably check that w is of type alpha! probably a different function.
         # Now we actually build the recording tableau.
-        tab = [[] for i in range(self.k+1)]
+        tab = [[] for _ in repeat(None, self.k + 1)]
         label = 1
         al_index = 0
         j = 0
@@ -1066,6 +1064,8 @@ class AffinePermutationTypeA(AffinePermutation):
         return tab
 
 #-------------------------------------------------------------------------------
+
+
 class AffinePermutationTypeC(AffinePermutation):
     #----------------------
     #Type-specific methods.
@@ -1207,7 +1207,7 @@ class AffinePermutationTypeC(AffinePermutation):
                     l.append(self[m])
         elif i == 0:
             for m in range(self.k):
-                res = self[m]%self.N
+                res = self[m] % self.N
                 if res == 1:
                     l.append(self[m] - 2)
                 elif res == self.N - 1:
@@ -1322,7 +1322,6 @@ class AffinePermutationTypeB(AffinePermutationTypeC):
             raise ValueError("type B affine permutations have an even number of "
                              "entries less than 0 to the right of the 0th position")
 
-
     def apply_simple_reflection_right(self, i):
         r"""
         Apply the simple reflection indexed by ``i`` on positions.
@@ -1400,7 +1399,7 @@ class AffinePermutationTypeB(AffinePermutationTypeC):
                     l.append(self[m])
         elif i == self.k:
             for m in range(self.k):
-                res = self[m]%self.N
+                res = self[m] % self.N
                 if res == i:
                     l.append(self[m] + 1)
                 elif res == j:
@@ -1707,7 +1706,7 @@ class AffinePermutationTypeG(AffinePermutation):
         EXAMPLES::
 
             sage: G = AffinePermutationGroup(['G',2,1])
-            sage: p=G([2, 10, -5, 12, -3, 5])
+            sage: p = G([2, 10, -5, 12, -3, 5])
             sage: p.apply_simple_reflection_right(0)
             Type G affine permutation with window [-9, -1, -5, 12, 8, 16]
             sage: p.apply_simple_reflection_right(1)
@@ -1715,7 +1714,7 @@ class AffinePermutationTypeG(AffinePermutation):
             sage: p.apply_simple_reflection_right(2)
             Type G affine permutation with window [2, -5, 10, -3, 12, 5]
         """
-        if not i in self.parent().index_set():
+        if i not in self.parent().index_set():
             raise ValueError('index not in index set')
         j = i
         l = self[:]
@@ -1844,8 +1843,6 @@ class AffinePermutationTypeG(AffinePermutation):
         return A(self)
 
 
-
-
 #-------------------------------------------------------------------------
 #    Class of all affine permutations.
 #-------------------------------------------------------------------------
@@ -2047,26 +2044,6 @@ class AffinePermutationGroupGeneric(UniqueRepresentation, Parent):
         """
         return "The group of affine permutations of type "+str(self.cartan_type())
 
-    def _test_coxeter_relations(self, **options):
-        r"""
-        Tests whether the Coxeter relations hold for ``self``.
-        This should probably be implemented at the Coxeter groups level.
-
-        TESTS::
-
-            sage: A = AffinePermutationGroup(['A',7,1])
-            sage: A._test_coxeter_relations()
-        """
-        tester = self._tester(**options)
-        ct = self.cartan_type()
-        D = ct.coxeter_diagram()
-        s = self.simple_reflections()
-        for e in D.edges():
-            l = s[e[0]] * s[e[1]]
-            tester.assertEqual(l**e[2], self.one(), "Coxeter relation fails")
-            for p in range(1, e[2]):
-                tester.assertNotEqual(l**p, self.one(), "smaller relation found")
-
     def _test_enumeration(self, n=4, **options):
         r"""
         Test that ``self`` has same number of elements of length ``n`` as the
@@ -2349,6 +2326,7 @@ class AffinePermutationGroupTypeA(AffinePermutationGroupGeneric):
 
     Element = AffinePermutationTypeA
 
+
 class AffinePermutationGroupTypeC(AffinePermutationGroupGeneric):
     #------------------------
     #Type-specific methods.
@@ -2422,4 +2400,3 @@ class AffinePermutationGroupTypeG(AffinePermutationGroupGeneric):
         return self([1,2,3,4,5,6])
 
     Element = AffinePermutationTypeG
-
