@@ -27,6 +27,7 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.parent import Parent
 from sage.structure.element_wrapper import ElementWrapper
 
+
 class InducedCrystal(UniqueRepresentation, Parent):
     r"""
     A crystal induced from an injection.
@@ -120,7 +121,7 @@ class InducedCrystal(UniqueRepresentation, Parent):
         if from_crystal:
             return InducedFromCrystal(X, phi, inverse)
 
-        return super(InducedCrystal, cls).__classcall__(cls, X, phi, inverse)
+        return super().__classcall__(cls, X, phi, inverse)
 
     def __init__(self, X, phi, inverse):
         """
@@ -292,6 +293,7 @@ class InducedCrystal(UniqueRepresentation, Parent):
         """
         An element of an induced crystal.
         """
+
         def e(self, i):
             """
             Return `e_i` of ``self``.
@@ -396,6 +398,7 @@ class InducedCrystal(UniqueRepresentation, Parent):
             """
             return self.parent()._phi(self.value).weight()
 
+
 class InducedFromCrystal(UniqueRepresentation, Parent):
     r"""
     A crystal induced from an injection.
@@ -426,6 +429,7 @@ class InducedFromCrystal(UniqueRepresentation, Parent):
         sage: psi_inv = lambda x: C(RSK(*x)[0])
         sage: I = crystals.Induced(C, psi, psi_inv, from_crystal=True)
     """
+
     def __init__(self, X, phi, inverse):
         """
         Initialize ``self``.
@@ -589,6 +593,7 @@ class InducedFromCrystal(UniqueRepresentation, Parent):
         """
         An element of an induced crystal.
         """
+
         def e(self, i):
             """
             Return `e_i` of ``self``.
