@@ -4,7 +4,7 @@ Balanced Incomplete Block Designs (BIBD)
 This module gathers everything related to Balanced Incomplete Block Designs. One can build a
 BIBD (or check that it can be built) with :func:`balanced_incomplete_block_design`::
 
-    sage: BIBD = designs.balanced_incomplete_block_design(7,3,1)
+    sage: BIBD = designs.balanced_incomplete_block_design(7,3,1)                        # needs sage.schemes
 
 In particular, Sage can build a `(v,k,1)`-BIBD when one exists for all `k\leq
 5`. The following functions are available:
@@ -50,12 +50,16 @@ Functions
 ---------
 """
 
+from sage.arith.misc import binomial, is_prime_power, is_square
 from sage.categories.sets_cat import EmptySetError
+from sage.misc.lazy_import import lazy_import
 from sage.misc.unknown import Unknown
+
 from .design_catalog import transversal_design  # type:ignore
-from sage.arith.all import binomial, is_prime_power
-from .group_divisible_designs import GroupDivisibleDesign
 from .designs_pyx import is_pairwise_balanced_design
+from .group_divisible_designs import GroupDivisibleDesign
+
+lazy_import('sage.schemes.plane_conics.constructor', 'Conic')
 
 
 def biplane(n, existence=False):
@@ -71,12 +75,12 @@ def biplane(n, existence=False):
 
      - ``existence`` (boolean) -- instead of building the design, return:
 
-        - ``True`` -- meaning that Sage knows how to build the design
+       - ``True`` -- meaning that Sage knows how to build the design
 
-        - ``Unknown`` -- meaning that Sage does not know how to build the
-          design, but that the design may exist (see :mod:`sage.misc.unknown`).
+       - ``Unknown`` -- meaning that Sage does not know how to build the
+         design, but that the design may exist (see :mod:`sage.misc.unknown`).
 
-        - ``False`` -- meaning that the design does not exist.
+       - ``False`` -- meaning that the design does not exist.
 
     .. SEEALSO::
 
@@ -84,21 +88,22 @@ def biplane(n, existence=False):
 
     EXAMPLES::
 
-        sage: designs.biplane(4)
+        sage: designs.biplane(4)                                                        # needs sage.rings.finite_rings
         (16,6,2)-Balanced Incomplete Block Design
-        sage: designs.biplane(7, existence=True)
+        sage: designs.biplane(7, existence=True)                                        # needs sage.schemes
         True
-        sage: designs.biplane(11)
+        sage: designs.biplane(11)                                                       # needs sage.schemes
         (79,13,2)-Balanced Incomplete Block Design
 
     TESTS::
 
-        sage: designs.biplane(9)
+        sage: designs.biplane(9)                                                        # needs sage.libs.gap
         (56,11,2)-Balanced Incomplete Block Design
 
     Check all known biplanes::
 
-        sage: [n for n in [0,1,2,3,4,7,9,11] if designs.biplane(n, existence=True) is True]
+        sage: [n for n in [0,1,2,3,4,7,9,11]                                            # needs sage.schemes
+        ....:  if designs.biplane(n, existence=True) is True]
         [0, 1, 2, 3, 4, 7, 9, 11]
     """
     k = n+2
@@ -149,9 +154,10 @@ def balanced_incomplete_block_design(v, k, lambd=1, existence=False, use_LJCR=Fa
 
     EXAMPLES::
 
-        sage: designs.balanced_incomplete_block_design(7, 3, 1).blocks()
+        sage: designs.balanced_incomplete_block_design(7, 3, 1).blocks()                # needs sage.schemes
         [[0, 1, 3], [0, 2, 4], [0, 5, 6], [1, 2, 6], [1, 4, 5], [2, 3, 5], [3, 4, 6]]
-        sage: B = designs.balanced_incomplete_block_design(66, 6, 1, use_LJCR=True) # optional - internet
+        sage: B = designs.balanced_incomplete_block_design(66, 6, 1,         # optional - internet
+        ....:                                              use_LJCR=True)
         sage: B                                                              # optional - internet
         (66,6,1)-Balanced Incomplete Block Design
         sage: B.blocks()                                                     # optional - internet
@@ -165,11 +171,11 @@ def balanced_incomplete_block_design(v, k, lambd=1, existence=False, use_LJCR=Fa
 
         sage: designs.balanced_incomplete_block_design(85,5,existence=True)
         True
-        sage: _ = designs.balanced_incomplete_block_design(85,5)
+        sage: _ = designs.balanced_incomplete_block_design(85,5)                        # needs sage.libs.pari
 
     A BIBD from a Finite Projective Plane::
 
-        sage: _ = designs.balanced_incomplete_block_design(21,5)
+        sage: _ = designs.balanced_incomplete_block_design(21,5)                        # needs sage.schemes
 
     Some trivial BIBD::
 
@@ -180,22 +186,23 @@ def balanced_incomplete_block_design(v, k, lambd=1, existence=False, use_LJCR=Fa
 
     Existence of BIBD with `k=3,4,5`::
 
-        sage: [v for v in range(50) if designs.balanced_incomplete_block_design(v,3,existence=True)]
+        sage: [v for v in range(50) if designs.balanced_incomplete_block_design(v,3,existence=True)]                    # needs sage.schemes
         [1, 3, 7, 9, 13, 15, 19, 21, 25, 27, 31, 33, 37, 39, 43, 45, 49]
-        sage: [v for v in range(100) if designs.balanced_incomplete_block_design(v,4,existence=True)]
+        sage: [v for v in range(100) if designs.balanced_incomplete_block_design(v,4,existence=True)]                   # needs sage.schemes
         [1, 4, 13, 16, 25, 28, 37, 40, 49, 52, 61, 64, 73, 76, 85, 88, 97]
-        sage: [v for v in range(150) if designs.balanced_incomplete_block_design(v,5,existence=True)]
+        sage: [v for v in range(150) if designs.balanced_incomplete_block_design(v,5,existence=True)]                   # needs sage.schemes
         [1, 5, 21, 25, 41, 45, 61, 65, 81, 85, 101, 105, 121, 125, 141, 145]
 
     For `k > 5` there are currently very few constructions::
 
-        sage: [v for v in range(300) if designs.balanced_incomplete_block_design(v,6,existence=True) is True]
+        sage: [v for v in range(300) if designs.balanced_incomplete_block_design(v,6,existence=True) is True]           # needs sage.schemes
         [1, 6, 31, 66, 76, 91, 96, 106, 111, 121, 126, 136, 141, 151, 156, 171, 181, 186, 196, 201, 211, 241, 271]
-        sage: [v for v in range(300) if designs.balanced_incomplete_block_design(v,6,existence=True) is Unknown]
+        sage: [v for v in range(300) if designs.balanced_incomplete_block_design(v,6,existence=True) is Unknown]        # needs sage.schemes
         [51, 61, 81, 166, 216, 226, 231, 246, 256, 261, 276, 286, 291]
 
     Here are some constructions with `k \geq 7` and `v` a prime power::
 
+        sage: # needs sage.libs.pari
         sage: designs.balanced_incomplete_block_design(169,7)
         (169,7,1)-Balanced Incomplete Block Design
         sage: designs.balanced_incomplete_block_design(617,8)
@@ -214,22 +221,22 @@ def balanced_incomplete_block_design(v, k, lambd=1, existence=False, use_LJCR=Fa
 
         sage: designs.balanced_incomplete_block_design(176, 50, 14, existence=True)
         True
-        sage: designs.balanced_incomplete_block_design(64,28,12)
+        sage: designs.balanced_incomplete_block_design(64,28,12)                        # needs sage.libs.pari
         (64,28,12)-Balanced Incomplete Block Design
-        sage: designs.balanced_incomplete_block_design(37,9,8)
+        sage: designs.balanced_incomplete_block_design(37,9,8)                          # needs sage.libs.pari
         (37,9,8)-Balanced Incomplete Block Design
-        sage: designs.balanced_incomplete_block_design(15,7,3)
+        sage: designs.balanced_incomplete_block_design(15,7,3)                          # needs sage.schemes
         (15,7,3)-Balanced Incomplete Block Design
 
     Some BIBDs from the recursive construction ::
 
-        sage: designs.balanced_incomplete_block_design(76,16,4)
+        sage: designs.balanced_incomplete_block_design(76,16,4)                         # needs sage.libs.pari
         (76,16,4)-Balanced Incomplete Block Design
-        sage: designs.balanced_incomplete_block_design(10,4,2)
+        sage: designs.balanced_incomplete_block_design(10,4,2)                          # needs sage.libs.pari
         (10,4,2)-Balanced Incomplete Block Design
-        sage: designs.balanced_incomplete_block_design(50,25,24)
+        sage: designs.balanced_incomplete_block_design(50,25,24)                        # needs sage.schemes
         (50,25,24)-Balanced Incomplete Block Design
-        sage: designs.balanced_incomplete_block_design(29,15,15)
+        sage: designs.balanced_incomplete_block_design(29,15,15)                        # needs sage.libs.pari
         (29,15,15)-Balanced Incomplete Block Design
     """
     # Trivial BIBD
@@ -333,7 +340,6 @@ def balanced_incomplete_block_design(v, k, lambd=1, existence=False, use_LJCR=Fa
                 else:
                     return BIBD(B.ground_set(), B.blocks(), k=k, lambd=1, copy=False)
 
-
     if ( (k+lambd)*(k+lambd-1) == lambd*(v+k+lambd-1) and
          balanced_incomplete_block_design(v+k+lambd, k+lambd, lambd, existence=True) is True):
         # By removing a block and all points of that block from the
@@ -384,15 +390,15 @@ def BruckRyserChowla_check(v, k, lambd):
     Nonexistence of projective planes of order 6 and 14
 
         sage: from sage.combinat.designs.bibd import BruckRyserChowla_check
-        sage: BruckRyserChowla_check(43,7,1)
+        sage: BruckRyserChowla_check(43,7,1)                                            # needs sage.schemes
         False
-        sage: BruckRyserChowla_check(211,15,1)
+        sage: BruckRyserChowla_check(211,15,1)                                          # needs sage.schemes
         False
 
     Existence of symmetric BIBDs with parameters `(79,13,2)` and `(56,11,2)`
 
         sage: from sage.combinat.designs.bibd import BruckRyserChowla_check
-        sage: BruckRyserChowla_check(79,13,2)
+        sage: BruckRyserChowla_check(79,13,2)                                           # needs sage.schemes
         True
         sage: BruckRyserChowla_check(56,11,2)
         True
@@ -410,12 +416,10 @@ def BruckRyserChowla_check(v, k, lambd):
     Clearly wrong parameters satisfying the theorem::
 
         sage: from sage.combinat.designs.bibd import BruckRyserChowla_check
-        sage: BruckRyserChowla_check(13,25,50)
+        sage: BruckRyserChowla_check(13,25,50)                                          # needs sage.schemes
         True
 
     """
-    from sage.arith.misc import is_square
-    from sage.schemes.plane_conics.constructor import Conic
     from sage.rings.rational_field import QQ
 
     # design is not symmetric
@@ -568,23 +572,23 @@ def BIBD_from_TD(v,k,existence=False):
     First construction::
 
         sage: from sage.combinat.designs.bibd import BIBD_from_TD
-        sage: BIBD_from_TD(25,5,existence=True)
+        sage: BIBD_from_TD(25,5,existence=True)                                         # needs sage.schemes
         True
-        sage: _ = BlockDesign(25,BIBD_from_TD(25,5))
+        sage: _ = BlockDesign(25,BIBD_from_TD(25,5))                                    # needs sage.schemes
 
     Second construction::
 
         sage: from sage.combinat.designs.bibd import BIBD_from_TD
-        sage: BIBD_from_TD(21,5,existence=True)
+        sage: BIBD_from_TD(21,5,existence=True)                                         # needs sage.schemes
         True
-        sage: _ = BlockDesign(21,BIBD_from_TD(21,5))
+        sage: _ = BlockDesign(21,BIBD_from_TD(21,5))                                    # needs sage.schemes
 
     Third construction::
 
         sage: from sage.combinat.designs.bibd import BIBD_from_TD
-        sage: BIBD_from_TD(85,5,existence=True)
+        sage: BIBD_from_TD(85,5,existence=True)                                         # needs sage.schemes
         True
-        sage: _ = BlockDesign(85,BIBD_from_TD(85,5))
+        sage: _ = BlockDesign(85,BIBD_from_TD(85,5))                                    # needs sage.schemes
 
     No idea::
 
@@ -661,7 +665,6 @@ def BIBD_from_TD(v,k,existence=False):
     return BIBD
 
 
-
 def BIBD_from_difference_family(G, D, lambd=None, check=True):
     r"""
     Return the BIBD associated to the difference family ``D`` on the group ``G``.
@@ -774,8 +777,8 @@ def v_4_1_BIBD(v, check=True):
 
         sage: from sage.combinat.designs.bibd import v_4_1_BIBD  # long time
         sage: for n in range(13,100):                            # long time
-        ....:    if n%12 in [1,4]:                               # long time
-        ....:       _ = v_4_1_BIBD(n, check = True)              # long time
+        ....:    if n%12 in [1,4]:
+        ....:       _ = v_4_1_BIBD(n, check = True)
 
     TESTS:
 
@@ -789,8 +792,8 @@ def v_4_1_BIBD(v, check=True):
     Check some larger `(v,4,1)`-BIBD (see :trac:`17557`)::
 
         sage: for v in range(400):                                      # long time
-        ....:     if v%12 in [1,4]:                                     # long time
-        ....:         _ = designs.balanced_incomplete_block_design(v,4) # long time
+        ....:     if v%12 in [1,4]:
+        ....:         _ = designs.balanced_incomplete_block_design(v,4)
     """
     k = 4
     if v == 0:
@@ -866,8 +869,8 @@ def BIBD_from_PBD(PBD, v, k, check=True, base_cases=None):
         sage: from sage.combinat.designs.bibd import PBD_4_5_8_9_12
         sage: from sage.combinat.designs.bibd import BIBD_from_PBD
         sage: from sage.combinat.designs.bibd import is_pairwise_balanced_design
-        sage: PBD = PBD_4_5_8_9_12(17)
-        sage: bibd = is_pairwise_balanced_design(BIBD_from_PBD(PBD,52,4),52,[4])
+        sage: PBD = PBD_4_5_8_9_12(17)                                                  # needs sage.schemes
+        sage: bibd = is_pairwise_balanced_design(BIBD_from_PBD(PBD,52,4),52,[4])        # needs sage.schemes
     """
     if base_cases is None:
         base_cases = {}
@@ -904,11 +907,11 @@ def _relabel_bibd(B,n,p=None):
 
     - ``n`` (integer) -- number of points.
 
-    - ``p`` (optional) -- the point that will be labeled with n-1.
+    - ``p`` (optional) -- the point that will be labeled with `n-1`.
 
     EXAMPLES::
 
-        sage: designs.balanced_incomplete_block_design(40,4).blocks() # indirect doctest
+        sage: designs.balanced_incomplete_block_design(40,4).blocks()  # indirect doctest           # needs sage.schemes
         [[0, 1, 2, 12], [0, 3, 6, 9], [0, 4, 8, 10],
          [0, 5, 7, 11], [0, 13, 26, 39], [0, 14, 25, 28],
          [0, 15, 27, 38], [0, 16, 22, 32], [0, 17, 23, 34],
@@ -950,7 +953,7 @@ def PBD_4_5_8_9_12(v, check=True):
 
     EXAMPLES::
 
-        sage: designs.balanced_incomplete_block_design(40,4).blocks() # indirect doctest
+        sage: designs.balanced_incomplete_block_design(40,4).blocks()  # indirect doctest           # needs sage.schemes
         [[0, 1, 2, 12], [0, 3, 6, 9], [0, 4, 8, 10],
          [0, 5, 7, 11], [0, 13, 26, 39], [0, 14, 25, 28],
          [0, 15, 27, 38], [0, 16, 22, 32], [0, 17, 23, 34],
@@ -959,7 +962,7 @@ def PBD_4_5_8_9_12(v, check=True):
     Check that :trac:`16476` is fixed::
 
         sage: from sage.combinat.designs.bibd import PBD_4_5_8_9_12
-        sage: for v in (0,1,4,5,8,9,12,13,16,17,20,21,24,25):
+        sage: for v in (0,1,4,5,8,9,12,13,16,17,20,21,24,25):                           # needs sage.schemes
         ....:     _ = PBD_4_5_8_9_12(v)
     """
     if v % 4 not in [0, 1]:
@@ -1029,7 +1032,7 @@ def _PBD_4_5_8_9_12_closure(B):
 
     EXAMPLES::
 
-        sage: designs.balanced_incomplete_block_design(40,4).blocks() # indirect doctest
+        sage: designs.balanced_incomplete_block_design(40,4).blocks()  # indirect doctest           # needs sage.schemes
         [[0, 1, 2, 12], [0, 3, 6, 9], [0, 4, 8, 10],
          [0, 5, 7, 11], [0, 13, 26, 39], [0, 14, 25, 28],
          [0, 15, 27, 38], [0, 16, 22, 32], [0, 17, 23, 34],
@@ -1038,7 +1041,7 @@ def _PBD_4_5_8_9_12_closure(B):
     BB = []
     for X in B:
         if len(X) not in [4,5,8,9,12]:
-            PBD = PBD_4_5_8_9_12(len(X), check = False)
+            PBD = PBD_4_5_8_9_12(len(X), check=False)
             X = [[X[i] for i in XX] for XX in PBD]
             BB.extend(X)
         else:
@@ -1121,7 +1124,7 @@ def v_5_1_BIBD(v, check=True):
 
         sage: from sage.combinat.designs.bibd import v_5_1_BIBD
         sage: i = 0
-        sage: while i<200:
+        sage: while i<200:                                                              # needs sage.libs.pari
         ....:    i += 20
         ....:    _ = v_5_1_BIBD(i+1)
         ....:    _ = v_5_1_BIBD(i+5)
@@ -1130,7 +1133,7 @@ def v_5_1_BIBD(v, check=True):
 
     Check that the needed difference families are there::
 
-        sage: for v in [21,41,61,81,141,161,281]:
+        sage: for v in [21,41,61,81,141,161,281]:                                       # needs sage.libs.pari
         ....:     assert designs.difference_family(v,5,existence=True)
         ....:     _ = designs.difference_family(v,5)
     """
@@ -1197,7 +1200,7 @@ def _get_r_s_t_u(v):
     s = r//150
     x = r%150
 
-    if   x == 0:
+    if x == 0:
         t,u = 30*s-5,  25
     elif x == 1:
         t,u = 30*s-5,  26
@@ -1264,7 +1267,7 @@ def BIBD_5q_5_for_q_prime_power(q):
 
         sage: from sage.combinat.designs.bibd import BIBD_5q_5_for_q_prime_power
         sage: for q in [25, 45, 65, 85, 125, 145, 185, 205, 305, 405, 605]: # long time
-        ....:     _ = BIBD_5q_5_for_q_prime_power(q/5)                      # long time
+        ....:     _ = BIBD_5q_5_for_q_prime_power(q/5)
     """
     from sage.rings.finite_rings.finite_field_constructor import FiniteField
 
@@ -1316,14 +1319,14 @@ def BIBD_from_arc_in_desarguesian_projective_plane(n,k,existence=False):
 
         sage: from sage.combinat.designs.bibd import BIBD_from_arc_in_desarguesian_projective_plane
         sage: from sage.combinat.designs.bibd import BalancedIncompleteBlockDesign
-        sage: D = BIBD_from_arc_in_desarguesian_projective_plane(232,8)
-        sage: BalancedIncompleteBlockDesign(232,D)
+        sage: D = BIBD_from_arc_in_desarguesian_projective_plane(232,8)                 # needs sage.libs.gap sage.modules sage.rings.finite_rings
+        sage: BalancedIncompleteBlockDesign(232,D)                                      # needs sage.libs.gap sage.modules sage.rings.finite_rings
         (232,8,1)-Balanced Incomplete Block Design
 
     A `(120,8,1)`-BIBD::
 
-        sage: D = BIBD_from_arc_in_desarguesian_projective_plane(120,8)
-        sage: BalancedIncompleteBlockDesign(120,D)
+        sage: D = BIBD_from_arc_in_desarguesian_projective_plane(120,8)                 # needs sage.libs.gap sage.modules sage.rings.finite_rings
+        sage: BalancedIncompleteBlockDesign(120,D)                                      # needs sage.libs.gap sage.modules sage.rings.finite_rings
         (120,8,1)-Balanced Incomplete Block Design
 
     Other parameters::
@@ -1374,15 +1377,15 @@ def BIBD_from_arc_in_desarguesian_projective_plane(n,k,existence=False):
     from sage.libs.gap.libgap import libgap
     from sage.matrix.constructor import Matrix
 
-    K   = GF(q,'a')
+    K = GF(q,'a')
     one = K.one()
 
     # An irreducible quadratic form over K[X,Y]
     GO = libgap.GeneralOrthogonalGroup(-1,2,q)
-    M  = libgap.InvariantQuadraticForm(GO)['matrix']
-    M  = Matrix(M)
-    M  = M.change_ring(K)
-    Q  = lambda xx,yy : M[0,0]*xx**2+(M[0,1]+M[1,0])*xx*yy+M[1,1]*yy**2
+    M = libgap.InvariantQuadraticForm(GO)['matrix']
+    M = Matrix(M)
+    M = M.change_ring(K)
+    Q = lambda xx,yy : M[0,0]*xx**2+(M[0,1]+M[1,0])*xx*yy+M[1,1]*yy**2
 
     # Here, the additive subgroup H (of order n) of K mentioned in
     # [Denniston69] is the set of all elements of K of degree < log_n
@@ -1569,14 +1572,13 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
 
         EXAMPLES::
 
+            sage: # needs sage.schemes
             sage: B = designs.balanced_incomplete_block_design(21, 5)
-            sage: a2 = B.arc()
-            sage: a2 # random
+            sage: a2 = B.arc(); a2  # random
             [5, 9, 10, 12, 15, 20]
             sage: len(a2)
             6
-            sage: a4 = B.arc(4)
-            sage: a4 # random
+            sage: a4 = B.arc(4); a4  # random
             [0, 1, 2, 5, 6, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 20]
             sage: len(a4)
             16
@@ -1591,13 +1593,14 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
             sage: 1 + r*3
             16
 
-            sage: B.trace(a2).is_t_design(2, return_parameters=True)
+            sage: B.trace(a2).is_t_design(2, return_parameters=True)                    # needs sage.schemes
             (True, (2, 6, 2, 1))
-            sage: B.trace(a4).is_t_design(2, return_parameters=True)
+            sage: B.trace(a4).is_t_design(2, return_parameters=True)                    # needs sage.schemes
             (True, (2, 16, 4, 1))
 
         Some other examples which are not maximal::
 
+            sage: # needs sage.numerical.mip
             sage: B = designs.balanced_incomplete_block_design(25, 4)
             sage: a2 = B.arc(2)
             sage: r = (25-1)//(4-1)
@@ -1609,6 +1612,7 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
             sage: B.trace(a2).is_t_design(2)
             False
 
+            sage: # needs sage.numerical.mip
             sage: a3 = B.arc(3)
             sage: len(a3), 1 + 2*r
             (15, 17)
@@ -1622,9 +1626,9 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
 
         Test consistency with relabeling::
 
-            sage: b = designs.balanced_incomplete_block_design(7,3)
-            sage: b.relabel(list("abcdefg"))
-            sage: set(b.arc()).issubset(b.ground_set())
+            sage: b = designs.balanced_incomplete_block_design(7,3)                     # needs sage.schemes
+            sage: b.relabel(list("abcdefg"))                                            # needs sage.schemes
+            sage: set(b.arc()).issubset(b.ground_set())                                 # needs sage.schemes
             True
         """
         s = int(s)
