@@ -474,11 +474,11 @@ def AllExactCovers(M):
 
     EXAMPLES::
 
-        sage: M = Matrix([[1,1,0],[1,0,1],[0,1,1]])  #no exact covers
-        sage: for cover in AllExactCovers(M):
+        sage: M = Matrix([[1,1,0],[1,0,1],[0,1,1]])  # no exact covers                  # optional - sage.modules
+        sage: for cover in AllExactCovers(M):                                           # optional - sage.modules
         ....:     print(cover)
-        sage: M = Matrix([[1,1,0],[1,0,1],[0,0,1],[0,1,0]]) #two exact covers
-        sage: for cover in AllExactCovers(M):
+        sage: M = Matrix([[1,1,0],[1,0,1],[0,0,1],[0,1,0]]) # two exact covers          # optional - sage.modules
+        sage: for cover in AllExactCovers(M):                                           # optional - sage.modules
         ....:     print(cover)
         [(1, 1, 0), (0, 0, 1)]
         [(1, 0, 1), (0, 1, 0)]
@@ -503,11 +503,11 @@ def OneExactCover(M):
 
     EXAMPLES::
 
-        sage: M = Matrix([[1,1,0],[1,0,1],[0,1,1]])  # no exact covers
-        sage: OneExactCover(M)
+        sage: M = Matrix([[1,1,0],[1,0,1],[0,1,1]])  # no exact covers                  # optional - sage.modules
+        sage: OneExactCover(M)                                                          # optional - sage.modules
 
-        sage: M = Matrix([[1,1,0],[1,0,1],[0,0,1],[0,1,0]]) # two exact covers
-        sage: OneExactCover(M)
+        sage: M = Matrix([[1,1,0],[1,0,1],[0,0,1],[0,1,0]])  # two exact covers         # optional - sage.modules
+        sage: OneExactCover(M)                                                          # optional - sage.modules
         [(1, 1, 0), (0, 0, 1)]
     """
     for s in AllExactCovers(M):
