@@ -159,9 +159,9 @@ Plotting patches made of unit segments instead of unit faces::
     sage: P = Patch([Face([0,0], 1), Face([0,0], 2)])
     sage: E = E1Star(WordMorphism({1:[1,2],2:[1]}))
     sage: F = E1Star(WordMorphism({1:[1,1,2],2:[2,1]}))
-    sage: E(P,5).plot()
+    sage: E(P,5).plot()                                                                 # optional - sage.plot
     Graphics object consisting of 21 graphics primitives
-    sage: F(P,3).plot()
+    sage: F(P,3).plot()                                                                 # optional - sage.plot
     Graphics object consisting of 34 graphics primitives
 
 Everything works in any dimension (except for the plotting features
@@ -264,6 +264,7 @@ class Face(SageObject):
         sage: f.color()
         RGB color (0.5, 0.5, 0.5)
     """
+
     def __init__(self, v, t, color=None):
         r"""
         Face constructor. See class doc for more information.
@@ -287,7 +288,7 @@ class Face(SageObject):
         self._vector.set_immutable()
 
         if not((t in ZZ) and 1 <= t <= len(v)):
-            raise ValueError('The type must be an integer between 1 and len(v)')
+            raise ValueError('the type must be an integer between 1 and len(v)')
         self._type = t
 
         if color is None:
@@ -489,12 +490,12 @@ class Face(SageObject):
             sage: face_contour[1] = map(vector, [(0,0,0),(0,1,0),(0,1,1),(0,0,1)])
             sage: face_contour[2] = map(vector, [(0,0,0),(0,0,1),(1,0,1),(1,0,0)])
             sage: face_contour[3] = map(vector, [(0,0,0),(1,0,0),(1,1,0),(0,1,0)])
-            sage: G = f._plot(projmat, face_contour, 0.75)
+            sage: G = f._plot(projmat, face_contour, 0.75)                              # optional - sage.plot
 
         ::
 
             sage: f = Face((0,0), 2)
-            sage: f._plot(None, None, 1)
+            sage: f._plot(None, None, 1)                                                # optional - sage.plot
             Graphics object consisting of 1 graphics primitive
         """
         v = self.vector()
@@ -513,7 +514,7 @@ class Face(SageObject):
                          thickness=1, rgbcolor=self.color())
 
         else:
-            raise NotImplementedError("Plotting is implemented only for patches in two or three dimensions.")
+            raise NotImplementedError("plotting is implemented only for patches in two or three dimensions.")
 
         return G
 
@@ -578,6 +579,7 @@ class Patch(SageObject):
         sage: Patch([Face((0,0,0),t) for t in [1,2,3]], face_contour=face_contour)
         Patch: [[(0, 0, 0), 1]*, [(0, 0, 0), 2]*, [(0, 0, 0), 3]*]
     """
+
     def __init__(self, faces, face_contour=None):
         r"""
         Constructor of a patch (set of faces).
@@ -1069,14 +1071,14 @@ class Patch(SageObject):
                 from matplotlib import cm
             assert cm is not None
             if cmap not in cm.datad:
-                raise RuntimeError("Color map %s not known (type sorted(colors) for valid names)" % cmap)
+                raise RuntimeError("color map %s not known (type sorted(colors) for valid names)" % cmap)
             cmap = cm.__dict__[cmap]
             dim = float(len(self))
             for i, f in enumerate(self):
                 f.color(cmap(i / dim)[:3])
 
         else:
-            raise TypeError("Type of cmap (=%s) must be dict, list or str" % cmap)
+            raise TypeError("type of cmap (=%s) must be dict, list or str" % cmap)
 
     def plot(self, projmat=None, opacity=0.75) -> Graphics:
         r"""
@@ -1100,7 +1102,7 @@ class Patch(SageObject):
 
             sage: from sage.combinat.e_one_star import E1Star, Face, Patch
             sage: P = Patch([Face((0,0,0),t) for t in [1,2,3]])
-            sage: P.plot()
+            sage: P.plot()                                                              # optional - sage.plot
             Graphics object consisting of 3 graphics primitives
 
         ::
@@ -1109,7 +1111,7 @@ class Patch(SageObject):
             sage: E = E1Star(sigma)
             sage: P = Patch([Face((0,0,0),t) for t in [1,2,3]])
             sage: P = E(P, 5)
-            sage: P.plot()
+            sage: P.plot()                                                              # optional - sage.plot
             Graphics object consisting of 57 graphics primitives
 
         Plot with a different projection matrix::
@@ -1119,7 +1121,7 @@ class Patch(SageObject):
             sage: P = Patch([Face((0,0,0),t) for t in [1,2,3]])
             sage: M = matrix(2, 3, [1,0,-1,0.3,1,-3])
             sage: P = E(P, 3)
-            sage: P.plot(projmat=M)
+            sage: P.plot(projmat=M)                                                     # optional - sage.plot
             Graphics object consisting of 17 graphics primitives
 
         Plot patches made of unit segments::
@@ -1127,9 +1129,9 @@ class Patch(SageObject):
             sage: P = Patch([Face([0,0], 1), Face([0,0], 2)])
             sage: E = E1Star(WordMorphism({1:[1,2],2:[1]}))
             sage: F = E1Star(WordMorphism({1:[1,1,2],2:[2,1]}))
-            sage: E(P,5).plot()
+            sage: E(P,5).plot()                                                         # optional - sage.plot
             Graphics object consisting of 21 graphics primitives
-            sage: F(P,3).plot()
+            sage: F(P,3).plot()                                                         # optional - sage.plot
             Graphics object consisting of 34 graphics primitives
         """
         if self.dimension() == 2:
@@ -1152,7 +1154,7 @@ class Patch(SageObject):
             return G
 
         else:
-            raise NotImplementedError("Plotting is implemented only for patches in two or three dimensions.")
+            raise NotImplementedError("plotting is implemented only for patches in two or three dimensions.")
 
     def plot3d(self):
         r"""
@@ -1178,7 +1180,7 @@ class Patch(SageObject):
             sage: P.plot3d()                #not tested
         """
         if self.dimension() != 3:
-            raise NotImplementedError("3D plotting is implemented only for patches in three dimensions.")
+            raise NotImplementedError("3D plotting is implemented only for patches in three dimensions")
 
         face_list = [face._plot3d(self._face_contour) for face in self]
         G = sum(face_list)
@@ -1300,7 +1302,7 @@ class Patch(SageObject):
             \end{tikzpicture}
         """
         if self.dimension() != 3:
-            raise NotImplementedError("Tikz Plotting is implemented only for patches in three dimensions.")
+            raise NotImplementedError("Tikz plotting is implemented only for patches in three dimensions")
 
         if projmat is None:
             projmat = matrix(2, [-1.7320508075688772 * 0.5,
@@ -1393,6 +1395,7 @@ class E1Star(SageObject):
         sage: E(P)
         Patch: [[(0, 0, 0, 0), 3]*, [(0, 0, 0, 0), 4]*, [(0, 0, 1, -1), 3]*, [(0, 1, 0, -1), 2]*, [(1, 0, 0, -1), 1]*]
     """
+
     def __init__(self, sigma, method='suffix'):
         r"""
         E1Star constructor. See class doc for more information.
@@ -1409,14 +1412,14 @@ class E1Star(SageObject):
             raise TypeError("sigma (=%s) must be an instance of WordMorphism" % sigma)
 
         if sigma.domain().alphabet() != sigma.codomain().alphabet():
-            raise ValueError("The domain and codomain of (%s) must be the same." % sigma)
+            raise ValueError("the domain and codomain of (%s) must be the same" % sigma)
 
         if abs(det(matrix(sigma))) != 1:
-            raise ValueError("The substitution (%s) must be unimodular." % sigma)
+            raise ValueError("the substitution (%s) must be unimodular" % sigma)
 
         first_letter = sigma.codomain().alphabet()[0]
         if not (first_letter in ZZ) or (first_letter < 1):
-            raise ValueError("The substitution (%s) must be defined on positive integers." % sigma)
+            raise ValueError("the substitution (%s) must be defined on positive integers" % sigma)
 
         self._sigma = WordMorphism(sigma)
         self._d = self._sigma.domain().alphabet().cardinality()
@@ -1433,7 +1436,7 @@ class E1Star(SageObject):
                 elif method == 'prefix':
                     image_word = subst_im[:n]
                 else:
-                    raise ValueError("Option 'method' can only be 'prefix' or 'suffix'.")
+                    raise ValueError("option 'method' can only be 'prefix' or 'suffix'")
                 if letter not in X:
                     X[letter] = []
                 v = self.inverse_matrix() * vector(image_word.abelian_vector())
@@ -1502,7 +1505,7 @@ class E1Star(SageObject):
         if iterations == 0:
             return Patch(patch)
         elif iterations < 0:
-            raise ValueError("iterations (=%s) must be >= 0." % iterations)
+            raise ValueError("iterations (=%s) must be >= 0" % iterations)
         else:
             old_faces = patch
             for i in range(iterations):
@@ -1579,7 +1582,7 @@ class E1Star(SageObject):
             [[(3, 0, -3), 1]*, [(2, 1, -3), 2]*, [(2, 0, -2), 3]*]
         """
         if len(face.vector()) != self._d:
-            raise ValueError("The dimension of the faces must be equal to the size of the alphabet of the substitution.")
+            raise ValueError("the dimension of the faces must be equal to the size of the alphabet of the substitution")
         x_new = self.inverse_matrix() * face.vector()
         t = face.type()
         return (Face(x_new + v, k, color=color) for v, k in self._base_iter[t])
