@@ -192,7 +192,6 @@ class AutomatonGenerators():
                          initial_states=[z],
                          final_states=[z])
 
-
     def EmptyWord(self, input_alphabet=None):
         r"""
         Return an automaton recognizing the empty word.
@@ -224,7 +223,6 @@ class AutomatonGenerators():
                          final_states=[z],
                          input_alphabet=input_alphabet)
 
-
     def Word(self, word, input_alphabet=None):
         r"""
         Return an automaton recognizing the given word.
@@ -278,13 +276,12 @@ class AutomatonGenerators():
         letters = list(word)
         length = len(letters)
         from sage.rings.integer_ring import ZZ
-        return Automaton([(ZZ(i), ZZ(i+1), letter)
+        return Automaton([(ZZ(i), ZZ(i + 1), letter)
                           for i, letter in enumerate(letters)],
                          initial_states=[ZZ(0)],
                          final_states=[ZZ(length)],
                          input_alphabet=input_alphabet)
 
-
     def ContainsWord(self, word, input_alphabet):
         r"""
         Return an automaton recognizing the words containing
@@ -530,7 +527,6 @@ class TransducerGenerators():
             s.is_final = True
         return T
 
-
     def Wait(self, input_alphabet, threshold=1):
         r"""
         Writes ``False`` until reading the ``threshold``-th occurrence
@@ -574,7 +570,6 @@ class TransducerGenerators():
 
         return T
 
-
     def map(self, f, input_alphabet):
         r"""
         Return a transducer which realizes a function
@@ -620,7 +615,6 @@ class TransducerGenerators():
                           initial_states=[0],
                           final_states=[0])
 
-
     def operator(self, operator, input_alphabet, number_of_operands=2):
         r"""
         Returns a transducer which realizes an operation
@@ -703,7 +697,6 @@ class TransducerGenerators():
                           initial_states=[0],
                           final_states=[0])
 
-
     def all(self, input_alphabet, number_of_operands=2):
         r"""
         Returns a transducer which realizes logical ``and`` over the given
@@ -755,7 +748,6 @@ class TransducerGenerators():
         return self.operator(lambda *args: all(args),
                              input_alphabet, number_of_operands)
 
-
     def any(self, input_alphabet, number_of_operands=2):
         r"""
         Returns a transducer which realizes logical ``or`` over the given
@@ -807,7 +799,6 @@ class TransducerGenerators():
         return self.operator(lambda *args: any(args),
                              input_alphabet, number_of_operands)
 
-
     def add(self, input_alphabet, number_of_operands=2):
         r"""
         Returns a transducer which realizes addition on pairs over the
@@ -862,7 +853,6 @@ class TransducerGenerators():
                              input_alphabet,
                              number_of_operands=number_of_operands)
 
-
     def sub(self, input_alphabet):
         r"""
         Returns a transducer which realizes subtraction on pairs over
@@ -902,7 +892,6 @@ class TransducerGenerators():
         """
         return self.operator(operator.sub, input_alphabet)
 
-
     def weight(self, input_alphabet, zero=0):
         r"""
         Returns a transducer which realizes the Hamming weight of the input
@@ -969,7 +958,6 @@ class TransducerGenerators():
                           initial_states=[0],
                           final_states=[0])
 
-
     def abs(self, input_alphabet):
         r"""
         Returns a transducer which realizes the letter-wise
@@ -1004,7 +992,6 @@ class TransducerGenerators():
         """
         return self.map(abs, input_alphabet)
 
-
     def GrayCode(self):
         """
         Returns a transducer converting the standard binary
@@ -1057,10 +1044,8 @@ class TransducerGenerators():
                           final_states=[1],
                           with_final_word_out=[0])
 
-
     RecursionRule = namedtuple('RecursionRule', ['K', 'r', 'k', 's', 't'])
 
-
     def _parse_recursion_equation_(self, equation, base, function, var,
                                    word_function=None, output_rings=[ZZ, QQ]):
         """
@@ -1094,15 +1079,15 @@ class TransducerGenerators():
 
         EXAMPLES::
 
-            sage: var('n')
+            sage: var('n')                                                              # optional - sage.symbolic
             n
-            sage: function('f')
+            sage: function('f')                                                         # optional - sage.symbolic
             f
-            sage: transducers._parse_recursion_equation_(
+            sage: transducers._parse_recursion_equation_(                               # optional - sage.symbolic
             ....:     f(8*n + 7) == f(2*n + 3) + 5,
             ....:     2, f, n)
             RecursionRule(K=3, r=7, k=1, s=3, t=[5])
-            sage: transducers._parse_recursion_equation_(
+            sage: transducers._parse_recursion_equation_(                               # optional - sage.symbolic
             ....:     f(42) == 5,
             ....:     2, f, n)
             {42: [5]}
@@ -1111,14 +1096,14 @@ class TransducerGenerators():
 
             The following tests check that the equations are well-formed::
 
-                sage: transducers._parse_recursion_equation_(f(4*n + 1), 2, f, n)
+                sage: transducers._parse_recursion_equation_(f(4*n + 1), 2, f, n)       # optional - sage.symbolic
                 Traceback (most recent call last):
                 ...
                 ValueError: f(4*n + 1) is not an equation with ==.
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(n) + 1 == f(2*n),
+                sage: transducers._parse_recursion_equation_(f(n) + 1 == f(2*n),        # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1126,7 +1111,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n, 5) == 3,
+                sage: transducers._parse_recursion_equation_(f(2*n, 5) == 3,            # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1134,7 +1119,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(1/n) == f(n) + 3,
+                sage: transducers._parse_recursion_equation_(f(1/n) == f(n) + 3,        # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1142,7 +1127,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(n^2 + 5) == 3,
+                sage: transducers._parse_recursion_equation_(f(n^2 + 5) == 3,           # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1150,7 +1135,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(3*n + 5) == f(n) + 7,
+                sage: transducers._parse_recursion_equation_(f(3*n + 5) == f(n) + 7,    # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1158,7 +1143,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(n + 5) == f(n) + 7,
+                sage: transducers._parse_recursion_equation_(f(n + 5) == f(n) + 7,      # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1166,7 +1151,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(
+                sage: transducers._parse_recursion_equation_(                           # optional - sage.symbolic
                 ....:     f(2*n + 1) == f(n + 1) + f(n) + 2,
                 ....:     2, f, n)
                 Traceback (most recent call last):
@@ -1176,7 +1161,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == sin(n) + 2,
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == sin(n) + 2,  # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1185,7 +1170,8 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(n) + n + 2,
+                sage: transducers._parse_recursion_equation_(                           # optional - sage.symbolic
+                ....:     f(2*n + 1) == f(n) + n + 2,
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1193,7 +1179,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == sin(n),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == sin(n),      # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1201,7 +1187,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(n, 2),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(n, 2),     # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1209,7 +1195,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(1/n),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(1/n),      # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1217,7 +1203,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(n^2 + 5),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(n^2 + 5),  # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1225,7 +1211,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(3*n + 5),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(3*n + 5),  # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1233,7 +1219,8 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f((1/2)*n + 5),
+                sage: transducers._parse_recursion_equation_(                           # optional - sage.symbolic
+                ....:     f(2*n + 1) == f((1/2)*n + 5),
                 ....:     QQ(2), f, n)
                 Traceback (most recent call last):
                 ...
@@ -1241,7 +1228,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(2*n + 5),
+                sage: transducers._parse_recursion_equation_(f(2*n + 1) == f(2*n + 5),  # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1256,7 +1243,7 @@ class TransducerGenerators():
             for ring in output_rings:
                 try:
                     return ring(output)
-                except (ValueError,TypeError):
+                except (ValueError, TypeError):
                     pass
             return output
 
@@ -1368,13 +1355,12 @@ class TransducerGenerators():
         assert equation == parsed_equation, \
             "Parsing of %s failed for unknown reasons." % (equation,)
 
-        rule = self.RecursionRule(K=K,r=r, k=k, s=s, t=to_list(t))
+        rule = self.RecursionRule(K=K, r=r, k=k, s=s, t=to_list(t))
         return rule
 
-
     def Recursion(self, recursions, base, function=None, var=None,
                   input_alphabet=None, word_function=None,
-                  is_zero=None,  output_rings=[ZZ, QQ]):
+                  is_zero=None, output_rings=[ZZ, QQ]):
         r"""
         Return a transducer realizing the given recursion when reading
         the digit expansion with base ``base``.
@@ -1448,17 +1434,17 @@ class TransducerGenerators():
         -   The following example computes the Hamming weight of the
             ternary expansion of integers. ::
 
-                sage: function('f')
+                sage: function('f')                                                     # optional - sage.symbolic
                 f
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(3*n + 1) == f(n) + 1,
                 ....:     f(3*n + 2) == f(n) + 1,
                 ....:     f(3*n) == f(n),
                 ....:     f(0) == 0],
                 ....:     3, f, n)
-                sage: T.transitions()
+                sage: T.transitions()                                                   # optional - sage.symbolic
                 [Transition from (0, 0) to (0, 0): 0|-,
                  Transition from (0, 0) to (0, 0): 1|1,
                  Transition from (0, 0) to (0, 0): 2|1]
@@ -1466,13 +1452,13 @@ class TransducerGenerators():
             To illustrate what this transducer does, we consider the
             example of `n=601`::
 
-                sage: ternary_expansion = 601.digits(base=3)
-                sage: ternary_expansion
+                sage: ternary_expansion = 601.digits(base=3)                            # optional - sage.symbolic
+                sage: ternary_expansion                                                 # optional - sage.symbolic
                 [1, 2, 0, 1, 1, 2]
-                sage: weight_sequence = T(ternary_expansion)
-                sage: weight_sequence
+                sage: weight_sequence = T(ternary_expansion)                            # optional - sage.symbolic
+                sage: weight_sequence                                                   # optional - sage.symbolic
                 [1, 1, 1, 1, 1]
-                sage: sum(weight_sequence)
+                sage: sum(weight_sequence)                                              # optional - sage.symbolic
                 5
 
             Note that the digit zero does not show up in the output because
@@ -1482,24 +1468,24 @@ class TransducerGenerators():
         -   The following example computes the Hamming weight of the
             non-adjacent form, cf. the :wikipedia:`Non-adjacent_form`. ::
 
-                sage: function('f')
+                sage: function('f')                                                     # optional - sage.symbolic
                 f
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(4*n + 1) == f(n) + 1,
                 ....:     f(4*n - 1) == f(n) + 1,
                 ....:     f(2*n) == f(n),
                 ....:     f(0) == 0],
                 ....:     2, f, n)
-                sage: T.transitions()
+                sage: T.transitions()                                                   # optional - sage.symbolic
                 [Transition from (0, 0) to (0, 0): 0|-,
                  Transition from (0, 0) to (1, 1): 1|-,
                  Transition from (1, 1) to (0, 0): 0|1,
                  Transition from (1, 1) to (1, 0): 1|1,
                  Transition from (1, 0) to (1, 1): 0|-,
                  Transition from (1, 0) to (1, 0): 1|-]
-                sage: [(s.label(), s.final_word_out)
+                sage: [(s.label(), s.final_word_out)                                    # optional - sage.symbolic
                 ....:  for s in T.iter_final_states()]
                 [((0, 0), []),
                  ((1, 1), [1]),
@@ -1521,9 +1507,9 @@ class TransducerGenerators():
                 sage: binary_expansion = 29.digits(base=2)
                 sage: binary_expansion
                 [1, 0, 1, 1, 1]
-                sage: T(binary_expansion)
+                sage: T(binary_expansion)                                               # optional - sage.symbolic
                 [1, 1, 1]
-                sage: sum(T(binary_expansion))
+                sage: sum(T(binary_expansion))                                          # optional - sage.symbolic
                 3
 
             Indeed, the given non-adjacent form has three non-zero
@@ -1549,11 +1535,11 @@ class TransducerGenerators():
             the point of view of this method---is a contradicting recursion.
             We override this by the parameter ``is_zero``. ::
 
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: function('f w')
+                sage: function('f w')                                                   # optional - sage.symbolic
                 (f, w)
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:      f(2*n) == f(n) + w(0),
                 ....:      f(4*n + 1) == f(n) + w(1, 0),
                 ....:      f(4*n - 1) == f(n) + w(-1, 0),
@@ -1561,14 +1547,14 @@ class TransducerGenerators():
                 ....:      2, f, n,
                 ....:      word_function=w,
                 ....:      is_zero=lambda x: sum(x).is_zero())
-                sage: T.transitions()
+                sage: T.transitions()                                                   # optional - sage.symbolic
                 [Transition from (0, 0) to (0, 0): 0|0,
                  Transition from (0, 0) to (1, 1): 1|-,
                  Transition from (1, 1) to (0, 0): 0|1,0,
                  Transition from (1, 1) to (1, 0): 1|-1,0,
                  Transition from (1, 0) to (1, 1): 0|-,
                  Transition from (1, 0) to (1, 0): 1|0]
-                sage: for s in T.iter_states():
+                sage: for s in T.iter_states():                                         # optional - sage.symbolic
                 ....:     print("{} {}".format(s, s.final_word_out))
                 (0, 0) []
                 (1, 1) [1, 0]
@@ -1576,7 +1562,7 @@ class TransducerGenerators():
 
             We again consider the example of `n=29`::
 
-                sage: T(29.digits(base=2))
+                sage: T(29.digits(base=2))                                              # optional - sage.symbolic
                 [1, 0, -1, 0, 0, 1, 0]
 
             The same transducer can also be entered bypassing the
@@ -1590,22 +1576,22 @@ class TransducerGenerators():
                 ....:       (0, [])],
                 ....:       2,
                 ....:       is_zero=lambda x: sum(x).is_zero())
-                sage: TR == T
+                sage: TR == T                                                           # optional - sage.symbolic
                 True
 
         -   Here is an artificial example where some of the `s` are
             negative::
 
-                sage: function('f')
+                sage: function('f')                                                     # optional - sage.symbolic
                 f
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(2*n + 1) == f(n-1) + 1,
                 ....:     f(2*n) == f(n),
                 ....:     f(1) == 1,
                 ....:     f(0) == 0], 2, f, n)
-                sage: T.transitions()
+                sage: T.transitions()                                                   # optional - sage.symbolic
                 [Transition from (0, 0) to (0, 0): 0|-,
                  Transition from (0, 0) to (1, 1): 1|-,
                  Transition from (1, 1) to (-1, 1): 0|1,
@@ -1616,7 +1602,7 @@ class TransducerGenerators():
                  Transition from (-1, 2) to (0, 0): 1|1,
                  Transition from (1, 2) to (-1, 2): 0|1,
                  Transition from (1, 2) to (1, 2): 1|1]
-                sage: [(s.label(), s.final_word_out)
+                sage: [(s.label(), s.final_word_out)                                    # optional - sage.symbolic
                 ....:  for s in T.iter_final_states()]
                 [((0, 0), []),
                  ((1, 1), [1]),
@@ -1627,7 +1613,7 @@ class TransducerGenerators():
         -   Abelian complexity of the paperfolding sequence
             (cf. [HKP2015]_, Example 2.8)::
 
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(4*n) == f(2*n),
                 ....:     f(4*n+2) == f(2*n+1)+1,
                 ....:     f(16*n+1) == f(8*n+1),
@@ -1637,7 +1623,7 @@ class TransducerGenerators():
                 ....:     f(1) == 2, f(0) == 0]
                 ....:     + [f(16*n+jj) == f(2*n+1)+2 for jj in [3,7,9,13]],
                 ....:     2, f, n)
-                sage: T.transitions()
+                sage: T.transitions()                                                   # optional - sage.symbolic
                 [Transition from (0, 0) to (0, 1): 0|-,
                  Transition from (0, 0) to (1, 1): 1|-,
                  Transition from (0, 1) to (0, 1): 0|-,
@@ -1658,7 +1644,7 @@ class TransducerGenerators():
                  Transition from (7, 3) to (2, 1): 1|1,
                  Transition from (2, 1) to (1, 1): 0|1,
                  Transition from (2, 1) to (2, 1): 1|-]
-                sage: for s in T.iter_states():
+                sage: for s in T.iter_states():                                         # optional - sage.symbolic
                 ....:     print("{} {}".format(s, s.final_word_out))
                 (0, 0) []
                 (0, 1) []
@@ -1670,52 +1656,52 @@ class TransducerGenerators():
                 (3, 3) [2, 2]
                 (7, 3) [2, 2]
                 (2, 1) [1, 2]
-                sage: list(sum(T(n.bits())) for n in srange(1, 21))
+                sage: list(sum(T(n.bits())) for n in srange(1, 21))                     # optional - sage.symbolic
                 [2, 3, 4, 3, 4, 5, 4, 3, 4, 5, 6, 5, 4, 5, 4, 3, 4, 5, 6, 5]
 
         -   We now demonstrate the use of the ``output_rings``
             parameter.  If no ``output_rings`` are specified, the
             output labels are converted into ``ZZ``::
 
-                sage: function('f')
+                sage: function('f')                                                     # optional - sage.symbolic
                 f
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(2*n + 1) == f(n) + 1,
                 ....:     f(2*n) == f(n),
                 ....:     f(0) == 2],
                 ....:     2, f, n)
-                sage: for t in T.transitions():
+                sage: for t in T.transitions():                                         # optional - sage.symbolic
                 ....:     print([x.parent() for x in t.word_out])
                 []
                 [Integer Ring]
-                sage: [x.parent() for x in T.states()[0].final_word_out]
+                sage: [x.parent() for x in T.states()[0].final_word_out]                # optional - sage.symbolic
                 [Integer Ring]
 
             In contrast, if ``output_rings`` is set to the empty list, the
             results are not converted::
 
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(2*n + 1) == f(n) + 1,
                 ....:     f(2*n) == f(n),
                 ....:     f(0) == 2],
                 ....:     2, f, n, output_rings=[])
-                sage: for t in T.transitions():
+                sage: for t in T.transitions():                                         # optional - sage.symbolic
                 ....:     print([x.parent() for x in t.word_out])
                 []
                 [Symbolic Ring]
-                sage: [x.parent() for x in T.states()[0].final_word_out]
+                sage: [x.parent() for x in T.states()[0].final_word_out]                # optional - sage.symbolic
                 [Symbolic Ring]
 
             Finally, we use a somewhat questionable conversion::
 
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.rings.finite_rings sage.symbolic
                 ....:     f(2*n + 1) == f(n) + 1,
                 ....:     f(2*n) == f(n),
                 ....:     f(0) == 0],
                 ....:     2, f, n, output_rings=[GF(5)])
-                sage: for t in T.transitions():
+                sage: for t in T.transitions():                                         # optional - sage.rings.finite_rings sage.symbolic
                 ....:     print([x.parent() for x in t.word_out])
                 []
                 [Finite Field of size 5]
@@ -1742,11 +1728,11 @@ class TransducerGenerators():
             The following tests fail due to missing or superfluous recursions
             or initial conditions. ::
 
-                sage: var('n')
+                sage: var('n')                                                          # optional - sage.symbolic
                 n
-                sage: function('f')
+                sage: function('f')                                                     # optional - sage.symbolic
                 f
-                sage: transducers.Recursion([f(2*n) == f(n)],
+                sage: transducers.Recursion([f(2*n) == f(n)],                           # optional - sage.symbolic
                 ....:     2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1755,9 +1741,9 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers.Recursion([f(2*n + 1) == f(n),
+                sage: transducers.Recursion([f(2*n + 1) == f(n),                        # optional - sage.symbolic
                 ....:                        f(4*n) == f(2*n) + 1,
-                ....:                        f(2*n) == f(n) +1],
+                ....:                        f(2*n) == f(n) + 1],
                 ....:                       2, f, n)
                 Traceback (most recent call last):
                 ...
@@ -1765,7 +1751,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers.Recursion([f(2*n + 1) == f(n) + 1,
+                sage: transducers.Recursion([f(2*n + 1) == f(n) + 1,                    # optional - sage.symbolic
                 ....:                        f(2*n) == f(n),
                 ....:                        f(0) == 0,
                 ....:                        f(42) == 42], 2, f, n)
@@ -1775,7 +1761,7 @@ class TransducerGenerators():
 
             ::
 
-                sage: transducers.Recursion([f(2*n + 1) == f(n) + 1,
+                sage: transducers.Recursion([f(2*n + 1) == f(n) + 1,                    # optional - sage.symbolic
                 ....:                        f(2*n) == f(n - 2) + 4,
                 ....:                        f(0) == 0], 2, f, n)
                 Traceback (most recent call last):
@@ -1785,7 +1771,7 @@ class TransducerGenerators():
             Here is an example of a transducer with a conflicting rule
             (it cannot hold for `n = 0`)::
 
-                sage: T = transducers.Recursion([
+                sage: T = transducers.Recursion([                                       # optional - sage.symbolic
                 ....:     f(2*n + 1) == f(n - 1),
                 ....:     f(2*n) == f(n) + 1,
                 ....:     f(1) == 1,
@@ -1831,11 +1817,11 @@ class TransducerGenerators():
 
         for given_rule in rules:
             q, remainder = given_rule.r.quo_rem(base**given_rule.K)
-            rule=self.RecursionRule(K=given_rule.K,
-                                    r=remainder,
-                                    k=given_rule.k,
-                                    s=given_rule.s - base**given_rule.k*q,
-                                    t=given_rule.t)
+            rule = self.RecursionRule(K=given_rule.K,
+                                      r=remainder,
+                                      k=given_rule.k,
+                                      s=given_rule.s - base**given_rule.k * q,
+                                      t=given_rule.t)
             for m in range(max_K - rule.K + 1):
                 for ell in range(base**m):
                     R = rule.r + base**rule.K * ell
@@ -2004,9 +1990,8 @@ class TransducerGenerators():
                     "Too many initial conditions, only give one of %s." %
                     cycle[1:])
             required_initial_values.update(intersection)
-            output_sum = sum([edge[2]
-                              for edge in recursion_digraph.\
-                                  outgoing_edge_iterator(cycle[1:])],
+            output_sum = sum([e[2]
+                for e in recursion_digraph.outgoing_edge_iterator(cycle[1:])],
                              [])
             if not is_zero(output_sum):
                 raise ValueError(
