@@ -30,6 +30,7 @@ AUTHORS:
 
 from sage.combinat.integer_lists import IntegerListsLex
 from itertools import product
+from collections.abc import Sequence
 import numbers
 
 from sage.structure.parent import Parent
@@ -41,11 +42,12 @@ from sage.categories.enumerated_sets import EnumeratedSets
 from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
 from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
 from sage.rings.infinity import PlusInfinity
-from sage.arith.all import binomial
+from sage.arith.misc import binomial
 from sage.rings.integer_ring import ZZ
-from sage.rings.semirings.all import NN
+from sage.rings.semirings.non_negative_integer_semiring import NN
 from sage.rings.integer import Integer
 
+
 def is_gale_ryser(r,s):
     r"""
     Tests whether the given sequences satisfy the condition
@@ -90,11 +92,11 @@ def is_gale_ryser(r,s):
     EXAMPLES::
 
         sage: from sage.combinat.integer_vector import is_gale_ryser
-        sage: is_gale_ryser([4,2,2],[3,3,1,1])
+        sage: is_gale_ryser([4,2,2], [3,3,1,1])                                         # optional - sage.combinat
         True
-        sage: is_gale_ryser([4,2,1,1],[3,3,1,1])
+        sage: is_gale_ryser([4,2,1,1], [3,3,1,1])                                       # optional - sage.combinat
         True
-        sage: is_gale_ryser([3,2,1,1],[3,3,1,1])
+        sage: is_gale_ryser([3,2,1,1], [3,3,1,1])                                       # optional - sage.combinat
         False
 
     REMARK: In the literature, what we are calling a
@@ -121,6 +123,7 @@ def is_gale_ryser(r,s):
     #                                same number of 1s           domination
     return len(rstar) <= len(s2) and sum(r2) == sum(s2) and rstar.dominates(s)
 
+
 def gale_ryser_theorem(p1, p2, algorithm="gale",
                        *, solver=None, integrality_tolerance=1e-3):
     r"""
@@ -204,14 +207,14 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
         sage: from sage.combinat.integer_vector import gale_ryser_theorem
         sage: p1 = [2,2,1]
         sage: p2 = [2,2,1]
-        sage: print(gale_ryser_theorem(p1, p2))     # not tested
+        sage: print(gale_ryser_theorem(p1, p2))     # not tested                        # optional - sage.combinat
         [1 1 0]
         [1 0 1]
         [0 1 0]
-        sage: A = gale_ryser_theorem(p1, p2)
-        sage: rs = [sum(x) for x in A.rows()]
-        sage: cs = [sum(x) for x in A.columns()]
-        sage: p1 == rs; p2 == cs
+        sage: A = gale_ryser_theorem(p1, p2)                                            # optional - sage.combinat
+        sage: rs = [sum(x) for x in A.rows()]                                           # optional - sage.combinat
+        sage: cs = [sum(x) for x in A.columns()]                                        # optional - sage.combinat
+        sage: p1 == rs; p2 == cs                                                        # optional - sage.combinat
         True
         True
 
@@ -221,27 +224,27 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
         sage: from sage.combinat.integer_vector import gale_ryser_theorem
         sage: p1 = [3,3,1,1]
         sage: p2 = [3,3,1,1]
-        sage: gale_ryser_theorem(p1, p2, algorithm = "ryser")
+        sage: gale_ryser_theorem(p1, p2, algorithm="ryser")                             # optional - sage.combinat
         [1 1 1 0]
         [1 1 0 1]
         [1 0 0 0]
         [0 1 0 0]
         sage: p1 = [4,2,2]
         sage: p2 = [3,3,1,1]
-        sage: gale_ryser_theorem(p1, p2, algorithm = "ryser")
+        sage: gale_ryser_theorem(p1, p2, algorithm="ryser")                             # optional - sage.combinat
         [1 1 1 1]
         [1 1 0 0]
         [1 1 0 0]
         sage: p1 = [4,2,2,0]
         sage: p2 = [3,3,1,1,0,0]
-        sage: gale_ryser_theorem(p1, p2, algorithm = "ryser")
+        sage: gale_ryser_theorem(p1, p2, algorithm="ryser")                             # optional - sage.combinat
         [1 1 1 1 0 0]
         [1 1 0 0 0 0]
         [1 1 0 0 0 0]
         [0 0 0 0 0 0]
         sage: p1 = [3,3,2,1]
         sage: p2 = [3,2,2,1,1]
-        sage: print(gale_ryser_theorem(p1, p2, algorithm="gale"))  # not tested
+        sage: print(gale_ryser_theorem(p1, p2, algorithm="gale"))  # not tested         # optional - sage.combinat
         [1 1 1 0 0]
         [1 1 0 0 1]
         [1 0 1 0 0]
@@ -250,7 +253,7 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
     With `0` in the sequences, and with unordered inputs::
 
         sage: from sage.combinat.integer_vector import gale_ryser_theorem
-        sage: gale_ryser_theorem([3,3,0,1,1,0], [3,1,3,1,0], algorithm="ryser")
+        sage: gale_ryser_theorem([3,3,0,1,1,0], [3,1,3,1,0], algorithm="ryser")         # optional - sage.combinat
         [1 1 1 0 0]
         [1 0 1 1 0]
         [0 0 0 0 0]
@@ -258,7 +261,7 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
         [0 0 1 0 0]
         [0 0 0 0 0]
         sage: p1 = [3,1,1,1,1]; p2 = [3,2,2,0]
-        sage: gale_ryser_theorem(p1, p2, algorithm="ryser")
+        sage: gale_ryser_theorem(p1, p2, algorithm="ryser")                             # optional - sage.combinat
         [1 1 1 0]
         [1 0 0 0]
         [1 0 0 0]
@@ -285,17 +288,17 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
         ....:        print("Algorithm %s failed with this input:" % algorithm)
         ....:        print(s1, s2)
 
-        sage: for algorithm in ["gale", "ryser"]:             # long time
-        ....:    for i in range(50):                          # long time
-        ....:       test_algorithm(algorithm, 3, 10)          # long time
+        sage: for algorithm in ["gale", "ryser"]:             # long time               # optional - sage.combinat
+        ....:    for i in range(50):
+        ....:       test_algorithm(algorithm, 3, 10)
 
     Null matrix::
 
-        sage: gale_ryser_theorem([0,0,0],[0,0,0,0], algorithm="gale")
+        sage: gale_ryser_theorem([0,0,0],[0,0,0,0], algorithm="gale")                   # optional - sage.combinat
         [0 0 0 0]
         [0 0 0 0]
         [0 0 0 0]
-        sage: gale_ryser_theorem([0,0,0],[0,0,0,0], algorithm="ryser")
+        sage: gale_ryser_theorem([0,0,0],[0,0,0,0], algorithm="ryser")                  # optional - sage.combinat
         [0 0 0 0]
         [0 0 0 0]
         [0 0 0 0]
@@ -360,7 +363,7 @@ def gale_ryser_theorem(p1, p2, algorithm="gale",
         from sage.numerical.mip import MixedIntegerLinearProgram
         k1, k2=len(p1), len(p2)
         p = MixedIntegerLinearProgram(solver=solver)
-        b = p.new_variable(binary = True)
+        b = p.new_variable(binary=True)
         for (i,c) in enumerate(p1):
             p.add_constraint(p.sum([b[i,j] for j in range(k2)]) ==c)
         for (i,c) in enumerate(p2):
@@ -443,6 +446,7 @@ class IntegerVector(ClonableArray):
     """
     An integer vector.
     """
+
     def check(self):
         """
         Check to make sure this is a valid integer vector by making sure
@@ -453,9 +457,97 @@ class IntegerVector(ClonableArray):
             sage: IV = IntegerVectors()
             sage: elt = IV([1,2,1])
             sage: elt.check()
+
+        Check :trac:`34510`::
+
+            sage: IV3 = IntegerVectors(n=3)
+            sage: IV3([2,2])
+            Traceback (most recent call last):
+            ...
+            ValueError: [2, 2] doesn't satisfy correct constraints
+            sage: IVk3 = IntegerVectors(k=3)
+            sage: IVk3([2,2])
+            Traceback (most recent call last):
+            ...
+            ValueError: [2, 2] doesn't satisfy correct constraints
+            sage: IV33 = IntegerVectors(n=3, k=3)
+            sage: IV33([2,2])
+            Traceback (most recent call last):
+            ...
+            ValueError: [2, 2] doesn't satisfy correct constraints
         """
         if any(x < 0 for x in self):
             raise ValueError("all entries must be non-negative")
+        if self not in self.parent():
+            raise ValueError(f"{self} doesn't satisfy correct constraints")
+
+    def trim(self):
+        """
+        Remove trailing zeros from the integer vector.
+
+        EXAMPLES::
+
+            sage: IV = IntegerVectors()
+            sage: IV([5,3,5,1,0,0]).trim()
+            [5, 3, 5, 1]
+            sage: IV([5,0,5,1,0]).trim()
+            [5, 0, 5, 1]
+            sage: IV([4,3,3]).trim()
+            [4, 3, 3]
+            sage: IV([0,0,0]).trim()
+            []
+
+            sage: IV = IntegerVectors(k=4)
+            sage: v = IV([4,3,2,0]).trim(); v
+            [4, 3, 2]
+            sage: v.parent()
+            Integer vectors
+        """
+        P = IntegerVectors()
+        v = list(self)
+        if all(i == 0 for i in v):
+            return P.element_class(P, [], check=False)
+        while not v[-1]:
+            v = v[:-1]
+        return P.element_class(P, v, check=False)
+
+    def specht_module(self, base_ring=None):
+        r"""
+        Return the Specht module corresponding to ``self``.
+
+        EXAMPLES::
+
+            sage: SM = IntegerVectors()([2,0,1,0,2]).specht_module(QQ); SM              # optional - sage.combinat
+            Specht module of [(0, 0), (0, 1), (2, 0), (4, 0), (4, 1)] over Rational Field
+            sage: s = SymmetricFunctions(QQ).s()                                        # optional - sage.combinat
+            sage: s(SM.frobenius_image())                                               # optional - sage.combinat
+            s[2, 2, 1]
+        """
+        from sage.combinat.specht_module import SpechtModule
+        from sage.combinat.symmetric_group_algebra import SymmetricGroupAlgebra
+        if base_ring is None:
+            from sage.rings.rational_field import QQ
+            base_ring = QQ
+        R = SymmetricGroupAlgebra(base_ring, sum(self))
+        return SpechtModule(R, self)
+
+    def specht_module_dimension(self, base_ring=None):
+        r"""
+        Return the dimension of the Specht module corresponding to ``self``.
+
+        INPUT:
+
+        - ``BR`` -- (default: `\QQ`) the base ring
+
+        EXAMPLES::
+
+            sage: IntegerVectors()([2,0,1,0,2]).specht_module_dimension()               # optional - sage.combinat
+            5
+            sage: IntegerVectors()([2,0,1,0,2]).specht_module_dimension(GF(2))          # optional - sage.combinat sage.rings.finite_rings
+            5
+        """
+        from sage.combinat.specht_module import specht_module_rank
+        return specht_module_rank(self, base_ring)
 
 
 class IntegerVectors(Parent, metaclass=ClasscallMetaclass):
@@ -502,7 +594,7 @@ class IntegerVectors(Parent, metaclass=ClasscallMetaclass):
     Note that trailing zeros are ignored so that ``[3, 0]`` does not show
     up in the following list (since ``[3]`` does)::
 
-        sage: IntegerVectors(3, max_length=2).list()
+        sage: IntegerVectors(3, max_length=2).list()                                    # optional - sage.combinat
         [[3], [2, 1], [1, 2], [0, 3]]
 
     If ``n`` and ``k`` are both specified, then it returns the class
@@ -521,9 +613,9 @@ class IntegerVectors(Parent, metaclass=ClasscallMetaclass):
 
     Further examples::
 
-        sage: IntegerVectors(-1, 0, min_part = 1).list()
+        sage: IntegerVectors(-1, 0, min_part=1).list()
         []
-        sage: IntegerVectors(-1, 2, min_part = 1).list()
+        sage: IntegerVectors(-1, 2, min_part=1).list()
         []
         sage: IntegerVectors(0, 0, min_part=1).list()
         [[]]
@@ -574,14 +666,14 @@ class IntegerVectors(Parent, metaclass=ClasscallMetaclass):
 
     An example showing the same output by using IntegerListsLex::
 
-        sage: IntegerVectors(4, max_length=2).list()
+        sage: IntegerVectors(4, max_length=2).list()                                    # optional - sage.combinat
         [[4], [3, 1], [2, 2], [1, 3], [0, 4]]
-        sage: list(IntegerListsLex(4, max_length=2))
+        sage: list(IntegerListsLex(4, max_length=2))                                    # optional - sage.combinat
         [[4], [3, 1], [2, 2], [1, 3], [0, 4]]
 
     .. SEEALSO::
 
-        :class: `sage.combinat.integer_lists.invlex.IntegerListsLex`.
+        :class:`sage.combinat.integer_lists.invlex.IntegerListsLex`
     """
     @staticmethod
     def __classcall_private__(cls, n=None, k=None, **kwargs):
@@ -676,7 +768,7 @@ class IntegerVectors(Parent, metaclass=ClasscallMetaclass):
         if isinstance(x, IntegerVector):
             return True
 
-        if not isinstance(x, (list, tuple)):
+        if not isinstance(x, Sequence):
             return False
 
         for i in x:
@@ -691,6 +783,7 @@ class IntegerVectors_all(UniqueRepresentation, IntegerVectors):
     """
     Class of all integer vectors.
     """
+
     def __init__(self):
         """
         Initialize ``self``.
@@ -735,6 +828,7 @@ class IntegerVectors_n(UniqueRepresentation, IntegerVectors):
     """
     Integer vectors that sum to `n`.
     """
+
     def __init__(self, n):
         """
         TESTS::
@@ -807,6 +901,7 @@ class IntegerVectors_k(UniqueRepresentation, IntegerVectors):
     """
     Integer vectors of length `k`.
     """
+
     def __init__(self, k):
         """
         TESTS::
@@ -881,6 +976,7 @@ class IntegerVectors_nk(UniqueRepresentation, IntegerVectors):
     - Martin Albrecht
     - Mike Hansen
     """
+
     def __init__(self, n, k):
         """
         TESTS::
@@ -1015,10 +1111,15 @@ class IntegerVectors_nk(UniqueRepresentation, IntegerVectors):
             False
             sage: [3,2,2,1] in IntegerVectors(8, 4)
             True
-        """
-        if isinstance(x, IntegerVector) and x.parent() is self:
-            return True
 
+        Check :trac:`34510`::
+
+            sage: IV33 = IntegerVectors(n=3, k=3)
+            sage: IV33([0])
+            Traceback (most recent call last):
+            ...
+            ValueError: [0] doesn't satisfy correct constraints
+        """
         if not IntegerVectors.__contains__(self, x):
             return False
 
@@ -1186,6 +1287,7 @@ class IntegerVectorsConstraints(IntegerVectors):
     """
     Class of integer vectors subject to various constraints.
     """
+
     def __init__(self, n=None, k=None, **constraints):
         """
         Initialize ``self``.
@@ -1289,12 +1391,12 @@ class IntegerVectorsConstraints(IntegerVectors):
         """
         TESTS::
 
-            sage: [3,2,2,1] in IntegerVectors(8,4, min_part = 1)
+            sage: [3,2,2,1] in IntegerVectors(8, 4, min_part=1)                         # optional - sage.combinat
             True
-            sage: [3,2,2,1] in IntegerVectors(8,4, min_part = 2)
+            sage: [3,2,2,1] in IntegerVectors(8, 4, min_part=2)                         # optional - sage.combinat
             False
 
-            sage: [0,3,0,1,2] in IntegerVectors(6, max_length=3)
+            sage: [0,3,0,1,2] in IntegerVectors(6, max_length=3)                        # optional - sage.combinat
             False
         """
         if isinstance(x, IntegerVector) and x.parent() is self:
@@ -1318,17 +1420,17 @@ class IntegerVectorsConstraints(IntegerVectors):
 
         EXAMPLES::
 
-            sage: IntegerVectors(3, 3, min_part=1).cardinality()
+            sage: IntegerVectors(3, 3, min_part=1).cardinality()                        # optional - sage.combinat
             1
-            sage: IntegerVectors(5, 3, min_part=1).cardinality()
+            sage: IntegerVectors(5, 3, min_part=1).cardinality()                        # optional - sage.combinat
             6
-            sage: IntegerVectors(13, 4, max_part=4).cardinality()
+            sage: IntegerVectors(13, 4, max_part=4).cardinality()                       # optional - sage.combinat
             20
-            sage: IntegerVectors(k=4, max_part=3).cardinality()
+            sage: IntegerVectors(k=4, max_part=3).cardinality()                         # optional - sage.combinat
             256
-            sage: IntegerVectors(k=3, min_part=2, max_part=4).cardinality()
+            sage: IntegerVectors(k=3, min_part=2, max_part=4).cardinality()             # optional - sage.combinat
             27
-            sage: IntegerVectors(13, 4, min_part=2, max_part=4).cardinality()
+            sage: IntegerVectors(13, 4, min_part=2, max_part=4).cardinality()           # optional - sage.combinat
             16
         """
         if self.k is None:
@@ -1352,17 +1454,19 @@ class IntegerVectorsConstraints(IntegerVectors):
                     return Integer(binomial(self.n + self.k - 1, self.n))
                 # do by inclusion / exclusion on the number
                 # i of parts greater than m
-                return Integer(sum( (-1)**i * binomial(self.n+self.k-1-i*(m+1), self.k-1) \
-                    * binomial(self.k,i) for i in range(self.n/(m+1)+1) ))
+                n, k = self.n, self.k
+                return Integer(sum(
+                    (-1)**i * binomial(n + k - 1 - i * (m + 1), k - 1)
+                    * binomial(k, i) for i in range(self.n // (m + 1) + 1)))
         return ZZ.sum(ZZ.one() for x in self)
 
     def __iter__(self):
         """
         EXAMPLES::
 
-            sage: IntegerVectors(-1, 0, min_part = 1).list()
+            sage: IntegerVectors(-1, 0, min_part=1).list()
             []
-            sage: IntegerVectors(-1, 2, min_part = 1).list()
+            sage: IntegerVectors(-1, 2, min_part=1).list()
             []
             sage: IntegerVectors(0, 0, min_part=1).list()
             [[]]
@@ -1407,7 +1511,7 @@ class IntegerVectorsConstraints(IntegerVectors):
             sage: all(map(lambda x: x.cardinality() == len(x.list()), iv))
             True
             sage: essai = [[1,1,1], [2,5,6], [6,5,2]]
-            sage: iv = [ IntegerVectors(x[0], x[1], max_part = x[2]-1) for x in essai ]
+            sage: iv = [ IntegerVectors(x[0], x[1], max_part=x[2]-1) for x in essai ]
             sage: all(map(lambda x: x.cardinality() == len(x.list()), iv))
             True
         """
