@@ -224,7 +224,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         .. NOTE::
 
-            It is possible to bypass the automatic parent mechanism using:
+            It is possible to bypass the automatic parent mechanism using::
 
                 sage: t1 = OrderedTree.__new__(OrderedTree, Parent(), [])
                 sage: t1.__init__(Parent(), [])
@@ -353,26 +353,27 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         INPUT:
 
-        - ``bijection`` -- (default:``'Boussicault-Socci'``) is the name of the
+        - ``bijection`` -- (default: ``'Boussicault-Socci'``) is the name of the
           bijection to use. Possible values are ``'Boussicault-Socci'``,
           ``'via dyck and Delest-Viennot'``.
 
         EXAMPLES::
 
             sage: T = OrderedTree([[[], [[], [[]]]], [], [[[],[]]], [], []])
-            sage: T.to_parallelogram_polyomino( bijection='Boussicault-Socci' )
-            [[0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1], [1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0]]
+            sage: T.to_parallelogram_polyomino(bijection='Boussicault-Socci')           # optional - sage.combinat
+            [[0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1],
+             [1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0]]
             sage: T = OrderedTree( [] )
-            sage: T.to_parallelogram_polyomino()
+            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
             [[1], [1]]
             sage: T = OrderedTree( [[]] )
-            sage: T.to_parallelogram_polyomino()
+            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
             [[0, 1], [1, 0]]
             sage: T = OrderedTree( [[],[]] )
-            sage: T.to_parallelogram_polyomino()
+            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
             [[0, 1, 1], [1, 1, 0]]
             sage: T = OrderedTree( [[[]]] )
-            sage: T.to_parallelogram_polyomino()
+            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
             [[0, 0, 1], [1, 0, 0]]
         """
         if (bijection is None) or (bijection == 'Boussicault-Socci'):
@@ -391,19 +392,19 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             sage: T = OrderedTree(
             ....:     [[[], [[], [[]]]], [], [[[],[]]], [], []]
             ....: )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
             [[0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1], [1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0]]
             sage: T = OrderedTree( [] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
             [[1], [1]]
             sage: T = OrderedTree( [[]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
             [[0, 1], [1, 0]]
             sage: T = OrderedTree( [[],[]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
             [[0, 1, 1], [1, 1, 0]]
             sage: T = OrderedTree( [[[]]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
             [[0, 0, 1], [1, 0, 0]]
         """
         from sage.combinat.parallelogram_polyomino import ParallelogramPolyomino
@@ -500,13 +501,13 @@ class OrderedTree(AbstractClonableTree, ClonableList,
         EXAMPLES::
 
             sage: T = OrderedTree([[],[]])
-            sage: T.to_dyck_word()
+            sage: T.to_dyck_word()                                                      # optional - sage.combinat
             [1, 0, 1, 0]
             sage: T = OrderedTree([[],[[]]])
-            sage: T.to_dyck_word()
+            sage: T.to_dyck_word()                                                      # optional - sage.combinat
             [1, 0, 1, 1, 0, 0]
             sage: T = OrderedTree([[], [[], []], [[], [[]]]])
-            sage: T.to_dyck_word()
+            sage: T.to_dyck_word()                                                      # optional - sage.combinat
             [1, 0, 1, 1, 0, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0, 0]
         """
         word = []
@@ -674,7 +675,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             o o o
             |
             o
-            sage: p.plot()
+            sage: p.plot()                                                              # optional - sage.plot
             Graphics object consisting of 10 graphics primitives
 
         .. PLOT::
@@ -691,7 +692,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             2 3 5
               |
               4
-            sage: g.plot()
+            sage: g.plot()                                                              # optional - sage.plot
             Graphics object consisting of 10 graphics primitives
 
         .. PLOT::
@@ -1013,6 +1014,7 @@ class OrderedTrees_size(OrderedTrees):
         sage: S.list()
         [[[], []], [[[]]]]
     """
+
     def __init__(self, size):
         """
         TESTS::
@@ -1086,22 +1088,23 @@ class OrderedTrees_size(OrderedTrees):
 
         EXAMPLES::
 
-            sage: OrderedTrees(5).random_element() # random
+            sage: OrderedTrees(5).random_element()  # random                            # optional - sage.combinat
             [[[], []], []]
-            sage: OrderedTrees(0).random_element()
+            sage: OrderedTrees(0).random_element()                                      # optional - sage.combinat
             Traceback (most recent call last):
             ...
-            EmptySetError: There are no ordered trees of size 0
-            sage: OrderedTrees(1).random_element()
+            EmptySetError: there are no ordered trees of size 0
+            sage: OrderedTrees(1).random_element()                                      # optional - sage.combinat
             []
 
         TESTS::
 
-            sage: all(OrderedTrees(10).random_element() in OrderedTrees(10) for i in range(20))
+            sage: all(OrderedTrees(10).random_element() in OrderedTrees(10)             # optional - sage.combinat
+            ....:     for i in range(20))
             True
         """
         if self._size == 0:
-            raise EmptySetError("There are no ordered trees of size 0")
+            raise EmptySetError("there are no ordered trees of size 0")
         return CompleteDyckWords_size(self._size - 1).random_element().to_ordered_tree()
 
     def __iter__(self):
@@ -1348,6 +1351,7 @@ class LabelledOrderedTrees(UniqueRepresentation, Parent):
         sage: y.parent() is LOT
         True
     """
+
     def __init__(self, category=None):
         """
         TESTS::
