@@ -1,13 +1,13 @@
 r"""
 Ambient lattices and ambient spaces
 """
-#*****************************************************************************
+# ***************************************************************************
 #       Copyright (C) 2008-2009 Daniel Bump
 #       Copyright (C) 2008-2013 Nicolas M. Thiery <nthiery at users.sf.net>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ***************************************************************************
 from sage.misc.cachefunc import cached_method
 from sage.combinat.free_module import CombinatorialFreeModule
 from .weight_lattice_realizations import WeightLatticeRealizations
@@ -71,6 +71,7 @@ class AmbientSpace(CombinatorialFreeModule):
         sage: e1 == e2
         False
     """
+
     def __init__(self, root_system, base_ring, index_set=None):
         """
         EXAMPLES::
@@ -118,7 +119,7 @@ class AmbientSpace(CombinatorialFreeModule):
         T = self.cartan_type()
         D = T.symmetrizer()
         alpha = self.simple_roots()
-        for C in T.dynkin_diagram().connected_components():
+        for C in T.dynkin_diagram().connected_components(sort=False):
             tester.assertEqual(len( set( alpha[i].scalar(alpha[i]) / D[i] for i in C ) ), 1)
 
     # FIXME: attribute or method?
@@ -194,7 +195,6 @@ class AmbientSpace(CombinatorialFreeModule):
         else:
             return CombinatorialFreeModule.__call__(self, v)
 
-
     def __getitem__(self,i):
         """
         Note that indexing starts at 1.
@@ -353,6 +353,7 @@ class AmbientSpace(CombinatorialFreeModule):
         """
         return End(self).identity()
 
+
 class AmbientSpaceElement(CombinatorialFreeModule.Element):
     # For backward compatibility
     def _repr_(self):
@@ -487,7 +488,7 @@ class AmbientSpaceElement(CombinatorialFreeModule.Element):
         v0 = self.parent()._v0
         v1 = self.parent()._v1
         x = x - (x.inner_product(v0)/2)*v0
-        return  x - (x.inner_product(v1)/6)*v1
+        return x - (x.inner_product(v1)/6)*v1
 
     def to_ambient(self):
         r"""
@@ -506,4 +507,5 @@ class AmbientSpaceElement(CombinatorialFreeModule.Element):
         """
         return self
 
+
 AmbientSpace.Element = AmbientSpaceElement
