@@ -202,9 +202,8 @@ class Algebras(AlgebrasCategory):
                 raise ValueError("the weight does not have an integral scalar product with the coroot")
             alphai = P.simple_root(i)
             if n >= 0:
-                return  self.sum_of_monomials(weight-j*alphai for j in range(n + 1))
-            else:
-                return -self.sum_of_monomials(weight-j*alphai for j in range(n+1,0))
+                return self.sum_of_monomials(weight-j*alphai for j in range(n + 1))
+            return -self.sum_of_monomials(weight-j*alphai for j in range(n + 1, 0))
 
         def demazure_operators(self):
             r"""
@@ -317,7 +316,6 @@ class Algebras(AlgebrasCategory):
                     tester.assertEqual(result * (self.one()-emalphai),
                                        x - emalphai * x.map_support(s[i]))
 
-
         def demazure_lusztig_operator_on_basis(self, weight, i, q1, q2, convention="antidominant"):
             r"""
             Return the result of applying the `i`-th Demazure-Lusztig operator on ``weight``.
@@ -579,10 +577,9 @@ class Algebras(AlgebrasCategory):
                 ....:    T._test_relations(elements=elements)
             """
             T_on_basis = functools.partial(self.demazure_lusztig_operator_on_basis,
-                                           q1 = q1, q2 = q2, convention = convention)
+                                           q1=q1, q2=q2, convention=convention)
             return HeckeAlgebraRepresentation(self, T_on_basis, self.cartan_type(), q1, q2, side="left")
 
-
         def demazure_lusztig_operator_on_classical_on_basis(self, weight, i, q, q1, q2, convention="antidominant"):
             r"""
             Return the result of applying the `i`-th Demazure-Lusztig operator on the classical weight ``weight`` embedded at level 0.
@@ -1120,7 +1117,7 @@ class Algebras(AlgebrasCategory):
                                               T_on_basis,
                                               self.cartan_type().classical().dual().affine().dual(),
                                               q1, q2,
-                                              side = "left")
+                                              side="left")
 
     class ElementMethods:
 
@@ -1169,13 +1166,13 @@ class Algebras(AlgebrasCategory):
             TESTS::
 
                 sage: type(p.expand(F.gens()))
-                <class 'sage.rings.polynomial.laurent_polynomial.LaurentPolynomial_mpair'>
+                <class 'sage.rings.polynomial.laurent_polynomial_mpair.LaurentPolynomial_mpair'>
 
                 sage: p = KL.zero()
                 sage: p.expand(F.gens())
                 0
                 sage: type(p.expand(F.gens()))
-                <class 'sage.rings.polynomial.laurent_polynomial.LaurentPolynomial_mpair'>
+                <class 'sage.rings.polynomial.laurent_polynomial_mpair.LaurentPolynomial_mpair'>
             """
             codomain = alphabet[0].parent()
             return codomain.sum(c * prod(X**int(n)
