@@ -33,6 +33,7 @@ class AmbientSpace(ambient_space.AmbientSpace):
          1: (0, 0, 0, 1, 0),
          2: (0, 0, 0, 0, 1)}
     """
+
     def __init__(self, root_system, base_ring, index_set=None):
         """
         Initialize ``self``.
@@ -442,16 +443,18 @@ class AmbientSpace(ambient_space.AmbientSpace):
             """
             alpha = self.parent().simple_roots()
             l = self.parent().cartan_type().symmetrizer()
-            from sage.rings.semirings.all import NN
+            from sage.rings.semirings.non_negative_integer_semiring import NN
             return all(l[i] * self.inner_product(alpha[i]) in NN
                        for i in self.parent().index_set())
 
+
 class CartanType(SuperCartanType_standard):
     """
     Cartan Type `A(m|n)`.
 
     .. SEEALSO:: :func:`~sage.combinat.root_systems.cartan_type.CartanType`
     """
+
     def __init__(self, m, n):
         """
         EXAMPLES::
@@ -812,7 +815,7 @@ class CartanType(SuperCartanType_standard):
         """
         if node is None:
             node = lambda i: 'O'
-        ret  = "---".join(node(label(i)) for i in range(1,self.m+1))
+        ret = "---".join(node(label(i)) for i in range(1,self.m+1))
         if self.m == 0:
             if self.n == 0:
                 ret = "X"
