@@ -53,7 +53,7 @@ from sage.categories.homset import Hom
 from sage.categories.modules_with_basis import ModulesWithBasis
 from . import sfa
 from sage.combinat.partition import Partitions_n, _Partitions
-from sage.matrix.all import MatrixSpace
+from sage.matrix.matrix_space import MatrixSpace
 from sage.rings.rational_field import QQ
 from sage.misc.misc_c import prod
 from sage.misc.cachefunc import cached_function
@@ -539,10 +539,12 @@ class Macdonald(UniqueRepresentation):
         """
         return MacdonaldPolynomials_s(self)
 
+
 QQqt = QQ['q,t'].fraction_field()
 
 ##############################################
 
+
 def c1(part, q, t):
     r"""
     This function returns the qt-Hall scalar product between ``J(part)``
@@ -652,6 +654,7 @@ def cmunu1(mu, nu):
                       / (q**nu.arm_length(s, 0) - t**(nu.leg_length(s, 0)+1))
                       for s in range(len(nu._list)) ))
 
+
 @cached_function
 def cmunu(mu, nu):
     r"""
@@ -715,6 +718,8 @@ def cmunu(mu, nu):
                 for al in nu.up()) / Bmu_skew(mu, nulist))
 
 #Generic MacdonaldPolynomials
+
+
 class MacdonaldPolynomials_generic(sfa.SymmetricFunctionAlgebra_generic):
 
     def __init__(self, macdonald):
@@ -985,6 +990,8 @@ class MacdonaldPolynomials_generic(sfa.SymmetricFunctionAlgebra_generic):
             return parent(Ht(self).nabla(power=power))
 
 #P basis
+
+
 class MacdonaldPolynomials_p(MacdonaldPolynomials_generic):
     def __init__(self, macdonald):
         r"""
@@ -1407,6 +1414,7 @@ class MacdonaldPolynomials_h(MacdonaldPolynomials_generic):
     class Element(MacdonaldPolynomials_generic.Element):
         pass
 
+
 class MacdonaldPolynomials_ht(MacdonaldPolynomials_generic):
     def __init__(self, macdonald):
         r"""
@@ -1700,6 +1708,7 @@ class MacdonaldPolynomials_ht(MacdonaldPolynomials_generic):
             f = lambda part: t**(part.weighted_size()*power)*q**(part.conjugate().weighted_size()*power)*Ht(part)
             return P(Ht._apply_module_morphism(selfHt, f))
 
+
 class MacdonaldPolynomials_s(MacdonaldPolynomials_generic):
     def __init__(self, macdonald):
         r"""
@@ -1821,7 +1830,6 @@ class MacdonaldPolynomials_s(MacdonaldPolynomials_generic):
                               self._s_to_self_cache,
                               to_other_function=self._to_s)
 
-
     class Element(MacdonaldPolynomials_generic.Element):
 
         def _creation_by_determinant_helper(self, k, part):
