@@ -7,6 +7,7 @@ AUTHORS:
 - Mike Hansen: Initial version
 - Travis Scrimshaw, Arthur Lubovsky (2013-02-11):
   Factored out ``CombinatorialClass``
+- Trevor K. Karn (2022-08-03): added `backward_slide`
 """
 # ****************************************************************************
 #       Copyright (C) 2007 Mike Hansen <mhansen@gmail.com>,
@@ -35,9 +36,9 @@ from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.arith.all import factorial
+from sage.arith.misc import factorial
 from sage.rings.infinity import PlusInfinity
-from sage.matrix.all import zero_matrix
+from sage.matrix.special import zero_matrix
 
 from sage.structure.list_clone import ClonableList
 from sage.combinat.partition import Partition
@@ -147,11 +148,11 @@ class SkewTableau(ClonableList,
 
         INPUT:
 
-        ``other`` -- the element that ``self`` is compared to
+        - ``other`` -- the element that ``self`` is compared to
 
         OUTPUT:
 
-        A Boolean.
+        A boolean.
 
         TESTS::
 
@@ -160,6 +161,10 @@ class SkewTableau(ClonableList,
             False
             sage: t == SkewTableaux()([[None,1,2]])
             True
+            sage: t == [(None,1,2)]
+            True
+            sage: t == [[None,1,2]]
+            True
 
             sage: s = SkewTableau([[1,2]])
             sage: s == 0
@@ -170,7 +175,7 @@ class SkewTableau(ClonableList,
         if isinstance(other, (Tableau, SkewTableau)):
             return list(self) == list(other)
         else:
-            return list(self) == other
+            return list(self) == other or list(list(row) for row in self) == other
 
     def __ne__(self, other):
         r"""
@@ -180,22 +185,33 @@ class SkewTableau(ClonableList,
 
         INPUT:
 
-        ``other`` -- the element that ``self`` is compared to
+        - ``other`` -- the element that ``self`` is compared to
 
         OUTPUT:
 
-        A Boolean.
+        A boolean.
 
         TESTS::
 
-            sage: t = Tableau([[2,3],[1]])
+            sage: t = SkewTableau([[None,1,2]])
             sage: t != []
             True
         """
-        if isinstance(other, (Tableau, SkewTableau)):
-            return list(self) != list(other)
-        else:
-            return list(self) != other
+        return not (self == other)
+
+    def __hash__(self):
+        """
+        Return the hash of ``self``.
+
+        EXAMPLES:
+
+        Check that :trac:`35137` is fixed::
+
+            sage: t = SkewTableau([[None,1,2]])
+            sage: hash(t) == hash(tuple(t))
+            True
+        """
+        return hash(tuple(self))
 
     def check(self):
         r"""
@@ -907,6 +923,140 @@ class SkewTableau(ClonableList,
             return (SkewTableau(new_st), (spotl, spotc))
         return SkewTableau(new_st)
 
+    def backward_slide(self, corner=None):
+        r"""
+        Apply a backward jeu de taquin slide on the specified outside
+        ``corner`` of ``self``.
+
+        Backward jeu de taquin slides are defined in Section 3.7 of
+        [Sag2001]_.
+
+        .. WARNING::
+
+            The :meth:`inner_corners` and :meth:`outer_corners` are the
+            :meth:`sage.combinat.partition.Partition.corners` of the inner and
+            outer partitions of the skew shape. They are different from the
+            inner/outer corners defined in [Sag2001]_.
+
+            The "inner corners" of [Sag2001]_ may be found by calling
+            :meth:`outer_corners`. The "outer corners" of [Sag2001]_ may be
+            found by calling ``self.outer_shape().outside_corners()``.
+
+        EXAMPLES::
+
+            sage: T = SkewTableaux()([[2, 2], [4, 4], [5]])
+            sage: Tableaux.options.display='array'
+            sage: Q = T.backward_slide(); Q
+            . 2 2
+            4 4
+            5
+            sage: Q.backward_slide((1, 2))
+            . 2 2
+            . 4 4
+            5
+            sage: Q.reverse_slide((1, 2)) == Q.backward_slide((1, 2))
+            True
+
+            sage: T = SkewTableaux()([[1, 3],[3],[5]]); T
+            1 3
+            3
+            5
+            sage: T.reverse_slide((1,1))
+            . 1
+            3 3
+            5
+
+        TESTS::
+
+            sage: T = SkewTableaux()([[2, 2], [4, 4], [5]])
+            sage: Q = T.backward_slide((0, 2))
+            sage: Q.backward_slide((2,1))
+            . 2 2
+            . 4
+            4 5
+            sage: Q.backward_slide((3,0))
+            . 2 2
+            . 4
+            4
+            5
+            sage: Q = T.backward_slide((2,1)); Q
+            . 2
+            2 4
+            4 5
+            sage: Q.backward_slide((3,0))
+            . 2
+            . 4
+            2 5
+            4
+            sage: Q = T.backward_slide((3,0)); Q
+            . 2
+            2 4
+            4
+            5
+            sage: Q.backward_slide((4,0))
+            . 2
+            . 4
+            2
+            4
+            5
+            sage: Tableaux.options.display='list'
+        """
+        new_st = self.to_list()
+        inner_outside_corners = self.inner_shape().outside_corners()
+        outer_outisde_corners = self.outer_shape().outside_corners()
+        if corner is not None:
+            if tuple(corner) not in outer_outisde_corners:
+                raise ValueError("corner must be an outside corner"
+                                 " of the outer shape")
+        else:
+            if not outer_outisde_corners:
+                return self
+            else:
+                corner = outer_outisde_corners[0]
+
+        i, j = corner
+
+        # add the empty cell
+        # the column only matters if it is zeroth column, in which
+        # case we need to add a new row.
+        if not j:
+            new_st.append(list())
+        new_st[i].append(None)
+
+        while (i, j) not in inner_outside_corners:
+            # get the value of the cell above the temporarily empty cell (if
+            # it exists)
+            if i > 0:
+                P_up = new_st[i-1][j]
+            else:
+                P_up = -1  # a dummy value less than all positive numbers
+
+            # get the value of the cell to the left of the temp. empty cell
+            # (if it exists)
+            if j > 0:
+                P_left = new_st[i][j-1]
+            else:
+                P_left = -1  # a dummy value less than all positive numbers
+
+            # get the next cell
+            # p_left will always be positive, but if P_left
+            # and P_up are both None, then it will return
+            # -1, which doesn't trigger the conditional
+            if P_left > P_up:
+                new_st[i][j] = P_left
+                i, j = (i, j - 1)
+            else:  # if they are equal, we slide up
+                new_st[i][j] = P_up
+                i, j = (i - 1, j)
+        # We don't need to reset the intermediate cells inside the loop
+        # because the conditional above will continue to overwrite it until
+        # the while loop terminates. We do need to reset it at the end.
+        new_st[i][j] = None
+
+        return SkewTableaux()(new_st)
+
+    reverse_slide = backward_slide
+
     def rectify(self, algorithm=None):
         """
         Return a :class:`StandardTableau`, :class:`SemistandardTableau`,
@@ -1647,6 +1797,7 @@ class SkewTableaux(UniqueRepresentation, Parent):
     r"""
     Class of all skew tableaux.
     """
+
     def __init__(self, category=None):
         """
         Initialize ``self``.
@@ -1799,7 +1950,7 @@ class StandardSkewTableaux(SkewTableaux):
 
         sage: S = StandardSkewTableaux(2); S
         Standard skew tableaux of size 2
-        sage: S.cardinality()
+        sage: S.cardinality()                                                           # optional - sage.modules
         4
 
     ::
@@ -1833,7 +1984,7 @@ class StandardSkewTableaux(SkewTableaux):
         elif skp in SkewPartitions():
             return StandardSkewTableaux_shape(skp)
         else:
-            raise TypeError("Invalid argument")
+            raise TypeError("invalid argument")
 
     def __contains__(self, x):
         """
@@ -1858,12 +2009,13 @@ class StandardSkewTableaux_all(StandardSkewTableaux):
     """
     Class of all standard skew tableaux.
     """
+
     def __init__(self):
         """
         EXAMPLES::
 
             sage: s = StandardSkewTableaux()
-            sage: TestSuite(s).run()
+            sage: TestSuite(s).run()                                                    # optional - sage.graphs
         """
         StandardSkewTableaux.__init__(self, category=InfiniteEnumeratedSets())
 
@@ -1885,7 +2037,7 @@ class StandardSkewTableaux_all(StandardSkewTableaux):
         EXAMPLES::
 
             sage: it = StandardSkewTableaux().__iter__()
-            sage: [next(it) for x in range(10)]
+            sage: [next(it) for x in range(10)]                                         # optional - sage.graphs
             [[],
              [[1]],
              [[1, 2]], [[1], [2]], [[None, 2], [1]], [[None, 1], [2]],
@@ -1902,12 +2054,13 @@ class StandardSkewTableaux_size(StandardSkewTableaux):
     """
     Standard skew tableaux of a fixed size `n`.
     """
+
     def __init__(self, n):
         """
         EXAMPLES::
 
             sage: S = StandardSkewTableaux(3)
-            sage: TestSuite(S).run()
+            sage: TestSuite(S).run()                                                    # optional - sage.graphs
         """
         self.n = n
         StandardSkewTableaux.__init__(self, category=FiniteEnumeratedSets())
@@ -1925,13 +2078,13 @@ class StandardSkewTableaux_size(StandardSkewTableaux):
         """
         EXAMPLES::
 
-            sage: StandardSkewTableaux(1).cardinality()
+            sage: StandardSkewTableaux(1).cardinality()                                 # optional - sage.modules
             1
-            sage: StandardSkewTableaux(2).cardinality()
+            sage: StandardSkewTableaux(2).cardinality()                                 # optional - sage.modules
             4
-            sage: StandardSkewTableaux(3).cardinality()
+            sage: StandardSkewTableaux(3).cardinality()                                 # optional - sage.modules
             24
-            sage: StandardSkewTableaux(4).cardinality()
+            sage: StandardSkewTableaux(4).cardinality()                                 # optional - sage.modules
             194
         """
         count = 0
@@ -1948,10 +2101,10 @@ class StandardSkewTableaux_size(StandardSkewTableaux):
 
         EXAMPLES::
 
-            sage: StandardSkewTableaux(2).list()
+            sage: StandardSkewTableaux(2).list()                                        # optional - sage.graphs
             [[[1, 2]], [[1], [2]], [[None, 2], [1]], [[None, 1], [2]]]
 
-            sage: StandardSkewTableaux(3).list()
+            sage: StandardSkewTableaux(3).list()                                        # optional - sage.graphs
             [[[1, 2, 3]],
              [[1, 2], [3]], [[1, 3], [2]],
              [[None, 2, 3], [1]], [[None, 1, 2], [3]], [[None, 1, 3], [2]],
@@ -1996,7 +2149,7 @@ class StandardSkewTableaux_shape(StandardSkewTableaux):
         TESTS::
 
             sage: S = StandardSkewTableaux([[3, 2, 1], [1, 1]])
-            sage: TestSuite(S).run()
+            sage: TestSuite(S).run()                                                    # optional - sage.graphs sage.modules
         """
         self.skp = skp
         StandardSkewTableaux.__init__(self, category=FiniteEnumeratedSets())
@@ -2020,7 +2173,7 @@ class StandardSkewTableaux_shape(StandardSkewTableaux):
 
         EXAMPLES::
 
-            sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).cardinality()
+            sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).cardinality()               # optional - sage.modules
             8
         """
         outer, inner = self.skp
@@ -2047,7 +2200,7 @@ class StandardSkewTableaux_shape(StandardSkewTableaux):
 
         EXAMPLES::
 
-            sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).list()
+            sage: StandardSkewTableaux([[3, 2, 1], [1, 1]]).list()                      # optional - sage.graphs
             [[[None, 2, 3], [None, 4], [1]],
              [[None, 1, 2], [None, 3], [4]],
              [[None, 1, 2], [None, 4], [3]],
@@ -2180,7 +2333,7 @@ class SemistandardSkewTableaux(SkewTableaux):
         if p is None:
             if mu is None:
                 return SemistandardSkewTableaux_all(max_entry)
-            raise ValueError("You must specify either a size or a shape")
+            raise ValueError("you must specify either a size or a shape")
 
         if isinstance(p, (int, Integer)):
             if mu is None:
@@ -2194,7 +2347,7 @@ class SemistandardSkewTableaux(SkewTableaux):
             else:
                 return SemistandardSkewTableaux_shape_weight(p, mu)
 
-        raise ValueError("Invalid input")
+        raise ValueError("invalid input")
 
     def __contains__(self, x):
         """
@@ -2224,6 +2377,7 @@ class SemistandardSkewTableaux_all(SemistandardSkewTableaux):
     Class of all semistandard skew tableaux, possibly with a given
     maximum entry.
     """
+
     def __init__(self, max_entry):
         """
         Initialize ``self``.
@@ -2312,6 +2466,7 @@ class SemistandardSkewTableaux_size(SemistandardSkewTableaux):
     Class of all semistandard skew tableaux of a fixed size `n`,
     possibly with a given maximum entry.
     """
+
     def __init__(self, n, max_entry):
         """
         EXAMPLES::
@@ -2585,6 +2740,7 @@ class SkewTableau_class(SkewTableau):
     """
     This exists solely for unpickling ``SkewTableau_class`` objects.
     """
+
     def __setstate__(self, state):
         r"""
         Unpickle old ``SkewTableau_class`` objects.
