@@ -1,7 +1,7 @@
 r"""
 Subsets
 
-The set of subsets of a finite set. The set can be given as a list or a Set
+The set of subsets of a finite set. The set can be given as a list or a :class:`Set`
 or else as an integer `n` which encodes the set `\{1,2,...,n\}`.
 See :class:`Subsets` for more information and examples.
 
@@ -38,8 +38,7 @@ from sage.structure.parent import Parent
 from sage.structure.element import Element
 
 from sage.sets.set import Set, Set_object_enumerated
-from sage.arith.all import binomial
-from sage.misc.misc import _stable_uniq as uniq
+from sage.arith.misc import binomial
 from sage.rings.integer_ring import ZZ
 from sage.rings.integer import Integer
 from . import combination
@@ -169,6 +168,7 @@ def Subsets(s, k=None, submultiset=False):
         else:
             return Subsets_sk(s, k)
 
+
 class Subsets_s(Parent):
     r"""
     Subsets of a given set.
@@ -185,11 +185,11 @@ class Subsets_s(Parent):
          {1, 2, 3}, {1, 2, 4}, {1, 3, 4}, {2, 3, 4},
          {1, 2, 3, 4}]
 
-        sage: S = Subsets(Subsets(Subsets(GF(3)))); S
+        sage: S = Subsets(Subsets(Subsets(GF(3)))); S                                   # optional - sage.rings.finite_rings
         Subsets of Subsets of Subsets of Finite Field of size 3
-        sage: S.cardinality()
+        sage: S.cardinality()                                                           # optional - sage.rings.finite_rings
         115792089237316195423570985008687907853269984665640564039457584007913129639936
-        sage: S.unrank(3149254230)  # random
+        sage: S.unrank(3149254230)  # random                                            # optional - sage.rings.finite_rings
         {{{1}, {0, 2}}, {{0, 1, 2}, {0, 1}, {1}, {1, 2}},
          {{2}, {1, 2}, {0, 1, 2}, {0, 2}, {1}, {}},
          {{1, 2}, {0}},
@@ -247,7 +247,7 @@ class Subsets_s(Parent):
 
         EXAMPLES::
 
-            sage: Subsets(GF(13)).underlying_set()
+            sage: Subsets(GF(13)).underlying_set()                                      # optional - sage.rings.finite_rings
             {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
         """
         return self.element_class(self._s)
@@ -341,9 +341,9 @@ class Subsets_s(Parent):
             sage: Subsets(3).cardinality()
             8
 
-        TESTS::
+        TESTS:
 
-            ``__len__`` should return a Python int.
+        ``__len__`` should return a Python int::
 
             sage: S = Subsets(Set([1,2,3]))
             sage: len(S)
@@ -549,16 +549,17 @@ class Subsets_s(Parent):
         EXAMPLES::
 
             sage: X = Subsets([7,8,9])
-            sage: X.lattice()
+            sage: X.lattice()                                                           # optional - sage.combinat sage.graphs
             Finite lattice containing 8 elements
             sage: Y = Subsets(0)
-            sage: Y.lattice()
+            sage: Y.lattice()                                                           # optional - sage.combinat sage.graphs
             Finite lattice containing 1 elements
 
         """
         S = self.underlying_set()
         return S.subsets_lattice()
 
+
 class Subsets_sk(Subsets_s):
     r"""
     Subsets of fixed size of a set.
@@ -584,6 +585,7 @@ class Subsets_sk(Subsets_s):
         ...
         ValueError: {0} not in Subsets of {0, 1, 2, 5, 7} of size 3
     """
+
     def __init__(self, s, k):
         """
         TESTS::
@@ -871,8 +873,8 @@ class Subsets_sk(Subsets_s):
 
 def dict_to_list(d):
     r"""
-    Return a list whose elements are the elements of i of d repeated with
-    multiplicity d[i].
+    Return a list whose elements are the elements of ``i`` of ``d`` repeated with
+    multiplicity ``d[i]``.
 
     EXAMPLES::
 
@@ -1059,7 +1061,7 @@ class SubMultiset_s(Parent):
             sage: len(S.list())
             24
         """
-        from sage.all import prod
+        from sage.misc.misc_c import prod
         return Integer(prod(k + 1 for k in self._d.values()))
 
     def random_element(self):
@@ -1127,8 +1129,7 @@ class SubMultiset_s(Parent):
              [1, 2, 2, 3]]
         """
         for k in range(len(self._l) + 1):
-            for s in SubMultiset_sk(self._l, k):
-                yield s
+            yield from SubMultiset_sk(self._l, k)
 
     def __call__(self, el):
         r"""
@@ -1163,10 +1164,9 @@ class SubMultiset_s(Parent):
         return e
 
 
-
 class SubMultiset_sk(SubMultiset_s):
     """
-    The combinatorial class of the subsets of size k of a multiset s.  Note
+    The combinatorial class of the subsets of size ``k`` of a multiset ``s``.  Note
     that each subset is represented by a list of the elements rather than a
     set since we can have multiplicities (no multiset data structure yet in
     sage).
@@ -1185,6 +1185,7 @@ class SubMultiset_sk(SubMultiset_s):
         sage: [sub for sub in S]
         [[1, 2], [1, 3], [2, 3], [3, 3]]
         """
+
     def __init__(self, s, k):
         """
         TESTS::
@@ -1288,7 +1289,7 @@ class SubMultiset_sk(SubMultiset_s):
 
     def random_element(self):
         r"""
-        Return a random submultiset of given length
+        Return a random submultiset of given length.
 
         EXAMPLES::
 
@@ -1468,3 +1469,93 @@ class SubsetsSorted(Subsets_s):
             [(), (0,), (1,), (2,), (0, 1), (0, 2), (1, 2), (0, 1, 2)]
         """
         return self.element_class(sorted(set(x)))
+
+
+def powerset(X):
+    r"""
+    Iterator over the *list* of all subsets of the iterable ``X``, in no
+    particular order. Each list appears exactly once, up to order.
+
+    INPUT:
+
+    -  ``X`` - an iterable
+
+    OUTPUT: iterator of lists
+
+    EXAMPLES::
+
+        sage: list(powerset([1,2,3]))
+        [[], [1], [2], [1, 2], [3], [1, 3], [2, 3], [1, 2, 3]]
+        sage: [z for z in powerset([0,[1,2]])]
+        [[], [0], [[1, 2]], [0, [1, 2]]]
+
+    Iterating over the power set of an infinite set is also allowed::
+
+        sage: i = 0
+        sage: L = []
+        sage: for x in powerset(ZZ):
+        ....:     if i > 10:
+        ....:         break
+        ....:     else:
+        ....:         i += 1
+        ....:     L.append(x)
+        sage: print(" ".join(str(x) for x in L))
+        [] [0] [1] [0, 1] [-1] [0, -1] [1, -1] [0, 1, -1] [2] [0, 2] [1, 2]
+
+    You may also use subsets as an alias for powerset::
+
+        sage: subsets([1,2,3])
+        <generator object ...powerset at 0x...>
+        sage: list(subsets([1,2,3]))
+        [[], [1], [2], [1, 2], [3], [1, 3], [2, 3], [1, 2, 3]]
+
+        The reason we return lists instead of sets is that the elements of
+        sets must be hashable and many structures on which one wants the
+        powerset consist of non-hashable objects.
+
+    AUTHORS:
+
+    - William Stein
+
+    - Nils Bruin (2006-12-19): rewrite to work for not-necessarily
+      finite objects X.
+    """
+    yield []
+    pairs = []
+    power2 = 1
+    for x in X:
+        pairs.append((power2, x))
+        next_power2 = power2 << 1
+        for w in range(power2, next_power2):
+            yield [x for m, x in pairs if m & w]
+        power2 = next_power2
+
+
+subsets = powerset
+
+
+def uniq(L):
+    """
+    Iterate over the elements of ``L``, yielding every element at most
+    once: keep only the first occurrence of any item.
+
+    The items must be hashable.
+
+    INPUT:
+
+    - ``L`` -- iterable
+
+    EXAMPLES::
+
+        sage: L = [1, 1, 8, -5, 3, -5, 'a', 'x', 'a']
+        sage: it = uniq(L); it
+        <generator object uniq at ...>
+        sage: list(it)
+        [1, 8, -5, 3, 'a', 'x']
+    """
+    seen = set()
+    for x in L:
+        if x in seen:
+            continue
+        yield x
+        seen.add(x)
