@@ -109,8 +109,8 @@ It has 65 different solutions up to isometries::
 Showing one solution::
 
     sage: solution = next(T.solve())                                  # long time
-    sage: G = sum([piece.show2d() for piece in solution], Graphics()) # long time
-    sage: G.show(aspect_ratio=1, axes=False)                          # long time
+    sage: G = sum([piece.show2d() for piece in solution], Graphics()) # long time       # optional - sage.plot
+    sage: G.show(aspect_ratio=1, axes=False)                          # long time       # optional - sage.plot
 
 1d Easy Example
 ---------------
@@ -162,8 +162,8 @@ one solution::
 
     sage: T = TilingSolver(L, box=(8,8), reflection=True)
     sage: solution = next(T.solve())                                  # long time (7s)
-    sage: G = sum([piece.show2d() for piece in solution], Graphics()) # long time (<1s)
-    sage: G.show(aspect_ratio=1, axes=False)                          # long time (2s)
+    sage: G = sum([piece.show2d() for piece in solution], Graphics()) # long time (<1s) # optional - sage.plot
+    sage: G.show(aspect_ratio=1, axes=False)                          # long time (2s)  # optional - sage.plot
 
 Compute the number of solutions::
 
@@ -218,8 +218,8 @@ Donald Knuth [Knuth1]_ considered the problem of packing 45 Y pentaminoes into a
     sage: T.number_of_solutions()
     10
     sage: solution = next(T.solve())
-    sage: G = sum([p.show2d() for p in solution], Graphics())
-    sage: G.show(aspect_ratio=1)                       # long time (2s)
+    sage: G = sum([p.show2d() for p in solution], Graphics())                           # optional - sage.plot
+    sage: G.show(aspect_ratio=1)                       # long time (2s)                 # optional - sage.plot
 
 ::
 
@@ -240,16 +240,15 @@ Animation of the solutions::
     sage: from sage.combinat.tiling import Polyomino, TilingSolver
     sage: Y = Polyomino([(0,0),(1,0),(2,0),(3,0),(2,1)], color='yellow')
     sage: T = TilingSolver([Y], box=(15,15), reusable=True, reflection=True)
-    sage: a = T.animate(stop=40)            # long time  # optional -- ImageMagick
-    sage: a                                 # long time  # optional -- ImageMagick
+    sage: a = T.animate(stop=40); a              # long time  # optional -- ImageMagick sage.plot
     Animation with 40 frames
 
 Incremental animation of the solutions (one piece is removed/added at a time)::
 
-    sage: a = T.animate('incremental', stop=40)   # long time  # optional -- ImageMagick
-    sage: a                                       # long time  # optional -- ImageMagick
+    sage: a = T.animate('incremental', stop=40)  # long time  # optional -- ImageMagick sage.plot
+    sage: a                                      # long time  # optional -- ImageMagick sage.plot
     Animation with 40 frames
-    sage: a.show(delay=50, iterations=1)          # long time  # optional -- ImageMagick
+    sage: a.show(delay=50, iterations=1)         # long time  # optional -- ImageMagick sage.plot
 
 5d Easy Example
 ---------------
@@ -467,6 +466,8 @@ def ncube_isometry_group_cosets(n, orientation_preserving=True):
 ##############################
 # Class Polyomino
 ##############################
+
+
 class Polyomino(SageObject):
     r"""
     A polyomino in `\ZZ^d`.
@@ -489,6 +490,7 @@ class Polyomino(SageObject):
         sage: Polyomino([(0,0,0), (0,1,0), (1,1,0), (1,1,1)], color='blue')
         Polyomino: [(0, 0, 0), (0, 1, 0), (1, 1, 0), (1, 1, 1)], Color: blue
     """
+
     def __init__(self, coords, color='gray', dimension=None):
         r"""
         Constructor.
@@ -1217,8 +1219,7 @@ class Polyomino(SageObject):
         all_distinct_cano = self.canonical_isometric_copies(orientation_preserving,
                                                             mod_box_isometries)
         for cano in all_distinct_cano:
-            for t in cano.translated_copies(box=box):
-                yield t
+            yield from cano.translated_copies(box=box)
 
     def isometric_copies_intersection(self, box, orientation_preserving=True):
         r"""
@@ -1386,7 +1387,7 @@ class Polyomino(SageObject):
 
             sage: from sage.combinat.tiling import Polyomino
             sage: p = Polyomino([(0,0,0), (0,1,0), (1,1,0), (1,1,1)], color='blue')
-            sage: p.show3d()                # long time (2s)
+            sage: p.show3d()                # long time (2s)                            # optional -- sage.plot
             Graphics3d Object
         """
         assert self._dimension == 3, "Dimension of the polyomino must be 3."
@@ -1419,7 +1420,7 @@ class Polyomino(SageObject):
 
             sage: from sage.combinat.tiling import Polyomino
             sage: p = Polyomino([(0,0),(1,0),(1,1),(1,2)], color='deeppink')
-            sage: p.show2d()              # long time (0.5s)
+            sage: p.show2d()              # long time (0.5s)                            # optional -- sage.plot
             Graphics object consisting of 17 graphics primitives
         """
         assert self._dimension == 2, "Dimension of the polyomino must be 2."
@@ -1440,7 +1441,6 @@ class Polyomino(SageObject):
             G += line(edge, color=color, thickness=thickness)
         return G
 
-
     def self_surrounding(self, radius, remove_incomplete_copies=True,
                          ncpus=None):
         r"""
@@ -1471,12 +1471,12 @@ class Polyomino(SageObject):
             ....: (1, 3), (1, 4), (1, 5), (1, 6), (1, 7), (1, 8), (2, 0), (2, 2),
             ....: (2, 3), (2, 5), (2, 6), (2, 8)])
             sage: solution = H.self_surrounding(8)
-            sage: G = sum([p.show2d() for p in solution], Graphics())
+            sage: G = sum([p.show2d() for p in solution], Graphics())                   # optional - sage.plot
 
         ::
 
             sage: solution = H.self_surrounding(8, remove_incomplete_copies=False)
-            sage: G = sum([p.show2d() for p in solution], Graphics())
+            sage: G = sum([p.show2d() for p in solution], Graphics())                   # optional - sage.plot
 
         """
         # Define the box to tile
@@ -1594,6 +1594,7 @@ class TilingSolver(SageObject):
         ...
         NotImplementedError: When reflection is allowed and rotation is not allowed
     """
+
     def __init__(self, pieces, box, rotation=True,
                  reflection=False, reusable=False, outside=False):
         r"""
@@ -2060,7 +2061,7 @@ class TilingSolver(SageObject):
 
         TESTS:
 
-        We check that ticket :trac:`32252` is fixed and that colors of
+        We check that issue :trac:`32252` is fixed and that colors of
         polyominoes are properly recovered::
 
             sage: v = Polyomino([(0, 0), (0, 1)], color="blue")
@@ -2422,38 +2423,38 @@ class TilingSolver(SageObject):
             sage: from sage.combinat.tiling import Polyomino, TilingSolver
             sage: y = Polyomino([(0,0),(1,0),(2,0),(3,0),(2,1)], color='cyan')
             sage: T = TilingSolver([y], box=(5,10), reusable=True, reflection=True)
-            sage: a = T.animate()
-            sage: a          # optional -- ImageMagick    # long time
+            sage: a = T.animate()                                                       # optional - sage.plot
+            sage: a          # optional -- ImageMagick    # long time                   # optional - sage.plot
             Animation with 10 frames
 
         Include partial solutions (common prefix between two consecutive
         solutions)::
 
-            sage: a = T.animate('common_prefix')
-            sage: a          # optional -- ImageMagick    # long time
+            sage: a = T.animate('common_prefix')                                        # optional - sage.plot
+            sage: a          # optional -- ImageMagick    # long time                   # optional - sage.plot
             Animation with 19 frames
 
         Incremental solutions (one piece removed or added at a time)::
 
-            sage: a = T.animate('incremental')      # long time (2s)
-            sage: a                                 # long time (2s)  # optional -- ImageMagick
+            sage: a = T.animate('incremental')      # long time (2s)                    # optional - sage.plot
+            sage: a                                 # long time (2s)  # optional -- ImageMagick sage.plot
             Animation with 123 frames
 
         ::
 
-            sage: a.show()           # optional -- ImageMagick   # long time
+            sage: a.show()           # optional -- ImageMagick   # long time            # optional - sage.plot
 
         The ``show`` function takes arguments to specify the delay between
         frames (measured in hundredths of a second, default value 20) and
         the number of iterations (default value 0, which means to iterate
         forever). To iterate 4 times with half a second between each frame::
 
-            sage: a.show(delay=50, iterations=4)  # optional -- ImageMagick # long time
+            sage: a.show(delay=50, iterations=4)  # optional -- ImageMagick # long time # optional - sage.plot
 
         Limit the number of frames::
 
-            sage: a = T.animate('incremental', stop=13)     # not tested
-            sage: a                                         # not tested
+            sage: a = T.animate('incremental', stop=13)     # not tested                # optional - sage.plot
+            sage: a                                         # not tested                # optional - sage.plot
             Animation with 13 frames
         """
         dimension = self._box._dimension
