@@ -1,7 +1,20 @@
-# -*- coding: utf-8 -*-
 r"""
 Features for testing the presence of ``latte_int``
 """
+
+# ****************************************************************************
+#       Copyright (C) 2018 Vincent Delecroix
+#                     2019 Frédéric Chapoton
+#                     2021 Matthias Koeppe
+#                     2021 Kwankyu Lee
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
+
 from . import Executable
 from .join_feature import JoinFeature
 
@@ -11,7 +24,7 @@ LATTE_URL = "https://www.math.ucdavis.edu/~latte/software.php"
 
 class Latte_count(Executable):
     r"""
-    Feature for the executable ``count`` from the LattE suite.
+    Feature for the executable ``count`` from :ref:`LattE integrale <spkg_latte_int>`.
     """
     def __init__(self):
         r"""
@@ -28,7 +41,7 @@ class Latte_count(Executable):
 
 class Latte_integrate(Executable):
     r"""
-    Feature for the executable ``integrate`` from the LattE suite.
+    Feature for the executable ``integrate`` from :ref:`LattE integrale <spkg_latte_int>`.
     """
     def __init__(self):
         r"""
@@ -45,8 +58,8 @@ class Latte_integrate(Executable):
 
 class Latte(JoinFeature):
     r"""
-    A :class:`~sage.features.Feature` describing the presence of the ``LattE``
-    binaries which comes as a part of ``latte_int``.
+    A :class:`~sage.features.Feature` describing the presence of excecutables
+    from :ref:`LattE integrale <spkg_latte_int>`.
 
     EXAMPLES::
 
