@@ -1,5 +1,5 @@
 r"""
-Bessel Functions
+Bessel functions
 
 This module provides symbolic Bessel and Hankel functions, and their
 spherical versions. These functions use the `mpmath library`_ for numerical
@@ -293,9 +293,6 @@ class Function_Bessel_J(BuiltinFunction):
         sage: f = bessel_J(2, x)
         sage: f.integrate(x)
         1/24*x^3*hypergeometric((3/2,), (5/2, 3), -1/4*x^2)
-        sage: m = maxima(bessel_J(2, x))
-        sage: m.integrate(x)
-        (hypergeometric([3/2],[5/2,3],-_SAGE_VAR_x^2/4)*_SAGE_VAR_x^3)/24
 
     Visualization (set plot_points to a higher value to get more detail)::
 
@@ -1118,11 +1115,11 @@ def Bessel(*args, **kwds):
     Conversion to other systems::
 
         sage: x,y = var('x,y')
-        sage: f = maxima(Bessel(typ='K')(x,y))
-        sage: f.derivative('_SAGE_VAR_x')
-        (%pi*csc(%pi*_SAGE_VAR_x) *('diff(bessel_i(-_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1) -'diff(bessel_i(_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1))) /2 -%pi*bessel_k(_SAGE_VAR_x,_SAGE_VAR_y)*cot(%pi*_SAGE_VAR_x)
-        sage: f.derivative('_SAGE_VAR_y')
-        -(bessel_k(_SAGE_VAR_x+1,_SAGE_VAR_y)+bessel_k(_SAGE_VAR_x-1, _SAGE_VAR_y))/2
+        sage: f = Bessel(typ='K')(x,y)
+        sage: expected = f.derivative(y)
+        sage: actual = maxima(f).derivative('_SAGE_VAR_y').sage()
+        sage: bool(actual == expected)
+        True
 
     Compute the particular solution to Bessel's Differential Equation that
     satisfies `y(1) = 1` and `y'(1) = 1`, then verify the initial conditions
@@ -1434,6 +1431,8 @@ class Function_Struve_L(BuiltinFunction):
 
     def _print_latex_(self, a, z):
         """
+        EXAMPLES::
+
             sage: latex(struve_L(2,x))
             L_{{2}}({x})
         """
