@@ -1,20 +1,5 @@
 r"""
-Miscellaneous Special Functions
-
-AUTHORS:
-
-- David Joyner (2006-13-06): initial version
-
-- David Joyner (2006-30-10): bug fixes to pari wrappers of Bessel
-  functions, hypergeometric_U
-
-- William Stein (2008-02): Impose some sanity checks.
-
-- David Joyner (2008-04-23): addition of elliptic integrals
-
-- Eviatar Bach (2013): making elliptic integrals symbolic
-
-- Eric Gourgoulhon (2022): add Condon-Shortley phase to spherical harmonics
+Miscellaneous special functions
 
 This module provides easy access to many of Maxima and PARI's
 special functions.
@@ -104,6 +89,11 @@ implemented here.
 
   and the complete ones are obtained by taking `\phi =\pi/2`.
 
+.. WARNING::
+
+    SciPy's versions are poorly documented and seem less accurate than the
+    Maxima and PARI versions. Typically they are limited by hardware floats
+    precision.
 
 REFERENCES:
 
@@ -118,16 +108,20 @@ REFERENCES:
 
 AUTHORS:
 
-- David Joyner and William Stein
+- David Joyner (2006-13-06): initial version
 
-Added 16-02-2008 (wdj): optional calls to scipy and replace all
-'#random' by '...' (both at the request of William Stein)
+- David Joyner (2006-30-10): bug fixes to pari wrappers of Bessel
+  functions, hypergeometric_U
 
-.. warning::
+- William Stein (2008-02): Impose some sanity checks.
 
-    SciPy's versions are poorly documented and seem less
-    accurate than the Maxima and PARI versions; typically they are limited
-    by hardware floats precision.
+- David Joyner (2008-02-16): optional calls to scipy and replace all ``#random`` by ``...``
+
+- David Joyner (2008-04-23): addition of elliptic integrals
+
+- Eviatar Bach (2013): making elliptic integrals symbolic
+
+- Eric Gourgoulhon (2022): add Condon-Shortley phase to spherical harmonics
 """
 
 # ****************************************************************************
@@ -236,10 +230,10 @@ class SphericalHarmonic(BuiltinFunction):
         """
         BuiltinFunction.__init__(self, 'spherical_harmonic', nargs=4,
                                  conversions=dict(
-                                    maple='SphericalY',
-                                    mathematica='SphericalHarmonicY',
-                                    maxima='spherical_harmonic',
-                                    sympy='Ynm'))
+                                     maple='SphericalY',
+                                     mathematica='SphericalHarmonicY',
+                                     maxima='spherical_harmonic',
+                                     sympy='Ynm'))
 
     def _eval_(self, n, m, theta, phi, **kwargs):
         r"""
@@ -295,8 +289,8 @@ class SphericalHarmonic(BuiltinFunction):
             from sage.functions.trig import cos
             from sage.functions.orthogonal_polys import gen_legendre_P
             res = (sqrt(factorial(n-m) * (2*n+1) / (4*pi * factorial(n+m)))
-                    * gen_legendre_P(n, m, cos(theta))
-                    * exp(I*m*phi)).simplify_trig()
+                   * gen_legendre_P(n, m, cos(theta))
+                   * exp(I*m*phi)).simplify_trig()
             res = res.substitute({sqrt(sin(theta)**2): sin(theta)})
             return res
 
@@ -376,11 +370,13 @@ class SphericalHarmonic(BuiltinFunction):
             Y_{3}^{2}\left(x, y\right)
         """
         return r"Y_{{{}}}^{{{}}}\left({}, {}\right)".format(
-                 latex(n), latex(m), latex(theta), latex(phi))
+            latex(n), latex(m), latex(theta), latex(phi))
+
 
 spherical_harmonic = SphericalHarmonic()
 
-####### elliptic functions and integrals
+
+# elliptic functions and integrals
 
 def elliptic_j(z, prec=53):
     r"""
@@ -445,7 +441,8 @@ def elliptic_j(z, prec=53):
     from sage.libs.pari.all import pari
     return CC(pari(z).ellj())
 
-#### elliptic integrals
+
+# elliptic integrals
 
 class EllipticE(BuiltinFunction):
     r"""
@@ -461,9 +458,8 @@ class EllipticE(BuiltinFunction):
         sage: z = var("z")
         sage: elliptic_e(z, 1)
         elliptic_e(z, 1)
-        sage: # this is still wrong: must be abs(sin(z)) + 2*round(z/pi)
-        sage: elliptic_e(z, 1).simplify()
-        2*round(z/pi) + sin(z)
+        sage: elliptic_e(z, 1).simplify() # not tested - gives wrong answer with maxima < 5.47
+        2*round(z/pi) - sin(pi*round(z/pi) - z)
         sage: elliptic_e(z, 0)
         z
         sage: elliptic_e(0.5, 0.1)  # abs tol 2e-15
@@ -544,7 +540,7 @@ class EllipticE(BuiltinFunction):
             sage: elliptic_e(z, 1)
             elliptic_e(z, 1)
 
-        Here arccoth doesn't have 1 in its domain, so we just hold the expression:
+        Here arccoth doesn't have 1 in its domain, so we just hold the expression::
 
             sage: elliptic_e(arccoth(1), x^2*e)
             elliptic_e(+Infinity, x^2*e)
@@ -602,6 +598,7 @@ class EllipticE(BuiltinFunction):
         """
         return r"E(%s\,|\,%s)" % (latex(z), latex(m))
 
+
 elliptic_e = EllipticE()
 
 
@@ -693,8 +690,10 @@ class EllipticEC(BuiltinFunction):
         """
         return (elliptic_ec(x) - elliptic_kc(x)) / (Integer(2) * x)
 
+
 elliptic_ec = EllipticEC()
 
+
 class EllipticEU(BuiltinFunction):
     r"""
     Return Jacobi's form of the incomplete elliptic integral of the second kind:
@@ -791,6 +790,7 @@ class EllipticEU(BuiltinFunction):
         """
         return r"E(%s;%s)" % (latex(u), latex(m))
 
+
 def elliptic_eu_f(u, m):
     r"""
     Internal function for numeric evaluation of ``elliptic_eu``, defined as
@@ -817,8 +817,10 @@ def elliptic_eu_f(u, m):
     finally:
         ctx.prec = prec
 
+
 elliptic_eu = EllipticEU()
 
+
 class EllipticF(BuiltinFunction):
     r"""
     Return the incomplete elliptic integral of the first kind.
@@ -849,7 +851,7 @@ class EllipticF(BuiltinFunction):
     - :wikipedia:`Elliptic_integral#Incomplete_elliptic_integral_of_the_first_kind`
     """
     def __init__(self):
-        """
+        r"""
         EXAMPLES::
 
             sage: loads(dumps(elliptic_f))
@@ -956,6 +958,7 @@ class EllipticF(BuiltinFunction):
         """
         return r"F(%s\,|\,%s)" % (latex(z), latex(m))
 
+
 elliptic_f = EllipticF()
 
 
@@ -1060,8 +1063,10 @@ class EllipticKC(BuiltinFunction):
         return ((elliptic_ec(z) - (Integer(1) - z) * elliptic_kc(z)) /
                 (Integer(2) * (Integer(1) - z) * z))
 
+
 elliptic_kc = EllipticKC()
 
+
 class EllipticPi(BuiltinFunction):
     r"""
     Return the incomplete elliptic integral of the third kind:
@@ -1183,4 +1188,5 @@ class EllipticPi(BuiltinFunction):
         """
         return r"\Pi(%s,%s,%s)" % (latex(n), latex(z), latex(m))
 
+
 elliptic_pi = EllipticPi()
