@@ -24,7 +24,7 @@ the axis.
 
 ::
 
-    sage: g.plot(axes=True)
+    sage: g.plot(axes=True)                                                             # needs sage.plot
     Graphics object consisting of 2 graphics primitives
 
 .. PLOT::
@@ -37,7 +37,7 @@ the axis.
     sage: g = HyperbolicPlane().UHP().get_geodesic(I, 3 + I)
     sage: g.length()
     arccosh(11/2)
-    sage: g.plot(axes=True)
+    sage: g.plot(axes=True)                                                             # needs sage.plot
     Graphics object consisting of 2 graphics primitives
 
 .. PLOT::
@@ -49,7 +49,7 @@ Geodesics of both types in UHP are supported::
     sage: g = HyperbolicPlane().UHP().get_geodesic(I, 3*I)
     sage: g
     Geodesic in UHP from I to 3*I
-    sage: g.plot()
+    sage: g.plot()                                                                      # needs sage.plot
     Graphics object consisting of 2 graphics primitives
 
 .. PLOT::
@@ -86,20 +86,24 @@ from sage.structure.sage_object import SageObject
 from sage.symbolic.constants import I
 from sage.misc.lazy_attribute import lazy_attribute
 from sage.rings.infinity import infinity
-from sage.rings.all import CC, RR
-from sage.plot.arc import arc
-from sage.plot.line import line
+from sage.rings.cc import CC
+from sage.rings.real_mpfr import RR
+from sage.misc.lazy_import import lazy_import
+lazy_import("sage.plot.arc", "arc")
+lazy_import("sage.plot.line", "line")
+lazy_import("sage.plot.arc", "arc")
+lazy_import("sage.plot.bezier_path", "bezier_path")
 from sage.symbolic.constants import pi
 from sage.modules.free_module_element import vector
 from sage.matrix.constructor import matrix
-from sage.functions.other import real, imag, sqrt
+from sage.functions.other import real, imag
+from sage.misc.functional import sqrt
 from sage.functions.trig import arccos
 from sage.functions.log import exp
 from sage.functions.hyperbolic import sinh, cosh, arcsinh
 from sage.symbolic.ring import SR
 from sage.geometry.hyperbolic_space.hyperbolic_constants import EPSILON
 
-from sage.misc.lazy_import import lazy_import
 lazy_import('sage.geometry.hyperbolic_space.hyperbolic_isometry',
             'moebius_transform')
 
@@ -694,15 +698,27 @@ class HyperbolicGeodesic(SageObject):
         ::
 
             sage: KM = H.KM()
-            sage: KM.get_geodesic((0,0), (0, 1/2)).complete()
+            sage: KM.get_geodesic((0,0), (0,1/2)).complete()
             Geodesic in KM from (0, -1) to (0, 1)
 
         .. PLOT::
 
-            g = HyperbolicPlane().KM().get_geodesic((0.0,0.0), (0.0, 0.5))
+            g = HyperbolicPlane().KM().get_geodesic(CC(0,0), CC(0, 0.5))
             h = g.complete()
             sphinx_plot(g.plot()+h.plot(linestyle='dashed'))
 
+        ::
+
+            sage: KM.get_geodesic(-I, 1).complete()
+            Geodesic in KM from -I to 1
+
+        .. PLOT::
+
+            g = HyperbolicPlane().KM().get_geodesic(CC(0,-1), CC(1, 0))
+            h = g.complete()
+            sphinx_plot(g.plot()+h.plot(linestyle='dashed'))
+
+
         ::
 
             sage: HM = H.HM()
@@ -885,14 +901,14 @@ class HyperbolicGeodesic(SageObject):
 
             sage: PD = HyperbolicPlane().PD()
             sage: g = PD.get_geodesic(-0.3+0.4*I,+0.7-0.1*I)
-            sage: h = g.perpendicular_bisector()
+            sage: h = g.perpendicular_bisector().complete()
             sage: P = g.plot(color='blue')+h.plot(color='orange');P
             Graphics object consisting of 4 graphics primitives
 
         .. PLOT::
 
             g = HyperbolicPlane().PD().get_geodesic(-0.3+0.4*I,+0.7-0.1*I)
-            h = g.perpendicular_bisector()
+            h = g.perpendicular_bisector().complete()
             sphinx_plot(g.plot(color='blue')+h.plot(color='orange'))
 
         Complete geodesics cannot be bisected::
@@ -906,10 +922,14 @@ class HyperbolicGeodesic(SageObject):
         TESTS::
 
             sage: g = HyperbolicPlane().PD().random_geodesic()
-            sage: h = g.perpendicular_bisector()
+            sage: h = g.perpendicular_bisector().complete()
             sage: bool(h.intersection(g)[0].coordinates() - g.midpoint().coordinates() < 10**-9)
             True
 
+            sage: g = HyperbolicPlane().UHP().random_geodesic()
+            sage: h = g.perpendicular_bisector().complete()
+            sage: bool(h.intersection(g)[0].coordinates() - g.midpoint().coordinates() < 10**-9)
+            True
         """
 
         P = self._cached_geodesic.perpendicular_bisector()
@@ -1034,9 +1054,9 @@ class HyperbolicGeodesic(SageObject):
         return self._model._dist_points(self._start.coordinates(),
                                         self._end.coordinates())
 
-#***********************************************************************
+# ***********************************************************************
 #                       UHP geodesics
-#***********************************************************************
+# ***********************************************************************
 
 
 class HyperbolicGeodesicUHP(HyperbolicGeodesic):
@@ -1106,7 +1126,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         EXAMPLES::
 
             sage: UHP = HyperbolicPlane().UHP()
-            sage: UHP.get_geodesic(0, 1).plot()
+            sage: UHP.get_geodesic(0, 1).plot()                                         # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
@@ -1117,7 +1137,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         ::
 
-            sage: UHP.get_geodesic(I, 3+4*I).plot(linestyle="dashed", color="brown")
+            sage: UHP.get_geodesic(I, 3+4*I).plot(linestyle="dashed", color="brown")    # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
@@ -1128,7 +1148,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         ::
 
-            sage: UHP.get_geodesic(1, infinity).plot(color='orange')
+            sage: UHP.get_geodesic(1, infinity).plot(color='orange')                    # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
@@ -1142,25 +1162,25 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         Plotting a line with ``boundary=True``. ::
 
             sage: g = HyperbolicPlane().UHP().get_geodesic(0, I)
-            sage: g.plot()
+            sage: g.plot()                                                              # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         Plotting a line with ``boundary=False``. ::
-            
+
             sage: g = HyperbolicPlane().UHP().get_geodesic(0, I)
-            sage: g.plot(boundary=False)
+            sage: g.plot(boundary=False)                                                # needs sage.plot
             Graphics object consisting of 1 graphics primitive
 
         Plotting a circle with ``boundary=True``. ::
 
             sage: g = HyperbolicPlane().UHP().get_geodesic(-3, 19)
-            sage: g.plot()
+            sage: g.plot()                                                              # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         Plotting a circle with ``boundary=False``. ::
 
             sage: g = HyperbolicPlane().UHP().get_geodesic(3, 4)
-            sage: g.plot(boundary=False)
+            sage: g.plot(boundary=False)                                                # needs sage.plot
             Graphics object consisting of 1 graphics primitive
 
         """
@@ -1180,12 +1200,15 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             elif end_2 == CC(infinity):
                 end_2 = (real(end_1), (imag(end_1) + 10))
                 end_1 = (real(end_1), imag(end_1))
-            pic = line((end_1, end_2), **opts)
+            else:
+                end_1 = (real(end_1), imag(end_1))
+                end_2 = (real(end_2), imag(end_2))
+            pic = bezier_path([[end_1, end_2]], **opts)
             if boundary:
                 cent = min(bd_1, bd_2)
                 bd_dict = {'bd_min': cent - 3, 'bd_max': cent + 3}
                 bd_pic = self._model.get_background_graphic(**bd_dict)
-                pic = bd_pic + pic
+                pic += bd_pic
             return pic
         else:
             center = (bd_1 + bd_2) / 2  # Circle center
@@ -1207,7 +1230,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
                 bd_dict = {'bd_min': midpoint - length, 'bd_max': midpoint +
                            length}
                 bd_pic = self._model.get_background_graphic(**bd_dict)
-                pic = bd_pic + pic
+                pic += bd_pic
             return pic
 
     def ideal_endpoints(self):
@@ -1238,10 +1261,10 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         M = self._model
         # infinity is the first endpoint, so the other ideal endpoint
         # is just the real part of the second coordinate
-        if start == infinity:
+        if CC(start).is_infinity():
             return [M.get_point(start), M.get_point(x2)]
         # Same idea as above
-        if end == infinity:
+        if CC(end).is_infinity():
             return [M.get_point(x1), M.get_point(end)]
         # We could also have a vertical line with two interior points
         if x1 == x2:
@@ -1326,39 +1349,212 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: g.intersection(h)
             [Point in UHP 2/3*sqrt(-2) + 13/3]
 
+        .. PLOT::
+
+            UHP = HyperbolicPlane().UHP()
+            g = UHP.get_geodesic(3, 5)
+            h = UHP.get_geodesic(4, 7)
+            P = g.intersection(h)
+            pict = g.plot(color="red")+h.plot(color="red")
+            sphinx_plot(pict)
+
         If the given geodesics do not intersect, the function returns an
         empty list::
 
             sage: g = UHP.get_geodesic(4, 5)
-            sage: h = UHP.get_geodesic(5, 7)
+            sage: h = UHP.get_geodesic(6, 7)
             sage: g.intersection(h)
             []
 
+        .. PLOT::
+
+            UHP = HyperbolicPlane().UHP()
+            g = UHP.get_geodesic(4.0, 5.0)
+            h = UHP.get_geodesic(6.0, 7.0)
+            sphinx_plot(g.plot() + h.plot())
+
+        If the given geodesics are asymptotically parallel, the function returns the common boundary point::
+
+            sage: g = UHP.get_geodesic(4, 5)
+            sage: h = UHP.get_geodesic(5, 7)
+            sage: g.intersection(h)
+            [Boundary point in UHP 5.00000000000000]
+
+        .. PLOT::
+
+            UHP = HyperbolicPlane().UHP()
+            g = UHP.get_geodesic(4.0, 5.0)
+            h = UHP.get_geodesic(6.0, 7.0)
+            sphinx_plot(g.plot() + h.plot())
+
         If the given geodesics are identical, return that
         geodesic::
 
             sage: g = UHP.get_geodesic(4 + I, 18*I)
             sage: h = UHP.get_geodesic(4 + I, 18*I)
             sage: g.intersection(h)
-            [Boundary point in UHP -1/8*sqrt(114985) - 307/8,
-             Boundary point in UHP 1/8*sqrt(114985) - 307/8]
+            Geodesic in UHP from I + 4 to 18*I
+
+        TESTS:
+
+            sage: UHP = HyperbolicPlane().UHP()
+            sage: g1 = UHP.get_geodesic(2*QQbar.gen(), 5)
+            sage: g2 = UHP.get_geodesic(-1/2, Infinity)
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case Ia
+            sage: UHP = HyperbolicPlane().UHP()
+            sage: g1=UHP.get_geodesic(-1,I)
+            sage: g2=UHP.get_geodesic(0,2)
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case Ib
+            sage: g1=UHP.get_geodesic(-1,I)
+            sage: g2=UHP.get_geodesic(1/2,1/2+2*I)
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case IIa
+            sage: g1=UHP.get_geodesic(-1,+1)
+            sage: g2=UHP.get_geodesic(-1,2)
+            sage: g1.intersection(g2)
+            [Boundary point in UHP -1.00000000000000]
+
+            sage: UHP = HyperbolicPlane().UHP() #case IIb
+            sage: g1=UHP.get_geodesic(-1,+Infinity)
+            sage: g2=UHP.get_geodesic(+1,+Infinity)
+            sage: g1.intersection(g2)
+            [Boundary point in UHP +infinity]
+
+            sage: UHP = HyperbolicPlane().UHP() #case IIc
+            sage: g1=UHP.get_geodesic(-1,-1+I)
+            sage: g2=UHP.get_geodesic(+1,+1+I)
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case IId
+            sage: g1=UHP.get_geodesic(-1,+1)
+            sage: g2=UHP.get_geodesic(-1,-1+2*I)
+            sage: g1.intersection(g2)
+            [Boundary point in UHP -1.00000000000000]
+
+            sage: UHP = HyperbolicPlane().UHP() #case IIIa
+            sage: g1=UHP.get_geodesic(-1,I)
+            sage: g2=UHP.get_geodesic(+1,(+cos(pi/3)+I*sin(pi/3)))
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case IIIb
+            sage: g1=UHP.get_geodesic(I,2*I)
+            sage: g2=UHP.get_geodesic(3*I,4*I)
+            sage: g1.intersection(g2)
+            []
+
+            sage: UHP = HyperbolicPlane().UHP() #case IVa
+            sage: g1=UHP.get_geodesic(3*I,Infinity)
+            sage: g2=UHP.get_geodesic(2*I,4*I)
+            sage: g1.intersection(g2)
+            Geodesic in UHP from 3.00000000000000*I to 4.00000000000000*I
+
+            sage: UHP = HyperbolicPlane().UHP() #case IVb
+            sage: g1=UHP.get_geodesic(I,3*I)
+            sage: g2=UHP.get_geodesic(2*I,4*I)
+            sage: g1.intersection(g2)
+            Geodesic in UHP from 2.00000000000000*I to 3.00000000000000*I
+
+            sage: UHP = HyperbolicPlane().UHP() #case IVc
+            sage: g1=UHP.get_geodesic(2*I,infinity)
+            sage: g2=UHP.get_geodesic(3*I,infinity)
+            sage: g1.intersection(g2)
+            Geodesic in UHP from 3.00000000000000*I to +infinity
 
         """
 
-        start_1, end_1 = sorted(self.ideal_endpoints(), key=str)
-        start_2, end_2 = sorted(other.ideal_endpoints(), key=str)
-        if start_1 == start_2 and end_1 == end_2:  # Unoriented geods are same
-            return [start_1, end_1]
-        if start_1 == start_2:
-            return start_1
-        elif end_1 == end_2:
-            return end_1
-        A = self.reflection_involution()
-        B = other.reflection_involution()
-        C = A * B
-        if C.classification() in ['hyperbolic', 'parabolic']:
-            return []
-        return C.fixed_point_set()
+        UHP = self.model()
+        # Both geodesic need to be UHP geodesics for this to work
+        if other.model() != UHP:
+            other = other.to_model(UHP)
+        # Get endpoints and ideal endpoints
+        i_start_1, i_end_1 = sorted(self.ideal_endpoints(), key=str)
+        i_start_2, i_end_2 = sorted(other.ideal_endpoints(), key=str)
+        start_1, end_1 = [CC(x.coordinates()) for x in self.endpoints()]
+        start_2, end_2 = [CC(x.coordinates()) for x in other.endpoints()]
+        # sort the geodesic endpoints according to start_1.real() < end_1.real() and if start_1.real() ==  end_1.real()
+        # then start_1.imag() < end_1.imag()
+        if start_1.real() > end_1.real():  # enforce
+            start_1, end_1 = end_1, start_1
+        elif start_1.real() == end_1.real():
+            if start_1.imag() > end_1.imag():
+                start_1, end_1 = end_1, start_1
+        # sort the geodesic endpoints according to start_2.real() < end_2.real() and if start_2.real() ==  end_2.real()
+        # then start_2.imag() < end_2.imag()
+        if start_2.real() > end_2.real():
+            start_2, end_2 = end_2, start_2
+        elif start_2.real() == end_2.real():
+            if start_2.imag() > end_2.imag():
+                start_2, end_2 = end_2, start_2
+        if i_start_1 == i_start_2 and i_end_1 == i_end_2:
+            # Unoriented segments lie on the same complete geodesic
+            if start_1 == start_2 and end_1 == end_2:
+                return self
+            if start_1.real() == end_1.real() or end_1.real().is_infinity():
+                # Both geodesics are vertical
+                if start_2.imag() < start_1.imag():
+                    # make sure always start_1.imag() <= start_2.imag()
+                    start_1, start_2 = start_2, start_1
+                    end_1, end_2 = end_2, end_1
+                if end_1 == start_2:
+                    return [UHP.get_point(end_1)]
+                elif end_1.real().is_infinity() and end_2.real().is_infinity():
+                    return UHP.get_geodesic(start_2, end_2)
+                elif end_1.imag() < start_2.imag():
+                    return []
+                else:
+                    return UHP.get_geodesic(start_2, end_1)
+            else:
+                # Neither geodesic is vertical
+                # make sure always start_1.real() <= start_2.real()
+                if start_2.real() < start_1.real():
+                    start_1, start_2 = start_2, start_1
+                    end_1, end_2 = end_2, end_1
+                if end_1 == start_2:
+                    return [UHP.get_point(end_1)]
+                elif end_1.real() < start_2.real():
+                    return []
+                else:
+                    return UHP.get_geodesic(start_2, end_1)
+        else:
+            # Both segments do not have the same complete geodesic
+            # make sure always start_1.real() <= start_2.real()
+            if start_2.real() < start_1.real():
+                start_1, start_2 = start_2, start_1
+                end_1, end_2 = end_2, end_1
+            if self.is_asymptotically_parallel(other):
+                # asymptotic parallel
+                if start_1 == start_2:
+                    return [UHP.get_point(start_1)]
+                elif end_1 == start_2 or end_1 == end_2:
+                    return [UHP.get_point(end_1)]
+                else:
+                    return []
+            else:
+                A = self.reflection_involution()
+                B = other.reflection_involution()
+                C = A * B
+                if C.classification() in ['hyperbolic', 'parabolic']:
+                    return []
+                else:
+                    # the fixed point needs not to lie in both segments of geodesic
+                    if end_1 == start_2:
+                        return [UHP().get_point(end_1)]
+                    else:
+                        P = CC(C.fixed_point_set()[0].coordinates())
+                        if start_1.real() <= P.real() <= end_1.real() and start_2.real() <= P.real() <= end_2.real():
+                            return C.fixed_point_set()
+                        else:
+                            return []
 
     def perpendicular_bisector(self):  # UHP
         r"""
@@ -1367,25 +1563,25 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         EXAMPLES::
 
-            sage: UHP = HyperbolicPlane().UHP()
-            sage: g = UHP.random_geodesic()
-            sage: h = g.perpendicular_bisector()
-            sage: c = lambda x: x.coordinates()
-            sage: bool(c(g.intersection(h)[0]) - c(g.midpoint()) < 10**-9)
-            True
+             sage: UHP = HyperbolicPlane().UHP()
+             sage: g = UHP.random_geodesic()
+             sage: h = g.perpendicular_bisector().complete()
+             sage: c = lambda x: x.coordinates()
+             sage: bool(c(g.intersection(h)[0]) - c(g.midpoint()) < 10**-9)
+             True
 
         ::
 
             sage: UHP = HyperbolicPlane().UHP()
             sage: g = UHP.get_geodesic(1+I,2+0.5*I)
-            sage: h = g.perpendicular_bisector()
+            sage: h = g.perpendicular_bisector().complete()
             sage: show(g.plot(color='blue')+h.plot(color='orange'))
 
         .. PLOT::
 
             UHP = HyperbolicPlane().UHP()
             g = UHP.get_geodesic(1+I,2+0.5*I)
-            h = g.perpendicular_bisector()
+            h = g.perpendicular_bisector().complete()
             sphinx_plot(g.plot(color='blue')+h.plot(color='orange'))
 
         Infinite geodesics cannot be bisected::
@@ -1692,7 +1888,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             arccos(7/8)
             sage: h.angle(g)
             arccos(7/8)
-                                                                     
+
         Angle between circle and line. Note that ``1/2*sqrt(2)`` equals
         ``1/4*pi``. ::
 
@@ -1810,7 +2006,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             [   1.0    0.0]
             [   0.0 -1.0*I]
             sage: type(B)
-            <type 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
+            <class 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
 
       ::
 
@@ -1818,7 +2014,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             [ 1  0]
             [ 0 -I]
             sage: type(B)
-            <type 'sage.matrix.matrix_symbolic_dense.Matrix_symbolic_dense'>
+            <class 'sage.matrix.matrix_symbolic_dense.Matrix_symbolic_dense'>
 
       ::
 
@@ -1826,7 +2022,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             [   1.0    0.0]
             [   0.0 -1.0*I]
             sage: type(B)
-            <type 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
+            <class 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
 
       ::
 
@@ -1836,8 +2032,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: type(B[1,1])
             <class 'sage.rings.qqbar.AlgebraicNumber'>
             sage: type(B)
-            <type 'sage.matrix.matrix_generic_dense.Matrix_generic_dense'>
-
+            <class 'sage.matrix.matrix_generic_dense.Matrix_generic_dense'>
         """
         from sage.structure.element import Element
         from sage.symbolic.expression import Expression
@@ -1962,9 +2157,9 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         return matrix([[p1 - p2, (p1 - p2)*(-p0)],
                        [p1 - p0, (p1 - p0)*(-p2)]])
 
-#***********************************************************************
+# ***********************************************************************
 #                       Other geodesics
-#***********************************************************************
+# ***********************************************************************
 
 
 class HyperbolicGeodesicPD(HyperbolicGeodesic):
@@ -1996,11 +2191,9 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
          g = PD.get_geodesic(I,-I/2)
          h = PD.get_geodesic(-0.5+I*0.5,0.5+I*0.5)
          sphinx_plot(g.plot()+h.plot(color='green'))
-
     """
 
     def plot(self, boundary=True, **options):
-
         r"""
         Plot ``self``.
 
@@ -2009,7 +2202,7 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
         First some lines::
 
             sage: PD = HyperbolicPlane().PD()
-            sage: PD.get_geodesic(0, 1).plot()
+            sage: PD.get_geodesic(0, 1).plot()                                          # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
@@ -2018,7 +2211,7 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
 
         ::
 
-            sage: PD.get_geodesic(0, 0.3+0.8*I).plot()
+            sage: PD.get_geodesic(0, 0.3+0.8*I).plot()                                  # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
@@ -2028,15 +2221,15 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
 
         Then some generic geodesics::
 
-            sage: PD.get_geodesic(-0.5, 0.3+0.4*I).plot()
+            sage: PD.get_geodesic(-0.5, 0.3+0.4*I).plot()                               # needs sage.plot
             Graphics object consisting of 2 graphics primitives
             sage: g = PD.get_geodesic(-1, exp(3*I*pi/7))
-            sage: G = g.plot(linestyle="dashed",color="red"); G
+            sage: G = g.plot(linestyle="dashed",color="red"); G                         # needs sage.plot
             Graphics object consisting of 2 graphics primitives
             sage: h = PD.get_geodesic(exp(2*I*pi/11), exp(1*I*pi/11))
-            sage: H = h.plot(thickness=6, color="orange"); H
+            sage: H = h.plot(thickness=6, color="orange"); H                            # needs sage.plot
             Graphics object consisting of 2 graphics primitives
-            sage: show(G+H)
+            sage: show(G+H)                                                             # needs sage.plot
 
         .. PLOT::
 
@@ -2057,7 +2250,7 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
         bd_1, bd_2 = [CC(k.coordinates()) for k in self.ideal_endpoints()]
         # Check to see if it's a line
         if abs(bd_1 + bd_2) < EPSILON:
-            pic = line([end_1, end_2], **opts)
+            pic = bezier_path([[(real(end_1), imag(end_1)), (real(end_2), imag(end_2))]], **opts)
         else:
             # If we are here, we know it's not a line
             # So we compute the center and radius of the circle
@@ -2098,20 +2291,18 @@ class HyperbolicGeodesicKM(HyperbolicGeodesic):
     EXAMPLES::
 
         sage: KM = HyperbolicPlane().KM()
-        sage: g = KM.get_geodesic(KM.get_point((0.1,0.9)), KM.get_point((-0.1,-0.9)))
         sage: g = KM.get_geodesic((0.1,0.9),(-0.1,-0.9))
         sage: h = KM.get_geodesic((-0.707106781,-0.707106781),(0.707106781,-0.707106781))
-        sage: P = g.plot(color='orange')+h.plot(); P
+        sage: P = g.plot(color='orange')+h.plot(); P                                    # needs sage.plot
         Graphics object consisting of 4 graphics primitives
 
-
     .. PLOT::
 
         KM = HyperbolicPlane().KM()
-        g = KM.get_geodesic((0.1,0.9),
-                            (-0.1,-0.9))
-        h = KM.get_geodesic((-0.707106781,-0.707106781),
-                            (0.707106781,-0.707106781))
+        g = KM.get_geodesic(CC(0.1,0.9),
+                            CC(-0.1,-0.9))
+        h = KM.get_geodesic(CC(-0.707106781,-0.707106781),
+                            CC(0.707106781,-0.707106781))
         sphinx_plot(g.plot(color='orange')+h.plot())
 
     """
@@ -2122,19 +2313,26 @@ class HyperbolicGeodesicKM(HyperbolicGeodesic):
 
         EXAMPLES::
 
-            sage: HyperbolicPlane().KM().get_geodesic((0,0), (1,0)).plot()
+            sage: HyperbolicPlane().KM().get_geodesic(0, 1).plot()                      # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
 
             KM = HyperbolicPlane().KM()
-            sphinx_plot(KM.get_geodesic((0,0), (1,0)).plot())
+            sphinx_plot(KM.get_geodesic(CC(0,0), CC(1,0)).plot())
 
         """
         opts = {'axes': False, 'aspect_ratio': 1}
         opts.update(self.graphics_options())
         opts.update(options)
-        pic = line([k.coordinates() for k in self.endpoints()], **opts)
+
+        def map_pt(pt):
+            if pt in CC:
+                return CC(pt)
+            return CC(*pt)
+        end_1, end_2 = [map_pt(k.coordinates()) for k in self.endpoints()]
+        pic = bezier_path([[(real(end_1), imag(end_1)),
+                            (real(end_2), imag(end_2))]], **opts)
         if boundary:
             pic += self._model.get_background_graphic()
         return pic
@@ -2156,7 +2354,6 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
 
     EXAMPLES::
 
-        sage: from sage.geometry.hyperbolic_space.hyperbolic_geodesic import *
         sage: HM = HyperbolicPlane().HM()
         sage: p1 = HM.get_point((4, -4, sqrt(33)))
         sage: p2 = HM.get_point((-3,-3,sqrt(19)))
@@ -2172,6 +2369,51 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
         sphinx_plot(g.plot(color='blue'))
 
     """
+    def _plot_vertices(self, points=75):
+        r"""
+        Return ``self`` plotting vertices in `\RR^3`.
+
+        Auxiliary function needed to plot polygons.
+
+        EXAMPLES::
+
+            sage: HM = HyperbolicPlane().HM()
+            sage: p1 = HM.get_point((4, -4, sqrt(33)))
+            sage: p2 = HM.get_point((-3,-3,sqrt(19)))
+            sage: g = HM.get_geodesic(p1, p2)
+            sage: g._plot_vertices(5)
+            [(4.0, -4.0, 5.744562...),
+             (1.363213..., -1.637073..., 2.353372...),
+             (0.138568..., -0.969980..., 1.400022...),
+             (-0.942533..., -1.307681..., 1.896945...),
+             (-3.0, -3.0, 4.358898...)]
+        """
+        from sage.plot.misc import setup_for_eval_on_grid
+        from sage.arith.srange import xsrange
+
+        x = SR.var('x')
+        v1, u2 = [vector(k.coordinates()) for k in self.endpoints()]
+        # Lorentzian Gram Shmidt.  The original vectors will be
+        # u1, u2 and the orthogonal ones will be v1, v2.  Except
+        # v1 = u1, and I don't want to declare another variable,
+        # hence the odd naming convention above.
+        # We need the Lorentz dot product of v1 and u2.
+        v1_ldot_u2 = u2[0]*v1[0] + u2[1]*v1[1] - u2[2]*v1[2]
+        v2 = u2 + v1_ldot_u2 * v1
+        v2_norm = sqrt(v2[0]**2 + v2[1]**2 - v2[2]**2)
+        v2 = v2 / v2_norm
+        v2_ldot_u2 = u2[0]*v2[0] + u2[1]*v2[1] - u2[2]*v2[2]
+        # Now v1 and v2 are Lorentz orthogonal, and |v1| = -1, |v2|=1
+        # That is, v1 is unit timelike and v2 is unit spacelike.
+        # This means that cosh(x)*v1 + sinh(x)*v2 is unit timelike.
+        hyperbola = tuple(cosh(x)*v1 + sinh(x)*v2)
+        endtime = arcsinh(v2_ldot_u2)
+        # mimic the function _parametric_plot3d_curve using a bezier3d instead of a line3d
+        # this is required in order to be able to plot hyperbolic polygons whithin the plot library
+        g, ranges = setup_for_eval_on_grid(hyperbola, [(x, 0, endtime)], points)
+        f_x, f_y, f_z = g
+        points = [(f_x(u), f_y(u), f_z(u)) for u in xsrange(*ranges[0], include_endpoint=True)]
+        return points
 
     def plot(self, show_hyperboloid=True, **graphics_options):
         r"""
@@ -2182,7 +2424,7 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
             sage: from sage.geometry.hyperbolic_space.hyperbolic_geodesic \
             ....:    import *
             sage: g = HyperbolicPlane().HM().random_geodesic()
-            sage: g.plot()
+            sage: g.plot()                                                              # needs sage.plot
             Graphics3d Object
 
         .. PLOT::
