@@ -12,11 +12,12 @@ Base class for polyhedra over `\ZZ`
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.rings.all import ZZ, QQ
+from sage.rings.integer_ring import ZZ
+from sage.rings.rational_field import QQ
 from sage.misc.cachefunc import cached_method
 from sage.modules.free_module_element import vector
 from .base_QQ import Polyhedron_QQ
-from sage.arith.all import gcd
+from sage.arith.misc import gcd
 
 
 #########################################################################
@@ -47,8 +48,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
         """
         if name in ['ehrhart_quasipolynomial']:
             raise AttributeError(name)
-        else:
-            return super(Polyhedron_ZZ, self).__getattribute__(name)
+        return super().__getattribute__(name)
 
     def __dir__(self):
         r"""
@@ -79,7 +79,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
 
             sage: polytopes.cross_polytope(3).is_lattice_polytope()
             True
-            sage: polytopes.regular_polygon(5).is_lattice_polytope()
+            sage: polytopes.regular_polygon(5).is_lattice_polytope()                    # needs sage.rings.number_field
             False
 
         TESTS:
@@ -163,25 +163,26 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             7/2*t^3 + 2*t^2 - 1/2*t + 1
             sage: p(1)                                 # optional - latte_int
             6
-            sage: len(P.integral_points())             # optional - latte_int
+            sage: len(P.integral_points())
             6
             sage: p(2)                                 # optional - latte_int
             36
-            sage: len((2*P).integral_points())         # optional - latte_int
+            sage: len((2*P).integral_points())
             36
 
         The unit hypercubes::
 
+            sage: # optional - latte_int
             sage: from itertools import product
             sage: def hypercube(d):
             ....:     return Polyhedron(vertices=list(product([0,1],repeat=d)))
-            sage: hypercube(3)._ehrhart_polynomial_latte()   # optional - latte_int
+            sage: hypercube(3)._ehrhart_polynomial_latte()
             t^3 + 3*t^2 + 3*t + 1
-            sage: hypercube(4)._ehrhart_polynomial_latte()   # optional - latte_int
+            sage: hypercube(4)._ehrhart_polynomial_latte()
             t^4 + 4*t^3 + 6*t^2 + 4*t + 1
-            sage: hypercube(5)._ehrhart_polynomial_latte()   # optional - latte_int
+            sage: hypercube(5)._ehrhart_polynomial_latte()
             t^5 + 5*t^4 + 10*t^3 + 10*t^2 + 5*t + 1
-            sage: hypercube(6)._ehrhart_polynomial_latte()   # optional - latte_int
+            sage: hypercube(6)._ehrhart_polynomial_latte()
             t^6 + 6*t^5 + 15*t^4 + 20*t^3 + 15*t^2 + 6*t + 1
 
         TESTS:
@@ -193,7 +194,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             sage: p = P._ehrhart_polynomial_latte(maxdet=5, verbose=True)  # optional - latte_int
             This is LattE integrale ...
             ...
-            Invocation: latte-count --ehrhart-polynomial '--redundancy-check=none' --cdd '--maxdet=5' /dev/stdin
+            Invocation: ...count --ehrhart-polynomial '--redundancy-check=none' --cdd '--maxdet=5' /dev/stdin
             ...
             sage: p    # optional - latte_int
             1/2*t^2 + 3/2*t + 1
@@ -201,7 +202,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             sage: p = P._ehrhart_polynomial_latte(dual=True, verbose=True)  # optional - latte_int
             This is LattE integrale ...
             ...
-            Invocation: latte-count --ehrhart-polynomial '--redundancy-check=none' --cdd --dual /dev/stdin
+            Invocation: ...count --ehrhart-polynomial '--redundancy-check=none' --cdd --dual /dev/stdin
             ...
             sage: p   # optional - latte_int
             1/2*t^2 + 3/2*t + 1
@@ -209,7 +210,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             sage: p = P._ehrhart_polynomial_latte(irrational_primal=True, verbose=True)   # optional - latte_int
             This is LattE integrale ...
             ...
-            Invocation: latte-count --ehrhart-polynomial '--redundancy-check=none' --cdd --irrational-primal /dev/stdin
+            Invocation: ...count --ehrhart-polynomial '--redundancy-check=none' --cdd --irrational-primal /dev/stdin
             ...
             sage: p   # optional - latte_int
             1/2*t^2 + 3/2*t + 1
@@ -217,7 +218,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             sage: p = P._ehrhart_polynomial_latte(irrational_all_primal=True, verbose=True)  # optional - latte_int
             This is LattE integrale ...
             ...
-            Invocation: latte-count --ehrhart-polynomial '--redundancy-check=none' --cdd --irrational-all-primal /dev/stdin
+            Invocation: ...count --ehrhart-polynomial '--redundancy-check=none' --cdd --irrational-all-primal /dev/stdin
             ...
             sage: p   # optional - latte_int
             1/2*t^2 + 3/2*t + 1
@@ -229,7 +230,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             ...
             RuntimeError: LattE integrale program failed (exit code 1):
             ...
-            Invocation: latte-count --ehrhart-polynomial '--redundancy-check=none' --cdd '--bim-bam-boum=19' /dev/stdin
+            Invocation: ...count --ehrhart-polynomial '--redundancy-check=none' --cdd '--bim-bam-boum=19' /dev/stdin
             Unknown command/option --bim-bam-boum=19
         """
         # note: the options below are explicitly written in the function
@@ -281,7 +282,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
         Receive a type error if the backend is not normaliz::
 
             sage: c = Polyhedron(vertices = [[0,0,0],[0,0,1],[0,1,0],[0,1,1],[1,0,0],[1,0,1],[1,1,0],[1,1,1]])
-            sage: c._ehrhart_polynomial_normaliz()             # optional - pynormaliz
+            sage: c._ehrhart_polynomial_normaliz()
             Traceback (most recent call last):
             ...
             TypeError: The polyhedron's backend should be 'normaliz'
@@ -367,11 +368,11 @@ class Polyhedron_ZZ(Polyhedron_QQ):
             7/2*t^3 + 2*t^2 - 1/2*t + 1
             sage: poly(1)                                              # optional - latte_int
             6
-            sage: len(simplex.integral_points())                       # optional - latte_int
+            sage: len(simplex.integral_points())
             6
             sage: poly(2)                                              # optional - latte_int
             36
-            sage: len((2*simplex).integral_points())                   # optional - latte_int
+            sage: len((2*simplex).integral_points())
             36
 
         Now we find the same Ehrhart polynomial, this time using
@@ -387,7 +388,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
         it returns an error::
 
             sage: simplex = Polyhedron(vertices=[(0,0,0),(3,3,3),(-3,2,1),(1,-1,-2)])
-            sage: simplex.ehrhart_polynomial(engine='normaliz')        # optional - pynormaliz
+            sage: simplex.ehrhart_polynomial(engine='normaliz')
             Traceback (most recent call last):
             ...
             TypeError: The polyhedron's backend should be 'normaliz'
@@ -399,27 +400,29 @@ class Polyhedron_ZZ(Polyhedron_QQ):
         hypercube, and the coefficient of the leading monomial equals the
         volume of the unit hypercube::
 
+            sage: # optional - latte_int
             sage: from itertools import product
             sage: def hypercube(d):
             ....:     return Polyhedron(vertices=list(product([0,1],repeat=d)))
-            sage: hypercube(3).ehrhart_polynomial()   # optional - latte_int
+            sage: hypercube(3).ehrhart_polynomial()
             t^3 + 3*t^2 + 3*t + 1
-            sage: hypercube(4).ehrhart_polynomial()   # optional - latte_int
+            sage: hypercube(4).ehrhart_polynomial()
             t^4 + 4*t^3 + 6*t^2 + 4*t + 1
-            sage: hypercube(5).ehrhart_polynomial()   # optional - latte_int
+            sage: hypercube(5).ehrhart_polynomial()
             t^5 + 5*t^4 + 10*t^3 + 10*t^2 + 5*t + 1
-            sage: hypercube(6).ehrhart_polynomial()   # optional - latte_int
+            sage: hypercube(6).ehrhart_polynomial()
             t^6 + 6*t^5 + 15*t^4 + 20*t^3 + 15*t^2 + 6*t + 1
 
+            sage: # optional - pynormaliz
             sage: def hypercube(d):
-            ....:     return Polyhedron(vertices=list(product([0,1],repeat=d)),backend='normaliz') # optional - pynormaliz
-            sage: hypercube(3).ehrhart_polynomial(engine='normaliz') # optional - pynormaliz
+            ....:     return Polyhedron(vertices=list(product([0,1],repeat=d)),backend='normaliz')
+            sage: hypercube(3).ehrhart_polynomial(engine='normaliz')
             t^3 + 3*t^2 + 3*t + 1
-            sage: hypercube(4).ehrhart_polynomial(engine='normaliz') # optional - pynormaliz
+            sage: hypercube(4).ehrhart_polynomial(engine='normaliz')
             t^4 + 4*t^3 + 6*t^2 + 4*t + 1
-            sage: hypercube(5).ehrhart_polynomial(engine='normaliz') # optional - pynormaliz
+            sage: hypercube(5).ehrhart_polynomial(engine='normaliz')
             t^5 + 5*t^4 + 10*t^3 + 10*t^2 + 5*t + 1
-            sage: hypercube(6).ehrhart_polynomial(engine='normaliz') # optional - pynormaliz
+            sage: hypercube(6).ehrhart_polynomial(engine='normaliz')
             t^6 + 6*t^5 + 15*t^4 + 20*t^3 + 15*t^2 + 6*t + 1
 
         An empty polyhedron::
@@ -511,14 +514,14 @@ class Polyhedron_ZZ(Polyhedron_QQ):
         if not self.has_IP_property():
             raise ValueError('The polytope must have the IP property.')
 
-        vertices = tuple( ieq.A()/ieq.b() for
-                          ieq in self.inequality_generator() )
+        vertices = tuple(ieq.A() / ieq.b() for
+                         ieq in self.inequality_generator())
 
         ieqs = ((1,) + tuple(v[:]) for v in self.vertices())
 
         pref_rep = 'Hrep' if self.n_vertices() <= self.n_inequalities() else 'Vrep'
 
-        if all( all(v_i in ZZ for v_i in v) for v in vertices):
+        if all(v_i in ZZ for v in vertices for v_i in v):
             parent = self.parent()
             vertices = (v.change_ring(ZZ) for v in vertices)
         else:
@@ -626,8 +629,8 @@ class Polyhedron_ZZ(Polyhedron_QQ):
 
         EXAMPLES::
 
-            sage: P = Polyhedron(toric_varieties.P4_11169().fan().rays(), base_ring=ZZ)
-            sage: list( P.fibration_generator(2) )
+            sage: P = Polyhedron(toric_varieties.P4_11169().fan().rays(), base_ring=ZZ)             # needs palp sage.graphs
+            sage: list(P.fibration_generator(2))                                        # needs palp sage.graphs
             [A 2-dimensional polyhedron in ZZ^4 defined as the convex hull of 3 vertices]
         """
         from sage.combinat.combination import Combinations
@@ -805,12 +808,13 @@ class Polyhedron_ZZ(Polyhedron_QQ):
            sage: [ len(square.dilation(i).minkowski_decompositions())
            ....:   for i in range(6) ]
            [1, 2, 5, 8, 13, 18]
-           sage: [ ceil((i^2+2*i-1)/2)+1 for i in range(10) ]
+           sage: [ integer_ceil((i^2 + 2*i - 1) / 2) + 1 for i in range(10) ]
            [1, 2, 5, 8, 13, 18, 25, 32, 41, 50]
         """
         if self.dim() > 2 or not self.is_compact():
             raise NotImplementedError('only implemented for bounded polygons')
         summands = []
+
         def is_known_summand(poly):
             for summand in summands:
                 try:
@@ -824,7 +828,7 @@ class Polyhedron_ZZ(Polyhedron_QQ):
                 continue
             Y = self - X
             Y = Y.change_ring(ZZ)  # Minkowski difference returns QQ-polyhedron
-            if X+Y != self:
+            if X + Y != self:
                 continue
             decompositions.append((X, Y))
             summands += [X, Y]
