@@ -170,7 +170,7 @@ def CircularLadderGraph(n):
     Construct and show a circular ladder graph with 26 nodes::
 
         sage: g = graphs.CircularLadderGraph(13)
-        sage: g.show() # long time
+        sage: g.show()  # long time
 
     Create several circular ladder graphs in a Sage graphics array::
 
@@ -179,13 +179,13 @@ def CircularLadderGraph(n):
         sage: for i in range(9):
         ....:    k = graphs.CircularLadderGraph(i+3)
         ....:    g.append(k)
-        sage: for i in range(3):
+        sage: for i in range(3):                                                        # needs sage.plot
         ....:    n = []
         ....:    for m in range(3):
         ....:        n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:    j.append(n)
-        sage: G = graphics_array(j)
-        sage: G.show() # long time
+        sage: G = graphics_array(j)                                                     # needs sage.plot
+        sage: G.show()                          # long time                             # needs sage.plot
     """
     G = Graph(2 * n, name="Circular Ladder graph")
     G._circle_embedding(list(range(n)), radius=1, angle=pi/2)
@@ -248,16 +248,18 @@ def CycleGraph(n):
 
     Compare plotting using the predefined layout and networkx::
 
+        sage: # needs networkx sage.plot
         sage: import networkx
         sage: n = networkx.cycle_graph(23)
         sage: spring23 = Graph(n)
         sage: posdict23 = graphs.CycleGraph(23)
-        sage: spring23.show()  # long time
-        sage: posdict23.show()  # long time
+        sage: spring23.show()                   # long time
+        sage: posdict23.show()                  # long time
 
     We next view many cycle graphs as a Sage graphics array. First we use the
     ``CycleGraph`` constructor, which fills in the position dictionary::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -269,10 +271,11 @@ def CycleGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     Compare to plotting with the spring-layout algorithm::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -285,7 +288,7 @@ def CycleGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     TESTS:
 
@@ -334,6 +337,7 @@ def CompleteGraph(n):
     We view many Complete graphs with a Sage Graphics Array, first with this
     constructor (i.e., the position dictionary filled)::
 
+        sage: # needs sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -345,10 +349,11 @@ def CompleteGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     We compare to plotting with the spring-layout algorithm::
 
+        sage: # needs networkx sage.plot
         sage: import networkx
         sage: g = []
         sage: j = []
@@ -362,10 +367,11 @@ def CompleteGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     Compare the constructors (results will vary)::
 
+        sage: # needs networkx
         sage: import networkx
         sage: t = cputime()
         sage: n = networkx.complete_graph(389); spring389 = Graph(n)
@@ -378,12 +384,13 @@ def CompleteGraph(n):
 
     We compare plotting::
 
+        sage: # needs networkx
         sage: import networkx
         sage: n = networkx.complete_graph(23)
         sage: spring23 = Graph(n)
         sage: posdict23 = graphs.CompleteGraph(23)
-        sage: spring23.show()  # long time
-        sage: posdict23.show()  # long time
+        sage: spring23.show()                   # long time                             # needs sage.plot
+        sage: posdict23.show()                  # long time                             # needs sage.plot
     """
     G = Graph(n, name="Complete graph")
     if n == 1:
@@ -393,6 +400,46 @@ def CompleteGraph(n):
     G.add_edges(((i, j) for i in range(n) for j in range(i + 1, n)))
     return G
 
+def CorrelationGraph(seqs, alpha, include_anticorrelation):
+    """
+    Constructs and returns a correlation graph with a node corresponding to each sequence in `seqs`.
+
+    Edges are added between nodes where the corresponding sequences have a correlation coeffecient greater than alpha.
+
+    If include_anticorrelation is true, then edges are also added between nodes with correlation coeffecient less than -alpha.
+
+    EXAMPLES:
+
+        sage: # needs numpy
+        sage: from sage.graphs.generators.basic import CorrelationGraph
+        sage: data = [[1,2,3], [4,5,6], [7,8,9999]]
+        sage: CG1 = CorrelationGraph(data, 0.9, False)
+        sage: CG2 = CorrelationGraph(data, 0.9, True)
+        sage: CG3 = CorrelationGraph(data, 0.1, True)
+        sage: CG1.edges(sort=False)
+        [(0, 0, None), (0, 1, None), (1, 1, None), (2, 2, None)]
+        sage: CG2.edges(sort=False)
+        [(0, 0, None), (0, 1, None), (1, 1, None), (2, 2, None)]
+        sage: CG3.edges(sort=False)
+        [(0, 0, None), (0, 1, None), (0, 2, None), (1, 1, None), (1, 2, None), (2, 2, None)]
+
+    """
+    from numpy import corrcoef
+    from sage.matrix.constructor import Matrix
+
+    # compute pairwise correlation coeffecients
+    corrs = corrcoef(seqs)
+
+    # compare against alpha to get adjacency matrix
+    if include_anticorrelation:
+        boolean_adjacency_matrix = abs(corrs)>=alpha
+    else:
+        boolean_adjacency_matrix = corrs>=alpha
+
+    adjacency_matrix = Matrix(boolean_adjacency_matrix.astype(int))
+
+    # call graph constructor
+    return Graph(adjacency_matrix, format="adjacency_matrix", name="Correlation Graph")
 
 def CompleteBipartiteGraph(p, q, set_position=True):
     r"""
@@ -438,19 +485,21 @@ def CompleteBipartiteGraph(p, q, set_position=True):
     Two ways of constructing the complete bipartite graph, using different
     layout algorithms::
 
+        sage: # needs networkx
         sage: import networkx
-        sage: n = networkx.complete_bipartite_graph(389, 157); spring_big = Graph(n)   # long time
-        sage: posdict_big = graphs.CompleteBipartiteGraph(389, 157)                    # long time
+        sage: n = networkx.complete_bipartite_graph(389, 157)   # long time
+        sage: spring_big = Graph(n)             # long time
+        sage: posdict_big = graphs.CompleteBipartiteGraph(389, 157)        # long time
 
     Compare the plotting::
 
-        sage: n = networkx.complete_bipartite_graph(11, 17)
-        sage: spring_med = Graph(n)
+        sage: n = networkx.complete_bipartite_graph(11, 17)                             # needs networkx
+        sage: spring_med = Graph(n)                                                     # needs networkx
         sage: posdict_med = graphs.CompleteBipartiteGraph(11, 17)
 
     Notice here how the spring-layout tends to center the nodes of `n1`::
 
-        sage: spring_med.show()  # long time
+        sage: spring_med.show()                 # long time                             # needs networkx
         sage: posdict_med.show()  # long time
 
     View many complete bipartite graphs with a Sage Graphics Array, with this
@@ -461,16 +510,17 @@ def CompleteBipartiteGraph(p, q, set_position=True):
         sage: for i in range(9):
         ....:     k = graphs.CompleteBipartiteGraph(i+1,4)
         ....:     g.append(k)
-        sage: for i in range(3):
+        sage: for i in range(3):                                                        # needs sage.plot
         ....:     n = []
         ....:     for m in range(3):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
-        sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G = graphics_array(j)                                                     # needs sage.plot
+        sage: G.show()                          # long time                             # needs sage.plot
 
     We compare to plotting with the spring-layout algorithm::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -483,7 +533,7 @@ def CompleteBipartiteGraph(p, q, set_position=True):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     :trac:`12155`::
 
@@ -785,13 +835,13 @@ def Toroidal6RegularGrid2dGraph(p, q):
         sage: g = graphs.Toroidal6RegularGrid2dGraph(5,5)
         sage: g.is_regular(k=6)
         True
-        sage: g.is_vertex_transitive()
+        sage: g.is_vertex_transitive()                                                  # needs sage.groups
         True
-        sage: g.line_graph().is_vertex_transitive()
+        sage: g.line_graph().is_vertex_transitive()                                     # needs sage.groups
         True
-        sage: g.automorphism_group().cardinality()
+        sage: g.automorphism_group().cardinality()                                      # needs sage.groups
         300
-        sage: g.is_hamiltonian()
+        sage: g.is_hamiltonian()                                                        # needs sage.numerical.mip
         True
 
     TESTS:
@@ -933,9 +983,9 @@ def GridGraph(dim_list):
 
         sage: dim = [randint(1,4) for i in range(4)]
         sage: g = graphs.GridGraph(dim)
-        sage: import networkx
-        sage: h = Graph( networkx.grid_graph(list(dim)) )
-        sage: g.is_isomorphic(h)
+        sage: import networkx                                                           # needs networkx
+        sage: h = Graph(networkx.grid_graph(list(dim)))                                 # needs networkx
+        sage: g.is_isomorphic(h)                                                        # needs networkx
         True
 
     Trivial cases::
@@ -1070,6 +1120,7 @@ def LadderGraph(n):
 
     Create several ladder graphs in a Sage graphics array::
 
+        sage: # needs sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -1081,7 +1132,7 @@ def LadderGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
     """
     pos_dict = {}
     for i in range(n):
@@ -1223,14 +1274,15 @@ def StarGraph(n):
 
     EXAMPLES::
 
-        sage: import networkx
+        sage: import networkx                                                           # needs networkx
 
     Compare the plots::
 
+        sage: # needs networkx sage.plot
         sage: n = networkx.star_graph(23)
         sage: spring23 = Graph(n)
         sage: posdict23 = graphs.StarGraph(23)
-        sage: spring23.show()  # long time
+        sage: spring23.show()                   # long time
         sage: posdict23.show()  # long time
 
     View many star graphs as a Sage Graphics Array
@@ -1239,6 +1291,7 @@ def StarGraph(n):
 
     ::
 
+        sage: # needs sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -1250,12 +1303,13 @@ def StarGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     Compared to plotting with the spring-layout algorithm
 
     ::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -1268,7 +1322,7 @@ def StarGraph(n):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
     """
     G = Graph({0: list(range(1, n + 1))}, name="Star graph", format="dict_of_lists")
     G.set_pos({0: (0, 0)})
