@@ -78,13 +78,13 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
         sage: for i in range(9):
         ....:     k = graphs.RandomGNP(i+3,.43)
         ....:     g.append(k)
-        sage: for i in range(3):
+        sage: for i in range(3):                                                        # needs sage.plot
         ....:     n = []
         ....:     for m in range(3):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
-        sage: G = graphics_array(j)
-        sage: G.show() # long time
+        sage: G = graphics_array(j)                                                     # needs sage.plot
+        sage: G.show()                          # long time                             # needs sage.plot
         sage: graphs.RandomGNP(4,1)
         Complete graph: Graph on 4 vertices
 
@@ -97,7 +97,7 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
         sage: set_random_seed(0)
         sage: graphs.RandomGNP(50,.2, algorithm="Sage").size()
         243
-        sage: graphs.RandomGNP(50,.2, algorithm="networkx").size()
+        sage: graphs.RandomGNP(50,.2, algorithm="networkx").size()                      # needs networkx
         279     # 32-bit
         209     # 64-bit
     """
@@ -149,19 +149,20 @@ def RandomBarabasiAlbert(n, m, seed=None):
 
     We show the edge list of a random graph on 6 nodes with `m = 2`::
 
-        sage: G = graphs.RandomBarabasiAlbert(6,2)
-        sage: G.order(), G.size()
+        sage: G = graphs.RandomBarabasiAlbert(6,2)                                      # needs networkx
+        sage: G.order(), G.size()                                                       # needs networkx
         (6, 8)
-        sage: G.degree_sequence()  # random
+        sage: G.degree_sequence()  # random                                             # needs networkx
         [4, 3, 3, 2, 2, 2]
 
     We plot a random graph on 12 nodes with `m = 3`::
 
-        sage: ba = graphs.RandomBarabasiAlbert(12,3)
-        sage: ba.show()  # long time
+        sage: ba = graphs.RandomBarabasiAlbert(12,3)                                    # needs networkx
+        sage: ba.show()                         # long time                             # needs networkx sage.plot
 
     We view many random graphs using a graphics array::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(1,10):
@@ -173,11 +174,11 @@ def RandomBarabasiAlbert(n, m, seed=None):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
 
     When `m = 1`, the generated graph is a tree::
 
-        sage: graphs.RandomBarabasiAlbert(6, 1).is_tree()
+        sage: graphs.RandomBarabasiAlbert(6, 1).is_tree()                               # needs networkx
         True
     """
     if seed is None:
@@ -206,28 +207,29 @@ def RandomBipartite(n1, n2, p, set_position=False, seed=None):
 
     EXAMPLES::
 
-        sage: g = graphs.RandomBipartite(5, 2, 0.5)
-        sage: g.vertices(sort=True)
+        sage: g = graphs.RandomBipartite(5, 2, 0.5)                                     # needs numpy
+        sage: g.vertices(sort=True)                                                     # needs numpy
         [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 0), (1, 1)]
 
     TESTS::
 
-        sage: g = graphs.RandomBipartite(5, -3, 0.5)
+        sage: g = graphs.RandomBipartite(5, -3, 0.5)                                    # needs numpy
         Traceback (most recent call last):
         ...
         ValueError: n1 and n2 should be integers strictly greater than 0
-        sage: g = graphs.RandomBipartite(5, 3, 1.5)
+        sage: g = graphs.RandomBipartite(5, 3, 1.5)                                     # needs numpy
         Traceback (most recent call last):
         ...
         ValueError: parameter p is a probability, and so should be a real value between 0 and 1
 
     :trac:`12155`::
 
-        sage: graphs.RandomBipartite(5, 6, .2).complement()
+        sage: graphs.RandomBipartite(5, 6, .2).complement()                             # needs numpy
         complement(Random bipartite graph of order 5+6 with edge probability 0.200000000000000): Graph on 11 vertices
 
     Test assigned positions::
 
+        sage: # needs numpy
         sage: graphs.RandomBipartite(1, 2, .1, set_position=True).get_pos()
         {(0, 0): (1, 1.0), (1, 0): (0, 0), (1, 1): (2.0, 0.0)}
         sage: graphs.RandomBipartite(2, 1, .1, set_position=True).get_pos()
@@ -512,7 +514,7 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False, seed=None):
         sage: m, k = 6, 4
         sage: IS = graphs.RandomBlockGraph(m, k, incidence_structure=True)
         sage: from sage.combinat.designs.incidence_structures import IncidenceStructure
-        sage: IncidenceStructure(IS)
+        sage: IncidenceStructure(IS)                                                    # needs sage.modules
         Incidence structure with 19 points and 6 blocks
         sage: m*(k-1)+1
         19
@@ -665,12 +667,12 @@ def RandomGNM(n, m, dense=False, seed=None):
 
     INPUT:
 
-    - ``n`` - number of vertices.
+    - ``n`` -- number of vertices.
 
-    - ``m`` - number of edges.
+    - ``m`` -- number of edges.
 
-    - ``dense`` - whether to use NetworkX's
-      dense_gnm_random_graph or gnm_random_graph
+    - ``dense`` -- whether to use NetworkX's
+      :func:`dense_gnm_random_graph` or :func:`gnm_random_graph`
 
     - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
       number generator (default: ``None``)
@@ -679,16 +681,17 @@ def RandomGNM(n, m, dense=False, seed=None):
 
     We show the edge list of a random graph on 5 nodes with 10 edges::
 
-        sage: graphs.RandomGNM(5, 10).edges(sort=True, labels=False)
+        sage: graphs.RandomGNM(5, 10).edges(sort=True, labels=False)                    # needs networkx
         [(0, 1), (0, 2), (0, 3), (0, 4), (1, 2), (1, 3), (1, 4), (2, 3), (2, 4), (3, 4)]
 
     We plot a random graph on 12 nodes with m = 12::
 
-        sage: gnm = graphs.RandomGNM(12, 12)
-        sage: gnm.show()  # long time
+        sage: gnm = graphs.RandomGNM(12, 12)                                            # needs networkx
+        sage: gnm.show()                        # long time                             # needs networkx sage.plot
 
     We view many random graphs using a graphics array::
 
+        sage: # needs networkx sage.plot
         sage: g = []
         sage: j = []
         sage: for i in range(9):
@@ -700,7 +703,7 @@ def RandomGNM(n, m, dense=False, seed=None):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
         sage: G = graphics_array(j)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -737,6 +740,7 @@ def RandomNewmanWattsStrogatz(n, k, p, seed=None):
 
     We check that the generated graph contains a cycle of order `n`::
 
+        sage: # needs networkx
         sage: G = graphs.RandomNewmanWattsStrogatz(7, 2, 0.2)
         sage: G.order()
         7
@@ -748,22 +752,22 @@ def RandomNewmanWattsStrogatz(n, k, p, seed=None):
 
     ::
 
-        sage: G = graphs.RandomNewmanWattsStrogatz(12, 2, .3)
-        sage: G.show()  # long time
+        sage: G = graphs.RandomNewmanWattsStrogatz(12, 2, .3)                           # needs networkx
+        sage: G.show()                          # long time                             # needs networkx sage.plot
 
     TESTS:
 
     We check that when `k = 2` and `p = 0`, the generated graph is a cycle::
 
-        sage: G = graphs.RandomNewmanWattsStrogatz(7, 2, 0)
-        sage: G.is_cycle()
+        sage: G = graphs.RandomNewmanWattsStrogatz(7, 2, 0)                             # needs networkx
+        sage: G.is_cycle()                                                              # needs networkx
         True
 
     We check that when `k = 4` and `p = 0`, the generated graph is a circulant
     graph of parameters ``[1, 2]``::
 
-        sage: G = graphs.RandomNewmanWattsStrogatz(7, 4, 0)
-        sage: G.is_isomorphic(graphs.CirculantGraph(7, [1, 2]))
+        sage: G = graphs.RandomNewmanWattsStrogatz(7, 4, 0)                             # needs networkx
+        sage: G.is_isomorphic(graphs.CirculantGraph(7, [1, 2]))                         # needs networkx
         True
 
     REFERENCE:
@@ -805,22 +809,10 @@ def RandomHolmeKim(n, m, p, seed=None):
     may not be all linked to a new node on the first iteration like the BA
     model.
 
-    EXAMPLES:
+    EXAMPLES::
 
-    We check that a random graph on 8 nodes with 2 random edges per node and a
-    probability `p = 0.5` of forming triangles contains a triangle::
-
-        sage: G = graphs.RandomHolmeKim(8, 2, 0.5)
-        sage: G.order(), G.size()
-        (8, 12)
-        sage: C3 = graphs.CycleGraph(3)
-        sage: G.subgraph_search(C3)
-        Subgraph of (): Graph on 3 vertices
-
-    ::
-
-        sage: G = graphs.RandomHolmeKim(12, 3, .3)
-        sage: G.show()  # long time
+        sage: G = graphs.RandomHolmeKim(12, 3, .3)                                      # needs networkx
+        sage: G.show()                          # long time                             # needs networkx sage.plot
 
     REFERENCE:
 
@@ -964,8 +956,8 @@ def connecting_nodes(T, l):
 
         sage: from sage.graphs.generators.random import connecting_nodes
         sage: T = graphs.RandomTree(10)
-        sage: S = connecting_nodes(T, 5)
-        sage: len(S)
+        sage: S = connecting_nodes(T, 5)                                                # needs numpy
+        sage: len(S)                                                                    # needs numpy
         10
     """
     from sage.combinat.permutation import Permutations
@@ -1190,8 +1182,8 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None, s
         sage: T = RandomChordalGraph(20, algorithm="growing", k=5)
         sage: T.is_chordal()
         True
-        sage: T = RandomChordalGraph(20, algorithm="connecting", l=3)
-        sage: T.is_chordal()
+        sage: T = RandomChordalGraph(20, algorithm="connecting", l=3)                   # needs numpy
+        sage: T.is_chordal()                                                            # needs numpy
         True
         sage: T = RandomChordalGraph(20, algorithm="pruned", f=1/3, s=.5)
         sage: T.is_chordal()
@@ -1315,6 +1307,7 @@ def RandomLobster(n, p, q, seed=None):
     We check a random graph with 12 backbone
     nodes and probabilities `p = 0.7` and `q = 0.3`::
 
+        sage: # needs networkx
         sage: G = graphs.RandomLobster(12, 0.7, 0.3)
         sage: leaves = [v for v in G.vertices(sort=False) if G.degree(v) == 1]
         sage: G.delete_vertices(leaves)                                 # caterpillar
@@ -1330,8 +1323,8 @@ def RandomLobster(n, p, q, seed=None):
 
     ::
 
-        sage: G = graphs.RandomLobster(9, .6, .3)
-        sage: G.show()  # long time
+        sage: G = graphs.RandomLobster(9, .6, .3)                                       # needs networkx
+        sage: G.show()                          # long time                             # needs networkx sage.plot
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -1446,17 +1439,17 @@ def RandomTreePowerlaw(n, gamma=3, tries=1000, seed=None):
 
     We check that the generated graph is a tree::
 
-        sage: G = graphs.RandomTreePowerlaw(10, 3)
-        sage: G.is_tree()
+        sage: G = graphs.RandomTreePowerlaw(10, 3)                                      # needs networkx
+        sage: G.is_tree()                                                               # needs networkx
         True
-        sage: G.order(), G.size()
+        sage: G.order(), G.size()                                                       # needs networkx
         (10, 9)
 
     ::
 
-        sage: G = graphs.RandomTreePowerlaw(15, 2)
-        sage: if G:
-        ....:     G.show()  # random output, long time
+        sage: G = graphs.RandomTreePowerlaw(15, 2)                                      # needs networkx
+        sage: if G:                             # random output         # long time, needs networkx sage.plot
+        ....:     G.show()
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -1486,17 +1479,17 @@ def RandomRegular(d, n, seed=None):
 
     We check that a random graph with 8 nodes each of degree 3 is 3-regular::
 
-        sage: G = graphs.RandomRegular(3, 8)
-        sage: G.is_regular(k=3)
+        sage: G = graphs.RandomRegular(3, 8)                                            # needs networkx
+        sage: G.is_regular(k=3)                                                         # needs networkx
         True
-        sage: G.degree_histogram()
+        sage: G.degree_histogram()                                                      # needs networkx
         [0, 0, 0, 8]
 
     ::
 
-        sage: G = graphs.RandomRegular(3, 20)
-        sage: if G:
-        ....:     G.show()  # random output, long time
+        sage: G = graphs.RandomRegular(3, 20)                                           # needs networkx
+        sage: if G:                             # random output         # long time, needs networkx sage.plot
+        ....:     G.show()
 
     REFERENCES:
 
@@ -1536,10 +1529,10 @@ def RandomShell(constructor, seed=None):
 
     EXAMPLES::
 
-        sage: G = graphs.RandomShell([(10,20,0.8),(20,40,0.8)])
-        sage: G.order(), G.size()
+        sage: G = graphs.RandomShell([(10,20,0.8),(20,40,0.8)])                         # needs networkx
+        sage: G.order(), G.size()                                                       # needs networkx
         (30, 52)
-        sage: G.show()  # long time
+        sage: G.show()                          # long time                             # needs networkx sage.plot
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -1901,7 +1894,7 @@ def RandomTriangulation(n, set_position=False, k=3, seed=None):
         True
         sage: G.girth()
         3
-        sage: G.plot(vertex_size=0, vertex_labels=False)
+        sage: G.plot(vertex_size=0, vertex_labels=False)                                # needs sage.plot
         Graphics object consisting of 13 graphics primitives
 
         sage: H = graphs.RandomTriangulation(7, k=5)
@@ -2017,16 +2010,16 @@ def blossoming_contour(t, shift=0, seed=None):
         sage: print(blossoming_contour(BinaryTrees(1).an_element()))
         [('i', 0), ('xb',), ('i', 0), ('xb',), ('i', 0)]
 
-        sage: t = BinaryTrees(2).random_element()
-        sage: print(blossoming_contour(t))  # random
+        sage: t = BinaryTrees(2).random_element()                                       # needs sage.combinat
+        sage: print(blossoming_contour(t))  # random                                    # needs sage.combinat
         [('i', 0), ('xb',), ('i', 0), ('n', 2), ('i', 1), ('xb',), ('i', 1),
         ('xb',), ('i', 1), ('n', 2), ('x',), ('n', 2), ('i', 0)]
 
-        sage: w = blossoming_contour(BinaryTrees(3).random_element()); len(w)
+        sage: w = blossoming_contour(BinaryTrees(3).random_element()); len(w)           # needs sage.combinat
         21
-        sage: w.count(('xb',))
+        sage: w.count(('xb',))                                                          # needs sage.combinat
         4
-        sage: w.count(('x',))
+        sage: w.count(('x',))                                                           # needs sage.combinat
         2
 
     TESTS::
@@ -2110,6 +2103,7 @@ def RandomBicubicPlanar(n, seed=None):
 
     EXAMPLES::
 
+        sage: # needs sage.combinat
         sage: n = randint(200, 300)
         sage: G = graphs.RandomBicubicPlanar(n)
         sage: G.order() == 2*n
@@ -2118,9 +2112,9 @@ def RandomBicubicPlanar(n, seed=None):
         True
         sage: G.is_bipartite() and G.is_planar() and G.is_regular(3)
         True
-        sage: dic = {'red':[v for v in G.vertices(sort=False) if v[0] == 'n'],
+        sage: dic = {'red': [v for v in G.vertices(sort=False) if v[0] == 'n'],
         ....:        'blue': [v for v in G.vertices(sort=False) if v[0] != 'n']}
-        sage: G.plot(vertex_labels=False,vertex_size=20,vertex_colors=dic)
+        sage: G.plot(vertex_labels=False, vertex_size=20, vertex_colors=dic)            # needs sage.plot
         Graphics object consisting of ... graphics primitives
 
     .. PLOT::
@@ -2222,6 +2216,7 @@ def RandomUnitDiskGraph(n, radius=.1, side=1, seed=None):
 
     When using twice the same seed, the vertices get the same positions::
 
+        sage: # needs scipy
         sage: from sage.misc.randstate import current_randstate
         sage: seed = current_randstate().seed()
         sage: G = graphs.RandomUnitDiskGraph(20, radius=.5, side=1, seed=seed)
@@ -2237,8 +2232,8 @@ def RandomUnitDiskGraph(n, radius=.1, side=1, seed=None):
 
     When the radius is more than `\sqrt{2 \text{side}}`, the graph is a clique::
 
-        sage: G = graphs.RandomUnitDiskGraph(10, radius=2, side=1)
-        sage: G.is_clique()
+        sage: G = graphs.RandomUnitDiskGraph(10, radius=2, side=1)                      # needs scipy
+        sage: G.is_clique()                                                             # needs scipy
         True
     """
     if seed is not None:
