@@ -202,18 +202,22 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
+from sage.arith.functions import lcm
+from sage.arith.misc import divisors, gcd
+from sage.categories.groups import Groups
+from sage.groups.abelian_gps.abelian_group_element import AbelianGroupElement
+from sage.groups.group import AbelianGroup as AbelianGroupBase
+from sage.matrix.constructor import matrix
+from sage.matrix.special import diagonal_matrix
+from sage.misc.cachefunc import cached_method
+from sage.misc.misc_c import prod
+from sage.misc.mrange import cartesian_product_iterator, mrange
+from sage.modules.free_module_element import vector
+from sage.rings.infinity import infinity
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.structure.category_object import normalize_names
 from sage.structure.unique_representation import UniqueRepresentation
-from sage.rings.infinity import infinity
-from sage.arith.all import divisors, gcd, lcm
-from sage.groups.abelian_gps.abelian_group_element import AbelianGroupElement
-from sage.misc.cachefunc import cached_method
-from sage.misc.all import prod
-from sage.misc.mrange import mrange, cartesian_product_iterator
-from sage.groups.group import AbelianGroup as AbelianGroupBase
-from sage.categories.groups import Groups
 
 
 # TODO: this uses perm groups - the AbelianGroupElement instance method
@@ -643,9 +647,9 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         """
         return self.elementary_divisors() == ()
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         """
-        Returns True if this group is nontrivial.
+        Return ``True`` if this group is nontrivial.
 
         EXAMPLES::
 
@@ -659,8 +663,6 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         """
         return not self.is_trivial()
 
-    __nonzero__ = __bool__
-
     @cached_method
     def dual_group(self, names="X", base_ring=None):
         """
@@ -854,7 +856,7 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         Requires the optional ``gap_packages`` for infinite groups::
 
             sage: G = AbelianGroup(3, [0,3,4], names="abc")
-            sage: libgap(G)   # optional - gap_packages
+            sage: libgap(G)   # optional - gap_package_polycyclic
             Pcp-group with orders [ 0, 3, 4 ]
         """
         from sage.libs.gap.libgap import libgap
@@ -883,7 +885,7 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
             sage: G = AbelianGroup(3,[0,3,4], names="abc"); G
             Multiplicative Abelian group isomorphic to Z x C3 x C4
-            sage: G._gap_init_()   # optional - gap_packages
+            sage: G._gap_init_()   # optional - gap_package_polycyclic
             'AbelianPcpGroup([0, 3, 4])'
         """
         if self.is_finite():
@@ -974,9 +976,9 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
             sage: F = AbelianGroup(3, [2], names='abc')
             sage: list(map(type, F.gens_orders()))
-            [<type 'sage.rings.integer.Integer'>,
-             <type 'sage.rings.integer.Integer'>,
-             <type 'sage.rings.integer.Integer'>]
+            [<class 'sage.rings.integer.Integer'>,
+             <class 'sage.rings.integer.Integer'>,
+             <class 'sage.rings.integer.Integer'>]
         """
         return self._gens_orders
 
@@ -1022,9 +1024,9 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
             sage: F = AbelianGroup(3, [2], names='abc')
             sage: list(map(type, F.gens_orders()))
-            [<type 'sage.rings.integer.Integer'>,
-             <type 'sage.rings.integer.Integer'>,
-             <type 'sage.rings.integer.Integer'>]
+            [<class 'sage.rings.integer.Integer'>,
+             <class 'sage.rings.integer.Integer'>,
+             <class 'sage.rings.integer.Integer'>]
         """
         # TODO: deprecate
         return self.gens_orders()
@@ -1167,7 +1169,7 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         result = self.one()
         for g in self.gens():
             order = g.order()
-            if order not in ZZ:
+            if order is infinity:
                 order = 42  # infinite order; randomly chosen maximum
             result *= g**(randint(0,order))
         return result
@@ -1245,7 +1247,7 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
             (1,)
         """
         if not self.is_finite():
-           raise NotImplementedError("group must be finite")
+            raise NotImplementedError("group must be finite")
         return tuple(iter(self))
 
     def __len__(self):
@@ -1547,9 +1549,13 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         return self.subgroup([self([x[0][i] % self.gens_orders()[i]
                                     for i in range(d)]) for x in new_basis if x[1] != 1])
 
-    def torsion_subgroup(self):
+    def torsion_subgroup(self, n=None):
         """
-        Return the torsion subgroup of this group.
+        Return the `n`-torsion subgroup of this abelian group when `n`
+        is given, and the torsion subgroup otherwise.
+
+        The [`n`-]torsion subgroup consists of all elements whose order
+        is finite [and divides `n`].
 
         EXAMPLES::
 
@@ -1567,8 +1573,26 @@ class AbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
             sage: G = AbelianGroup([0, 0])
             sage: G.torsion_subgroup()
             Trivial Abelian subgroup
+
+        ::
+
+            sage: G = AbelianGroup([2, 2*3, 2*3*5, 0, 2*3*5*7, 2*3*5*7*11])
+            sage: G.torsion_subgroup(5)
+            Multiplicative Abelian subgroup isomorphic to C5 x C5 x C5 generated by {f2^6, f4^42, f5^462}
         """
-        torsion_generators = [g for g in self.gens() if g.order() != infinity]
+        if n is None:
+            torsion_generators = [g for g in self.gens() if g.order() != infinity]
+        else:
+            n = ZZ(n)
+            if n <= 0:
+                raise ValueError('n must be a positive integer')
+            torsion_generators = []
+            for g in self.gens():
+                o = g.order()
+                if o == infinity:
+                    continue
+                d = n.gcd(o)
+                torsion_generators.append(g**(o//d))
         return self.subgroup(torsion_generators)
 
 
@@ -1652,62 +1676,32 @@ class AbelianGroup_subgroup(AbelianGroup_class):
             sage: F.order()
             +Infinity
 
-        Testing ticket :trac:`18863`::
+        Testing issue :trac:`18863`::
 
             sage: G = AbelianGroup(5,[2])
             sage: G.subgroup([prod(g^k for g,k in zip(G.gens(),[1,-2,3,-4,5]))])
             Multiplicative Abelian subgroup isomorphic to Z generated by {f0*f1^-2*f2^3*f3^-4*f4}
         """
-        from sage.interfaces.all import gap
+        from sage.libs.gap.libgap import libgap
         if not isinstance(ambient, AbelianGroup_class):
-            raise TypeError("ambient (=%s) must be an abelian group."%ambient)
+            raise TypeError("ambient (=%s) must be an abelian group" % ambient)
         if not isinstance(gens, tuple):
-            raise TypeError("gens (=%s) must be a tuple"%gens)
+            raise TypeError("gens (=%s) must be a tuple" % gens)
 
         self._ambient_group = ambient
-        Hgens = tuple(x for x in gens if x != ambient.one())  ## in case someone puts 1 in the list of generators
-        self._gens = Hgens
-        ambient_invs = ambient.gens_orders()
-        invsf = [x for x in ambient_invs if x > 0]    ## fixes the problem with
-        invs0 = [x for x in ambient_invs if x == 0]   ## the infinite parts
-        Ggens = list(ambient.variable_names())
-        if invs0!=[]:
-            Gfgens = [x for x in ambient.variable_names() if
-                        ambient_invs[Ggens.index(x)] != 0]
-            Gf = AbelianGroup(invsf, names=Gfgens)
-            s1 = "G:= %s; gens := GeneratorsOfGroup(G)"%Gf._gap_init_()
-            gap.eval(s1)
-            Hgens0 = [
-                x for x in Hgens if
-                any(e!=0 and (g.order() not in ZZ) for e,g in zip(x.exponents(),ambient.gens()))
-            ]
-            Hgensf = [x for x in Hgens if x not in Hgens0]
-            # the "infinite" generators of H
-            for i in range(len(Gfgens)):
-               cmd = ("%s := gens["+str(i+1)+"]")%Gfgens[i]
-               gap.eval(cmd)
-        else:  # invs0==[]:
-            Hgensf = Hgens
-            Hgens0 = []  # added for consistency
-            G = ambient
-            s1 = "G:= %s; gens := GeneratorsOfGroup(G)"%G._gap_init_()
-            gap.eval(s1)
-            for i in range(len(Ggens)):
-                cmd = '%s := gens[%s]'%(Ggens[i], i+1)
-                gap.eval(cmd)
-        s2 = "gensH:=%s"%list(Hgensf) #### remove from this the ones <--> 0 invar
-        gap.eval(s2)
-        s3 = 'H:=Subgroup(G,gensH)'
-        gap.eval(s3)
-        # a GAP command which returns the "invariants" of the
-        # subgroup as an AbelianPcpGroup, RelativeOrdersOfPcp(Pcp(G)),
-        # works if G is the subgroup declared as a AbelianPcpGroup
-        self._abinvs = eval(gap.eval("AbelianInvariants(H)"))
-        invs = self._abinvs
-        if Hgens0 != []:
-            for x in Hgens0:
-               invs.append(0)
+        H_gens = tuple(x for x in gens if x != ambient.one())  # clean entry
+        self._gens = H_gens
+
+        H = libgap(ambient).Subgroup(H_gens)
+
+        invs = H.TorsionSubgroup().AbelianInvariants().sage()
+        rank = len([1 for g in H.GeneratorsOfGroup()
+                    if g.Order().sage() is infinity])
+        invs += [0] * rank
+
+        self._abinvs = invs
         invs = tuple(ZZ(i) for i in invs)
+
         if category is None:
             category = Groups().Commutative().Subobjects()
         AbelianGroup_class.__init__(self, invs, names, category=category)
@@ -1724,34 +1718,45 @@ class AbelianGroup_subgroup(AbelianGroup_class):
             True
             sage: a in A
             True
+
+        TESTS:
+
+        Check that :trac:`32910` is fixed::
+
+            sage: G.<a,b> = AbelianGroup(2, [4, 576])
+            sage: Hgens = [a^2, a*b^2]
+            sage: H = G.subgroup(Hgens)
+            sage: [g in H for g in (a^3, b^2, b^3, a^3*b^2, "junk")]
+            [False, False, False, True, False]
+
+        Check that :trac:`31507` is fixed::
+
+            sage: G = AbelianGroup(2, gens_orders=[16, 16])
+            sage: f0, f1 = G.gens()
+            sage: H = G.subgroup([f0*f1^3])
+            sage: [g in H for g in (f0, f0*f1^2, f0*f1^3, f0*f1^4)]
+            [False, False, True, False]
+
+            sage: G.<a,b> = AbelianGroup(2)
+            sage: Hgens =  [a*b, a*b^-1]
+            sage: H = G.subgroup(Hgens)
+            sage: b^2 in H
+            True
         """
         if not isinstance(x, AbelianGroupElement):
             return False
         if x.parent() is self:
             return True
-        elif x in self.ambient_group():
+        if x in self.ambient_group():
             amb_inv = self.ambient_group().gens_orders()
-            for a in range(len(amb_inv)):
-                if amb_inv[a] == 0 and x.list()[a] != 0:
-                    for g in self._gens:
-                        if g.list()[a] == 0:
-                            continue
-                        if abs(x.list()[a]%g.list()[a]) < abs(x.list()[a]):
-                            if g.list()[a]*x.list()[a] < 0:
-                                x *= g**(x.list()[a]/g.list()[a])
-                            else:
-                                x *= g**((-1)*(x.list()[a]/g.list()[a]))
-                        if x.list()[a] == 0:
-                            break
-                elif x.list()[a] != 0:
-                    for g in self._gens:
-                        if g.list()[a] == 0:
-                            continue
-                        if abs(x.list()[a]%g.list()[a])%abs(amb_inv[a]) < x.list()[a]%abs(amb_inv[a]):
-                            x *= g**((-1)*(x.list()[a]/g.list()[a]))
-                        if x.list()[a] == 0:
-                            break
-            return x == x.parent()(1)
+            inv_basis = diagonal_matrix(ZZ, amb_inv)
+            gens_basis = matrix(
+                ZZ, len(self._gens), len(amb_inv),
+                [g.list() for g in self._gens]
+            )
+            return (vector(ZZ, x.list())
+                in inv_basis.stack(gens_basis).row_module())
+        return False
 
     def ambient_group(self):
         """
@@ -1834,7 +1839,7 @@ class AbelianGroup_subgroup(AbelianGroup_class):
             sage: A._repr_()
             'Multiplicative Abelian subgroup isomorphic to Z generated by {a}'
        """
-        eldv = self.gens_orders()
+        eldv = self._abinvs
         if self.is_trivial():
             return "Trivial Abelian subgroup"
         s = 'Multiplicative Abelian subgroup isomorphic to '
@@ -1877,4 +1882,3 @@ class AbelianGroup_subgroup(AbelianGroup_class):
 
 # We allow subclasses to override this, analogous to Element
 AbelianGroup_class.Subgroup = AbelianGroup_subgroup
-
