@@ -28,7 +28,6 @@ AUTHORS:
 - François Bissey, Bill Page, Jeroen Demeyer (2015-12-09): Upgrade to
   pexpect 4.0.1 + patches, see :trac:`10295`.
 """
-
 # ****************************************************************************
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
 #
@@ -38,7 +37,6 @@ AUTHORS:
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
-
 import io
 import os
 import re
@@ -52,6 +50,7 @@ from random import randrange
 
 import pexpect
 from pexpect import ExceptionPexpect
+import sage.interfaces.abc
 from sage.interfaces.sagespawn import SageSpawn
 from sage.interfaces.interface import (Interface, InterfaceElement,
             InterfaceFunction, InterfaceFunctionElement)
@@ -218,7 +217,7 @@ class Expect(Interface):
 
     def server(self):
         """
-        Returns the server used in this interface.
+        Return the server used in this interface.
 
         EXAMPLES::
 
@@ -231,7 +230,7 @@ class Expect(Interface):
 
     def command(self):
         """
-        Returns the command used in this interface.
+        Return the command used in this interface.
 
         EXAMPLES::
 
@@ -474,7 +473,7 @@ If this all works, you can then make calls like:
         # Unset some environment variables for the children to
         # reduce the chances they do something complicated breaking
         # the terminal interface.
-        # See Trac #12221 and #13859.
+        # See Issue #12221 and #13859.
         pexpect_env = dict(os.environ)
         pexpect_env.update(self._env)
         pexpect_del_vars = ['TERM', 'COLUMNS']
@@ -544,7 +543,7 @@ If this all works, you can then make calls like:
         does *not* mark the process as terminated.  The same exception results,
         then, from any attempt to close the pexpect process.
 
-        See https://trac.sagemath.org/ticket/28354
+        See https://github.com/sagemath/sage/issues/28354
         """
         try:
             return self._expect is not None and self._expect.isalive()
@@ -621,7 +620,7 @@ If this all works, you can then make calls like:
 
             sage: a = maxima('y')
             sage: maxima.quit(verbose=True)
-            Exiting Maxima with PID ... running .../bin/maxima...
+            Exiting Maxima with PID ... running ...maxima...
             sage: a._check_valid()
             Traceback (most recent call last):
             ...
@@ -941,7 +940,6 @@ If this all works, you can then make calls like:
         The interface still works after this interrupt::
 
             sage: singular('2+3')
-            Singular crashed -- automatically restarting.
             5
 
         Last, we demonstrate that by default the execution of a command
@@ -984,7 +982,7 @@ If this all works, you can then make calls like:
                     if sys.platform.startswith('sunos'):
                         # On (Open)Solaris, we might need to wait a
                         # while because the process might not die
-                        # immediately. See Trac #14371.
+                        # immediately. See Issue #14371.
                         for t in [0.5, 1.0, 2.0]:
                             if self._isalive():
                                 time.sleep(t)
@@ -1082,11 +1080,11 @@ If this all works, you can then make calls like:
     # BEGIN Synchronization code.
     ###########################################################################
 
-    def _before(self, encoding=None, errors=None):
+    def _before(self, encoding=None, errors=None) -> str:
         r"""
         Return the previous string that was sent through the interface.
 
-        Returns ``str`` objects on both Python 2 and Python 3.
+        This returns a ``str`` object.
 
         The ``encoding`` and ``errors`` arguments are passed to
         :func:`sage.misc.cpython.bytes_to_str`.
@@ -1126,7 +1124,7 @@ If this all works, you can then make calls like:
 
         return after
 
-    def _readline(self, size=-1, encoding=None, errors=None):
+    def _readline(self, size=-1, encoding=None, errors=None) -> str:
         r"""
         Wraps ``spawn.readline`` to pass the return values through
         ``bytes_to_str``, like `Expect._before` and `Expect._after`.
@@ -1139,7 +1137,6 @@ If this all works, you can then make calls like:
             sage: singular._readline()
             '2\r\n'
         """
-
         return bytes_to_str(self._expect.readline(size=size), encoding, errors)
 
     def _interrupt(self):
@@ -1166,12 +1163,10 @@ If this all works, you can then make calls like:
 
         INPUT:
 
-
-        -  ``expr`` - None or a string or list of strings
+        -  ``expr`` -- None or a string or list of strings
            (default: None)
 
-        -  ``timeout`` - None or a number (default: None)
-
+        -  ``timeout`` -- None or a number (default: None)
 
         EXAMPLES:
 
@@ -1181,15 +1176,13 @@ If this all works, you can then make calls like:
             sage: singular._sendstr('def abc = 10 + 15;\n')
 
         Then we tell singular to print 10, which is an arbitrary number
-        different from the expected result 35.
+        different from the expected result 35::
 
             sage: singular._sendstr('10;\n')
 
         Here an exception is raised because 25 hasn't appeared yet in the
         output stream. The key thing is that this doesn't lock, but instead
-        quickly raises an exception.
-
-        ::
+        quickly raises an exception::
 
             sage: t = walltime()
             sage: try:
@@ -1203,21 +1196,15 @@ If this all works, you can then make calls like:
             sage: w = walltime(t); 0.3 < w < 10
             True
 
-        We tell Singular to print abc, which equals 25.
-
-        ::
+        We tell Singular to print abc, which equals 25::
 
             sage: singular._sendstr('abc;\n')
 
-        Now 25 is in the output stream, so we can wait for it.
-
-        ::
+        Now 25 is in the output stream, so we can wait for it::
 
             sage: singular._expect_expr('25')
 
-        This gives us everything before the 25, including the 10 we printed earlier.
-
-        ::
+        This gives us everything before the 25, including the 10 we printed earlier::
 
             sage: singular._expect.before.decode('ascii')
             '...10\r\n> '
@@ -1353,7 +1340,6 @@ If this all works, you can then make calls like:
         """
         INPUT:
 
-
         -  ``code``       -- text to evaluate
 
         -  ``strip``      -- bool; whether to strip output prompts,
@@ -1401,8 +1387,8 @@ If this all works, you can then make calls like:
                         self._eval_using_file_cutoff and len(code) > self._eval_using_file_cutoff):
                     return self._eval_line_using_file(code)
                 elif split_lines:
-                    return '\n'.join([self._eval_line(L, allow_use_file=allow_use_file, **kwds)
-                                      for L in code.split('\n') if L != ''])
+                    return '\n'.join(self._eval_line(L, allow_use_file=allow_use_file, **kwds)
+                                     for L in code.split('\n') if L)
                 else:
                     return self._eval_line(code, allow_use_file=allow_use_file, **kwds)
         # DO NOT CATCH KeyboardInterrupt, as it is being caught
@@ -1466,11 +1452,28 @@ class FunctionElement(InterfaceFunctionElement):
 
 
 def is_ExpectElement(x):
+    """
+    Return True if ``x`` is of type :class:`ExpectElement`
+
+    This function is deprecated; use :func:`isinstance`
+    (of :class:`sage.interfaces.abc.ExpectElement`) instead.
+
+    EXAMPLES::
+
+        sage: from sage.interfaces.expect import is_ExpectElement
+        sage: is_ExpectElement(2)
+        doctest:...: DeprecationWarning: the function is_ExpectElement is deprecated; use isinstance(x, sage.interfaces.abc.ExpectElement) instead
+        See https://github.com/sagemath/sage/issues/34804 for details.
+        False
+    """
+    from sage.misc.superseded import deprecation
+    deprecation(34804, "the function is_ExpectElement is deprecated; use isinstance(x, sage.interfaces.abc.ExpectElement) instead")
+
     return isinstance(x, ExpectElement)
 
 
 @instancedoc
-class ExpectElement(InterfaceElement):
+class ExpectElement(InterfaceElement, sage.interfaces.abc.ExpectElement):
     """
     Expect element.
     """
@@ -1503,7 +1506,9 @@ class ExpectElement(InterfaceElement):
 
     def __hash__(self):
         """
-        Returns the hash of self. This is a default implementation of hash
+        Return the hash of self.
+
+        This is a default implementation of hash
         which just takes the hash of the string of self.
         """
         return hash('%s%s' % (self, self._session_number))
@@ -1535,7 +1540,7 @@ class ExpectElement(InterfaceElement):
                 if P is not None:
                     P.clear(self._name)
 
-        except (RuntimeError, ExceptionPexpect):    # needed to avoid infinite loops in some rare cases
+        except (RuntimeError, ExceptionPexpect):  # needed to avoid infinite loops in some rare cases
             pass
 
 #    def _sage_repr(self):
@@ -1554,11 +1559,11 @@ class StdOutContext:
 
         INPUT:
 
-        - ``interface`` - the interface whose communication shall be dumped.
+        - ``interface`` -- the interface whose communication shall be dumped.
 
-        - ``silent`` - if ``True`` this context does nothing
+        - ``silent`` -- if ``True`` this context does nothing
 
-        - ``stdout`` - optional parameter for alternative stdout device (default: ``None``)
+        - ``stdout`` -- optional parameter for alternative stdout device (default: ``None``)
 
         EXAMPLES::
 
@@ -1612,7 +1617,3 @@ class StdOutContext:
         self.interface._expect.logfile.flush()
         self.stdout.write("\n")
         self.interface._expect.logfile = self._logfile_backup
-
-
-def console(cmd):
-    os.system(cmd)
