@@ -39,17 +39,17 @@ import operator
 # Sage matrix imports see :trac:`34283`
 
 # Sage imports
-import sage.structure.coerce
+import sage.structure.coerce_actions
 from sage.structure.parent import Parent
 from sage.structure.unique_representation import UniqueRepresentation
 import sage.rings.integer as integer
-import sage.rings.finite_rings.finite_field_constructor
+from sage.rings.finite_rings.finite_field_base import FiniteField
 import sage.misc.latex as latex
 import sage.modules.free_module
 
 from sage.misc.lazy_attribute import lazy_attribute
 from sage.misc.superseded import deprecated_function_alias
-
+from sage.misc.persist import register_unpickle_override
 from sage.categories.rings import Rings
 from sage.categories.fields import Fields
 from sage.categories.enumerated_sets import EnumeratedSets
@@ -166,10 +166,12 @@ def get_matrix_class(R, nrows, ncols, sparse, implementation):
         sage: get_matrix_class(Zmod(2**30), 2, 2, False, 'linbox-double')
         Traceback (most recent call last):
         ...
-        ValueError: 'linbox-double' matrices can only deal with order < 8388608
+        ValueError: 'linbox-double' matrices can only deal with order < 94906266
 
         sage: type(matrix(SR, 2, 2, 0))
         <class 'sage.matrix.matrix_symbolic_dense.Matrix_symbolic_dense'>
+        sage: type(matrix(SR, 2, 2, 0, sparse=True))
+        <class 'sage.matrix.matrix_symbolic_sparse.Matrix_symbolic_sparse'>
         sage: type(matrix(GF(7), 2, range(4)))
         <class 'sage.matrix.matrix_modn_dense_float.Matrix_modn_dense_float'>
         sage: type(matrix(GF(16007), 2, range(4)))
@@ -223,7 +225,7 @@ def get_matrix_class(R, nrows, ncols, sparse, implementation):
                     else:
                         return matrix_complex_double_dense.Matrix_complex_double_dense
 
-            elif sage.rings.finite_rings.finite_field_constructor.is_FiniteField(R):
+            elif isinstance(R, FiniteField):
                 if R.order() == 2:
                     try:
                         from . import matrix_mod2_dense
@@ -397,16 +399,27 @@ def get_matrix_class(R, nrows, ncols, sparse, implementation):
         else:
             return matrix_integer_sparse.Matrix_integer_sparse
 
-    if R is sage.rings.real_double.RDF or R is sage.rings.complex_double.CDF:
+    if isinstance(R, (sage.rings.abc.RealDoubleField, sage.rings.abc.ComplexDoubleField)):
         from . import matrix_double_sparse
         return matrix_double_sparse.Matrix_double_sparse
+    try:
+        from sage.symbolic.ring import SR
+    except ImportError:
+        pass
+    else:
+        if R is SR:
+            try:
+                from . import matrix_symbolic_sparse
+            except ImportError:
+                pass
+            else:
+                return matrix_symbolic_sparse.Matrix_symbolic_sparse
 
     # the fallback
     from sage.matrix.matrix_generic_sparse import Matrix_generic_sparse
     return Matrix_generic_sparse
 
 
-
 class MatrixSpace(UniqueRepresentation, Parent):
     """
     The space of matrices of given size and base ring
@@ -544,10 +557,10 @@ class MatrixSpace(UniqueRepresentation, Parent):
             sage: class MyMatrixSpace(MatrixSpace):
             ....:     @staticmethod
             ....:     def __classcall__(cls, base_ring, nrows, ncols=None, my_option=True, sparse=False, implementation=None):
-            ....:         return super(MyMatrixSpace, cls).__classcall__(cls, base_ring, nrows, ncols=ncols, my_option=my_option, sparse=sparse, implementation=implementation)
+            ....:         return super().__classcall__(cls, base_ring, nrows, ncols=ncols, my_option=my_option, sparse=sparse, implementation=implementation)
             ....:
             ....:     def __init__(self, base_ring, nrows, ncols, sparse,  implementation, my_option=True):
-            ....:         super(MyMatrixSpace, self).__init__(base_ring, nrows, ncols, sparse, implementation)
+            ....:         super().__init__(base_ring, nrows, ncols, sparse, implementation)
             ....:         self._my_option = my_option
 
             sage: MS1 = MyMatrixSpace(ZZ, 2)
@@ -558,7 +571,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
             False
         """
         if base_ring not in _Rings:
-            raise TypeError("base_ring (=%s) must be a ring"%base_ring)
+            raise TypeError("base_ring (=%s) must be a ring" % base_ring)
         nrows = int(nrows)
         if ncols is None:
             ncols = nrows
@@ -574,8 +587,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
             raise OverflowError("number of rows and columns may be at most %s" % sys.maxsize)
 
         matrix_cls = get_matrix_class(base_ring, nrows, ncols, sparse, implementation)
-        return super(MatrixSpace, cls).__classcall__(
-                cls, base_ring, nrows, ncols, sparse, matrix_cls, **kwds)
+        return super().__classcall__(cls, base_ring, nrows,
+                                     ncols, sparse, matrix_cls, **kwds)
 
     def __init__(self, base_ring, nrows, ncols, sparse, implementation):
         r"""
@@ -604,7 +617,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
            - ``linbox-float`` - for integer mod rings up to `2^8 = 256`
 
-           - ``linbox-double`` - for integer mod rings up to `2^23 = 8388608`
+           - ``linbox-double`` - for integer mod rings up to
+             `floor(2^26*sqrt(2) + 1/2) = 94906266`
 
            - ``numpy`` - for real and complex floating point numbers
 
@@ -680,7 +694,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
         self.__ncols = ncols
         self.__is_sparse = sparse
 
-        from sage.categories.all import Modules, Algebras
+        from sage.categories.modules import Modules
+        from sage.categories.algebras import Algebras
         if nrows == ncols:
             category = Algebras(base_ring.category())
         else:
@@ -1054,7 +1069,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
                         return matrix_action.MatrixPolymapAction(self, S)
                     else:
                         # action of base ring
-                        return sage.structure.coerce.RightModuleAction(S, self)
+                        return sage.structure.coerce_actions.RightModuleAction(S, self)
                 else:
                     if is_MatrixSpace(S):
                         # matrix multiplications
@@ -1065,7 +1080,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
                         return matrix_action.PolymapMatrixAction(self, S)
                     else:
                         # action of base ring
-                        return sage.structure.coerce.LeftModuleAction(S, self)
+                        return sage.structure.coerce_actions.LeftModuleAction(S, self)
         except TypeError:
             return None
 
@@ -1209,7 +1224,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
             if B is not T:
                 # Matrix spaces over different base rings.
                 # TODO: make this an actual map induced by the map
-                # on the bases, see Trac #25540
+                # on the bases, see Issue #25540
                 return B.has_coerce_map_from(T)
 
             # Base ring and dimensions are the same. So the only
@@ -1230,12 +1245,24 @@ class MatrixSpace(UniqueRepresentation, Parent):
             pass
         else:
             MS = meth_matrix_space()
-            from sage.groups.matrix_gps.matrix_group import is_MatrixGroup
-            from sage.modular.arithgroup.arithgroup_generic import is_ArithmeticSubgroup
-            if is_MatrixGroup(S) or is_ArithmeticSubgroup(S):
-                return self.has_coerce_map_from(MS)
+
+            try:
+                from sage.groups.matrix_gps.matrix_group import is_MatrixGroup
+            except ImportError:
+                pass
             else:
-                return False
+                if is_MatrixGroup(S):
+                    return self.has_coerce_map_from(MS)
+
+            try:
+                from sage.modular.arithgroup.arithgroup_generic import is_ArithmeticSubgroup
+            except ImportError:
+                pass
+            else:
+                if is_ArithmeticSubgroup(S):
+                    return self.has_coerce_map_from(MS)
+
+            return False
 
         # The parent is not matrix-like: coerce via base ring
         return (self.nrows() == self.ncols()) and self._coerce_map_via([B], S)
@@ -1261,8 +1288,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
             s = "sparse"
         else:
             s = "dense"
-        s = "Full MatrixSpace of %s by %s %s matrices over %s"%(
-                    self.__nrows, self.__ncols, s, self.base_ring())
+        s = "Full MatrixSpace of %s by %s %s matrices over %s" % (
+            self.__nrows, self.__ncols, s, self.base_ring())
 
         if not self._has_default_implementation():
             s += " (using {})".format(self.Element.__name__)
@@ -1283,7 +1310,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         if key == 'element_ascii_art':
             return self.__nrows > 1
-        return super(MatrixSpace, self)._repr_option(key)
+        return super()._repr_option(key)
 
     def _latex_(self):
         r"""
@@ -1295,8 +1322,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
             sage: latex(MS3)
             \mathrm{Mat}_{6\times 6}(\Bold{Q})
         """
-        return "\\mathrm{Mat}_{%s\\times %s}(%s)"%(self.nrows(), self.ncols(),
-                                                      latex.latex(self.base_ring()))
+        return "\\mathrm{Mat}_{%s\\times %s}(%s)" % (self.nrows(), self.ncols(),
+                                                     latex.latex(self.base_ring()))
 
     def __len__(self):
         """
@@ -1504,14 +1531,14 @@ class MatrixSpace(UniqueRepresentation, Parent):
             ...
             NotImplementedError: len() of an infinite set
         """
-        #Make sure that we can iterate over the base ring
+        # Make sure that we can iterate over the base ring
         base_ring = self.base_ring()
         base_iter = iter(base_ring)
 
-        number_of_entries = (self.__nrows*self.__ncols)
+        number_of_entries = (self.__nrows * self.__ncols)
 
-        #If the number of entries is zero, then just
-        #yield the empty matrix in that case and return
+        # If the number of entries is zero, then just
+        # yield the empty matrix in that case and return
         if number_of_entries == 0:
             yield self(0)
             return
@@ -1519,11 +1546,11 @@ class MatrixSpace(UniqueRepresentation, Parent):
         import sage.combinat.integer_vector
 
         if not base_ring.is_finite():
-            #When the base ring is not finite, then we should go
-            #through and yield the matrices by "weight", which is
-            #the total number of iterations that need to be done
-            #on the base ring to reach the matrix.
-            base_elements = [ next(base_iter) ]
+            # When the base ring is not finite, then we should go
+            # through and yield the matrices by "weight", which is
+            # the total number of iterations that need to be done
+            # on the base ring to reach the matrix.
+            base_elements = [next(base_iter)]
             weight = 0
             while True:
                 for iv in sage.combinat.integer_vector.IntegerVectors(weight, number_of_entries):
@@ -1579,7 +1606,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         if isinstance(x, (integer.Integer, int)):
             return self.list()[x]
-        return super(MatrixSpace, self).__getitem__(x)
+        return super().__getitem__(x)
 
     def basis(self):
         """
@@ -1639,7 +1666,6 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         return (self.__nrows, self.__ncols)
 
-
     def submodule(self, gens, check=True, already_echelonized=False,
                   unitriangular=False, support_order=None, category=None,
                   *args, **opts):
@@ -1733,6 +1759,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
                                   category=category, *args, **opts)
 
     from sage.misc.cachefunc import cached_method
+
     @cached_method
     def identity_matrix(self):
         """
@@ -1903,7 +1930,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
         r = n // self.__ncols
         c = n - (r * self.__ncols)
         z = self.zero_matrix().__copy__()
-        z[r,c] = 1
+        z[r, c] = 1
         return z
 
     @cached_method
@@ -2019,9 +2046,10 @@ class MatrixSpace(UniqueRepresentation, Parent):
             sage: MS([[1],[2]])
             [1]
             [2]
-            sage: MS = MatrixSpace(CC,2,1)
-            sage: F = NumberField(x^2+1, name='x')
-            sage: MS([F(1),F(0)])
+            sage: MS = MatrixSpace(CC, 2, 1)
+            sage: x = polygen(ZZ, 'x')
+            sage: F = NumberField(x^2 + 1, name='x')                                    # optional - sage.rings.number_field
+            sage: MS([F(1), F(0)])                                                      # optional - sage.rings.number_field
             [ 1.00000000000000]
             [0.000000000000000]
 
@@ -2208,10 +2236,10 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         Z = self.zero_matrix().__copy__()
         if density is None:
-            Z.randomize(density=float(1), nonzero=kwds.pop('nonzero', False), \
+            Z.randomize(density=float(1), nonzero=kwds.pop('nonzero', False),
                 *args, **kwds)
         else:
-            Z.randomize(density=density, nonzero=kwds.pop('nonzero', True), \
+            Z.randomize(density=density, nonzero=kwds.pop('nonzero', True),
                 *args, **kwds)
         return Z
 
@@ -2328,10 +2356,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
         """
         K = magma(self.base_ring())
         if self.__nrows == self.__ncols:
-            s = 'MatrixAlgebra(%s,%s)'%(K.name(), self.__nrows)
-        else:
-            s = 'RMatrixSpace(%s,%s,%s)'%(K.name(), self.__nrows, self.__ncols)
-        return s
+            return 'MatrixAlgebra(%s,%s)' % (K.name(), self.__nrows)
+        return 'RMatrixSpace(%s,%s,%s)' % (K.name(), self.__nrows, self.__ncols)
 
     def _polymake_init_(self):
         r"""
@@ -2384,6 +2410,7 @@ class MatrixSpace(UniqueRepresentation, Parent):
             rand_matrix = self.random_element(*args, **kwds)
         return rand_matrix
 
+
 def dict_to_list(entries, nrows, ncols):
     r"""
     Given a dictionary of coordinate tuples, return the list given by
@@ -2468,59 +2495,59 @@ def _test_trivial_matrices_inverse(ring, sparse=True, implementation=None, check
     """
     # Check that the empty 0x0 matrix is it's own inverse with det=1.
     ms00 = MatrixSpace(ring, 0, 0, sparse=sparse)
-    m00  = ms00(0)
-    assert(m00.determinant() == ring(1))
-    assert(m00.is_invertible())
-    assert(m00.inverse() == m00)
+    m00 = ms00(0)
+    assert m00.determinant() == ring(1)
+    assert m00.is_invertible()
+    assert m00.inverse() == m00
     if checkrank:
-        assert(m00.rank() == 0)
+        assert m00.rank() == 0
 
     # Check that the empty 0x3 and 3x0 matrices are not invertible and that
     # computing the determinant raise the proper exception.
     for ms0 in [MatrixSpace(ring, 0, 3, sparse=sparse),
                 MatrixSpace(ring, 3, 0, sparse=sparse)]:
-        mn0  = ms0(0)
-        assert(not mn0.is_invertible())
+        mn0 = ms0(0)
+        assert not mn0.is_invertible()
         try:
             d = mn0.determinant()
             print(d)
             res = False
         except ValueError:
             res = True
-        assert(res)
+        assert res
         try:
             mn0.inverse()
             res = False
         except ArithmeticError:
             res = True
-        assert(res)
+        assert res
         if checkrank:
-            assert(mn0.rank() == 0)
+            assert mn0.rank() == 0
 
     # Check that the null 1x1 matrix is not invertible and that det=0
     ms1 = MatrixSpace(ring, 1, 1, sparse=sparse)
-    m0  = ms1(0)
-    assert(not m0.is_invertible())
-    assert(m0.determinant() == ring(0))
+    m0 = ms1(0)
+    assert not m0.is_invertible()
+    assert m0.determinant() == ring(0)
     try:
         m0.inverse()
         res = False
     except (ZeroDivisionError, RuntimeError):
-        #FIXME: Make pynac throw a ZeroDivisionError on division by
-        #zero instead of a runtime Error
+        # FIXME: Make pynac throw a ZeroDivisionError on division by
+        # zero instead of a runtime Error
         res = True
-    assert(res)
+    assert res
     if checkrank:
-        assert(m0.rank() == 0)
+        assert m0.rank() == 0
 
     # Check that the identity 1x1 matrix is its own inverse with det=1
-    m1  = ms1(1)
-    assert(m1.is_invertible())
-    assert(m1.determinant() == ring(1))
+    m1 = ms1(1)
+    assert m1.is_invertible()
+    assert m1.determinant() == ring(1)
     inv = m1.inverse()
-    assert(inv == m1)
+    assert inv == m1
     if checkrank:
-        assert(m1.rank() == 1)
+        assert m1.rank() == 1
 
 
 test_trivial_matrices_inverse = deprecated_function_alias(33612, _test_trivial_matrices_inverse)
@@ -2529,10 +2556,13 @@ test_trivial_matrices_inverse = deprecated_function_alias(33612, _test_trivial_m
 # Fix unpickling Matrix_modn_dense and Matrix_integer_2x2
 lazy_import('sage.matrix.matrix_modn_dense_double', 'Matrix_modn_dense_double')
 lazy_import('sage.matrix.matrix_integer_dense', 'Matrix_integer_dense')
-from sage.misc.persist import register_unpickle_override
+
+
 def _MatrixSpace_ZZ_2x2():
     from sage.rings.integer_ring import ZZ
-    return MatrixSpace(ZZ,2)
+    return MatrixSpace(ZZ, 2)
+
+
 register_unpickle_override('sage.matrix.matrix_modn_dense',
     'Matrix_modn_dense', Matrix_modn_dense_double)
 register_unpickle_override('sage.matrix.matrix_integer_2x2',
