@@ -41,6 +41,7 @@ Check that sphinx is not imported at Sage start-up::
 # ****************************************************************************
 import os
 import re
+import shutil
 import sys
 import pydoc
 from sage.misc.temporary_file import tmp_dir
@@ -423,7 +424,7 @@ def process_dollars(s):
         doctest:warning...
         DeprecationWarning: using dollar signs to mark up math in Sage docstrings
         is deprecated; use backticks instead
-        See https://trac.sagemath.org/33973 for details.
+        See https://github.com/sagemath/sage/issues/33973 for details.
         'some math: `x=y`'
 
     Replace \\$ with $, and don't do anything when backticks are involved::
@@ -501,11 +502,12 @@ def process_dollars(s):
     return s
 
 
-# Sage trac ticket shortcuts. For example, :trac:`7549` .
+# Sage github issue shortcuts. For example, :trac:`7549` .
 pythonversion = sys.version.split(' ')[0]
 extlinks = {
     'python': (f'https://docs.python.org/release/{pythonversion}/%s', None),
-    'trac': ('https://trac.sagemath.org/%s', 'trac ticket #%s'),
+    'trac': ('https://github.com/sagemath/sage/issues/%s', 'github issue #%s'), # support :trac: for backward compatibility
+    'issue': ('https://github.com/sagemath/sage/issues/%s', 'github issue #%s'),
     'wikipedia': ('https://en.wikipedia.org/wiki/%s', 'Wikipedia article %s'),
     'arxiv': ('https://arxiv.org/abs/%s', 'arXiv %s'),
     'oeis': ('https://oeis.org/%s', 'OEIS sequence %s'),
@@ -519,8 +521,8 @@ def process_extlinks(s, embedded=False):
     r"""nodetex
 
     In docstrings at the command line, process markup related to the
-    Sphinx extlinks extension. For example, replace ``:trac:`NUM```
-    with ``https://trac.sagemath.org/NUM``, and similarly with
+    Sphinx extlinks extension. For example, replace ``:issue:`NUM```
+    with ``https://github.com/sagemath/sage/issues/NUM``, and similarly with
     ``:python:TEXT`` and ``:wikipedia:TEXT``, looking up the url from
     the dictionary ``extlinks`` in ``sage_docbuild.conf``.
     If ``TEXT`` is of the form ``blah <LINK>``, then it uses ``LINK``
@@ -540,9 +542,9 @@ def process_extlinks(s, embedded=False):
 
         sage: from sage.misc.sagedoc import process_extlinks
         sage: process_extlinks('See :trac:`1234`, :wikipedia:`Wikipedia <Sage_(mathematics_software)>`, and :trac:`4321` ...')
-        'See https://trac.sagemath.org/1234, https://en.wikipedia.org/wiki/Sage_(mathematics_software), and https://trac.sagemath.org/4321 ...'
-        sage: process_extlinks('See :trac:`1234` for more information.', embedded=True)
-        'See :trac:`1234` for more information.'
+        'See https://github.com/sagemath/sage/issues/1234, https://en.wikipedia.org/wiki/Sage_(mathematics_software), and https://github.com/sagemath/sage/issues/4321 ...'
+        sage: process_extlinks('See :issue:`1234` for more information.', embedded=True)
+        'See :issue:`1234` for more information.'
         sage: process_extlinks('see :python:`Implementing Descriptors <reference/datamodel.html#implementing-descriptors>` ...')
         'see https://docs.python.org/release/.../reference/datamodel.html#implementing-descriptors ...'
     """
@@ -588,6 +590,35 @@ def process_mathtt(s):
     return s
 
 
+def process_optional_doctest_tags(s):
+    r"""
+    Remove ``# optional/needs`` doctest tags for present features from docstring ``s``.
+
+    EXAMPLES:
+
+        sage: from sage.misc.sagedoc import process_optional_doctest_tags
+        sage: process_optional_doctest_tags("sage: # needs sage.rings.finite_rings\nsage: K.<x> = FunctionField(GF(5^2,'a')); K\nRational function field in x over Finite Field in a of size 5^2")  # needs sage.rings.finite_rings
+        "sage: K.<x> = FunctionField(GF(5^2,'a')); K\nRational function field in x over Finite Field in a of size 5^2"
+    """
+    import io
+    from sage.doctest.external import available_software
+    from sage.doctest.parsing import parse_optional_tags, update_optional_tags
+
+    start = 0
+    with io.StringIO() as output:
+        for m in re.finditer('( *sage: *.*#.*)\n', s):
+            output.write(s[start:m.start(0)])
+            line = m.group(1)
+            tags = [tag for tag in parse_optional_tags(line)
+                    if tag not in available_software]
+            line = update_optional_tags(line, tags=tags)
+            if not re.fullmatch(' *sage: *', line):
+                print(line, file=output)
+            start = m.end(0)
+        output.write(s[start:])
+        return output.getvalue()
+
+
 def format(s, embedded=False):
     r"""noreplace
     Format Sage documentation ``s`` for viewing with IPython.
@@ -767,6 +798,10 @@ def format(s, embedded=False):
             s = process_mathtt(s)
         s = process_extlinks(s, embedded=embedded)
         s = detex(s, embedded=embedded)
+
+    if not embedded:
+        s = process_optional_doctest_tags(s)
+
     return s
 
 
@@ -884,8 +919,9 @@ def _search_src_or_doc(what, string, extra1='', extra2='', extra3='',
     results to stdout::
 
         sage: from sage.misc.sagedoc import _search_src_or_doc
-        sage: _search_src_or_doc('src', r'def _search_src_or_doc\(',
-        ....:                    interact=True)  # long time
+        sage: _search_src_or_doc('src',                        # long time
+        ....:                    r'def _search_src_or_doc\(',
+        ....:                    interact=True)
         misc/sagedoc.py:...:        def _search_src_or_doc(what, string, extra1='', extra2='', extra3='',
     """
 
