@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 r"""
-Congruence Subgroup `\Gamma_1(N)`
+Congruence subgroup `\Gamma_1(N)`
 """
 
 #*****************************************************************************
@@ -14,10 +14,10 @@ Congruence Subgroup `\Gamma_1(N)`
 
 from sage.misc.cachefunc import cached_method
 
-from sage.misc.all import prod
+from sage.misc.misc_c import prod
 from .congroup_gammaH import GammaH_class, is_GammaH, GammaH_constructor
-from sage.rings.all import ZZ
-from sage.arith.all import euler_phi as phi, moebius, divisors
+from sage.rings.integer_ring import ZZ
+from sage.arith.misc import euler_phi as phi, moebius, divisors
 from sage.modular.dirichlet import DirichletGroup
 
 
@@ -370,6 +370,7 @@ class Gamma1_class(GammaH_class):
 
         Check that :trac:`18436` is fixed::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^2 + x + 1)
             sage: G = DirichletGroup(13, base_ring=K)
             sage: Gamma1(13).dimension_modular_forms(2, G[1])
