@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Eisenstein Series
+Eisenstein series
 """
 # ****************************************************************************
 #       Copyright (C) 2004-2006 William Stein <wstein@gmail.com>
@@ -14,19 +14,20 @@ Eisenstein Series
 
 from sage.arith.functions import lcm
 from sage.arith.misc import bernoulli, divisors, is_squarefree
-from sage.misc.misc import cputime
+from sage.misc.lazy_import import lazy_import
+from sage.misc.timing import cputime
 from sage.modular.arithgroup.congroup_gammaH import GammaH_class
 from sage.modular.dirichlet import DirichletGroup
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
-from sage.rings.number_field.number_field import CyclotomicField
 from sage.rings.power_series_ring import PowerSeriesRing
 from sage.rings.rational_field import QQ
 
-from .eis_series_cython import eisenstein_series_poly, Ek_ZZ
+lazy_import('sage.modular.modform.eis_series_cython', ['eisenstein_series_poly', 'Ek_ZZ'])
+lazy_import('sage.rings.number_field.number_field', 'CyclotomicField')
 
 
-def eisenstein_series_qexp(k, prec = 10, K=QQ, var='q', normalization='linear'):
+def eisenstein_series_qexp(k, prec=10, K=QQ, var='q', normalization='linear'):
     r"""
     Return the `q`-expansion of the normalized weight `k` Eisenstein series on
     `\SL_2(\ZZ)` to precision prec in the ring `K`. Three normalizations
@@ -125,8 +126,8 @@ def eisenstein_series_qexp(k, prec = 10, K=QQ, var='q', normalization='linear'):
     - David Loeffler (2012-03-15): add options for alternative normalizations
       (motivated by :trac:`12043`)
     """
-    ## we use this to prevent computation if it would fail anyway.
-    if k <= 0 or k % 2 == 1 :
+    # we use this to prevent computation if it would fail anyway.
+    if k <= 0 or k % 2 == 1:
         raise ValueError("k must be positive and even")
 
     a0 = - bernoulli(k) / (2*k)
@@ -243,7 +244,6 @@ def __find_eisen_chars(character, k):
                         V.insert(0, (chi, chi_inv, t))
         return V
 
-
     eps = character
     if eps(-1) != (-1)**k:
         return []
@@ -420,28 +420,29 @@ def eisenstein_series_lseries(weight, prec=53,
         sage: L(2)
         -5.0235535164599797471968418348135050804419155747868718371029
     """
-    f = eisenstein_series_qexp(weight,prec)
+    f = eisenstein_series_qexp(weight, prec)
     from sage.lfunctions.all import Dokchitser
     j = weight
-    L = Dokchitser(conductor = 1,
-                   gammaV = [0,1],
-                   weight = j,
-                   eps = (-1)**Integer(j/2),
-                   poles = [j],
+    L = Dokchitser(conductor=1,
+                   gammaV=[0, 1],
+                   weight=j,
+                   eps=(-1)**Integer(j // 2),
+                   poles=[j],
                    # Using a string for residues is a hack but it works well
                    # since this will make PARI/GP compute sqrt(pi) with the
                    # right precision.
-                   residues = '[sqrt(Pi)*(%s)]'%((-1)**Integer(j/2)*bernoulli(j)/j),
-                   prec = prec)
+                   residues='[sqrt(Pi)*(%s)]'%((-1)**Integer(j/2)*bernoulli(j)/j),
+                   prec=prec)
 
     s = 'coeff = %s;'%f.list()
-    L.init_coeffs('coeff[k+1]',pari_precode = s,
+    L.init_coeffs('coeff[k+1]',pari_precode=s,
                   max_imaginary_part=max_imaginary_part,
                   max_asymp_coeffs=max_asymp_coeffs)
     L.check_functional_equation()
     L.rename('L-series associated to the weight %s Eisenstein series %s on SL_2(Z)'%(j,f))
     return L
 
+
 def compute_eisenstein_params(character, k):
     r"""
     Compute and return a list of all parameters `(\chi,\psi,t)` that
