@@ -397,7 +397,7 @@ class ModularFormsRing(Parent):
         nb_gens = self.ngens()
         if nb_var != nb_gens:
             raise ValueError('the number of variables (%s) must be equal to the number of generators of the modular forms ring (%s)'%(nb_var, self.ngens()))
-        return {poly_parent.gen(i) : self(gens[i]) for i in range(0, nb_var)}
+        return {poly_parent.gen(i): self(gens[i]) for i in range(0, nb_var)}
 
     def from_polynomial(self, polynomial, gens=None):
         r"""
@@ -518,7 +518,7 @@ class ModularFormsRing(Parent):
             forms_dictionary = forms_datum._forms_dictionary
         elif is_ModularFormElement(forms_datum):
             if self.group().is_subgroup(forms_datum.group()) and self.base_ring().has_coerce_map_from(forms_datum.base_ring()):
-                forms_dictionary = {forms_datum.weight():forms_datum}
+                forms_dictionary = {forms_datum.weight(): forms_datum}
             else:
                 raise ValueError('the group (%s) and/or the base ring (%s) of the given modular form is not consistant with the base space: %s'%(forms_datum.group(), forms_datum.base_ring(), self))
         elif forms_datum in self.base_ring():
@@ -803,7 +803,6 @@ class ModularFormsRing(Parent):
 
         return ret
 
-
     def gen_forms(self, maxweight=8, start_gens=[], start_weight=2):
         r"""
         Return a list of modular forms generating this ring (as an algebra over
@@ -1061,7 +1060,7 @@ class ModularFormsRing(Parent):
 
             # we may need to increase the precision of the cached cusp
             # generators
-            G =  []
+            G = []
             for j,f,F in self.__cached_cusp_gens:
                 if f.prec() >= working_prec:
                     f = F.qexp(working_prec).change_ring(self.base_ring())
@@ -1070,9 +1069,8 @@ class ModularFormsRing(Parent):
             k = 2
             G = []
 
-
         while k <= maxweight:
-            t = verbose("Looking for cusp generators in weight %s" % k)
+            t = verbose(f"Looking for cusp generators in weight {k}")
 
             kprec = self.modular_forms_of_weight(k).sturm_bound()
 
