@@ -16,7 +16,7 @@ different types.  The hierarchy is as follows:
   - :class:`ManinSymbolList_character`
 
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Sage: Open Source Mathematical Software
 #
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
@@ -30,13 +30,13 @@ different types.  The hierarchy is as follows:
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import sage.modular.modsym.p1list as p1list
 import sage.modular.modsym.g1list as g1list
 import sage.modular.modsym.ghlist as ghlist
-from sage.rings.all import Integer
+from sage.rings.integer import Integer
 from sage.structure.parent import Parent
 from sage.misc.persist import register_unpickle_override
 from sage.structure.richcmp import richcmp_method, richcmp
@@ -133,7 +133,7 @@ class ManinSymbolList(Parent):
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList
             sage: m = ManinSymbolList(6, P1List(11))
         """
-        return list(self._symbol_list) # This makes a shallow copy
+        return list(self._symbol_list)  # This makes a shallow copy
 
     def __len__(self):
         """
@@ -162,11 +162,10 @@ class ManinSymbolList(Parent):
             Traceback (most recent call last):
             ...
             NotImplementedError: Only implemented in derived classes
-
         """
         raise NotImplementedError("Only implemented in derived classes")
 
-    def _apply_S_only_0pm1(self):
+    def _apply_S_only_0pm1(self) -> bool:
         """
         Return True if the coefficient when applying the S relation is
         always 0, 1, or -1.  This is useful for optimizing code in
@@ -183,7 +182,7 @@ class ManinSymbolList(Parent):
             sage: ManinSymbolList_character(eps,2)._apply_S_only_0pm1()
             False
         """
-        return False # derived classes could overload and put True
+        return False  # derived classes could overload and put True
 
     def apply_S(self, j):
         """
@@ -351,7 +350,7 @@ class ManinSymbolList(Parent):
             sage: s = m.manin_symbol(3); s
             [Y^2,(1,2)]
             sage: type(s)
-            <type 'sage.modular.modsym.manin_symbol.ManinSymbol'>
+            <class 'sage.modular.modsym.manin_symbol.ManinSymbol'>
         """
         return self.element_class(self, self._symbol_list[i])
 
@@ -498,11 +497,8 @@ class ManinSymbolList_group(ManinSymbolList):
             (2, 1)]
         """
         i, u, v = self._symbol_list[j]
-        k = self.index((self._weight-2-i, v, -u))
-        if i%2 == 0:
-            return k, 1
-        else:
-            return k, -1
+        k = self.index((self._weight - 2 - i, v, -u))
+        return k, -1 if i % 2 else 1
 
     def _apply_S_only_0pm1(self):
         """
@@ -552,7 +548,7 @@ class ManinSymbolList_group(ManinSymbolList):
         """
         i, u, v = self._symbol_list[j]
         k = self.index((i, -u, v))
-        if i%2 == 0:
+        if i % 2 == 0:
             return k, 1
         else:
             return k, -1
@@ -761,10 +757,9 @@ class ManinSymbolList_gamma0(ManinSymbolList_group):
             sage: M11 = ManinSymbolList_gamma0(11,2)
             sage: str(M11)
             'Manin Symbol List of weight 2 for Gamma0(11)'
-
         """
-        return "Manin Symbol List of weight %s for Gamma0(%s)"%(
-                    self.weight(), self.level())
+        return "Manin Symbol List of weight %s for Gamma0(%s)" % (
+            self.weight(), self.level())
 
 
 class ManinSymbolList_gamma1(ManinSymbolList_group):
@@ -820,8 +815,8 @@ class ManinSymbolList_gamma1(ManinSymbolList_group):
             sage: str(M11)
             'Manin Symbol List of weight 4 for Gamma1(11)'
         """
-        return "Manin Symbol List of weight %s for Gamma1(%s)"%(
-                    self.weight(), self.level())
+        return "Manin Symbol List of weight %s for Gamma1(%s)" % (
+            self.weight(), self.level())
 
 
 class ManinSymbolList_gamma_h(ManinSymbolList_group):
@@ -890,8 +885,8 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
             sage: ModularSymbols(GammaH(12, [5]), 2).manin_symbols().__repr__()
             'Manin Symbol List of weight 2 for Congruence Subgroup Gamma_H(12) with H generated by [5]'
         """
-        return "Manin Symbol List of weight %s for %s"%(
-                    self.weight(), self.group())
+        return "Manin Symbol List of weight %s for %s" % (
+            self.weight(), self.group())
 
 
 class ManinSymbolList_character(ManinSymbolList):
@@ -949,8 +944,8 @@ class ManinSymbolList_character(ManinSymbolList):
         # The list returned from P1List is guaranteed to be sorted.
         # Thus each list constructed below is also sorted.  This is
         # important since the index function assumes the list is sorted.
-        L = [(i, u, v) for i in range(weight-2+1) \
-                            for u, v in self.__P1.list()]
+        L = [(i, u, v) for i in range(weight - 2 + 1)
+             for u, v in self.__P1.list()]
         self.__list = L
         ManinSymbolList.__init__(self, weight, L)
 
@@ -967,8 +962,8 @@ class ManinSymbolList_character(ManinSymbolList):
             sage: str(m) # indirect doctest
             'Manin Symbol List of weight 2 for Gamma1(4) with character [-1]'
         """
-        return "Manin Symbol List of weight %s for Gamma1(%s) with character %s"%(
-                    self.weight(), self.level(), self.character()._repr_short_())
+        return "Manin Symbol List of weight %s for Gamma1(%s) with character %s" % (
+            self.weight(), self.level(), self.character()._repr_short_())
 
     def level(self):
         """
@@ -1028,7 +1023,7 @@ class ManinSymbolList_character(ManinSymbolList):
             return []
         r = len(self.__P1)
         return [(m + r*k, s*P[k]) for k in range(self._weight-2+1)
-                            if P[k] != 0]
+                if P[k] != 0]
 
     def apply_S(self, j):
         """
@@ -1056,8 +1051,8 @@ class ManinSymbolList_character(ManinSymbolList):
             [(1, 1), (0, -1), (4, 1), (5, -1), (2, -1), (3, 1)]
         """
         i, u, v = self._symbol_list[j]
-        k, s = self.index((self._weight-2-i, v, -u))
-        if i%2 == 0:
+        k, s = self.index((self._weight - 2 - i, v, -u))
+        if i % 2 == 0:
             return k, s
         else:
             return k, -s
@@ -1106,7 +1101,7 @@ class ManinSymbolList_character(ManinSymbolList):
         """
         i, u, v = self._symbol_list[j]
         k, s = self.index((i, -u, v))
-        if i%2 == 0:
+        if i % 2 == 0:
             return k, s
         else:
             return k, -s
