@@ -1,5 +1,5 @@
 r"""
-Lists of Manin symbols (elements of `\mathbb{P}^1(R/N)`) over number fields
+Lists of Manin symbols over number fields, elements of `\mathbb{P}^1(R/N)`
 
 Lists of elements of `\mathbb{P}^1(R/N)` where `R` is the ring of integers of a number
 field `K` and `N` is an integral ideal.
@@ -14,6 +14,7 @@ We define a P1NFList:
 
 ::
 
+    sage: x = polygen(QQ, 'x')
     sage: k.<a> = NumberField(x^3 + 11)
     sage: N = k.ideal(5, a^2 - a + 1)
     sage: P = P1NFList(N); P
@@ -75,19 +76,20 @@ Lift an MSymbol from P1NFList to a matrix in `SL(2, R)`
     sage: P.lift_to_sl2_Ok(3)
     [0, -1, 1, -2*a]
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2009, Maite Aranes <M.T.Aranes@warwick.ac.uk>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from sage.structure.richcmp import richcmp_method, richcmp
 from sage.structure.sage_object import SageObject
 
 from sage.misc.search import search
 
-_level_cache = {} # The info stored here is used in the normalization of MSymbols.
+_level_cache = {}  # The info stored here is used in the normalization of MSymbols.
+
 
 def P1NFList_clear_level_cache():
     """
@@ -95,6 +97,7 @@ def P1NFList_clear_level_cache():
 
     EXAMPLES::
 
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^3 + 11)
         sage: N = k.ideal(a+1)
         sage: alpha = MSymbol(N, 2*a^2, 5)
@@ -136,6 +139,7 @@ class MSymbol(SageObject):
 
     EXAMPLES::
 
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^3 + 11)
         sage: N = k.ideal(a + 1, 2)
         sage: MSymbol(N, 3, a^2 + 1)
@@ -175,6 +179,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^4 + 13*x - 7)
             sage: N = k.ideal(5)
             sage: MSymbol(N, 0, 6*a)
@@ -197,16 +202,16 @@ class MSymbol(SageObject):
                     c1 = R(c[0])
                     d1 = R(c[1])
                 except (ValueError, TypeError):
-                    raise TypeError("Unable to create a Manin symbol from %s"%c)
+                    raise TypeError("Unable to create a Manin symbol from %s" % c)
         else:
             try:
                 c1 = R(c)
                 d1 = R(d)
             except (ValueError, TypeError):
-                raise TypeError("Unable to create a Manin symbol from (%s, %s)"%(c, d))
+                raise TypeError("Unable to create a Manin symbol from (%s, %s)" % (c, d))
         if check:
             if (c1.is_zero() and d1.is_zero()) or not N.is_coprime(k.ideal(c1, d1)):
-                raise ValueError("(%s, %s) is not an element of P1(R/N)."%(c1, d1))
+                raise ValueError("(%s, %s) is not an element of P1(R/N)." % (c1, d1))
         self.__c, self.__d = (c1, d1)
 
     def __repr__(self):
@@ -215,12 +220,13 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: MSymbol(N, 3, a)
             M-symbol (3: a) of level Fractional ideal (3, 1/2*a - 1/2)
         """
-        return "M-symbol (%s: %s) of level %s"%(self.__c, self.__d, self.__N)
+        return "M-symbol (%s: %s) of level %s" % (self.__c, self.__d, self.__N)
 
     def _latex_(self):
         r"""
@@ -228,6 +234,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^4 + 13*x - 7)
             sage: N = k.ideal(a^3 - 1)
             sage: alpha = MSymbol(N, 3, 5*a^2 - 1)
@@ -244,6 +251,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha = MSymbol(N, 3, a)
@@ -265,6 +273,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha = MSymbol(N, 3, a)
@@ -279,6 +288,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha = MSymbol(N, 3, a); alpha
@@ -299,6 +309,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha = MSymbol(N, 3, a); alpha
@@ -316,6 +327,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(a + 1, 2)
             sage: alpha = MSymbol(N, 3, a^2 + 1)
@@ -331,6 +343,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(a + 1, 2)
             sage: alpha = MSymbol(N, 3, a^2 + 1)
@@ -353,6 +366,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha = MSymbol(N, 3*a + 1, a)
@@ -380,6 +394,7 @@ class MSymbol(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3, a - 1)
             sage: alpha1 = MSymbol(N, 3, a); alpha1
@@ -454,9 +469,9 @@ class MSymbol(SageObject):
             return MSymbol(N, c, d)
 
 
-#**************************************************************************
-#*       P1NFList class                                                   *
-#**************************************************************************
+# ************************************************************************
+#        P1NFList class                                                  *
+# ************************************************************************
 
 
 @richcmp_method
@@ -475,6 +490,7 @@ class P1NFList(SageObject):
 
     EXAMPLES::
 
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^3 + 11)
         sage: N = k.ideal(5, a + 1)
         sage: P = P1NFList(N); P
@@ -494,6 +510,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 5)
             sage: N = k.ideal(3, a - 1)
             sage: P = P1NFList(N); P
@@ -511,6 +528,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N1 = k.ideal(3, a + 1)
             sage: P1 = P1NFList(N1)
@@ -533,6 +551,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(a)
             sage: P = P1NFList(N)
@@ -550,6 +569,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a^2 - a + 1)
             sage: P = P1NFList(N)
@@ -564,13 +584,13 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a+1)
             sage: P = P1NFList(N); P
             The projective line over the ring of integers modulo the Fractional ideal (5, a + 1)
-
         """
-        return "The projective line over the ring of integers modulo the %s"%self.__N
+        return "The projective line over the ring of integers modulo the %s" % self.__N
 
     def list(self):
         """
@@ -578,6 +598,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a+1)
             sage: P = P1NFList(N)
@@ -611,6 +632,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 31)
             sage: N = k.ideal(5, a + 3)
             sage: P = P1NFList(N)
@@ -637,8 +659,8 @@ class P1NFList(SageObject):
         """
         if d is None:
             try:
-                c = MSymbol(self.__N, c) # check that c is an MSymbol
-            except ValueError: # catch special case of wrong level
+                c = MSymbol(self.__N, c)  # check that c is an MSymbol
+            except ValueError:  # catch special case of wrong level
                 raise ValueError("The MSymbol is of a different level")
             return c.normalize(with_scalar)
         return MSymbol(self.N(), c, d).normalize(with_scalar)
@@ -649,6 +671,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 31)
             sage: N = k.ideal(5, a + 3)
             sage: P = P1NFList(N)
@@ -680,6 +703,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 31)
             sage: N = k.ideal(5, a + 3)
             sage: P = P1NFList(N)
@@ -720,8 +744,8 @@ class P1NFList(SageObject):
         """
         if d is None:
             try:
-                c = MSymbol(self.__N, c) # check that c is an MSymbol
-            except ValueError: # catch special case of wrong level
+                c = MSymbol(self.__N, c)  # check that c is an MSymbol
+            except ValueError:  # catch special case of wrong level
                 raise ValueError("The MSymbol is of a different level")
             if with_scalar:
                 u, norm_c = c.normalize(with_scalar=True)
@@ -760,6 +784,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 31)
             sage: N = k.ideal(5, a + 3)
             sage: P = P1NFList(N)
@@ -798,6 +823,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^2 + 23)
             sage: N = k.ideal(3)
             sage: P = P1NFList(N)
@@ -832,6 +858,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a + 1)
             sage: P = P1NFList(N)
@@ -866,6 +893,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a + 1)
             sage: P = P1NFList(N)
@@ -902,6 +930,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a + 1)
             sage: P = P1NFList(N)
@@ -941,6 +970,7 @@ class P1NFList(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(QQ, 'x')
             sage: k.<a> = NumberField(x^3 + 11)
             sage: N = k.ideal(5, a + 1)
             sage: P = P1NFList(N)
@@ -966,13 +996,13 @@ class P1NFList(SageObject):
         return j
 
 
-#**************************************************************************
+# *************************************************************************
 #  Global functions:
 #    - p1NFList --compute list of M-symbols
 #    - lift_to_sl2_Ok
 #    - make_coprime -- need it for ``lift_to_sl2_Ok``
 #    - psi -- useful to check cardinality of the M-symbols list
-#**************************************************************************
+# *************************************************************************
 
 def p1NFlist(N):
     """
@@ -985,6 +1015,7 @@ def p1NFlist(N):
 
     EXAMPLES::
 
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^2 + 23)
         sage: N = k.ideal(3)
         sage: from sage.modular.modsym.p1list_nf import p1NFlist, psi
@@ -993,14 +1024,14 @@ def p1NFlist(N):
     """
     k = N.number_field()
 
-    L = [MSymbol(N, k(0),k(1), check=False)]
-    #N.residues() = iterator through the residues mod N
-    L = L+[MSymbol(N, k(1), r, check=False) for r in N.residues()]
+    L = [MSymbol(N, k(0), k(1), check=False)]
+    # N.residues() = iterator through the residues mod N
+    L = L + [MSymbol(N, k(1), r, check=False) for r in N.residues()]
 
     from sage.arith.misc import divisors
     for D in divisors(N):
-        if not D.is_trivial() and D!=N:
-            #we find Dp ideal coprime to N, in inverse class to D
+        if not D.is_trivial() and D != N:
+            # we find Dp ideal coprime to N, in inverse class to D
             if D.is_principal():
                 Dp = k.ideal(1)
                 c = D.gens_reduced()[0]
@@ -1010,7 +1041,7 @@ def p1NFlist(N):
                 while not Dp.is_coprime(N) or not (Dp*D).is_principal():
                     Dp = next(it)
                 c = (D*Dp).gens_reduced()[0]
-            #now we find all the (c,d)'s which have associated divisor D
+            # now we find all the (c,d)'s which have associated divisor D
             I = D + N/D
             for d in (N/D).residues():
                 if I.is_coprime(d):
@@ -1020,6 +1051,7 @@ def p1NFlist(N):
                     L.append(MSymbol(N, c, d1, check=False).normalize())
     return L
 
+
 def lift_to_sl2_Ok(N, c, d):
     """
     Lift a pair (c, d) to an element of `SL(2, O_k)`, where `O_k` is the ring
@@ -1043,6 +1075,7 @@ def lift_to_sl2_Ok(N, c, d):
     EXAMPLES::
 
         sage: from sage.modular.modsym.p1list_nf import lift_to_sl2_Ok
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^2 + 23)
         sage: Ok = k.ring_of_integers()
         sage: N = k.ideal(3)
@@ -1091,17 +1124,17 @@ def lift_to_sl2_Ok(N, c, d):
         ValueError: <0> + <7> and the Fractional ideal (7, a) are not coprime.
     """
     k = N.number_field()
-    #check the input
+    # check the input
     if c.is_zero() and d.is_zero():
-        raise ValueError("Cannot lift (%s, %s) to an element of Sl2(Ok)."%(c, d))
+        raise ValueError("Cannot lift (%s, %s) to an element of Sl2(Ok)." % (c, d))
     if not N.is_coprime(k.ideal(c, d)):
-        raise ValueError("<%s> + <%s> and the %s are not coprime."%(c, d, N))
-    #a few special cases
+        raise ValueError("<%s> + <%s> and the %s are not coprime." % (c, d, N))
+    # a few special cases
     if c - 1 in N:
         return [k(0), k(-1), 1, d]
     if d - 1 in N:
         return [k(1), k(0), c, 1]
-    if c.is_zero(): # and d!=1, so won't happen for normalized M-symbols (c: d)
+    if c.is_zero():  # and d!=1, so won't happen for normalized M-symbols (c: d)
         it = k.primes_of_degree_one_iter()
         q = k.ideal(1)
         while not (q.is_coprime(d) and (q*N).is_principal()):
@@ -1109,7 +1142,7 @@ def lift_to_sl2_Ok(N, c, d):
         m = (q*N).gens_reduced()[0]
         B = k.ideal(m).element_1_mod(k.ideal(d))
         return [(1-B)/d, -B/m, m, d]
-    if d.is_zero(): # and c!=1, so won't happen for normalized M-symbols (c: d)
+    if d.is_zero():  # and c!=1, so won't happen for normalized M-symbols (c: d)
         it = k.primes_of_degree_one_iter()
         q = k.ideal(1)
         while not (q.is_coprime(c) and (q*N).is_principal()):
@@ -1148,6 +1181,7 @@ def make_coprime(N, c, d):
     EXAMPLES::
 
         sage: from sage.modular.modsym.p1list_nf import make_coprime
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^2 + 23)
         sage: N = k.ideal(3, a - 1)
         sage: c = 2*a; d = a + 1
@@ -1183,6 +1217,7 @@ def psi(N):
     EXAMPLES::
 
         sage: from sage.modular.modsym.p1list_nf import psi
+        sage: x = polygen(QQ, 'x')
         sage: k.<a> = NumberField(x^2 + 23)
         sage: N = k.ideal(3, a - 1)
         sage: psi(N)
@@ -1199,6 +1234,6 @@ def psi(N):
         raise ValueError("psi only defined for integral ideals")
 
     from sage.misc.misc_c import prod
-    return prod([(np+1)*np**(e-1) \
-                     for np,e in [(p.absolute_norm(),e) \
-                                  for p,e in N.factor()]])
+    return prod([(np + 1) * np**(e - 1)
+                 for np, e in [(p.absolute_norm(), e)
+                               for p, e in N.factor()]])
