@@ -72,11 +72,10 @@ def is_MatrixMorphism(x):
     return isinstance(x, MatrixMorphism_abstract)
 
 class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
-    def __init__(self, parent):
+    def __init__(self, parent, side='left'):
         """
         INPUT:
 
-
         -  ``parent`` - a homspace
 
         -  ``A`` - matrix
@@ -94,6 +93,9 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         """
         if not sage.categories.homset.is_Homset(parent):
             raise TypeError("parent must be a Hom space")
+        if side not in ["left", "right"]:
+            raise ValueError("the argument side must be either 'left' or 'right'")
+        self._side = side
         sage.categories.morphism.Morphism.__init__(self, parent)
 
     def _richcmp_(self, other, op):
@@ -192,7 +194,10 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         else:
             x = self.domain().coordinate_vector(x)
         C = self.codomain()
-        v = x.change_ring(C.base_ring()) * self.matrix()
+        if self.side() == "left":
+            v = x.change_ring(C.base_ring()) * self.matrix()
+        else:
+            v = self.matrix() * x.change_ring(C.base_ring())
         if not C.is_ambient():
             v = C.linear_combination_of_basis(v)
         # The call method of parents uses (coercion) morphisms.
@@ -259,13 +264,60 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         except ZeroDivisionError:
             raise ZeroDivisionError("matrix morphism not invertible")
         try:
-            return self.parent().reversed()(B)
+            return self.parent().reversed()(B, side=self.side())
         except TypeError:
             raise ZeroDivisionError("matrix morphism not invertible")
 
+    def side(self):
+        """
+        Return the side of vectors acted on, relative to the matrix.
+
+        EXAMPLES::
+
+            sage: m = matrix(2, [1, 1, 0, 1])
+            sage: V = ZZ^2
+            sage: h1 = V.hom(m); h2 = V.hom(m, side="right")
+            sage: h1.side()
+            'left'
+            sage: h1([1, 0])
+            (1, 1)
+            sage: h2.side()
+            'right'
+            sage: h2([1, 0])
+            (1, 0)
+        """
+        return self._side
+
+    def side_switch(self):
+        """
+        Return the same morphism, acting on vectors on the opposite side
+
+        EXAMPLES::
+
+            sage: m = matrix(2, [1,1,0,1]); m
+            [1 1]
+            [0 1]
+            sage: V = ZZ^2
+            sage: h = V.hom(m); h.side()
+            'left'
+            sage: h2 = h.side_switch(); h2
+            Free module morphism defined as left-multiplication by the matrix
+            [1 0]
+            [1 1]
+            Domain: Ambient free module of rank 2 over the principal ideal domain Integer Ring
+            Codomain: Ambient free module of rank 2 over the principal ideal domain Integer Ring
+            sage: h2.side()
+            'right'
+            sage: h2.side_switch().matrix()
+            [1 1]
+            [0 1]
+        """
+        side = "left" if self.side() == "right" else "right"
+        return self.parent()(self.matrix().transpose(), side=side)
+
     def inverse(self):
         r"""
-        Returns the inverse of this matrix morphism, if the inverse exists.
+        Return the inverse of this matrix morphism, if the inverse exists.
 
         Raises a ``ZeroDivisionError`` if the inverse does not exist.
 
@@ -405,7 +457,7 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             [0 4]...
         """
         R = self.base_ring()
-        return self.parent()(R(left) * self.matrix())
+        return self.parent()(R(left) * self.matrix(), side=self.side())
 
     def __mul__(self, right):
         r"""
@@ -471,9 +523,10 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
 
         Composite maps can be formed with matrix morphisms::
 
-            sage: K.<a> = NumberField(x^2 + 23)
-            sage: V, VtoK, KtoV = K.vector_space()
-            sage: f = V.hom([V.0 - V.1, V.0 + V.1])*KtoV; f
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a> = NumberField(x^2 + 23)                                         # optional - sage.rings.number_field
+            sage: V, VtoK, KtoV = K.vector_space()                                      # optional - sage.rings.number_field
+            sage: f = V.hom([V.0 - V.1, V.0 + V.1])*KtoV; f                             # optional - sage.rings.number_field
             Composite map:
             From: Number Field in a with defining polynomial x^2 + 23
             To:   Vector space of dimension 2 over Rational Field
@@ -488,16 +541,94 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
                     Codomain: Vector space of dimension 2 over Rational Field
             sage: f(a)
             (1, 1)
+            sage: V.hom([V.0 - V.1, V.0 + V.1], side="right")*KtoV
+            Composite map:
+              From: Number Field in a with defining polynomial x^2 + 23
+              To:   Vector space of dimension 2 over Rational Field
+              Defn:   Isomorphism map:
+                      From: Number Field in a with defining polynomial x^2 + 23
+                      To:   Vector space of dimension 2 over Rational Field
+                    then
+                      Vector space morphism represented as left-multiplication by the matrix:
+                    [ 1  1]
+                    [-1  1]
+                    Domain: Vector space of dimension 2 over Rational Field
+                    Codomain: Vector space of dimension 2 over Rational Field
+
+
+        We can test interraction between morphisms with different ``side``::
+
+            sage: V = ZZ^2
+            sage: m = matrix(2, [1,1,0,1])
+            sage: hl = V.hom(m)
+            sage: hr = V.hom(m, side="right")
+            sage: hl * hl
+            Free module morphism defined by the matrix
+            [1 2]
+            [0 1]...
+            sage: hl * hr
+            Free module morphism defined by the matrix
+            [1 1]
+            [1 2]...
+            sage: hl * hl.side_switch()
+            Free module morphism defined by the matrix
+            [1 2]
+            [0 1]...
+            sage: hr * hl
+            Free module morphism defined by the matrix
+            [2 1]
+            [1 1]...
+            sage: hl * hl
+            Free module morphism defined by the matrix
+            [1 2]
+            [0 1]...
+            sage: hr / hl
+            Free module morphism defined by the matrix
+            [ 0 -1]
+            [ 1  1]...
+            sage: hr / hr.side_switch()
+            Free module morphism defined by the matrix
+            [1 0]
+            [0 1]...
+            sage: hl / hl
+            Free module morphism defined by the matrix
+            [1 0]
+            [0 1]...
+            sage: hr / hr
+            Free module morphism defined as left-multiplication by the matrix
+            [1 0]
+            [0 1]...
+
+
+
+        .. WARNING::
+
+            Matrix morphisms can be defined by either left or right-multiplication.
+            The composite morphism always applies the morphism on the right of \* first.
+            The matrix of the composite morphism of two morphisms given by
+            right-multiplication is not the morphism given by the product of their
+            respective matrices.
+            If the two morphisms act on different sides, then the side of the resulting
+            morphism is the default one.
         """
         if not isinstance(right, MatrixMorphism):
             if isinstance(right, (sage.categories.morphism.Morphism, sage.categories.map.Map)):
                 return sage.categories.map.Map.__mul__(self, right)
             R = self.base_ring()
             return self.parent()(self.matrix() * R(right))
+        H = right.domain().Hom(self.codomain())
         if self.domain() != right.codomain():
             raise TypeError("Incompatible composition of morphisms: domain of left morphism must be codomain of right.")
-        M = right.matrix() * self.matrix()
-        return right.domain().Hom(self.codomain())(M)
+        if self.side() == "left":
+            if right.side() == "left":
+                return H(right.matrix() * self.matrix(), side=self.side())
+            else:
+                return H(right.matrix().transpose() * self.matrix(), side=self.side())
+        else:
+            if right.side() == "right":
+                return H(self.matrix() * right.matrix(), side=self.side())
+            else:
+                return H(right.matrix() * self.matrix().transpose(), side="left")
 
     def __add__(self, right):
         """
@@ -534,15 +665,52 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Traceback (most recent call last):
             ...
             ValueError: inconsistent number of rows: should be 2 but got 3
+
+        ::
+
+
+            sage: V = ZZ^2
+            sage: m = matrix(2, [1,1,0,1])
+            sage: hl = V.hom(m)
+            sage: hr = V.hom(m, side="right")
+            sage: hl + hl
+            Free module morphism defined by the matrix
+            [2 2]
+            [0 2]...
+            sage: hr + hr
+            Free module morphism defined as left-multiplication by the matrix
+            [2 2]
+            [0 2]...
+            sage: hr + hl
+            Free module morphism defined by the matrix
+            [2 1]
+            [1 2]...
+            sage: hl + hr
+            Free module morphism defined by the matrix
+            [2 1]
+            [1 2]...
+
+        .. WARNING::
+
+            If the two morphisms do not share the same ``side`` attribute, then
+            the resulting morphism will be defined with the default value.
         """
         # TODO: move over to any coercion model!
         if not isinstance(right, MatrixMorphism):
             R = self.base_ring()
             return self.parent()(self.matrix() + R(right))
         if not right.parent() == self.parent():
-            right = self.parent()(right)
-        M = self.matrix() + right.matrix()
-        return self.domain().Hom(right.codomain())(M)
+            right = self.parent()(right, side=right.side())
+        if self.side() == "left":
+            if right.side() == "left":
+                return self.parent()(self.matrix() + right.matrix(), side=self.side())
+            elif right.side() == "right":
+                return self.parent()(self.matrix() + right.matrix().transpose(), side="left")
+        if self.side() == "right":
+            if right.side() == "right":
+                return self.parent()(self.matrix() + right.matrix(), side=self.side())
+            elif right.side() == "left":
+                return self.parent()(self.matrix().transpose() + right.matrix(), side="left")
 
     def __neg__(self):
         """
@@ -553,8 +721,12 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Free module morphism defined by the matrix
             [-1 -1]
             [ 0 -2]...
+            sage: phi2 = phi.side_switch(); -phi2
+            Free module morphism defined as left-multiplication by the matrix
+            [-1  0]
+            [-1 -2]...
         """
-        return self.parent()(-self.matrix())
+        return self.parent()(-self.matrix(), side=self.side())
 
     def __sub__(self, other):
         """
@@ -565,14 +737,51 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Free module morphism defined by the matrix
             [0 0]
             [0 0]...
+
+        ::
+
+            sage: V = ZZ^2
+            sage: m = matrix(2, [1,1,0,1])
+            sage: hl = V.hom(m)
+            sage: hr = V.hom(m, side="right")
+            sage: hl - hr
+            Free module morphism defined by the matrix
+            [ 0  1]
+            [-1  0]...
+            sage: hl - hl
+            Free module morphism defined by the matrix
+            [0 0]
+            [0 0]...
+            sage: hr - hr
+            Free module morphism defined as left-multiplication by the matrix
+            [0 0]
+            [0 0]...
+            sage: hr-hl
+            Free module morphism defined by the matrix
+            [ 0 -1]
+            [ 1  0]...
+
+        .. WARNING::
+
+            If the two morphisms do not share the same ``side`` attribute, then
+            the resulting morphism will be defined with the default value.
         """
         # TODO: move over to any coercion model!
         if not isinstance(other, MatrixMorphism):
             R = self.base_ring()
-            return self.parent()(self.matrix() - R(other))
+            return self.parent()(self.matrix() - R(other), side=self.side())
         if not other.parent() == self.parent():
-            other = self.parent()(other)
-        return self.parent()(self.matrix() - other.matrix())
+            other = self.parent()(other, side=other.side())
+        if self.side() == "left":
+            if other.side() == "left":
+                return self.parent()(self.matrix() - other.matrix(), side=self.side())
+            elif other.side() == "right":
+                return self.parent()(self.matrix() - other.matrix().transpose(), side="left")
+        if self.side() == "right":
+            if other.side() == "right":
+                return self.parent()(self.matrix() - other.matrix(), side=self.side())
+            elif other.side() == "left":
+                return self.parent()(self.matrix().transpose() - other.matrix(), side="left")
 
     def base_ring(self):
         """
@@ -593,7 +802,8 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         ``characteristic_polynomial`` and ``char_poly`` are the same method.
 
         INPUT:
-            - var -- variable
+
+        - var -- variable
 
         EXAMPLES::
 
@@ -608,8 +818,8 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             T^2 - 3*T + 2
         """
         if not self.is_endomorphism():
-            raise ArithmeticError("charpoly only defined for endomorphisms " +\
-                    "(i.e., domain = range)")
+            raise ArithmeticError("charpoly only defined for endomorphisms "
+                                  "(i.e., domain = range)")
         return self.matrix().charpoly(var)
 
     charpoly = characteristic_polynomial
@@ -635,11 +845,24 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Echelon basis matrix:
             [ 1 -1]
             ]
+            sage: phi2 = V.hom(phi.matrix(), side="right")
+            sage: phi2.decomposition()
+            [
+            Free module of degree 2 and rank 1 over Integer Ring
+            Echelon basis matrix:
+            [1 1],
+            Free module of degree 2 and rank 1 over Integer Ring
+            Echelon basis matrix:
+            [1 0]
+            ]
         """
         if not self.is_endomorphism():
             raise ArithmeticError("Matrix morphism must be an endomorphism.")
         D = self.domain()
-        E = self.matrix().decomposition(*args,**kwds)
+        if self.side() == "left":
+            E = self.matrix().decomposition(*args,**kwds)
+        else:
+            E = self.matrix().transpose().decomposition(*args,**kwds)
         if D.is_ambient():
             return Sequence([D.submodule(V, check=False) for V, _ in E],
                             cr=True, check=False)
@@ -712,8 +935,25 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Vector space of degree 2 and dimension 0 over Complex Field with 53 bits of precision
             Basis matrix:
             []
+            sage: m = matrix(3, [1, 0, 0, 1, 0, 0, 0, 0, 1]); m
+            [1 0 0]
+            [1 0 0]
+            [0 0 1]
+            sage: f1 = V.hom(m)
+            sage: f2 = V.hom(m, side="right")
+            sage: f1.kernel()
+            Vector space of degree 3 and dimension 1 over Rational Field
+            Basis matrix:
+            [ 1 -1  0]
+            sage: f2.kernel()
+            Vector space of degree 3 and dimension 1 over Rational Field
+            Basis matrix:
+            [0 1 0]
         """
-        V = self.matrix().kernel()
+        if self.side() == "left":
+            V = self.matrix().left_kernel()
+        else:
+            V = self.matrix().right_kernel()
         D = self.domain()
         if not D.is_ambient():
             # Transform V to ambient space
@@ -740,6 +980,22 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Vector space of degree 2 and dimension 0 over Finite Field of size 7
             Basis matrix:
             []
+            sage: m = matrix(3, [1, 0, 0, 1, 0, 0, 0, 0, 1]); m
+            [1 0 0]
+            [1 0 0]
+            [0 0 1]
+            sage: f1 = V.hom(m)
+            sage: f2 = V.hom(m, side="right")
+            sage: f1.image()
+            Vector space of degree 3 and dimension 2 over Rational Field
+            Basis matrix:
+            [1 0 0]
+            [0 0 1]
+            sage: f2.image()
+            Vector space of degree 3 and dimension 2 over Rational Field
+            Basis matrix:
+            [1 1 0]
+            [0 0 1]
 
 
         Compute the image of the identity map on a ZZ-submodule::
@@ -758,13 +1014,16 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             sage: phi.image() == V
             True
         """
-        V = self.matrix().image()
-        D = self.codomain()
-        if not D.is_ambient():
+        if self.side() == 'left':
+            V = self.matrix().row_space()
+        else:
+            V = self.matrix().column_space()
+        C = self.codomain()
+        if not C.is_ambient():
             # Transform V to ambient space
             # This is a matrix multiply:  we take the linear combinations of the basis for
             # D given by the elements of the basis for V.
-            B = V.basis_matrix() * D.basis_matrix()
+            B = V.basis_matrix() * C.basis_matrix()
             V = B.row_module(self.domain().base_ring())
         return self.codomain().submodule(V, check=False)
 
@@ -844,8 +1103,23 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             sage: V = ZZ^2; phi = V.hom([V.0, V.0])
             sage: phi.nullity()
             1
+
+        ::
+
+            sage: m = matrix(2, [1, 2])
+            sage: V = ZZ^2
+            sage: h1 = V.hom(m)
+            sage: h1.nullity()
+            1
+            sage: W = ZZ^1
+            sage: h2 = W.hom(m, side="right")
+            sage: h2.nullity()
+            0
         """
-        return self._matrix.left_nullity()
+        if self.side() == "left":
+            return self._matrix.left_nullity()
+        else:
+            return self._matrix.right_nullity()
 
     def is_bijective(self):
         r"""
@@ -963,7 +1237,7 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         # testing for the identity matrix will only work for
         #   endomorphisms which have the same basis for domain and codomain
         #   so we test equality on a basis, which is sufficient
-        return all( self(u) == u for u in self.domain().basis() )
+        return all(self(u) == u for u in self.domain().basis())
 
     def is_zero(self):
         r"""
@@ -1096,7 +1370,7 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
         if self.codomain() != other.codomain():
             return False
         # check agreement on any basis of the domain
-        return all( self(u) == other(u) for u in self.domain().basis() )
+        return all(self(u) == other(u) for u in self.domain().basis())
 
     def restrict_domain(self, sub):
         """
@@ -1119,6 +1393,16 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             sage: phi.restrict_domain(V.span([V.1]))
             Free module morphism defined by the matrix
             [0 2]...
+            sage: m = matrix(2, range(1,5))
+            sage: f1 = V.hom(m); f2 = V.hom(m, side="right")
+            sage: SV = V.span([V.0])
+            sage: f1.restrict_domain(SV)
+            Free module morphism defined by the matrix
+            [1 2]...
+            sage: f2.restrict_domain(SV)
+            Free module morphism defined as left-multiplication by the matrix
+            [1]
+            [3]...
         """
         D = self.domain()
         if hasattr(D, 'coordinate_module'):
@@ -1127,9 +1411,15 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             V = D.coordinate_module(sub)
         else:
             V = sub.free_module()
-        A = self.matrix().restrict_domain(V)
+        if self.side() == "right":
+            A = self.matrix().transpose().restrict_domain(V).transpose()
+        else:
+            A = self.matrix().restrict_domain(V)
         H = sub.Hom(self.codomain())
-        return H(A)
+        try:
+            return H(A, side=self.side())
+        except Exception:
+            return H(A)
 
     def restrict_codomain(self, sub):
         """
@@ -1155,6 +1445,12 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             Domain: Ambient free module of rank 2 over the principal ideal domain ...
             Codomain: Free module of degree 2 and rank 1 over Integer Ring
             Echelon ...
+            sage: phi2 = phi.side_switch(); phi2.restrict_codomain(W)
+            Free module morphism defined as left-multiplication by the matrix
+            [2 0]
+            Domain: Ambient free module of rank 2 over the principal ideal domain Integer Ring
+            Codomain: Free module of degree 2 and rank 1 over Integer Ring
+            Echelon ...
 
         An example in which the codomain equals the full ambient space, but
         with a different basis::
@@ -1200,8 +1496,13 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             V = C.coordinate_module(sub)
         else:
             V = sub.free_module()
-        return H(self.matrix().restrict_codomain(V))
-
+        try:
+            if self.side() == "right":
+                return H(self.matrix().transpose().restrict_codomain(V).transpose(), side="right")
+            else:
+                return H(self.matrix().restrict_codomain(V))
+        except Exception:
+            return H(self.matrix().restrict_codomain(V))
 
     def restrict(self, sub):
         """
@@ -1242,6 +1543,37 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             True
             sage: psi(W.0) == 2*W.0
             True
+
+        ::
+
+            sage: V = ZZ^3
+            sage: h1 = V.hom([V.0, V.1+V.2, -V.1+V.2])
+            sage: h2 = h1.side_switch()
+            sage: SV = V.span([2*V.1,2*V.2])
+            sage: h1.restrict(SV)
+            Free module morphism defined by the matrix
+            [ 1  1]
+            [-1  1]
+            Domain: Free module of degree 3 and rank 2 over Integer Ring
+            Echelon basis matrix:
+            [0 2 0]
+            [0 0 2]
+            Codomain: Free module of degree 3 and rank 2 over Integer Ring
+            Echelon basis matrix:
+            [0 2 0]
+            [0 0 2]
+            sage: h2.restrict(SV)
+            Free module morphism defined as left-multiplication by the matrix
+            [ 1 -1]
+            [ 1  1]
+            Domain: Free module of degree 3 and rank 2 over Integer Ring
+            Echelon basis matrix:
+            [0 2 0]
+            [0 0 2]
+            Codomain: Free module of degree 3 and rank 2 over Integer Ring
+            Echelon basis matrix:
+            [0 2 0]
+            [0 0 2]
         """
         if not self.is_endomorphism():
             raise ArithmeticError("matrix morphism must be an endomorphism")
@@ -1256,9 +1588,12 @@ class MatrixMorphism_abstract(sage.categories.morphism.Morphism):
             V = D.coordinate_module(sub)
         else:
             V = sub.free_module()
-        A = self.matrix().restrict(V)
+        if self.side() == "right":
+            A = self.matrix().transpose().restrict(V).transpose()
+        else:
+            A = self.matrix().restrict(V)
         H = sage.categories.homset.End(sub, self.domain().category())
-        return H(A)
+        return H(A, side=self.side())
 
 
 class MatrixMorphism(MatrixMorphism_abstract):
@@ -1275,7 +1610,7 @@ class MatrixMorphism(MatrixMorphism_abstract):
        the matrix ``A`` if it is mutable; if ``False``, then this makes
        ``A`` immutable
     """
-    def __init__(self, parent, A, copy_matrix=True):
+    def __init__(self, parent, A, copy_matrix=True, side='left'):
         """
         Initialize ``self``.
 
@@ -1293,25 +1628,31 @@ class MatrixMorphism(MatrixMorphism_abstract):
             raise ValueError("no parent given when creating this matrix morphism")
         if isinstance(A, MatrixMorphism_abstract):
             A = A.matrix()
-        if A.nrows() != parent.domain().rank():
-            raise ArithmeticError("number of rows of matrix (={}) must equal rank of domain (={})".format(A.nrows(), parent.domain().rank()))
-        if A.ncols() != parent.codomain().rank():
-                raise ArithmeticError("number of columns of matrix (={}) must equal rank of codomain (={})".format(A.ncols(), parent.codomain().rank()))
+        if side == "left":
+            if A.nrows() != parent.domain().rank():
+                raise ArithmeticError("number of rows of matrix (={}) must equal rank of domain (={})".format(A.nrows(), parent.domain().rank()))
+            if A.ncols() != parent.codomain().rank():
+                    raise ArithmeticError("number of columns of matrix (={}) must equal rank of codomain (={})".format(A.ncols(), parent.codomain().rank()))
+        if side == "right":
+            if A.nrows() != parent.codomain().rank():
+                raise ArithmeticError("number of rows of matrix (={}) must equal rank of codomain (={})".format(A.nrows(), parent.domain().rank()))
+            if A.ncols() != parent.domain().rank():
+                raise ArithmeticError("number of columns of matrix (={}) must equal rank of domain (={})".format(A.ncols(), parent.codomain().rank()))
         if A.is_mutable():
             if copy_matrix:
                 from copy import copy
                 A = copy(A)
             A.set_immutable()
         self._matrix = A
-        MatrixMorphism_abstract.__init__(self, parent)
+        MatrixMorphism_abstract.__init__(self, parent, side)
 
-    def matrix(self, side='left'):
+    def matrix(self, side=None):
         r"""
         Return a matrix that defines this morphism.
 
         INPUT:
 
-        - ``side`` -- (default: ``'left'``) the side of the matrix
+        - ``side`` -- (default: ``'None'``) the side of the matrix
           where a vector is placed to effect the morphism (function)
 
         OUTPUT:
@@ -1352,12 +1693,11 @@ class MatrixMorphism(MatrixMorphism_abstract):
             ...
             ValueError: side must be 'left' or 'right', not junk
         """
-        if not side in ['left', 'right']:
+        if side not in ['left', 'right', None]:
             raise ValueError("side must be 'left' or 'right', not {0}".format(side))
-        if side == 'left':
+        if side == self.side() or side is None:
             return self._matrix
-        else:
-            return self._matrix.transpose()
+        return self._matrix.transpose()
 
     def is_injective(self):
         """
@@ -1378,7 +1718,11 @@ class MatrixMorphism(MatrixMorphism_abstract):
 
         -- Simon King (2010-05)
         """
-        return self._matrix.kernel().dimension() == 0
+        if self.side() == 'left':
+            ker = self._matrix.left_kernel()
+        else:
+            ker = self._matrix.right_kernel()
+        return ker.dimension() == 0
 
     def is_surjective(self):
         r"""
@@ -1427,7 +1771,7 @@ class MatrixMorphism(MatrixMorphism_abstract):
         - Rob Beezer (2011-06-28)
         """
         # Testing equality of free modules over PIDs is unreliable
-        #   see Trac #11579 for explanation and status
+        #   see Issue #11579 for explanation and status
         # We test if image equals codomain with two inclusions
         #   reverse inclusion of below is trivially true
         return self.codomain().is_submodule(self.image())
@@ -1447,4 +1791,7 @@ class MatrixMorphism(MatrixMorphism_abstract):
             sage: phi._repr_()
             'Free module morphism defined by the matrix\n[3 0]\n[0 2]\nDomain: Ambient free module of rank 2 over the principal ideal domain Integer Ring\nCodomain: Ambient free module of rank 2 over the principal ideal domain Integer Ring'
         """
-        return "Morphism defined by the matrix\n{0}".format(self.matrix())
+        rep = "Morphism defined by the matrix\n{0}".format(self.matrix())
+        if self._side == 'right':
+            rep += " acting by multiplication on the left"
+        return rep
