@@ -1,10 +1,12 @@
+# sage.doctest: needs sage.symbolic
 r"""
-Plotting Functions
+Plotting functions
 
 EXAMPLES::
 
     sage: x, y = var('x y')
-    sage: W = plot3d(sin(pi*((x)^2 + (y)^2))/2, (x, -1, 1), (y, -1, 1), frame=False, color='purple', opacity=0.8)
+    sage: W = plot3d(sin(pi*((x)^2 + (y)^2))/2, (x, -1, 1), (y, -1, 1),
+    ....:            frame=False, color='purple', opacity=0.8)
     sage: S = sphere((0, 0, 0), size=0.3, color='red', aspect_ratio=[1,1,1])
     sage: show(W + S, figsize=8)
 
@@ -30,7 +32,8 @@ EXAMPLES::
 
     sage: def f(x,y):
     ....:     return math.sin(y^2 + x^2)/math.sqrt(x^2 + y^2 + 0.0001)
-    sage: P = plot3d(f, (-3, 3),(-3, 3), adaptive=True, color=rainbow(60, 'rgbtuple'), max_bend=.1, max_depth=15)
+    sage: P = plot3d(f, (-3, 3),(-3, 3), adaptive=True,
+    ....:            color=rainbow(60, 'rgbtuple'), max_bend=.1, max_depth=15)
     sage: P.show()
 
 .. ONLY:: html
@@ -121,11 +124,14 @@ We plot "cape man"::
 
 ::
 
-    sage: S += sphere((.45, -.1, .15), size=.1, color='white') + sphere((.51,-.1,.17), size=.05, color='black')
-    sage: S += sphere((.45, .1, .15), size=.1, color='white') + sphere((.51, .1,.17), size=.05, color='black')
+    sage: S += sphere((.45, -.1, .15), size=.1, color='white')
+    sage: S += sphere((.51,-.1,.17), size=.05, color='black')
+    sage: S += sphere((.45, .1, .15), size=.1, color='white')
+    sage: S += sphere((.51, .1,.17), size=.05, color='black')
     sage: S += sphere((.5, 0, -.2), size=.1, color='yellow')
     sage: def f(x,y): return math.exp(x/5)*math.cos(y)
-    sage: P = plot3d(f, (-5, 5), (-5, 5), adaptive=True, color=['red','yellow'], max_depth=10)
+    sage: P = plot3d(f, (-5, 5), (-5, 5), adaptive=True,
+    ....:            color=['red','yellow'], max_depth=10)
     sage: cape_man = P.scale(.2) + S.translate(1, 0, 0)
     sage: cape_man.show(aspect_ratio=[1, 1, 1])
 
@@ -248,7 +254,7 @@ class _Coordinates():
 
         Because the base :class:`_Coordinates` class automatically checks the
         initializing variables with the transform method, :class:`_Coordinates`
-        cannot be instantiated by itself.  We test a subclass.
+        cannot be instantiated by itself.  We test a subclass::
 
             sage: from sage.plot.plot3d.plot3d import _ArbitraryCoordinates as arb
             sage: x,y,z=var('x,y,z')
@@ -329,19 +335,24 @@ class _Coordinates():
             sage: t1,t2,t3=T.to_cartesian(lambda a,b: 2*a+b)
             sage: from sage.misc.sageinspect import sage_getargspec
             sage: sage_getargspec(t1)
-            ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: sage_getargspec(t2)
-            ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: sage_getargspec(t3)
-            ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
 
             sage: def g(a,b): return 2*a+b
             sage: t1,t2,t3=T.to_cartesian(g)
             sage: sage_getargspec(t1)
-            ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: t1,t2,t3=T.to_cartesian(2*a+b)
             sage: sage_getargspec(t1)
-            ArgSpec(args=['a', 'b'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
 
         If we cannot guess the right parameter names, then the
         parameters are named `u` and `v`::
@@ -352,7 +363,8 @@ class _Coordinates():
             sage: T = _ArbitraryCoordinates((x + y, x - y, z), z,[x,y])
             sage: t1,t2,t3=T.to_cartesian(operator.add)
             sage: sage_getargspec(t1)
-            ArgSpec(args=['u', 'v'], varargs=None, keywords=None, defaults=None)
+            FullArgSpec(args=['u', 'v'], varargs=None, varkw=None, defaults=None,
+                        kwonlyargs=[], kwonlydefaults=None, annotations={})
             sage: [h(1,2) for h in T.to_cartesian(operator.mul)]
             [3.0, -1.0, 2.0]
             sage: [h(u=1,v=2) for h in T.to_cartesian(operator.mul)]
@@ -372,7 +384,7 @@ class _Coordinates():
             ....: [ 0.16763356,  0.19993708,  0.31403568,  0.47359696, 0.55282422],
             ....: [ 0.16763356,  0.25683223,  0.16649297,  0.10594339, 0.55282422]])
             sage: import scipy.interpolate
-            sage: f=scipy.interpolate.RectBivariateSpline(v_phi,v_theta,m_r)
+            sage: f=scipy.interpolate.RectBivariateSpline(v_phi,v_theta,m_r).ev
             sage: spherical_plot3d(f,(0,2*pi),(0,pi))
             Graphics3d Object
 
@@ -697,7 +709,8 @@ class SphericalElevation(_Coordinates):
 
     Plot a sin curve wrapped around the equator::
 
-        sage: P1 = plot3d( (pi/12)*sin(8*theta), (r,0.99,1), (theta, 0, 2*pi), transformation=SE, plot_points=(10,200))
+        sage: P1 = plot3d((pi/12)*sin(8*theta), (r,0.99,1), (theta, 0, 2*pi),
+        ....:             transformation=SE, plot_points=(10,200))
         sage: P2 = sphere(center=(0,0,0), size=1, color='red', opacity=0.3)
         sage: P1 + P2
         Graphics3d Object
@@ -730,10 +743,14 @@ class SphericalElevation(_Coordinates):
         sage: r, phi, theta = var('r phi theta')
         sage: SE = SphericalElevation('elevation', ['radius', 'azimuth'])
         sage: angles = [pi/18, pi/12, pi/6]
-        sage: P1 = [plot3d( a, (r,0,3), (theta, 0, 2*pi), transformation=SE, opacity=0.85, color='blue') for a in angles]
+        sage: P1 = [plot3d(a, (r,0,3), (theta, 0, 2*pi), transformation=SE,
+        ....:              opacity=0.85, color='blue')
+        ....:       for a in angles]
 
         sage: S = Spherical('inclination', ['radius', 'azimuth'])
-        sage: P2 = [plot3d( a, (r,0,3), (theta, 0, 2*pi), transformation=S, opacity=0.85, color='red') for a in angles]
+        sage: P2 = [plot3d(a, (r,0,3), (theta, 0, 2*pi), transformation=S,
+        ....:              opacity=0.85, color='red')
+        ....:       for a in angles]
         sage: show(sum(P1+P2), aspect_ratio=1)
 
     .. ONLY:: html
@@ -880,7 +897,7 @@ class TrivialTriangleFactory:
     but simply returning a list of vertices for both regular and
     smooth triangles.
     """
-    def triangle(self, a, b, c, color = None):
+    def triangle(self, a, b, c, color=None):
         """
         Function emulating behavior of
         :meth:`~sage.plot.plot3d.tri_plot.TriangleFactory.triangle`
@@ -905,8 +922,9 @@ class TrivialTriangleFactory:
             sage: tri
             [[0, 0, 0], [0, 0, 1], [1, 1, 0]]
         """
-        return [a,b,c]
-    def smooth_triangle(self, a, b, c, da, db, dc, color = None):
+        return [a, b, c]
+
+    def smooth_triangle(self, a, b, c, da, db, dc, color=None):
         """
         Function emulating behavior of
         :meth:`~sage.plot.plot3d.tri_plot.TriangleFactory.smooth_triangle`
@@ -1077,7 +1095,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
 
         sage: var('x,y')
         (x, y)
-        sage: plot3d(sin(x^2 + y^2),(x,-5,5),(y,-5,5), plot_points=200)
+        sage: plot3d(sin(x^2 + y^2), (x,-5,5), (y,-5,5), plot_points=200)
         Graphics3d Object
 
     .. ONLY:: html
@@ -1145,8 +1163,10 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
     Two wobby translucent planes::
 
         sage: x,y = var('x,y')
-        sage: P = plot3d(x + y + sin(x*y), (x, -10, 10), (y, -10, 10), opacity=0.87, color='blue')
-        sage: Q = plot3d(x - 2*y - cos(x*y),(x, -10, 10), (y, -10, 10), opacity=0.3, color='red')
+        sage: P = plot3d(x + y + sin(x*y), (x, -10, 10), (y, -10, 10),
+        ....:            opacity=0.87, color='blue')
+        sage: Q = plot3d(x - 2*y - cos(x*y),(x, -10, 10), (y, -10, 10),
+        ....:            opacity=0.3, color='red')
         sage: P + Q
         Graphics3d Object
 
@@ -1470,9 +1490,9 @@ def plot3d_adaptive(f, x_range, y_range, color="automatic",
             texture = Texture(kwds)
 
     factory = TrivialTriangleFactory()
-    plot = TrianglePlot(factory, g, (xmin, xmax), (ymin, ymax), g = grad_f,
+    plot = TrianglePlot(factory, g, (xmin, xmax), (ymin, ymax), g=grad_f,
                         min_depth=initial_depth, max_depth=max_depth,
-                        max_bend=max_bend, num_colors = None)
+                        max_bend=max_bend, num_colors=None)
 
     P = IndexFaceSet(plot._objects)
     if isinstance(texture, (list, tuple)):
