@@ -72,8 +72,9 @@ use its method continued_fraction (if it exists) or call
     sage: continued_fraction_list(pi, nterms=5)
     [3, 7, 15, 1, 292]
 
-    sage: K.<cbrt5> = NumberField(x^3 - 5, embedding=1.709)
-    sage: continued_fraction(cbrt5)
+    sage: x = polygen(ZZ, 'x')
+    sage: K.<cbrt5> = NumberField(x^3 - 5, embedding=1.709)                             # optional - sage.rings.number_field
+    sage: continued_fraction(cbrt5)                                                     # optional - sage.rings.number_field
     [1; 1, 2, 2, 4, 3, 3, 1, 5, 1, 1, 4, 10, 17, 1, 14, 1, 1, 3052, 1, ...]
 
 It is also possible to create a continued fraction from a list of partial
@@ -621,9 +622,10 @@ class ContinuedFraction_base(SageObject):
             sage: cf.n(digits=8)
             0.63459101
 
-            sage: K.<a> = NumberField(x^3-2, 'a', embedding=1.25)
-            sage: b = 504/253*a^2 + 635/253*a + 661/253
-            sage: cf = continued_fraction(b); cf
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a> = NumberField(x^3 - 2, 'a', embedding=1.25)                     # optional - sage.rings.number_field
+            sage: b = 504/253*a^2 + 635/253*a + 661/253                                 # optional - sage.rings.number_field
+            sage: cf = continued_fraction(b); cf                                        # optional - sage.rings.number_field
             [8; 1, 14, 1, 10, 2, 1, 4, 12, 2, 3, 2, 1, 3, 4, 1, 1, 2, 14, 3, ...]
             sage: cf.n(digits=3)
             8.94
@@ -1018,8 +1020,6 @@ class ContinuedFraction_base(SageObject):
         """
         return bool(self.quotient(0)) or self.quotient(1) is not Infinity
 
-    
-
     def is_zero(self):
         r"""
         Test whether ``self`` is zero.
@@ -1915,11 +1915,12 @@ class ContinuedFraction_real(ContinuedFraction_base):
         The same computation with an element of a number field instead of
         ``pi`` gives a very satisfactory answer::
 
-            sage: K.<a2> = NumberField(x^3 - 2, embedding=1.25)
-            sage: c2 = continued_fraction(a2)
-            sage: p0 = c2.numerator(111); q0 = c2.denominator(111)
-            sage: p1 = c2.numerator(112); q1 = c2.denominator(112)
-            sage: num = (q0*a2 - p0); num.n()
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a2> = NumberField(x^3 - 2, embedding=1.25)                         # optional - sage.rings.number_field
+            sage: c2 = continued_fraction(a2)                                           # optional - sage.rings.number_field
+            sage: p0 = c2.numerator(111); q0 = c2.denominator(111)                      # optional - sage.rings.number_field
+            sage: p1 = c2.numerator(112); q1 = c2.denominator(112)                      # optional - sage.rings.number_field
+            sage: num = (q0*a2 - p0); num.n()                                           # optional - sage.rings.number_field
             -4.56719261665907e46
             sage: den = (q1*a2 - p1); den.n()
             -3.65375409332726e47
@@ -2515,13 +2516,13 @@ def continued_fraction_list(x, type="std", partial_convergents=False,
 
 def continued_fraction(x, value=None):
     r"""
-    Return the continued fraction of ``x``.
+    Return the continued fraction of `x`.
 
     INPUT:
 
-        - `x` -- a number or a list of partial quotients (for finite
-          development) or two list of partial quotients (preperiod and period
-          for ultimately periodic development)
+    - ``x`` -- a number or a list of partial quotients (for finite
+      development) or two list of partial quotients (preperiod and period
+      for ultimately periodic development)
 
     EXAMPLES:
 
@@ -2536,40 +2537,41 @@ def continued_fraction(x, value=None):
     It can be called with elements defined from symbolic values, in which case
     the partial quotients are evaluated in a lazy way::
 
-        sage: c = continued_fraction(golden_ratio); c
+        sage: c = continued_fraction(golden_ratio); c                                   # optional - sage.symbolic
         [1; 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, ...]
-        sage: c.convergent(12)
+        sage: c.convergent(12)                                                          # optional - sage.symbolic
         377/233
         sage: fibonacci(14)/fibonacci(13)
         377/233
 
-        sage: continued_fraction(pi)
+        sage: continued_fraction(pi)                                                    # optional - sage.symbolic
         [3; 7, 15, 1, 292, 1, 1, 1, 2, 1, 3, 1, 14, 2, 1, 1, 2, 2, 2, 2, ...]
-        sage: c = continued_fraction(pi); c
+        sage: c = continued_fraction(pi); c                                             # optional - sage.symbolic
         [3; 7, 15, 1, 292, 1, 1, 1, 2, 1, 3, 1, 14, 2, 1, 1, 2, 2, 2, 2, ...]
-        sage: a = c.convergent(3); a
+        sage: a = c.convergent(3); a                                                    # optional - sage.symbolic
         355/113
-        sage: a.n()
+        sage: a.n()                                                                     # optional - sage.symbolic
         3.14159292035398
-        sage: pi.n()
+        sage: pi.n()                                                                    # optional - sage.symbolic
         3.14159265358979
 
-        sage: continued_fraction(sqrt(2))
+        sage: continued_fraction(sqrt(2))                                               # optional - sage.symbolic
         [1; 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, ...]
-        sage: continued_fraction(tan(1))
+        sage: continued_fraction(tan(1))                                                # optional - sage.symbolic
         [1; 1, 1, 3, 1, 5, 1, 7, 1, 9, 1, 11, 1, 13, 1, 15, 1, 17, 1, 19, ...]
-        sage: continued_fraction(tanh(1))
+        sage: continued_fraction(tanh(1))                                               # optional - sage.symbolic
         [0; 1, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 33, 35, 37, ...]
-        sage: continued_fraction(e)
+        sage: continued_fraction(e)                                                     # optional - sage.symbolic
         [2; 1, 2, 1, 1, 4, 1, 1, 6, 1, 1, 8, 1, 1, 10, 1, 1, 12, 1, 1, ...]
 
     If you want to play with quadratic numbers (such as ``golden_ratio`` and
     ``sqrt(2)`` above), it is much more convenient to use number fields as
     follows since preperiods and periods are computed::
 
-        sage: K.<sqrt5> = NumberField(x^2-5, embedding=2.23)
-        sage: my_golden_ratio = (1 + sqrt5)/2
-        sage: cf = continued_fraction((1+sqrt5)/2); cf
+        sage: x = polygen(ZZ, 'x')
+        sage: K.<sqrt5> = NumberField(x^2 - 5, embedding=2.23)                          # optional - sage.rings.number_field
+        sage: my_golden_ratio = (1 + sqrt5)/2                                           # optional - sage.rings.number_field
+        sage: cf = continued_fraction((1+sqrt5)/2); cf                                  # optional - sage.rings.number_field
         [(1)*]
         sage: cf.convergent(12)
         377/233
@@ -2582,7 +2584,7 @@ def continued_fraction(x, value=None):
         sage: cf.period()
         (1, 3, 1, 1, 3, 9)
 
-        sage: L.<sqrt2> = NumberField(x^2-2, embedding=1.41)
+        sage: L.<sqrt2> = NumberField(x^2 - 2, embedding=1.41)
         sage: cf = continued_fraction(sqrt2); cf
         [1; (2)*]
         sage: cf.period()
@@ -2596,7 +2598,7 @@ def continued_fraction(x, value=None):
     continued fraction from its preperiod and its period and get its value
     back::
 
-        sage: cf = continued_fraction([(1,1),(2,8)]); cf
+        sage: cf = continued_fraction([(1,1), (2,8)]); cf
         [1; 1, (2, 8)*]
         sage: cf.value()
         2/11*sqrt5 + 14/11
@@ -2604,7 +2606,7 @@ def continued_fraction(x, value=None):
     It is possible to deal with higher degree number fields but in that case the
     continued fraction expansion is known to be aperiodic::
 
-        sage: K.<a> = NumberField(x^3-2, embedding=1.25)
+        sage: K.<a> = NumberField(x^3 - 2, embedding=1.25)
         sage: cf = continued_fraction(a); cf
         [1; 3, 1, 5, 1, 1, 4, 1, 1, 8, 1, 14, 1, 10, 2, 1, 4, 12, 2, 3, ...]
 
@@ -2633,8 +2635,8 @@ def continued_fraction(x, value=None):
 
     Constants in symbolic subrings work like constants in ``SR``::
 
-        sage: SCR = SR.subring(no_variables=True)
-        sage: continued_fraction(SCR(pi))
+        sage: SCR = SR.subring(no_variables=True)                                       # optional - sage.symbolic
+        sage: continued_fraction(SCR(pi))                                               # optional - sage.symbolic
         [3; 7, 15, 1, 292, 1, 1, 1, 2, 1, 3, 1, 14, 2, 1, 1, 2, 2, 2, 2, ...]
     """
 
