@@ -35,7 +35,8 @@ as follows::
     sage: A.<x,y,z> = QQ[]
     sage: M = A.derivation_module()
     sage: M
-    Module of derivations over Multivariate Polynomial Ring in x, y, z over Rational Field
+    Module of derivations over
+     Multivariate Polynomial Ring in x, y, z over Rational Field
 
 The method :meth:`~sage.rings.derivation.RingDerivationModule.gens`
 returns the generators of this module::
@@ -76,8 +77,10 @@ of the ring `A` to create derivations::
 Sage knows moreover that `M` is a Lie algebra::
 
     sage: M.category()
-    Join of Category of lie algebras with basis over Rational Field
-     and Category of modules with basis over Multivariate Polynomial Ring in x, y, z over Rational Field
+    Join of
+     Category of lie algebras with basis over Rational Field and
+     Category of modules with basis over
+      Multivariate Polynomial Ring in x, y, z over Rational Field
 
 Computations of Lie brackets are implemented as well::
 
@@ -116,7 +119,9 @@ on `\QQ` and then build the following module of derivations::
 
     sage: M = A.derivation_module(ev)
     sage: M
-    Module of derivations from Multivariate Polynomial Ring in x, y, z over Rational Field to Rational Field
+    Module of derivations
+     from Multivariate Polynomial Ring in x, y, z over Rational Field
+       to Rational Field
     sage: M.gens()
     (d/dx, d/dy, d/dz)
 
@@ -138,7 +143,8 @@ Twisted derivations are handled similarly::
 
     sage: theta = B.hom([B(y),B(z),B(x)])
     sage: theta
-    Ring endomorphism of Fraction Field of Multivariate Polynomial Ring in x, y, z over Rational Field
+    Ring endomorphism of Fraction Field of
+     Multivariate Polynomial Ring in x, y, z over Rational Field
       Defn: x |--> y
             y |--> z
             z |--> x
@@ -196,7 +202,8 @@ from sage.rings.quotient_ring import QuotientRing_generic
 from sage.rings.polynomial.polynomial_quotient_ring import PolynomialQuotientRing_generic
 from sage.rings.finite_rings.integer_mod_ring import IntegerModRing_generic
 from sage.rings.padics.padic_generic import pAdicGeneric
-from sage.rings.function_field.function_field import FunctionField, RationalFunctionField
+from sage.rings.function_field.function_field import FunctionField
+from sage.rings.function_field.function_field_rational import RationalFunctionField
 from sage.categories.number_fields import NumberFields
 from sage.categories.finite_fields import FiniteFields
 from sage.categories.modules import Modules
@@ -224,25 +231,32 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: TestSuite(M).run()
 
             sage: from sage.rings.derivation import RingDerivationModule
-            sage: R5.<x> = GF(5)[]
-            sage: R25.<x> = GF(25)[]
-            sage: R7.<x> = GF(7)[]
+            sage: R5.<x> = GF(5)[]                                                      # optional - sage.rings.finite_rings
+            sage: R25.<x> = GF(25)[]                                                    # optional - sage.rings.finite_rings
+            sage: R7.<x> = GF(7)[]                                                      # optional - sage.rings.finite_rings
 
-            sage: RingDerivationModule(R5, R25)
-            Module of derivations from Univariate Polynomial Ring in x over Finite Field of size 5 to Univariate Polynomial Ring in x over Finite Field in z2 of size 5^2
-            sage: RingDerivationModule(R5, R5^2)
+            sage: RingDerivationModule(R5, R25)                                         # optional - sage.rings.finite_rings
+            Module of derivations
+             from Univariate Polynomial Ring in x over Finite Field of size 5
+               to Univariate Polynomial Ring in x over Finite Field in z2 of size 5^2
+            sage: RingDerivationModule(R5, R5^2)                                        # optional - sage.rings.finite_rings
             Traceback (most recent call last):
             ...
-            TypeError: the codomain must be an algebra over the domain or a morphism with the correct domain
-            sage: RingDerivationModule(R5, R7)
+            TypeError: the codomain must be an algebra over the domain
+             or a morphism with the correct domain
+            sage: RingDerivationModule(R5, R7)                                          # optional - sage.rings.finite_rings
             Traceback (most recent call last):
             ...
-            TypeError: the codomain must be an algebra over the domain or a morphism with the correct domain
+            TypeError: the codomain must be an algebra over the domain
+             or a morphism with the correct domain
 
-            sage: theta = R5.hom([R5.gen()^2])
-            sage: RingDerivationModule(R5, R25, twist=theta)
-            Module of twisted derivations from Univariate Polynomial Ring in x over Finite Field of size 5 to Univariate Polynomial Ring in x over Finite Field in z2 of size 5^2 (twisting morphism: x |--> x^2)
-            sage: RingDerivationModule(R7, R7, twist=theta)
+            sage: theta = R5.hom([R5.gen()^2])                                          # optional - sage.rings.finite_rings
+            sage: RingDerivationModule(R5, R25, twist=theta)                            # optional - sage.rings.finite_rings
+            Module of twisted derivations
+             from Univariate Polynomial Ring in x over Finite Field of size 5
+               to Univariate Polynomial Ring in x over Finite Field in z2 of size 5^2
+             (twisting morphism: x |--> x^2)
+            sage: RingDerivationModule(R7, R7, twist=theta)                             # optional - sage.rings.finite_rings
             Traceback (most recent call last):
             ...
             TypeError: the domain of the derivation must coerce to the domain of the twisting homomorphism
@@ -391,13 +405,13 @@ class RingDerivationModule(Module, UniqueRepresentation):
             constants, sharp = self._base_derivation._constants
             self._constants = (constants, False)  # can we do better?
         elif isinstance(domain, RationalFunctionField):
-            from sage.rings.function_field.maps import FunctionFieldDerivation_rational
+            from sage.rings.function_field.derivations_rational import FunctionFieldDerivation_rational
             self.Element = FunctionFieldDerivation_rational
             self._gens = self._basis = [ None ]
             self._dual_basis = [ domain.gen() ]
         elif isinstance(domain, FunctionField):
             if domain.is_separable():
-                from sage.rings.function_field.maps import FunctionFieldDerivation_separable
+                from sage.rings.function_field.derivations_polymod import FunctionFieldDerivation_separable
                 self._base_derivation = RingDerivationModule(domain.base_ring(), defining_morphism)
                 self.Element = FunctionFieldDerivation_separable
                 try:
@@ -410,7 +424,7 @@ class RingDerivationModule(Module, UniqueRepresentation):
                 except NotImplementedError:
                     pass
             else:
-                from sage.rings.function_field.maps import FunctionFieldDerivation_inseparable
+                from sage.rings.function_field.derivations_polymod import FunctionFieldDerivation_inseparable
                 M, f, self._t = domain.separable_model()
                 self._base_derivation = RingDerivationModule(M, defining_morphism * f)
                 self._d = self._base_derivation(None)
@@ -459,8 +473,10 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M1 = A.derivation_module(); M1
             Module of derivations over Univariate Polynomial Ring in x over Rational Field
             sage: M2 = A.derivation_module(B); M2
-            Module of derivations from Univariate Polynomial Ring in x over Rational Field
-             to Univariate Polynomial Ring in y over Univariate Polynomial Ring in x over Rational Field
+            Module of derivations
+             from Univariate Polynomial Ring in x over Rational Field
+               to Univariate Polynomial Ring in y over
+                   Univariate Polynomial Ring in x over Rational Field
             sage: M1._coerce_map_from_(M2) is None
             True
             sage: M1.has_coerce_map_from(M2)
@@ -566,7 +582,8 @@ class RingDerivationModule(Module, UniqueRepresentation):
             sage: M.defining_morphism()
             Polynomial base injection morphism:
               From: Univariate Polynomial Ring in x over Rational Field
-              To:   Univariate Polynomial Ring in y over Univariate Polynomial Ring in x over Rational Field
+              To:   Univariate Polynomial Ring in y over
+                     Univariate Polynomial Ring in x over Rational Field
 
             sage: ev = R.hom([QQ(0)])
             sage: M = R.derivation_module(ev)
@@ -856,7 +873,8 @@ class RingDerivation(ModuleElement):
             sage: S.<y> = R[]
             sage: M = R.derivation_module(S)
             sage: M.random_element().codomain()
-            Univariate Polynomial Ring in y over Univariate Polynomial Ring in x over Rational Field
+            Univariate Polynomial Ring in y over
+             Univariate Polynomial Ring in x over Rational Field
             sage: M.random_element().codomain() is S
             True
 
@@ -1056,10 +1074,10 @@ class RingDerivationWithoutTwist(RingDerivation):
 
         EXAMPLES::
 
-            sage: R.<x,y,z> = GF(5)[]
-            sage: D = sum(v*R.derivation(v) for v in R.gens()); D
+            sage: R.<x,y,z> = GF(5)[]                                                   # optional - sage.rings.finite_rings
+            sage: D = sum(v*R.derivation(v) for v in R.gens()); D                       # optional - sage.rings.finite_rings
             x*d/dx + y*d/dy + z*d/dz
-            sage: D.pth_power() == D
+            sage: D.pth_power() == D                                                    # optional - sage.rings.finite_rings
             True
 
         """
@@ -1131,17 +1149,17 @@ class RingDerivationWithoutTwist(RingDerivation):
 
         EXAMPLES::
 
-            sage: R.<x,y> = GF(5)[]
-            sage: Dx = R.derivation(x)
-            sage: Dx.pth_power()
+            sage: R.<x,y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: Dx = R.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: Dx.pth_power()                                                        # optional - sage.rings.finite_rings
             0
-            sage: (x*Dx).pth_power()
+            sage: (x*Dx).pth_power()                                                    # optional - sage.rings.finite_rings
             x*d/dx
-            sage: (x^6*Dx).pth_power()
+            sage: (x^6*Dx).pth_power()                                                  # optional - sage.rings.finite_rings
             x^26*d/dx
 
-            sage: Dy = R.derivation(y)
-            sage: (x*Dx + y*Dy).pth_power()
+            sage: Dy = R.derivation(y)                                                  # optional - sage.rings.finite_rings
+            sage: (x*Dx + y*Dy).pth_power()                                             # optional - sage.rings.finite_rings
             x*d/dx + y*d/dy
 
         An error is raised if the domain has characteristic zero::
@@ -1164,14 +1182,14 @@ class RingDerivationWithoutTwist(RingDerivation):
 
         TESTS::
 
-            sage: R.<x,y> = GF(3)[]
-            sage: D = R.derivation_module().random_element()
-            sage: Dp = D.pth_power()
-            sage: f = R.random_element()
-            sage: Dp(f) == D(D(D(f)))
+            sage: R.<x,y> = GF(3)[]                                                     # optional - sage.rings.finite_rings
+            sage: D = R.derivation_module().random_element()                            # optional - sage.rings.finite_rings
+            sage: Dp = D.pth_power()                                                    # optional - sage.rings.finite_rings
+            sage: f = R.random_element()                                                # optional - sage.rings.finite_rings
+            sage: Dp(f) == D(D(D(f)))                                                   # optional - sage.rings.finite_rings
             True
 
-            sage: D.bracket(Dp)
+            sage: D.bracket(Dp)                                                         # optional - sage.rings.finite_rings
             0
 
         """
@@ -1561,14 +1579,14 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
         TESTS::
 
             sage: from sage.rings.derivation import RingDerivationWithoutTwist_wrapper
-            sage: R.<x,y> = GF(5)[]
-            sage: S = R.quo([x^5, y^5])
-            sage: M = S.derivation_module()
-            sage: der = M.random_element()
-            sage: isinstance(der, RingDerivationWithoutTwist_wrapper)
+            sage: R.<x,y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S = R.quo([x^5, y^5])                                                 # optional - sage.rings.finite_rings
+            sage: M = S.derivation_module()                                             # optional - sage.rings.finite_rings
+            sage: der = M.random_element()                                              # optional - sage.rings.finite_rings
+            sage: isinstance(der, RingDerivationWithoutTwist_wrapper)                   # optional - sage.rings.finite_rings
             True
 
-            sage: TestSuite(der).run()
+            sage: TestSuite(der).run()                                                  # optional - sage.rings.finite_rings
 
         """
         if isinstance(arg, list) and len(arg) == 1 and isinstance(arg[0], RingDerivation):
@@ -1599,11 +1617,11 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: Dx = S.derivation(x)
-            sage: Dy = S.derivation(y)
-            sage: Dx + Dy
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: Dx = S.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: Dy = S.derivation(y)                                                  # optional - sage.rings.finite_rings
+            sage: Dx + Dy                                                               # optional - sage.rings.finite_rings
             d/dx + d/dy
 
         """
@@ -1615,11 +1633,11 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: Dx = S.derivation(x)
-            sage: Dy = S.derivation(y)
-            sage: Dx - Dy
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: Dx = S.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: Dy = S.derivation(y)                                                  # optional - sage.rings.finite_rings
+            sage: Dx - Dy                                                               # optional - sage.rings.finite_rings
             d/dx - d/dy
 
         """
@@ -1631,10 +1649,10 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: Dx = S.derivation(x)
-            sage: -Dx
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: Dx = S.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: -Dx                                                                   # optional - sage.rings.finite_rings
             -d/dx
 
         """
@@ -1646,12 +1664,12 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: Dx = S.derivation(x)
-            sage: Dx * 2
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: Dx = S.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: Dx * 2                                                                # optional - sage.rings.finite_rings
             2*d/dx
-            sage: Dx * x^2
+            sage: Dx * x^2                                                              # optional - sage.rings.finite_rings
             x^2*d/dx
 
         """
@@ -1663,12 +1681,12 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: Dx = S.derivation(x)
-            sage: 2 * Dx
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: Dx = S.derivation(x)                                                  # optional - sage.rings.finite_rings
+            sage: 2 * Dx                                                                # optional - sage.rings.finite_rings
             2*d/dx
-            sage: x^2 * Dx
+            sage: x^2 * Dx                                                              # optional - sage.rings.finite_rings
             x^2*d/dx
 
         """
@@ -1681,20 +1699,20 @@ class RingDerivationWithoutTwist_wrapper(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: M = S.derivation_module()
-            sage: M.basis()
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: M = S.derivation_module()                                             # optional - sage.rings.finite_rings
+            sage: M.basis()                                                             # optional - sage.rings.finite_rings
             Family (d/dx, d/dy)
 
-            sage: S.derivation(x).list()
+            sage: S.derivation(x).list()                                                # optional - sage.rings.finite_rings
             [1, 0]
-            sage: S.derivation(y).list()
+            sage: S.derivation(y).list()                                                # optional - sage.rings.finite_rings
             [0, 1]
 
-            sage: f = x*S.derivation(x) + y*S.derivation(y); f
+            sage: f = x*S.derivation(x) + y*S.derivation(y); f                          # optional - sage.rings.finite_rings
             x*d/dx + y*d/dy
-            sage: f.list()
+            sage: f.list()                                                              # optional - sage.rings.finite_rings
             [x, y]
 
         """
@@ -1815,7 +1833,7 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
         """
         factor = self.parent().codomain()(factor)
         base_derivation = factor * self._base_derivation
-        im = [ factor*x  for x in self._images ]
+        im = [ factor*x for x in self._images ]
         return type(self)(self.parent(), [base_derivation] + im)
 
     def _lmul_(self, factor):
@@ -1888,19 +1906,19 @@ class RingDerivationWithoutTwist_function(RingDerivationWithoutTwist):
 
         EXAMPLES::
 
-            sage: R.<x,y> = GF(5)[[]]
-            sage: M = R.derivation_module()
-            sage: M.basis()
+            sage: R.<x,y> = GF(5)[[]]                                                   # optional - sage.rings.finite_rings
+            sage: M = R.derivation_module()                                             # optional - sage.rings.finite_rings
+            sage: M.basis()                                                             # optional - sage.rings.finite_rings
             Family (d/dx, d/dy)
 
-            sage: R.derivation(x).list()
+            sage: R.derivation(x).list()                                                # optional - sage.rings.finite_rings
             [1, 0]
-            sage: R.derivation(y).list()
+            sage: R.derivation(y).list()                                                # optional - sage.rings.finite_rings
             [0, 1]
 
-            sage: f = x*R.derivation(x) + y*R.derivation(y); f
+            sage: f = x*R.derivation(x) + y*R.derivation(y); f                          # optional - sage.rings.finite_rings
             x*d/dx + y*d/dy
-            sage: f.list()
+            sage: f.list()                                                              # optional - sage.rings.finite_rings
             [x, y]
 
         """
@@ -1973,11 +1991,11 @@ class RingDerivationWithoutTwist_quotient(RingDerivationWithoutTwist_wrapper):
 
         EXAMPLES::
 
-            sage: R.<X,Y> = GF(5)[]
-            sage: S.<x,y> = R.quo([X^5, Y^5])
-            sage: f = x^3*S.derivation(); f
+            sage: R.<X,Y> = GF(5)[]                                                     # optional - sage.rings.finite_rings
+            sage: S.<x,y> = R.quo([X^5, Y^5])                                           # optional - sage.rings.finite_rings
+            sage: f = x^3*S.derivation(); f                                             # optional - sage.rings.finite_rings
             x^3*d/dx
-            sage: f(x^3)
+            sage: f(x^3)                                                                # optional - sage.rings.finite_rings
             0
 
         """
@@ -2073,10 +2091,10 @@ class RingDerivationWithTwist_generic(RingDerivation):
 
         EXAMPLES::
 
-            sage: k.<a> = GF(5^3)
-            sage: Frob = k.frobenius_endomorphism()
-            sage: der = k.derivation(a+1, twist=Frob)
-            sage: latex(der)
+            sage: k.<a> = GF(5^3)                                                       # optional - sage.rings.finite_rings
+            sage: Frob = k.frobenius_endomorphism()                                     # optional - sage.rings.finite_rings
+            sage: der = k.derivation(a + 1, twist=Frob)                                 # optional - sage.rings.finite_rings
+            sage: latex(der)                                                            # optional - sage.rings.finite_rings
             \left(a + 1\right)  \left(\left[a \mapsto a^{5}\right] - \text{id}\right)
         """
         scalar = self._scalar
