@@ -1,5 +1,5 @@
 """
-Finite Prime Fields
+Finite prime fields
 
 AUTHORS:
 
@@ -47,7 +47,7 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
         sage: FiniteField(3)
         Finite Field of size 3
 
-        sage: FiniteField(next_prime(1000))
+        sage: FiniteField(next_prime(1000))                                             # needs sage.rings.finite_rings
         Finite Field of size 1009
     """
     def __init__(self, p, check=True, modulus=None):
@@ -104,8 +104,11 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
             5
             sage: 12 % 7
             5
-            sage: ZZ.residue_field(7).hom(GF(7))(1)  # See trac 11319
+
+            sage: ZZ.residue_field(7).hom(GF(7))(1)  # See trac 11319                   # needs sage.rings.finite_rings
             1
+
+            sage: # needs sage.rings.finite_rings sage.rings.number_field
             sage: K.<w> = QuadraticField(337)  # See trac 11319
             sage: pp = K.ideal(13).factor()[0][0]
             sage: RF13 = K.residue_field(pp)
@@ -117,19 +120,19 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
 
         Check that :trac:`19573` is resolved::
 
-            sage: Integers(9).hom(GF(3))
+            sage: Integers(9).hom(GF(3))                                                # needs sage.rings.finite_rings
             Natural morphism:
               From: Ring of integers modulo 9
               To:   Finite Field of size 3
 
-            sage: Integers(9).hom(GF(5))
+            sage: Integers(9).hom(GF(5))                                                # needs sage.rings.finite_rings
             Traceback (most recent call last):
             ...
             TypeError: natural coercion morphism from Ring of integers modulo 9 to Finite Field of size 5 not defined
 
         There is no coercion from a `p`-adic ring to its residue field::
 
-            sage: GF(3).has_coerce_map_from(Zp(3))
+            sage: GF(3).has_coerce_map_from(Zp(3))                                      # needs sage.rings.padics
             False
         """
         if S is int:
@@ -155,6 +158,7 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
 
         EXAMPLES::
 
+            sage: # needs sage.rings.padics
             sage: GF(3).convert_map_from(Qp(3))
             Reduction morphism:
               From: 3-adic Field with capped relative precision 20
@@ -201,6 +205,7 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
             sage: k.is_prime_field()
             True
 
+            sage: # needs sage.rings.finite_rings
             sage: k.<a> = GF(3^2)
             sage: k.is_prime_field()
             False
@@ -221,7 +226,7 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
             name = self.variable_name()
         try:
             return self.__polynomial[name]
-        except  AttributeError:
+        except AttributeError:
             f = self[name]([0, 1])
             try:
                 self.__polynomial[name] = f
@@ -271,6 +276,8 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
             sage: k = GF(13)
             sage: k.gen()
             1
+
+            sage: # needs sage.rings.finite_rings
             sage: k = GF(1009, modulus="primitive")
             sage: k.gen()  # this gives a primitive element
             11
@@ -304,6 +311,7 @@ class FiniteField_prime_modn(FiniteField_generic, integer_mod_ring.IntegerModRin
         We can even start iterating over something that would be too big
         to actually enumerate::
 
+            sage: # needs sage.rings.finite_rings
             sage: K = GF(next_prime(2^256))
             sage: all = iter(K)
             sage: next(all)
