@@ -29,7 +29,7 @@ Power series arithmetic, tracking precision::
     sage: f*g - g
     2*s^2*t^2 + O(s, t)^5
 
-    sage: f*=s; f
+    sage: f *= s; f
     s + 2*s^2 + 3*s^3 + O(s, t)^8
     sage: f%2
     s + s^3 + O(s, t)^8
@@ -56,43 +56,43 @@ Calling::
 
     sage: f = s^2 + s*t + s^3 + s^2*t + 3*s^4 + 3*s^3*t + R.O(5); f
     s^2 + s*t + s^3 + s^2*t + 3*s^4 + 3*s^3*t + O(s, t)^5
-    sage: f(t,s)
+    sage: f(t, s)
     s*t + t^2 + s*t^2 + t^3 + 3*s*t^3 + 3*t^4 + O(s, t)^5
-    sage: f(t^2,s^2)
+    sage: f(t^2, s^2)
     s^2*t^2 + t^4 + s^2*t^4 + t^6 + 3*s^2*t^6 + 3*t^8 + O(s, t)^10
 
 Substitution is defined only for elements of positive valuation, unless `f`
 has infinite precision::
 
-    sage: f(t^2,s^2+1)
+    sage: f(t^2, s^2 + 1)
     Traceback (most recent call last):
     ...
     TypeError: Substitution defined only for elements of positive valuation,
     unless self has infinite precision.
 
     sage: g = f.truncate()
-    sage: g(t^2,s^2+1)
+    sage: g(t^2, s^2 + 1)
     t^2 + s^2*t^2 + 2*t^4 + s^2*t^4 + 4*t^6 + 3*s^2*t^6 + 3*t^8
-    sage: g(t^2,(s^2+1).O(3))
+    sage: g(t^2, (s^2+1).O(3))
     t^2 + s^2*t^2 + 2*t^4 + O(s, t)^5
 
 0 has valuation ``+Infinity``::
 
-    sage: f(t^2,0)
+    sage: f(t^2, 0)
     t^4 + t^6 + 3*t^8 + O(s, t)^10
-    sage: f(t^2,s^2+s)
+    sage: f(t^2, s^2 + s)
     s*t^2 + s^2*t^2 + t^4 + O(s, t)^5
 
 Substitution of power series with finite precision works too::
 
-    sage: f(s.O(2),t)
+    sage: f(s.O(2), t)
     s^2 + s*t + O(s, t)^3
-    sage: f(f,f)
+    sage: f(f, f)
     2*s^4 + 4*s^3*t + 2*s^2*t^2 + 4*s^5 + 8*s^4*t + 4*s^3*t^2 + 16*s^6 +
     34*s^5*t + 20*s^4*t^2 + 2*s^3*t^3 + O(s, t)^7
-    sage: t(f,f)
+    sage: t(f, f)
     s^2 + s*t + s^3 + s^2*t + 3*s^4 + 3*s^3*t + O(s, t)^5
-    sage: t(0,f) == s(f,0)
+    sage: t(0, f) == s(f, 0)
     True
 
 The ``subs`` syntax works as expected::
@@ -100,10 +100,10 @@ The ``subs`` syntax works as expected::
     sage: r0 = -t^2 - s*t^3 - 2*t^6 + s^7 + s^5*t^2 + R.O(10)
     sage: r1 = s^4 - s*t^4 + s^6*t - 4*s^2*t^5 - 6*s^3*t^5 + R.O(10)
     sage: r2 = 2*s^3*t^2 - 2*s*t^4 - 2*s^3*t^4 + s*t^7 + R.O(10)
-    sage: r0.subs({t:r2,s:r1})
+    sage: r0.subs({t: r2, s: r1})
     -4*s^6*t^4 + 8*s^4*t^6 - 4*s^2*t^8 + 8*s^6*t^6 - 8*s^4*t^8 - 4*s^4*t^9
     + 4*s^2*t^11 - 4*s^6*t^8 + O(s, t)^15
-    sage: r0.subs({t:r2,s:r1}) == r0(r1,r2)
+    sage: r0.subs({t: r2, s: r1}) == r0(r1, r2)
     True
 
 Construct ring homomorphisms from one power series ring to another::
@@ -253,19 +253,19 @@ class MPowerSeries(PowerSeries):
         1 + s + t - s*t + O(s, t)^5
 
 
-        sage: T = PowerSeriesRing(GF(3),5,'t'); T
-        Multivariate Power Series Ring in t0, t1, t2, t3, t4 over Finite
-        Field of size 3
-        sage: t = T.gens()
-        sage: w = t[0] - 2*t[1]*t[3] + 5*t[4]^3 - t[0]^3*t[2]^2; w
+        sage: T = PowerSeriesRing(GF(3),5,'t'); T                                       # optional - sage.rings.finite_rings
+        Multivariate Power Series Ring in t0, t1, t2, t3, t4
+         over Finite Field of size 3
+        sage: t = T.gens()                                                              # optional - sage.rings.finite_rings
+        sage: w = t[0] - 2*t[1]*t[3] + 5*t[4]^3 - t[0]^3*t[2]^2; w                      # optional - sage.rings.finite_rings
         t0 + t1*t3 - t4^3 - t0^3*t2^2
-        sage: w = w.add_bigoh(5); w
+        sage: w = w.add_bigoh(5); w                                                     # optional - sage.rings.finite_rings
         t0 + t1*t3 - t4^3 + O(t0, t1, t2, t3, t4)^5
-        sage: w in T
+        sage: w in T                                                                    # optional - sage.rings.finite_rings
         True
 
-        sage: w = t[0] - 2*t[0]*t[2] + 5*t[4]^3 - t[0]^3*t[2]^2 + T.O(6)
-        sage: w
+        sage: w = t[0] - 2*t[0]*t[2] + 5*t[4]^3 - t[0]^3*t[2]^2 + T.O(6)                # optional - sage.rings.finite_rings
+        sage: w                                                                         # optional - sage.rings.finite_rings
         t0 + t0*t2 - t4^3 - t0^3*t2^2 + O(t0, t1, t2, t3, t4)^6
 
 
@@ -274,20 +274,20 @@ class MPowerSeries(PowerSeries):
         sage: S.random_element(4) # random
         -2*t + t^2 - 12*s^3 + O(s, t)^4
 
-        sage: T.random_element(10) # random
+        sage: T.random_element(10) # random                                             # optional - sage.rings.finite_rings
         -t1^2*t3^2*t4^2 + t1^5*t3^3*t4 + O(t0, t1, t2, t3, t4)^10
 
 
     Convert elements from polynomial rings::
 
-        sage: R = PolynomialRing(ZZ,5,T.variable_names())
-        sage: t = R.gens()
-        sage: r = -t[2]*t[3] + t[3]^2 + t[4]^2
-        sage: T(r)
+        sage: R = PolynomialRing(ZZ, 5, T.variable_names())                             # optional - sage.libs.pari
+        sage: t = R.gens()                                                              # optional - sage.libs.pari
+        sage: r = -t[2]*t[3] + t[3]^2 + t[4]^2                                          # optional - sage.libs.pari
+        sage: T(r)                                                                      # optional - sage.libs.pari
         -t2*t3 + t3^2 + t4^2
-        sage: r.parent()
+        sage: r.parent()                                                                # optional - sage.libs.pari
         Multivariate Polynomial Ring in t0, t1, t2, t3, t4 over Integer Ring
-        sage: r in T
+        sage: r in T                                                                    # optional - sage.libs.pari
         True
     """
 
@@ -313,10 +313,12 @@ class MPowerSeries(PowerSeries):
             sage: g.parent()
             Multivariate Power Series Ring in s, t over Rational Field
 
-            sage: K = NumberField(x-3,'a')
-            sage: g = K.random_element()*f
-            sage: g.parent()
-            Multivariate Power Series Ring in s, t over Number Field in a with defining polynomial x - 3
+            sage: x = polygen(ZZ, 'x')
+            sage: K = NumberField(x - 3,'a')                                            # optional - sage.rings.number_field
+            sage: g = K.random_element()*f                                              # optional - sage.rings.number_field
+            sage: g.parent()                                                            # optional - sage.rings.number_field
+            Multivariate Power Series Ring in s, t over
+             Number Field in a with defining polynomial x - 3
 
         TESTS::
 
@@ -355,7 +357,6 @@ class MPowerSeries(PowerSeries):
         except AttributeError:
             pass
 
-
         # set the correct background value, depending on what type of input x is
         try:
             xparent = x.parent() # 'int' types have no parent
@@ -450,20 +451,20 @@ class MPowerSeries(PowerSeries):
 
         Checking that :trac:`15059` is fixed::
 
-            sage: M.<u,v> = PowerSeriesRing(GF(5))
-            sage: s = M.hom([u, u+v])
-            sage: s(M.one())
+            sage: M.<u,v> = PowerSeriesRing(GF(5))                                      # optional - sage.rings.finite_rings
+            sage: s = M.hom([u, u+v])                                                   # optional - sage.rings.finite_rings
+            sage: s(M.one())                                                            # optional - sage.rings.finite_rings
             1
 
         Since :trac:`26105` you can specify a map on the base ring::
 
             sage: Zx.<x> = ZZ[]
-            sage: K.<i> = NumberField(x^2 + 1)
-            sage: cc = K.hom([-i])
-            sage: R.<s,t> = PowerSeriesRing(K)
-            sage: f = s^2 + i*s*t + (3+4*i)*s^3 + R.O(4); f
+            sage: K.<i> = NumberField(x^2 + 1)                                          # optional - sage.rings.number_field
+            sage: cc = K.hom([-i])                                                      # optional - sage.rings.number_field
+            sage: R.<s,t> = PowerSeriesRing(K)                                          # optional - sage.rings.number_field
+            sage: f = s^2 + i*s*t + (3+4*i)*s^3 + R.O(4); f                             # optional - sage.rings.number_field
             s^2 + i*s*t + (4*i + 3)*s^3 + O(s, t)^4
-            sage: f(t, s, base_map=cc)
+            sage: f(t, s, base_map=cc)                                                  # optional - sage.rings.number_field
             (-i)*s*t + t^2 + (-4*i + 3)*t^3 + O(s, t)^4
         """
         if len(x) != self.parent().ngens():
@@ -566,14 +567,14 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: R.<a,b,c> = PowerSeriesRing(GF(5)); R
+            sage: R.<a,b,c> = PowerSeriesRing(GF(5)); R                                 # optional - sage.rings.finite_rings
             Multivariate Power Series Ring in a, b, c over Finite Field of
             size 5
-            sage: f = 1 + a + b - a*b + R.O(3); f
+            sage: f = 1 + a + b - a*b + R.O(3); f                                       # optional - sage.rings.finite_rings
             1 + a + b - a*b + O(a, b, c)^3
-            sage: f._value()
+            sage: f._value()                                                            # optional - sage.rings.finite_rings
             1 + a + b - a*b
-            sage: f._value().parent()
+            sage: f._value().parent()                                                   # optional - sage.rings.finite_rings
             Multivariate Polynomial Ring in a, b, c over Finite Field of size 5
         """
         return self._go_to_fg(self._bg_value)
@@ -602,15 +603,15 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: M = PowerSeriesRing(GF(5),3,'t'); M
+            sage: M = PowerSeriesRing(GF(5),3,'t'); M                                   # optional - sage.rings.finite_rings
             Multivariate Power Series Ring in t0, t1, t2 over Finite Field of size 5
-            sage: t = M.gens()
-            sage: f = -t[0]^4*t[1]^3*t[2]^4 - 2*t[0]*t[1]^4*t[2]^7 \
-            + 2*t[1]*t[2]^12 + 2*t[0]^7*t[1]^5*t[2]^2 + M.O(15)
-            sage: f
+            sage: t = M.gens()                                                          # optional - sage.rings.finite_rings
+            sage: f = (-t[0]^4*t[1]^3*t[2]^4 - 2*t[0]*t[1]^4*t[2]^7                     # optional - sage.rings.finite_rings
+            ....:      + 2*t[1]*t[2]^12 + 2*t[0]^7*t[1]^5*t[2]^2 + M.O(15))
+            sage: f                                                                     # optional - sage.rings.finite_rings
             -t0^4*t1^3*t2^4 - 2*t0*t1^4*t2^7 + 2*t1*t2^12 + 2*t0^7*t1^5*t2^2
             + O(t0, t1, t2)^15
-            sage: f._latex_()
+            sage: f._latex_()                                                           # optional - sage.rings.finite_rings
             '-t_{0}^{4} t_{1}^{3} t_{2}^{4} + 3 t_{0} t_{1}^{4} t_{2}^{7} +
             2 t_{1} t_{2}^{12} + 2 t_{0}^{7} t_{1}^{5} t_{2}^{2}
             + O(t_{0}, t_{1}, t_{2})^{15}'
@@ -631,7 +632,6 @@ class MPowerSeries(PowerSeries):
                  'gens':', '.join(g._latex_() for g in self.parent().gens()),
                  'prec':self._prec}
 
-
     def _im_gens_(self, codomain, im_gens, base_map=None):
         """
         Returns the image of this series under the map that sends the
@@ -709,30 +709,30 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: R.<a,b,c> = PowerSeriesRing(GF(5)); R
+            sage: R.<a,b,c> = PowerSeriesRing(GF(5)); R                                 # optional - sage.rings.finite_rings
             Multivariate Power Series Ring in a, b, c over Finite Field of size 5
-            sage: f = a + b + c + a^2*c
-            sage: f == f^2
+            sage: f = a + b + c + a^2*c                                                 # optional - sage.rings.finite_rings
+            sage: f == f^2                                                              # optional - sage.rings.finite_rings
             False
-            sage: f = f.truncate()
-            sage: f == f.O(4)
+            sage: f = f.truncate()                                                      # optional - sage.rings.finite_rings
+            sage: f == f.O(4)                                                           # optional - sage.rings.finite_rings
             True
 
         Ordering is determined by underlying polynomial ring::
 
-            sage: a > b
+            sage: a > b                                                                 # optional - sage.rings.finite_rings
             True
-            sage: a > a^2
+            sage: a > a^2                                                               # optional - sage.rings.finite_rings
             True
-            sage: b > a^2
+            sage: b > a^2                                                               # optional - sage.rings.finite_rings
             True
-            sage: (f^2).O(3)
+            sage: (f^2).O(3)                                                            # optional - sage.rings.finite_rings
             a^2 + 2*a*b + 2*a*c + b^2 + 2*b*c + c^2 + O(a, b, c)^3
-            sage: f < f^2
+            sage: f < f^2                                                               # optional - sage.rings.finite_rings
             False
-            sage: f > f^2
+            sage: f > f^2                                                               # optional - sage.rings.finite_rings
             True
-            sage: f < 2*f
+            sage: f < 2*f                                                               # optional - sage.rings.finite_rings
             True
         """
         return richcmp(self._bg_value, other._bg_value, op)
@@ -894,24 +894,24 @@ class MPowerSeries(PowerSeries):
             sage: R.<a,b,c> = PowerSeriesRing(ZZ)
             sage: f = 1 + a + b - a*b + R.O(3)
             sage: g = 1 + 2*a - 3*a*b + R.O(3)
-            sage: q, r = f.quo_rem(g); q, r
+            sage: q, r = f.quo_rem(g); q, r                                             # optional - sage.libs.singular
             (1 - a + b + 2*a^2 + O(a, b, c)^3, 0 + O(a, b, c)^3)
-            sage: f == q*g+r
+            sage: f == q*g + r                                                          # optional - sage.libs.singular
             True
 
-            sage: q, r = (a*f).quo_rem(g); q, r
+            sage: q, r = (a*f).quo_rem(g); q, r                                         # optional - sage.libs.singular
             (a - a^2 + a*b + 2*a^3 + O(a, b, c)^4, 0 + O(a, b, c)^4)
-            sage: a*f == q*g+r
+            sage: a*f == q*g + r                                                        # optional - sage.libs.singular
             True
 
-            sage: q, r = (a*f).quo_rem(a*g); q, r
+            sage: q, r = (a*f).quo_rem(a*g); q, r                                       # optional - sage.libs.singular
             (1 - a + b + 2*a^2 + O(a, b, c)^3, 0 + O(a, b, c)^4)
-            sage: a*f == q*(a*g)+r
+            sage: a*f == q*(a*g) + r                                                    # optional - sage.libs.singular
             True
 
-            sage: q, r = (a*f).quo_rem(b*g); q, r
+            sage: q, r = (a*f).quo_rem(b*g); q, r                                       # optional - sage.libs.singular
             (a - 3*a^2 + O(a, b, c)^3, a + a^2 + O(a, b, c)^4)
-            sage: a*f == q*(b*g)+r
+            sage: a*f == q*(b*g) + r                                                    # optional - sage.libs.singular
             True
 
         Trying to divide two polynomials, we run into the issue that
@@ -920,59 +920,61 @@ class MPowerSeries(PowerSeries):
         algorithm would never terminate). Here, default precision
         comes to our help::
 
-            sage: (1+a^3).quo_rem(a+a^2)
-            (a^2 - a^3 + a^4 - a^5 + a^6 - a^7 + a^8 - a^9 + a^10 + O(a, b, c)^11, 1 + O(a, b, c)^12)
+            sage: (1 + a^3).quo_rem(a + a^2)                                            # optional - sage.libs.singular
+            (a^2 - a^3 + a^4 - a^5 + a^6 - a^7 + a^8 - a^9 + a^10 + O(a, b, c)^11,
+             1 + O(a, b, c)^12)
 
-            sage: (1+a^3+a*b).quo_rem(b+c)
+            sage: (1 + a^3 + a*b).quo_rem(b + c)                                        # optional - sage.libs.singular
             (a + O(a, b, c)^11, 1 - a*c + a^3 + O(a, b, c)^12)
-            sage: (1+a^3+a*b).quo_rem(b+c, precision=17)
+            sage: (1 + a^3 + a*b).quo_rem(b + c, precision=17)                          # optional - sage.libs.singular
             (a + O(a, b, c)^16, 1 - a*c + a^3 + O(a, b, c)^17)
 
-            sage: (a^2+b^2+c^2).quo_rem(a+b+c)
+            sage: (a^2 + b^2 + c^2).quo_rem(a + b + c)                                  # optional - sage.libs.singular
             (a - b - c + O(a, b, c)^11, 2*b^2 + 2*b*c + 2*c^2 + O(a, b, c)^12)
 
-            sage: (a^2+b^2+c^2).quo_rem(1/(1+a+b+c))
-            (a^2 + b^2 + c^2 + a^3 + a^2*b + a^2*c + a*b^2 + a*c^2 + b^3 + b^2*c + b*c^2 + c^3 + O(a, b, c)^14,
+            sage: (a^2 + b^2 + c^2).quo_rem(1/(1+a+b+c))                                # optional - sage.libs.singular
+            (a^2 + b^2 + c^2 + a^3 + a^2*b + a^2*c + a*b^2 + a*c^2
+               + b^3 + b^2*c + b*c^2 + c^3 + O(a, b, c)^14,
              0)
 
-            sage: (a^2+b^2+c^2).quo_rem(a/(1+a+b+c))
+            sage: (a^2 + b^2 + c^2).quo_rem(a/(1+a+b+c))                                # optional - sage.libs.singular
             (a + a^2 + a*b + a*c + O(a, b, c)^13, b^2 + c^2)
 
-            sage: (1+a+a^15).quo_rem(a^2)
+            sage: (1 + a + a^15).quo_rem(a^2)                                           # optional - sage.libs.singular
             (0 + O(a, b, c)^10, 1 + a + O(a, b, c)^12)
-            sage: (1+a+a^15).quo_rem(a^2, precision=15)
+            sage: (1 + a + a^15).quo_rem(a^2, precision=15)                             # optional - sage.libs.singular
             (0 + O(a, b, c)^13, 1 + a + O(a, b, c)^15)
-            sage: (1+a+a^15).quo_rem(a^2, precision=16)
+            sage: (1 + a + a^15).quo_rem(a^2, precision=16)                             # optional - sage.libs.singular
             (a^13 + O(a, b, c)^14, 1 + a + O(a, b, c)^16)
 
         Illustrating the dependency on the ordering of variables::
 
-            sage: (1+a+b).quo_rem(b+c)
+            sage: (1 + a + b).quo_rem(b + c)                                            # optional - sage.libs.singular
             (1 + O(a, b, c)^11, 1 + a - c + O(a, b, c)^12)
-            sage: (1+b+c).quo_rem(c+a)
+            sage: (1 + b + c).quo_rem(c + a)                                            # optional - sage.libs.singular
             (0 + O(a, b, c)^11, 1 + b + c + O(a, b, c)^12)
-            sage: (1+c+a).quo_rem(a+b)
+            sage: (1 + c + a).quo_rem(a + b)                                            # optional - sage.libs.singular
             (1 + O(a, b, c)^11, 1 - b + c + O(a, b, c)^12)
 
         TESTS::
 
-            sage: (f).quo_rem(R.zero())
+            sage: (f).quo_rem(R.zero())                                                 # optional - sage.libs.singular
             Traceback (most recent call last):
             ...
             ZeroDivisionError
 
-            sage: (f).quo_rem(R.zero().add_bigoh(2))
+            sage: (f).quo_rem(R.zero().add_bigoh(2))                                    # optional - sage.libs.singular
             Traceback (most recent call last):
             ...
             ZeroDivisionError
 
         Coercion is applied on ``other``::
 
-            sage: (a+b).quo_rem(1)
+            sage: (a + b).quo_rem(1)                                                    # optional - sage.libs.singular
             (a + b + O(a, b, c)^12, 0 + O(a, b, c)^12)
 
             sage: R.<a,b,c> = PowerSeriesRing(QQ)
-            sage: R(3).quo_rem(2)
+            sage: R(3).quo_rem(2)                                                       # optional - sage.libs.singular
             (3/2 + O(a, b, c)^12, 0 + O(a, b, c)^12)
         """
         parent = self.parent()
@@ -1036,30 +1038,30 @@ class MPowerSeries(PowerSeries):
 
         When possible, division by non-units also works::
 
-            sage: a/(a*f)
+            sage: a/(a*f)                                                               # optional - sage.libs.singular
             1 - a - b + a^2 + 3*a*b + b^2 + O(a, b, c)^3
 
-            sage: a/(R.zero())
+            sage: a/(R.zero())                                                          # optional - sage.libs.singular
             Traceback (most recent call last):
             ZeroDivisionError
 
-            sage: (a*f)/f
+            sage: (a*f)/f                                                               # optional - sage.libs.singular
             a + O(a, b, c)^4
-            sage: f/(a*f)
+            sage: f/(a*f)                                                               # optional - sage.libs.singular
             Traceback (most recent call last):
             ...
             ValueError: not divisible
 
         An example where one loses precision::
 
-            sage: ((1+a)*f - f) / a*f
+            sage: ((1+a)*f - f) / a*f                                                   # optional - sage.libs.singular
             1 + 2*a + 2*b + O(a, b, c)^2
 
         TESTS::
 
-            sage: ((a+b)*f) / f == (a+b)
+            sage: ((a+b)*f) / f == (a+b)                                                # optional - sage.libs.singular
             True
-            sage: ((a+b)*f) / (a+b) == f
+            sage: ((a+b)*f) / (a+b) == f                                                # optional - sage.libs.singular
             True
         """
         if denom_r.is_unit(): # faster if denom_r is a unit
@@ -1082,7 +1084,7 @@ class MPowerSeries(PowerSeries):
             False
             sage: g in R.base_extend(Zmod(2))
             True
-            sage: g.polynomial() == f.polynomial() % 2
+            sage: g.polynomial() == f.polynomial() % 2                                              # optional - sage.libs.singular
             True
         """
         if isinstance(other, (int, Integer)):
@@ -1157,14 +1159,14 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: T = PowerSeriesRing(GF(3),5,'t'); T
+            sage: T = PowerSeriesRing(GF(3),5,'t'); T                                   # optional - sage.rings.finite_rings
             Multivariate Power Series Ring in t0, t1, t2, t3, t4 over
             Finite Field of size 3
-            sage: t = T.gens()
-            sage: w = t[0] - 2*t[0]*t[2] + 5*t[4]^3 - t[0]^3*t[2]^2 + T.O(6)
-            sage: w
+            sage: t = T.gens()                                                          # optional - sage.rings.finite_rings
+            sage: w = t[0] - 2*t[0]*t[2] + 5*t[4]^3 - t[0]^3*t[2]^2 + T.O(6)            # optional - sage.rings.finite_rings
+            sage: w                                                                     # optional - sage.rings.finite_rings
             t0 + t0*t2 - t4^3 - t0^3*t2^2 + O(t0, t1, t2, t3, t4)^6
-            sage: w.variables()
+            sage: w.variables()                                                         # optional - sage.rings.finite_rings
             (t0, t2, t4)
         """
         return tuple(self.parent(v) for v in self._value().variables())
@@ -1394,16 +1396,16 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: R.<a,b> = PowerSeriesRing(GF(4949717)); R
-            Multivariate Power Series Ring in a, b over Finite Field of
-            size 4949717
-            sage: f = a^2 + a*b + a^3 + R.O(9)
-            sage: f.valuation()
+            sage: R.<a,b> = PowerSeriesRing(GF(4949717)); R                             # optional - sage.rings.finite_rings
+            Multivariate Power Series Ring in a, b
+             over Finite Field of size 4949717
+            sage: f = a^2 + a*b + a^3 + R.O(9)                                          # optional - sage.rings.finite_rings
+            sage: f.valuation()                                                         # optional - sage.rings.finite_rings
             2
-            sage: g = 1 + a + a^3
-            sage: g.valuation()
+            sage: g = 1 + a + a^3                                                       # optional - sage.rings.finite_rings
+            sage: g.valuation()                                                         # optional - sage.rings.finite_rings
             0
-            sage: R.zero().valuation()
+            sage: R.zero().valuation()                                                  # optional - sage.rings.finite_rings
             +Infinity
         """
         try:
@@ -1443,8 +1445,7 @@ class MPowerSeries(PowerSeries):
         EXAMPLES::
 
             sage: R.<a,b,c> = PowerSeriesRing(Zmod(8)); R
-            Multivariate Power Series Ring in a, b, c over Ring of integers
-            modulo 8
+            Multivariate Power Series Ring in a, b, c over Ring of integers modulo 8
             sage: f = a + b + c + a^2*c
             sage: f.is_nilpotent()
             False
@@ -1537,7 +1538,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.is_square()
             Traceback (most recent call last):
@@ -1553,7 +1554,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.square_root()
             Traceback (most recent call last):
@@ -1571,7 +1572,7 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a^2*b + T.O(5)
             sage: f.derivative(a)
             1 + 2*a*b + O(a, b)^4
@@ -1604,7 +1605,7 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: T.<a,b> = PowerSeriesRing(QQ,2)
+            sage: T.<a,b> = PowerSeriesRing(QQ, 2)
             sage: f = a + b + a^2*b + T.O(5)
             sage: f.integral(a, 2)
             1/6*a^3 + 1/2*a^2*b + 1/12*a^4*b + O(a, b)^7
@@ -1615,7 +1616,7 @@ class MPowerSeries(PowerSeries):
 
         Only integration with respect to variables works::
 
-            sage: f.integral(a+b)
+            sage: f.integral(a + b)
             Traceback (most recent call last):
             ...
             ValueError: a + b is not a variable
@@ -1628,7 +1629,7 @@ class MPowerSeries(PowerSeries):
             first case, Sage will report that it has not been able to
             coerce some coefficient to the base ring::
 
-                sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+                sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
                 sage: f = a + T.O(5)
                 sage: f.integral(a)
                 Traceback (most recent call last):
@@ -1650,7 +1651,7 @@ class MPowerSeries(PowerSeries):
             In non-zero characteristic, Sage will report that a zero division
             occurred ::
 
-                sage: T.<a,b> = PowerSeriesRing(Zmod(3),2)
+                sage: T.<a,b> = PowerSeriesRing(Zmod(3), 2)
                 sage: (a^3).integral(a)
                 a^4
                 sage: (a^2).integral(a)
@@ -1668,8 +1669,10 @@ class MPowerSeries(PowerSeries):
         """
         Formal integral for multivariate power series.
 
-        INPUT: ``xx`` - a generator of the power series ring (the
-        one with respect to which to integrate)
+        INPUT:
+
+        - ``xx`` -- a generator of the power series ring (the
+          one with respect to which to integrate)
 
         EXAMPLES::
 
@@ -1724,7 +1727,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.ogf()
             Traceback (most recent call last):
@@ -1739,7 +1742,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.egf()
             Traceback (most recent call last):
@@ -1754,7 +1757,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.__pari__()
             Traceback (most recent call last):
@@ -1763,8 +1766,6 @@ class MPowerSeries(PowerSeries):
         """
         raise NotImplementedError("__pari__")
 
-
-
     ###
     ### the following don't make sense for multivariable power series
     ###
@@ -1775,7 +1776,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.list()
             Traceback (most recent call last):
@@ -1786,14 +1787,13 @@ class MPowerSeries(PowerSeries):
         #return [self.parent(c) for c in self._bg_value.list()]
         raise NotImplementedError("Multivariate power series do not have list of coefficients; use 'coefficients' to get a dict of coefficients.")
 
-
     def variable(self):
         """
         Doesn't make sense for multivariate power series.
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.variable()
             Traceback (most recent call last):
@@ -1809,7 +1809,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.shift(3)
             Traceback (most recent call last):
@@ -1824,7 +1824,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.__lshift__(3)
             Traceback (most recent call last):
@@ -1839,7 +1839,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.__rshift__(3)
             Traceback (most recent call last):
@@ -1855,7 +1855,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.valuation_zero_part()
             Traceback (most recent call last):
@@ -1871,7 +1871,7 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(5)
             sage: f.solve_linear_de()
             Traceback (most recent call last):
@@ -1896,15 +1896,15 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = a + b + a*b + T.O(3)
-            sage: exp(f)
+            sage: exp(f)                                                                # optional - sage.symbolic
             1 + a + b + 1/2*a^2 + 2*a*b + 1/2*b^2 + O(a, b)^3
-            sage: f.exp()
+            sage: f.exp()                                                               # optional - sage.symbolic
             1 + a + b + 1/2*a^2 + 2*a*b + 1/2*b^2 + O(a, b)^3
-            sage: f.exp(prec=2)
+            sage: f.exp(prec=2)                                                         # optional - sage.symbolic
             1 + a + b + O(a, b)^2
-            sage: log(exp(f)) - f
+            sage: log(exp(f)) - f                                                       # optional - sage.symbolic
             0 + O(a, b)^3
 
         If the power series has a constant coefficient `c` and
@@ -1912,8 +1912,8 @@ class MPowerSeries(PowerSeries):
         power series over the :class:`~sage.symbolic.ring.SymbolicRing`. These
         are not yet implemented and therefore such cases raise an error::
 
-            sage: g = 2+f
-            sage: exp(g)
+            sage: g = 2 + f
+            sage: exp(g)                                                                # optional - sage.symbolic
             Traceback (most recent call last):
             ...
             TypeError: unsupported operand parent(s) for *: 'Symbolic Ring' and
@@ -1923,7 +1923,7 @@ class MPowerSeries(PowerSeries):
         Another workaround for this limitation is to change base ring
         to one which is closed under exponentiation, such as `\RR` or `\CC`::
 
-            sage: exp(g.change_ring(RDF))
+            sage: exp(g.change_ring(RDF))                                               # optional - sage.symbolic
             7.38905609... + 7.38905609...*a + 7.38905609...*b + 3.69452804...*a^2 +
             14.7781121...*a*b + 3.69452804...*b^2 + O(a, b)^3
 
@@ -1931,17 +1931,17 @@ class MPowerSeries(PowerSeries):
 
             sage: T.default_prec()
             12
-            sage: exp(a)
+            sage: exp(a)                                                                # optional - sage.symbolic
             1 + a + 1/2*a^2 + 1/6*a^3 + 1/24*a^4 + 1/120*a^5 + 1/720*a^6 + 1/5040*a^7 +
             1/40320*a^8 + 1/362880*a^9 + 1/3628800*a^10 + 1/39916800*a^11 + O(a, b)^12
             sage: a.exp(prec=5)
             1 + a + 1/2*a^2 + 1/6*a^3 + 1/24*a^4 + O(a, b)^5
-            sage: exp(a + T.O(5))
+            sage: exp(a + T.O(5))                                                       # optional - sage.symbolic
             1 + a + 1/2*a^2 + 1/6*a^3 + 1/24*a^4 + O(a, b)^5
 
         TESTS::
 
-            sage: exp(a^2 + T.O(5))
+            sage: exp(a^2 + T.O(5))                                                     # optional - sage.symbolic
             1 + a^2 + 1/2*a^4 + O(a, b)^5
         """
         R = self.parent()
@@ -1988,13 +1988,13 @@ class MPowerSeries(PowerSeries):
 
         EXAMPLES::
 
-            sage: T.<a,b> = PowerSeriesRing(ZZ,2)
+            sage: T.<a,b> = PowerSeriesRing(ZZ, 2)
             sage: f = 1 + a + b + a*b + T.O(5)
-            sage: f.log()
+            sage: f.log()                                                               # optional - sage.symbolic
             a + b - 1/2*a^2 - 1/2*b^2 + 1/3*a^3 + 1/3*b^3 - 1/4*a^4 - 1/4*b^4 + O(a, b)^5
-            sage: log(f)
+            sage: log(f)                                                                # optional - sage.symbolic
             a + b - 1/2*a^2 - 1/2*b^2 + 1/3*a^3 + 1/3*b^3 - 1/4*a^4 - 1/4*b^4 + O(a, b)^5
-            sage: exp(log(f)) - f
+            sage: exp(log(f)) - f                                                       # optional - sage.symbolic
             0 + O(a, b)^5
 
         If the power series has a constant coefficient `c` and
@@ -2002,8 +2002,8 @@ class MPowerSeries(PowerSeries):
         power series over the :class:`~sage.symbolic.ring.SymbolicRing`. These
         are not yet implemented and therefore such cases raise an error::
 
-            sage: g = 2+f
-            sage: log(g)
+            sage: g = 2 + f                                                             # optional - sage.symbolic
+            sage: log(g)                                                                # optional - sage.symbolic
             Traceback (most recent call last):
             ...
             TypeError: unsupported operand parent(s) for -: 'Symbolic Ring' and 'Power
@@ -2012,7 +2012,7 @@ class MPowerSeries(PowerSeries):
         Another workaround for this limitation is to change base ring
         to one which is closed under exponentiation, such as `\RR` or `\CC`::
 
-            sage: log(g.change_ring(RDF))
+            sage: log(g.change_ring(RDF))                                               # optional - sage.symbolic
             1.09861228... + 0.333333333...*a + 0.333333333...*b - 0.0555555555...*a^2
             + 0.222222222...*a*b - 0.0555555555...*b^2 + 0.0123456790...*a^3
             - 0.0740740740...*a^2*b - 0.0740740740...*a*b^2 + 0.0123456790...*b^3
@@ -2021,17 +2021,17 @@ class MPowerSeries(PowerSeries):
 
         TESTS::
 
-            sage: (1+a).log(prec=10).exp()
+            sage: (1+a).log(prec=10).exp()                                              # optional - sage.symbolic
             1 + a + O(a, b)^10
-            sage: a.exp(prec=10).log()
+            sage: a.exp(prec=10).log()                                                  # optional - sage.symbolic
             a + O(a, b)^10
 
-            sage: log(1+a)
+            sage: log(1+a)                                                              # optional - sage.symbolic
             a - 1/2*a^2 + 1/3*a^3 - 1/4*a^4 + 1/5*a^5 - 1/6*a^6 + 1/7*a^7
             - 1/8*a^8 + 1/9*a^9 - 1/10*a^10 + 1/11*a^11 + O(a, b)^12
-            sage: -log(1-a+T.O(5))
+            sage: -log(1-a+T.O(5))                                                      # optional - sage.symbolic
             a + 1/2*a^2 + 1/3*a^3 + 1/4*a^4 + O(a, b)^5
-            sage: a.log(prec=10)
+            sage: a.log(prec=10)                                                        # optional - sage.symbolic
             Traceback (most recent call last):
             ...
             ValueError: Can only take formal power series for non-zero constant term.
@@ -2093,7 +2093,7 @@ class MO():
         sage: m^1
         0 + O(u, v)^1
 
-        sage: T.<a,b,c> = PowerSeriesRing(ZZ,3)
+        sage: T.<a,b,c> = PowerSeriesRing(ZZ, 3)
         sage: z = O(a, b, c)
         sage: z^1
         0 + O(a, b, c)^1
