@@ -9,6 +9,7 @@ the ``ideal()`` and ``exponents()`` methods respectively.
 
 EXAMPLES::
 
+    sage: x = polygen(ZZ, 'x')
     sage: K.<a> = NumberField(x^2 + 23)
     sage: I = K.class_group().gen(); I
     Fractional ideal class (2, 1/2*a - 1/2)
@@ -53,30 +54,31 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: G = NumberField(x^2 + 23,'a').class_group(); G
-        Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23
+        Class group of order 3 with structure C3 of
+         Number Field in a with defining polynomial x^2 + 23
         sage: I = G.0; I
         Fractional ideal class (2, 1/2*a - 1/2)
         sage: I.ideal()
         Fractional ideal (2, 1/2*a - 1/2)
 
-        EXAMPLES::
-
-            sage: K.<w>=QuadraticField(-23)
-            sage: OK=K.ring_of_integers()
-            sage: C=OK.class_group()
-            sage: P2a,P2b=[P for P,e in (2*OK).factor()]
-            sage: c = C(P2a); c
-            Fractional ideal class (2, 1/2*w - 1/2)
-            sage: c.gens()
-            (2, 1/2*w - 1/2)
+        sage: K.<w> = QuadraticField(-23)
+        sage: OK = K.ring_of_integers()
+        sage: C = OK.class_group()
+        sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+        sage: c = C(P2a); c
+        Fractional ideal class (2, 1/2*w - 1/2)
+        sage: c.gens()
+        (2, 1/2*w - 1/2)
     """
     def __init__(self, parent, element, ideal=None):
         """
-        Returns the ideal class of this fractional ideal.
+        Return the ideal class of this fractional ideal.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^2 + 23,'a'); G = K.class_group()
             sage: G(K.ideal(13, a + 4))
             Fractional ideal class (13, 1/2*a + 17/2)
@@ -91,6 +93,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
          EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^2 + 23,'a'); G = K.class_group()
             sage: G(K.ideal(13, a + 4))._repr_()
             'Fractional ideal class (13, 1/2*a + 17/2)'
@@ -107,8 +110,10 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: G = NumberField(x^2 + 23,'a').class_group(); G
-            Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23
+            Class group of order 3 with structure C3 of
+             Number Field in a with defining polynomial x^2 + 23
             sage: I = G.0; I
             Fractional ideal class (2, 1/2*a - 1/2)
             sage: I*I # indirect doctest
@@ -134,8 +139,10 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: G = NumberField(x^2 + 23,'a').class_group(); G
-            Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23
+            Class group of order 3 with structure C3 of
+             Number Field in a with defining polynomial x^2 + 23
             sage: I = G.0; I
             Fractional ideal class (2, 1/2*a - 1/2)
             sage: I*I # indirect doctest
@@ -153,8 +160,9 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^3 - 3*x + 8)
-            sage: C=K.class_group()
+            sage: C = K.class_group()
             sage: c = C(2, a)
             sage: c^2
             Fractional ideal class (4, a)
@@ -178,13 +186,14 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^3 - 3*x + 8); G = K.class_group()
             sage: G(2, a).inverse()
             Fractional ideal class (2, a^2 + 2*a - 1)
             sage: ~G(2, a)
             Fractional ideal class (2, a^2 + 2*a - 1)
         """
-        m = AbelianGroupElement.inverse(self)
+        m = AbelianGroupElement.__invert__(self)
         m._value = (~self.ideal()).reduce_equiv()
         return m
 
@@ -192,15 +201,15 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
     def is_principal(self):
         r"""
-        Returns True iff this ideal class is the trivial (principal) class
+        Return ``True`` iff this ideal class is the trivial (principal) class.
 
         EXAMPLES::
 
-            sage: K.<w>=QuadraticField(-23)
-            sage: OK=K.ring_of_integers()
-            sage: C=OK.class_group()
-            sage: P2a,P2b=[P for P,e in (2*OK).factor()]
-            sage: c=C(P2a)
+            sage: K.<w> = QuadraticField(-23)
+            sage: OK = K.ring_of_integers()
+            sage: C = OK.class_group()
+            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+            sage: c = C(P2a)
             sage: c.is_principal()
             False
             sage: (c^2).is_principal()
@@ -217,9 +226,10 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: k.<a> = NumberField(x^2 + 20072); G = k.class_group(); G
-            Class group of order 76 with structure C38 x C2
-            of Number Field in a with defining polynomial x^2 + 20072
+            Class group of order 76 with structure C38 x C2 of
+             Number Field in a with defining polynomial x^2 + 20072
             sage: I = (G.0)^11; I
             Fractional ideal class (33, 1/2*a + 8)
             sage: J = G(I.ideal()^5); J
@@ -237,11 +247,11 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         EXAMPLES::
 
-            sage: K.<w>=QuadraticField(-23)
-            sage: OK=K.ring_of_integers()
-            sage: C=OK.class_group()
-            sage: P2a,P2b=[P for P,e in (2*OK).factor()]
-            sage: c=C(P2a); c
+            sage: K.<w> = QuadraticField(-23)
+            sage: OK = K.ring_of_integers()
+            sage: C = OK.class_group()
+            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+            sage: c = C(P2a); c
             Fractional ideal class (2, 1/2*w - 1/2)
             sage: c.ideal()
             Fractional ideal (2, 1/2*w - 1/2)
@@ -254,31 +264,32 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         INPUT:
 
-        ``norm_bound`` (positive integer) -- upper bound on the norm of primes tested.
+        - ``norm_bound`` -- (positive integer) upper bound on the norm of primes tested.
 
         EXAMPLES::
 
-           sage: K.<a> = NumberField(x^2+31)
-           sage: K.class_number()
-           3
-           sage: Cl = K.class_group()
-           sage: [c.representative_prime() for c in Cl]
-           [Fractional ideal (3),
-           Fractional ideal (2, 1/2*a + 1/2),
-           Fractional ideal (2, 1/2*a - 1/2)]
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a> = NumberField(x^2 + 31)
+            sage: K.class_number()
+            3
+            sage: Cl = K.class_group()
+            sage: [c.representative_prime() for c in Cl]
+            [Fractional ideal (3),
+             Fractional ideal (2, 1/2*a + 1/2),
+             Fractional ideal (2, 1/2*a - 1/2)]
 
-           sage: K.<a> = NumberField(x^2+223)
-           sage: K.class_number()
-           7
-           sage: Cl = K.class_group()
-           sage: [c.representative_prime() for c in Cl]
-           [Fractional ideal (3),
-           Fractional ideal (2, 1/2*a + 1/2),
-           Fractional ideal (17, 1/2*a + 7/2),
-           Fractional ideal (7, 1/2*a - 1/2),
-           Fractional ideal (7, 1/2*a + 1/2),
-           Fractional ideal (17, 1/2*a + 27/2),
-           Fractional ideal (2, 1/2*a - 1/2)]
+            sage: K.<a> = NumberField(x^2 + 223)
+            sage: K.class_number()
+            7
+            sage: Cl = K.class_group()
+            sage: [c.representative_prime() for c in Cl]
+            [Fractional ideal (3),
+             Fractional ideal (2, 1/2*a + 1/2),
+             Fractional ideal (17, 1/2*a + 7/2),
+             Fractional ideal (7, 1/2*a - 1/2),
+             Fractional ideal (7, 1/2*a + 1/2),
+             Fractional ideal (17, 1/2*a + 27/2),
+             Fractional ideal (2, 1/2*a - 1/2)]
         """
         if self.value().is_prime():
             return self.value()
@@ -294,18 +305,17 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
                 return P
         raise RuntimeError("No prime of norm less than %s found in class %s" % (norm_bound, c))
 
-
     def gens(self):
         r"""
         Return generators for a representative ideal in this
-        (S-)ideal class.
+        (`S`-)ideal class.
 
         EXAMPLES::
 
-            sage: K.<w>=QuadraticField(-23)
+            sage: K.<w> = QuadraticField(-23)
             sage: OK = K.ring_of_integers()
             sage: C = OK.class_group()
-            sage: P2a,P2b=[P for P,e in (2*OK).factor()]
+            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
             sage: c = C(P2a); c
             Fractional ideal class (2, 1/2*w - 1/2)
             sage: c.gens()
@@ -314,51 +324,49 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
         return self.ideal().gens()
 
 
-
 class SFractionalIdealClass(FractionalIdealClass):
     r"""
-    An S-fractional ideal class in a number field for a tuple of primes S.
+    An `S`-fractional ideal class in a number field for a tuple `S` of primes.
 
-        EXAMPLES::
+    EXAMPLES::
 
-            sage: K.<a> = QuadraticField(-14)
-            sage: I = K.ideal(2,a)
-            sage: S = (I,)
-            sage: CS = K.S_class_group(S)
-            sage: J = K.ideal(7,a)
-            sage: G = K.ideal(3,a+1)
-            sage: CS(I)
-            Trivial S-ideal class
-            sage: CS(J)
-            Trivial S-ideal class
-            sage: CS(G)
-            Fractional S-ideal class (3, a + 1)
+        sage: K.<a> = QuadraticField(-14)
+        sage: I = K.ideal(2, a)
+        sage: S = (I,)
+        sage: CS = K.S_class_group(S)
+        sage: J = K.ideal(7, a)
+        sage: G = K.ideal(3, a + 1)
+        sage: CS(I)
+        Trivial S-ideal class
+        sage: CS(J)
+        Trivial S-ideal class
+        sage: CS(G)
+        Fractional S-ideal class (3, a + 1)
 
-        EXAMPLES::
+    ::
 
-            sage: K.<a> = QuadraticField(-14)
-            sage: I = K.ideal(2,a)
-            sage: S = (I,)
-            sage: CS = K.S_class_group(S)
-            sage: J = K.ideal(7,a)
-            sage: G = K.ideal(3,a+1)
-            sage: CS(I).ideal()
-            Fractional ideal (2, a)
-            sage: CS(J).ideal()
-            Fractional ideal (7, a)
-            sage: CS(G).ideal()
-            Fractional ideal (3, a + 1)
+        sage: K.<a> = QuadraticField(-14)
+        sage: I = K.ideal(2, a)
+        sage: S = (I,)
+        sage: CS = K.S_class_group(S)
+        sage: J = K.ideal(7, a)
+        sage: G = K.ideal(3, a + 1)
+        sage: CS(I).ideal()
+        Fractional ideal (2, a)
+        sage: CS(J).ideal()
+        Fractional ideal (7, a)
+        sage: CS(G).ideal()
+        Fractional ideal (3, a + 1)
 
+    ::
 
-        EXAMPLES::
-
-            sage: K.<a> = QuadraticField(-14)
-            sage: I = K.ideal(2,a)
-            sage: S = (I,)
-            sage: CS = K.S_class_group(S)
-            sage: G = K.ideal(3,a+1)
-            sage: CS(G).inverse()
-            Fractional S-ideal class (3, a + 2)
+        sage: K.<a> = QuadraticField(-14)
+        sage: I = K.ideal(2, a)
+        sage: S = (I,)
+        sage: CS = K.S_class_group(S)
+        sage: G = K.ideal(3, a + 1)
+        sage: CS(G).inverse()
+        Fractional S-ideal class (3, a + 2)
 
     TESTS::
 
@@ -378,7 +386,7 @@ class SFractionalIdealClass(FractionalIdealClass):
 
     def _repr_(self):
         r"""
-        Returns a string representation of the S-ideal class of this fractional ideal.
+        Return a string representation of the `S`-ideal class of this fractional ideal.
 
         EXAMPLES::
 
@@ -397,16 +405,17 @@ class SFractionalIdealClass(FractionalIdealClass):
         return 'Fractional S-ideal class %s' % self._value._repr_short()
 
 
-
 class ClassGroup(AbelianGroupWithValues_class):
     r"""
     The class group of a number field.
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 + 23)
         sage: G = K.class_group(); G
-        Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23
+        Class group of order 3 with structure C3 of
+         Number Field in a with defining polynomial x^2 + 23
         sage: G.category()
         Category of finite enumerated commutative groups
 
@@ -434,6 +443,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         TESTS::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^2 + 23)
             sage: G = K.class_group()
             sage: TestSuite(G).run()
@@ -451,6 +461,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<b> = NumberField(x^2 + 389)
             sage: C = K.class_group()
             sage: C(K.ideal(b)) # indirect doctest
@@ -485,7 +496,8 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         EXAMPLES::
 
-            sage: K.<a> = NumberField(x^2 + 23,'a')
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a> = NumberField(x^2 + 23, 'a')
             sage: G = K.class_group()
             sage: g = G.an_element()
             sage: G._ideal_log(g.ideal())
@@ -497,7 +509,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
     def gens_ideals(self):
         r"""
-        Return generating ideals for the (S-)class group.
+        Return generating ideals for the (`S`-)class group.
 
         This is an alias for :meth:`gens_values`.
 
@@ -507,6 +519,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^4 + 23)
             sage: K.class_group().gens_ideals()   # random gens (platform dependent)
             (Fractional ideal (2, 1/4*a^3 - 1/4*a^2 + 1/4*a - 1/4),)
@@ -527,6 +540,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a> = NumberField(x^4 + 23)
             sage: G = K.class_group()
             sage: G
@@ -584,10 +598,11 @@ class ClassGroup(AbelianGroupWithValues_class):
 
     def _repr_(self):
         r"""
-        Return string representation of self.
+        Return string representation of ``self``.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: C = NumberField(x^2 + 23, 'a').class_group()
             sage: C._repr_()
             'Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23'
@@ -600,12 +615,14 @@ class ClassGroup(AbelianGroupWithValues_class):
 
     def number_field(self):
         r"""
-        Return the number field that this (S-)class group is attached to.
+        Return the number field that this (`S`-)class group is attached to.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: C = NumberField(x^2 + 23, 'w').class_group(); C
-            Class group of order 3 with structure C3 of Number Field in w with defining polynomial x^2 + 23
+            Class group of order 3 with structure C3 of
+             Number Field in w with defining polynomial x^2 + 23
             sage: C.number_field()
             Number Field in w with defining polynomial x^2 + 23
 
@@ -617,12 +634,9 @@ class ClassGroup(AbelianGroupWithValues_class):
         return self._number_field
 
 
-
-
-
 class SClassGroup(ClassGroup):
     r"""
-    The S-class group of a number field.
+    The `S`-class group of a number field.
 
     EXAMPLES::
 
@@ -633,7 +647,8 @@ class SClassGroup(ClassGroup):
 
         sage: K.<a> = QuadraticField(-974)
         sage: CS = K.S_class_group(K.primes_above(2)); CS
-        S-class group of order 18 with structure C6 x C3 of Number Field in a with defining polynomial x^2 + 974 with a = 31.20897306865447?*I
+        S-class group of order 18 with structure C6 x C3 of
+         Number Field in a with defining polynomial x^2 + 974 with a = 31.20897306865447?*I
         sage: CS.gen(0) # random
         Fractional S-ideal class (3, a + 2)
         sage: CS.gen(1) # random
@@ -643,7 +658,7 @@ class SClassGroup(ClassGroup):
 
     def __init__(self, gens_orders, names, number_field, gens, S, proof=True):
         r"""
-        Create an S-class group.
+        Create an `S`-class group.
 
         EXAMPLES::
 
@@ -669,13 +684,15 @@ class SClassGroup(ClassGroup):
         EXAMPLES::
 
             sage: K.<a> = QuadraticField(-14)
-            sage: I = K.ideal(2,a)
+            sage: I = K.ideal(2, a)
             sage: S = (I,)
             sage: CS = K.S_class_group(S);CS
-            S-class group of order 2 with structure C2 of Number Field in a with defining polynomial x^2 + 14 with a = 3.741657386773942?*I
+            S-class group of order 2 with structure C2 of
+             Number Field in a with defining polynomial x^2 + 14 with a = 3.741657386773942?*I
             sage: T = tuple()
             sage: CT = K.S_class_group(T);CT
-            S-class group of order 4 with structure C4 of Number Field in a with defining polynomial x^2 + 14 with a = 3.741657386773942?*I
+            S-class group of order 4 with structure C4 of
+             Number Field in a with defining polynomial x^2 + 14 with a = 3.741657386773942?*I
             sage: CS.S()
             (Fractional ideal (2, a),)
             sage: CT.S()
