@@ -11,6 +11,7 @@ AUTHORS:
 
 EXAMPLES::
 
+    sage: x = polygen(ZZ, 'x')
     sage: K.<a,b> = NumberField([x^2 + 1, x^2 + 2])
     sage: A = K.absolute_field('z')
     sage: I = A.factor(7)[0][0]
@@ -49,6 +50,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField([x^2 + 1, x^2 + 2]); K
         Number Field in a0 with defining polynomial x^2 + 1 over its base field
         sage: i = K.ideal(38); i
@@ -81,6 +83,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 23, x^2 - 7])
             sage: I = K.ideal(2, (a + 2*b + 3)/2)
             sage: J = K.ideal(2, a - b)
@@ -93,12 +96,13 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def _contains_(self, x):
         """
-        Return True if x is an element of this ideal.
+        Return ``True`` if `x` is an element of this ideal.
 
         This function is called (indirectly) when the ``in`` operator is used.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 23, x^2 - 7])
             sage: I = K.ideal(2, (a + 2*b + 3)/2)
             sage: [z in I for z in [a, b, 2, a + b]] # indirect doctest
@@ -115,6 +119,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 23, x^2 - 7])
             sage: I = K.ideal(2, (a + 2*b + 3)/2)
             sage: I.pari_rhnf()
@@ -129,7 +134,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             self.__pari_rhnf = rnf.rnfidealabstorel(nfzk * L_hnf)
             return self.__pari_rhnf
 
-    def absolute_ideal(self, names = 'a'):
+    def absolute_ideal(self, names='a'):
         r"""
         If this is an ideal in the extension `L/K`, return the ideal with
         the same generators in the absolute field `L/\QQ`.
@@ -154,10 +159,10 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             Fractional ideal (13)
 
         Now a non-trivial ideal in `L` that is principal in the
-        subfield `K`.  Since the optional 'names' argument is not
-        passed, the generators of the absolute ideal J are returned
-        in terms of the default field generator 'a'. This does not agree
-        with the generator 'm' of the absolute field F defined above::
+        subfield `K`.  Since the optional ``names`` argument is not
+        passed, the generators of the absolute ideal `J` are returned
+        in terms of the default field generator `a`. This does not agree
+        with the generator `m` of the absolute field `F` defined above::
 
             sage: J = L.ideal(b); J
             Fractional ideal (b)
@@ -170,7 +175,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             sage: J.absolute_ideal().norm()
             4
 
-        Now pass 'm' as the name for the generator of the absolute field:
+        Now pass `m` as the name for the generator of the absolute field::
 
             sage: J.absolute_ideal('m')
             Fractional ideal (m^2)
@@ -202,14 +207,13 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def _from_absolute_ideal(self, id):
         r"""
-        Convert the absolute ideal id to a relative number field ideal.
-
-        Assumes id.number_field() == self.absolute_field('a').
+        Convert the absolute ideal ``id`` to a relative number field ideal.
 
         WARNING:  This is an internal helper function.
 
         TESTS::
 
+            sage: x = polygen(ZZ, 'x')
             sage: L.<a, b> = QQ.extension([x^2 + 71, x^3 + 2*x + 1])
             sage: (2*a + b).norm()
             22584817
@@ -218,18 +222,18 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             True
             sage: J.absolute_norm()
             22584817
-            sage: J.absolute_ideal()
-            Fractional ideal (22584817, -1473/812911*a^5 + 8695/4877466*a^4 - 1308209/4877466*a^3 + 117415/443406*a^2 - 22963264/2438733*a - 13721081784272/2438733)
-            sage: J.absolute_ideal().norm()
+            sage: Labs.<c> = L.absolute_field(); Labs # random (polynomial not unique)
+            Number Field in c with defining polynomial x^6 + 217*x^4 - 2*x^3 + 15127*x^2 + 422*x + 338032
+            sage: Jabs = J.absolute_ideal(names='c')
+            sage: Jabs == Labs.ideal(22584817, -1473/812911*c^5 + 8695/4877466*c^4 - 1308209/4877466*c^3 + 117415/443406*c^2 - 22963264/2438733*c - 13721081784272/2438733)
+            True
+            sage: Jabs.norm()
             22584817
-
-            sage: J._from_absolute_ideal(J.absolute_ideal()) == J
+            sage: J._from_absolute_ideal(Jabs) == J
             True
         """
-        L = self.number_field()
-        K = L.absolute_field('a')
-        to_L = K.structure()[0]
-        return L.ideal([to_L(_) for _ in id.gens()])
+        f, _ = id.number_field().structure()
+        return self.number_field().ideal([f(_) for _ in id.gens()])
 
     def free_module(self):
         r"""
@@ -238,6 +242,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^3 - x + 1, x^2 + 23])
             sage: I = K.ideal(a*b - 1)
             sage: I.free_module()
@@ -258,6 +263,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 1, x^2 - 2])
             sage: I = K.ideal((a + 1)*b/2 + 1)
             sage: I.gens_reduced()
@@ -293,10 +299,11 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def __invert__(self):
         """
-        Return the multiplicative inverse of self.  Call with ~self.
+        Return the multiplicative inverse of ``self``.  Call with ``~self``.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a,b> = NumberField([x^2 + 1, x^2 + 2])
             sage: I = K.fractional_ideal(4)
             sage: I^(-1)
@@ -310,11 +317,12 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def is_principal(self, proof=None):
         """
-        Return True if this ideal is principal.  If so, set
-        self.__reduced_generators, with length one.
+        Return ``True`` if this ideal is principal.  If so, set
+        ``self.__reduced_generators``, with length one.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 - 23, x^2 + 1])
             sage: I = K.ideal([7, (-1/2*b - 3/2)*a + 3/2*b + 9/2])
             sage: I.is_principal()
@@ -336,10 +344,11 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def is_zero(self):
         r"""
-        Return True if this is the zero ideal.
+        Return ``True`` if this is the zero ideal.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 3, x^3 + 4])
             sage: K.ideal(17).is_zero()
             False
@@ -356,6 +365,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: L.<a, b, c> = QQ.extension([x^2 - 23, x^2 - 5, x^2 - 7])
             sage: I = L.ideal(a + b)
             sage: I.absolute_norm()
@@ -373,7 +383,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         EXAMPLES::
 
             sage: R.<x> = QQ[]
-            sage: K.<a> = NumberField(x^2+6)
+            sage: K.<a> = NumberField(x^2 + 6)
             sage: L.<b> = K.extension(K['x'].gen()^4 + a)
             sage: N = L.ideal(b).relative_norm(); N
             Fractional ideal (-a)
@@ -418,11 +428,13 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 1, x^2 - 2])
             sage: K.ideal(2).norm()
             Traceback (most recent call last):
             ...
-            NotImplementedError: For a fractional ideal in a relative number field you must use relative_norm or absolute_norm as appropriate
+            NotImplementedError: For a fractional ideal in a relative number field
+            you must use relative_norm or absolute_norm as appropriate
         """
         raise NotImplementedError("For a fractional ideal in a relative number field you must use relative_norm or absolute_norm as appropriate")
 
@@ -433,12 +445,12 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         EXAMPLES::
 
             sage: R.<x> = QQ[]
-            sage: K.<a> = NumberField(x^2+6)
+            sage: K.<a> = NumberField(x^2 + 6)
             sage: L.<b> = K.extension(K['x'].gen()^4 + a)
             sage: N = L.ideal(b)
             sage: M = N.ideal_below(); M == K.ideal([-a])
             True
-            sage: Np = L.ideal( [ L(t) for t in M.gens() ])
+            sage: Np = L.ideal([L(t) for t in M.gens()])
             sage: Np.ideal_below() == M
             True
             sage: M.parent()
@@ -498,7 +510,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             sage: K0.ideal([-a0 + 1]) == K0.ideal([-a0 + 5])
             False
 
-        It works when the base_field is itself a relative number field::
+        It works when the base field is itself a relative number field::
 
             sage: PQ.<X> = QQ[]
             sage: F.<a, b> = NumberFieldTower([X^2 - 2, X^2 - 3])
@@ -534,11 +546,14 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = QQ.extension([x^2 + 11, x^2 - 5])
             sage: K.factor(5)
-            (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 3/4))^2 * (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 7/4))^2
+            (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 3/4))^2
+             * (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 7/4))^2
             sage: K.ideal(5).factor()
-            (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 3/4))^2 * (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 7/4))^2
+            (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 3/4))^2
+             * (Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 7/4))^2
             sage: K.ideal(5).prime_factors()
             [Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 3/4),
              Fractional ideal (5, (-1/4*b - 1/4)*a + 1/4*b - 7/4)]
@@ -566,13 +581,14 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def integral_basis(self):
         r"""
-        Return a basis for self as a `\ZZ`-module.
+        Return a basis for ``self`` as a `\ZZ`-module.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a,b> = NumberField([x^2 + 1, x^2 - 3])
             sage: I = K.ideal(17*b - 3*a)
-            sage: x = I.integral_basis(); x # random
+            sage: x = I.integral_basis(); x  # random
             [438, -b*a + 309, 219*a - 219*b, 156*a - 154*b]
 
         The exact results are somewhat unpredictable, hence the ``# random``
@@ -593,6 +609,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberFieldTower([x^2 - 23, x^2 + 1])
             sage: I = K.ideal([a + b/3])
             sage: J, d = I.integral_split()
@@ -610,6 +627,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 - 17, x^3 - 2])
             sage: K.ideal(a + b).is_prime()
             True
@@ -626,31 +644,32 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def is_integral(self):
         """
-        Return True if this ideal is integral.
+        Return ``True`` if this ideal is integral.
 
         EXAMPLES::
 
-           sage: K.<a, b> = QQ.extension([x^2 + 11, x^2 - 5])
-           sage: I = K.ideal(7).prime_factors()[0]
-           sage: I.is_integral()
-           True
-           sage: (I/2).is_integral()
-           False
+            sage: x = polygen(ZZ, 'x')
+            sage: K.<a, b> = QQ.extension([x^2 + 11, x^2 - 5])
+            sage: I = K.ideal(7).prime_factors()[0]
+            sage: I.is_integral()
+            True
+            sage: (I/2).is_integral()
+            False
         """
         return self.absolute_ideal().is_integral()
 
     def absolute_ramification_index(self):
         """
         Return the absolute ramification index of this fractional ideal,
-        assuming it is prime.  Otherwise, raise a ValueError.
+        assuming it is prime.  Otherwise, raise a :class:`ValueError`.
 
         The absolute ramification index is the power of this prime
         appearing in the factorization of the rational prime that
         this prime lies over.
 
-        Use relative_ramification_index to obtain the power of this
+        Use :meth:`relative_ramification_index` to obtain the power of this
         prime occurring in the factorization of the prime ideal
-        of the  base field that this prime lies over.
+        of the base field that this prime lies over.
 
         EXAMPLES::
 
@@ -673,13 +692,13 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
     def relative_ramification_index(self):
         """
         Return the relative ramification index of this fractional ideal,
-        assuming it is prime.  Otherwise, raise a ValueError.
+        assuming it is prime.  Otherwise, raise a :class:`ValueError`.
 
         The relative ramification index is the power of this prime
         appearing in the factorization of the prime ideal of the
         base field that this prime lies over.
 
-        Use absolute_ramification_index to obtain the power of this
+        Use :meth:`absolute_ramification_index` to obtain the power of this
         prime occurring in the factorization of the rational prime
         that this prime lies over.
 
@@ -707,18 +726,20 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def ramification_index(self):
         r"""
-        For ideals in relative number fields, ``ramification_index``
+        For ideals in relative number fields, :meth:`ramification_index`
         is deliberately not implemented in order to avoid ambiguity.
         Either :meth:`~relative_ramification_index` or
         :meth:`~absolute_ramification_index` should be used instead.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 + 1, x^2 - 2])
             sage: K.ideal(2).ramification_index()
             Traceback (most recent call last):
             ...
-            NotImplementedError: For an ideal in a relative number field you must use relative_ramification_index or absolute_ramification_index as appropriate
+            NotImplementedError: For an ideal in a relative number field you must use
+            relative_ramification_index or absolute_ramification_index as appropriate
         """
         raise NotImplementedError("For an ideal in a relative number field you must use relative_ramification_index or absolute_ramification_index as appropriate")
 
@@ -747,6 +768,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, w> = NumberFieldTower([x^2 - 3, x^2 + x + 1])
             sage: I = K.ideal(6, -w*a - w + 4)
             sage: list(I.residues())[:5]
@@ -764,7 +786,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def element_1_mod(self, other):
         r"""
-        Returns an element `r` in this ideal such that `1-r` is in other.
+        Returns an element `r` in this ideal such that `1-r` is in ``other``.
 
         An error is raised if either ideal is not integral of if they
         are not coprime.
@@ -776,10 +798,11 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         OUTPUT:
 
         an element `r` of the ideal self such that `1-r` is in the
-        ideal other.
+        ideal ``other``.
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberFieldTower([x^2 - 23, x^2 + 1])
             sage: I = Ideal(2, (a - 3*b + 2)/2)
             sage: J = K.ideal(a)
@@ -811,6 +834,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberFieldTower([x^2 - 23, x^2 + 1])
             sage: I = K.ideal([a + b])
             sage: I.smallest_integer()
@@ -822,7 +846,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
     def valuation(self, p):
         r"""
-        Return the valuation of this fractional ideal at ``p``.
+        Return the valuation of this fractional ideal at `\mathfrak{p}`.
 
         INPUT:
 
@@ -832,11 +856,12 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
         (integer) The valuation of this fractional ideal at the prime
         `\mathfrak{p}`.  If `\mathfrak{p}` is not prime, raise a
-        ValueError.
+        :class:`ValueError`.
 
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K.<a, b> = NumberField([x^2 - 17, x^3 - 2])
             sage: A = K.ideal(a + b)
             sage: A.is_prime()
@@ -860,7 +885,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
 
 def is_NumberFieldFractionalIdeal_rel(x):
     """
-    Return True if x is a fractional ideal of a relative number field.
+    Return ``True`` if `x` is a fractional ideal of a relative number field.
 
     EXAMPLES::
 
@@ -870,13 +895,14 @@ def is_NumberFieldFractionalIdeal_rel(x):
         False
         sage: is_NumberFieldFractionalIdeal_rel(ideal(5))
         False
+        sage: x = polygen(ZZ, 'x')
         sage: k.<a> = NumberField(x^2 + 2)
         sage: I = k.ideal([a + 1]); I
         Fractional ideal (a + 1)
         sage: is_NumberFieldFractionalIdeal_rel(I)
         False
         sage: R.<x> = QQ[]
-        sage: K.<a> = NumberField(x^2+6)
+        sage: K.<a> = NumberField(x^2 + 6)
         sage: L.<b> = K.extension(K['x'].gen()^4 + a)
         sage: I = L.ideal(b); I
         Fractional ideal (6, b)
