@@ -128,7 +128,7 @@ def _coords_in_C_p(I, C, p):
 
     """
     cyclic_orders = C.gens_orders()
-    non_p_indices = [i           for i,n in enumerate(cyclic_orders) if not p.divides(n)]
+    non_p_indices = [i for i,n in enumerate(cyclic_orders) if not p.divides(n)]
     p_indices     = [(i, n // p) for i,n in enumerate(cyclic_orders) if p.divides(n)]
 
     coords = C(I).exponents()
@@ -172,6 +172,7 @@ def _coords_in_C_mod_p(I,C,p):
     of which is not cyclic::
 
         sage: from sage.rings.number_field.selmer_group import _coords_in_C_mod_p
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - x + 58)
         sage: C = K.class_group()
         sage: C.gens_orders()
@@ -207,6 +208,7 @@ def _root_ideal(I, C, p):
     EXAMPLES::
 
         sage: from sage.rings.number_field.selmer_group import _root_ideal
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - x + 58)
         sage: C = K.class_group()
         sage: cyclic_gens   = C.gens_ideals()
@@ -264,6 +266,7 @@ def coords_in_U_mod_p(u, U, p):
     EXAMPLES::
 
         sage: from sage.rings.number_field.selmer_group import coords_in_U_mod_p
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^4 - 5*x^2 + 1)
         sage: U = K.unit_group()
         sage: U
@@ -283,7 +286,7 @@ def coords_in_U_mod_p(u, U, p):
     """
     coords = U.log(u)
     start = 1 - int(p.divides(U.zeta_order())) # 0 or 1
-    return  [c%p for c in coords[start:]]
+    return [c%p for c in coords[start:]]
 
 def basis_for_p_cokernel(S, C, p):
     r"""
@@ -314,6 +317,7 @@ def basis_for_p_cokernel(S, C, p):
     EXAMPLES::
 
         sage: from sage.rings.number_field.selmer_group import basis_for_p_cokernel
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - x + 58)
         sage: S = K.ideal(30).support(); S
         [Fractional ideal (2, a),
@@ -353,23 +357,23 @@ def basis_for_p_cokernel(S, C, p):
 
 def pSelmerGroup(K, S, p, proof=None, debug=False):
     r"""
-    Return the ``p``-Selmer group `K(S,p)` of the number field ``K``
-    with respect to the prime ideals in ``S``
+    Return the `p`-Selmer group `K(S,p)` of the number field `K`
+    with respect to the prime ideals in ``S``.
 
     INPUT:
 
-    - ``K`` (number field) -- a number field, or `\QQ`.
+    - ``K`` -- a number field or `\QQ`.
 
-    - ``S`` (list) -- a list of prime ideals in ``K``, or prime
-      numbers when ``K`` is `\QQ`.
+    - ``S`` -- a list of prime ideals in `K`, or prime
+      numbers when `K` is `\QQ`.
 
-    - ``p`` (prime) -- a prime number.
+    - ``p`` -- a prime number.
 
-    - ``proof`` - if True then compute the class group provably
-      correctly. Default is True. Call :meth:`proof.number_field` to
+    - ``proof`` -- if ``True``, compute the class group provably
+      correctly. Default is ``True``. Call :meth:`proof.number_field` to
       change this default globally.
 
-    - ``debug`` (boolean, default ``False``) -- debug flag.
+    - ``debug`` -- (boolean, default ``False``) debug flag.
 
     OUTPUT:
 
@@ -646,7 +650,7 @@ def pSelmerGroup(K, S, p, proof=None, debug=False):
         vals = [a.valuation(P) for P in supp]
         if debug:
             assert all(v % p == 0 for v in vals)
-        one = K(1)    if K == QQ else K.ideal(1)
+        one = K(1) if K == QQ else K.ideal(1)
         aa  = a.abs() if K == QQ else K.ideal(a)
         B = prod((P ** (v // p) for P, v in zip(supp,vals)), one)
         if debug:
