@@ -9,7 +9,7 @@ TESTS::
 
     sage: R = ZpLC(2)
     doctest:...: FutureWarning: This class/method/function is marked as experimental. It, its functionality or its interface might change without a formal deprecation.
-    See http://trac.sagemath.org/23505 for details.
+    See https://github.com/sagemath/sage/issues/23505 for details.
     sage: prec = R.precision()
     sage: prec
     Precision lattice on 0 objects
@@ -32,7 +32,7 @@ TESTS::
 
 from collections import defaultdict
 
-from sage.misc.misc import walltime
+from sage.misc.timing import walltime
 
 from sage.structure.sage_object import SageObject
 from sage.structure.unique_representation import UniqueRepresentation
@@ -60,7 +60,7 @@ class pRational:
     r"""
     This class implements rational numbers viewed as elements of ``Qp``.
     In particular, it provides additional methods which are specific to
-    ``p``-adics (as ``p``-adic valuation).
+    `p`-adics (as `p`-adic valuation).
 
     Only for internal use.
 
@@ -72,8 +72,8 @@ class pRational:
 
     - ``exponent`` -- an integer (default: 0)
 
-    - ``valuation`` -- an integer or None (default: ``None``),
-      the ``p``-adic valuation of this element
+    - ``valuation`` -- an integer or ``None`` (default: ``None``),
+      the `p`-adic valuation of this element
 
     If not ``None``, this method trusts the given value to the
     attribute ``valuation``.
@@ -259,7 +259,7 @@ class pRational:
 
     def is_p_power(self):
         r"""
-        Return true if this element is a power of `p`.
+        Return ``True`` if this element is a power of `p`.
 
         TESTS::
 
@@ -279,7 +279,7 @@ class pRational:
 
     def is_zero(self):
         r"""
-        Return true if this element vanishes.
+        Return ``True`` if this element vanishes.
 
         TESTS::
 
@@ -440,7 +440,6 @@ class pRational:
             return (self.__class__(self.p, (sx - sred)/(pd*ox), 0),
                     self.__class__(self.p, sred, sval, valuation=sval))
 
-
     def __lshift__(self, n):
         r"""
         Return the product of this element by ``p^n``.
@@ -504,7 +503,7 @@ class pRational:
     def xgcd(self, other):
         r"""
         Return the gcd of ``self`` and ``other`` together with two
-        element ``u`` and ``v`` such that ``u*self + v*other = gcd``.
+        elements ``u`` and ``v`` such that ``u*self + v*other = gcd``.
 
         The ``gcd`` is normalized so that it is a power of `p`.
 
@@ -974,7 +973,7 @@ class DifferentialPrecisionGeneric(SageObject):
             [   0 2048]
 
         If the precision module does not project to a lattice,
-        an error is raised.
+        an error is raised. ::
 
             sage: R = ZpLF(2, label='precision_lattice')
             sage: prec = R.precision()
@@ -1250,7 +1249,6 @@ class DifferentialPrecisionGeneric(SageObject):
         else:
             return status
 
-
     def history(self, compact=True, separate_reduce=False, timings=True, output_type='asciiart'):
         r"""
         Show history.
@@ -1485,20 +1483,20 @@ class DifferentialPrecisionGeneric(SageObject):
 
         INPUT:
 
-        - ``action`` -- ``None`` (the default), ``add``, ``mark``, ``del``,
-          ``partial reduce`` or ``full reduce``; if not None, return the
+        - ``action`` -- ``None`` (the default), ``'add'``, ``'mark'``, ``'del'``,
+          ``'partial reduce'`` or ``'full reduce'``; if not ``None``, return the
           cumulated timing corresponding to this action; otherwise, return
           a dictionary
 
         Here are the meanings of the keywords above:
 
-        - ``add``: time spent in adding new columns to the precision matrix
+        - ``'add'``: time spent in adding new columns to the precision matrix
           (corresponding to the creation of new elements)
-        - ``mark``: time spent in marking elements for deletion
-        - ``del``: time spent in deleting columns of the precision matrix
+        - ``'mark'``: time spent in marking elements for deletion
+        - ``'del'``: time spent in deleting columns of the precision matrix
           and re-echelonizing the matrix
-        - ``partial reduce``: time spent in partial Hermite reduction
-        - ``full reduce``: time spent in full Hermite reduction.
+        - ``'partial reduce'``: time spent in partial Hermite reduction
+        - ``'full reduce'``: time spent in full Hermite reduction.
 
         EXAMPLES::
 
@@ -2689,7 +2687,7 @@ class PrecisionModule(UniqueRepresentation, DifferentialPrecisionGeneric):
             [   0 2048]
 
         If the precision module does not project to a lattice,
-        an error is raised.
+        an error is raised. ::
 
             sage: prec.precision_lattice([x, y, u, v])
             Traceback (most recent call last):
@@ -2862,8 +2860,8 @@ class pAdicLatticeElementWeakProxy():
 
 def list_of_padics(elements):
     r"""
-    Convert a list of p-adic composed elements (such as polynomials, matrices)
-    to a list of weak references of their p-adic coefficients.
+    Convert a list of `p`-adic composed elements (such as polynomials, matrices)
+    to a list of weak references of their `p`-adic coefficients.
 
     This is a helper function for the method :meth:`precision_lattice`.
 
