@@ -1,5 +1,5 @@
 """
-p-Adic Extension Generic
+`p`-adic Extension Generic
 
 A common superclass for all extensions of Qp and Zp.
 
@@ -107,8 +107,8 @@ class pAdicExtensionGeneric(pAdicGeneric):
 
     def _extension_type(self):
         """
-        Return the type (``Unramified``, ``Eisenstein``) of this 
-        extension as a string, if any. 
+        Return the type (``Unramified``, ``Eisenstein``) of this
+        extension as a string, if any.
 
         Used for printing.
 
@@ -118,6 +118,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             sage: K._extension_type()
             'Unramified'
 
+            sage: x = polygen(ZZ, 'x')
             sage: L.<pi> = Qp(5).extension(x^2 - 5)
             sage: L._extension_type()
             'Eisenstein'
@@ -138,7 +139,8 @@ class pAdicExtensionGeneric(pAdicGeneric):
             7-adic Unramified Extension Ring in a defined by x^3 + 6*x^2 + 4
             sage: R1._latex_()
             '\\Bold{Z}_{7^{3}}'
-            sage: R2.<t> = R.ext(x^2+7)
+            sage: x = polygen(ZZ, 'x')
+            sage: R2.<t> = R.ext(x^2 + 7)
             sage: R2 #indirect doctest
             7-adic Eisenstein Extension Ring in t defined by x^2 + 7
             sage: R2._latex_()
@@ -510,7 +512,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             sage: c(R0) == R
             True
 
-        For a field, by default we return a fraction field functor.
+        For a field, by default we return a fraction field functor. ::
 
             sage: K.<a> = Qq(25, 8)
             sage: c, R = K.construction(); R
@@ -550,12 +552,12 @@ class pAdicExtensionGeneric(pAdicGeneric):
 
         EXAMPLES::
 
-            sage: R.<a> = Zq(125, 5); R.random_element()
-            (3*a^2 + 3*a + 3) + (a^2 + 4*a + 1)*5 + (3*a^2 + 4*a + 1)*5^2 + 
-            (2*a^2 + 3*a + 3)*5^3 + (4*a^2 + 3)*5^4 + O(5^5)
+            sage: R.<a> = Zq(125, 5)
+            sage: R.random_element().parent() is R
+            True
             sage: R = Zp(5,3); S.<x> = ZZ[]; f = x^5 + 25*x^2 - 5; W.<w> = R.ext(f)
-            sage: W.random_element()
-            4 + 3*w + w^2 + 4*w^3 + w^5 + 3*w^6 + w^7 + 4*w^10 + 2*w^12 + 4*w^13 + 3*w^14 + O(w^15)
+            sage: W.random_element().parent() is W
+            True
         """
         return reduce(lambda x,y: x+y,
                       [self.ground_ring().random_element() * self.gen()**i for i in
@@ -890,8 +892,11 @@ class DefPolyConversion(Morphism):
             sage: S.<x> = ZZ[]
             sage: W.<w> = Zp(3).extension(x^4 + 9*x^2 + 3*x - 3)
             sage: z = W.random_element()
-            sage: repr(W.change(print_mode='digits')(z))
-            '...20112102111011011200001212210222202220100111100200011222122121202100210120010120'
+            sage: r = repr(W.change(print_mode='digits')(z))
+            sage: r[:3] == '...'
+            True
+            sage: all(l in ['0', '1', '2'] for l in r[3:])
+            True
 
         TESTS:
 
@@ -934,8 +939,11 @@ class DefPolyConversion(Morphism):
             sage: S.<x> = ZZ[]
             sage: W.<w> = Zp(3).extension(x^4 + 9*x^2 + 3*x - 3)
             sage: z = W.random_element()
-            sage: repr(W.change(print_mode='digits')(z, absprec=8)) # indirect doctest
-            '...20010120'
+            sage: r = repr(W.change(print_mode='digits')(z, absprec=8)) # indirect doctest
+            sage: r[:3] == '...'
+            True
+            sage: all(l in ['0', '1', '2'] for l in r[3:])
+            True
 
         TESTS::
 
