@@ -1,5 +1,5 @@
 r"""
-`p`-Adic Elements with lattice precision.
+`p`-adic Elements with lattice precision.
 
 AUTHOR:
 
@@ -12,15 +12,16 @@ tests because they take a few minutes as of mid 2018, see :trac:`25431`::
 
     sage: R1 = ZpLC(2)
     doctest:...: FutureWarning: This class/method/function is marked as experimental. It, its functionality or its interface might change without a formal deprecation.
-    See http://trac.sagemath.org/23505 for details.
+    See https://github.com/sagemath/sage/issues/23505 for details.
     sage: R2 = ZpLF(2)
     sage: R3 = QpLC(2)
     sage: R4 = QpLF(2)
 
-    sage: TestSuite(R1).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
-    sage: TestSuite(R2).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
-    sage: TestSuite(R3).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
-    sage: TestSuite(R4).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
+    sage: # long time
+    sage: TestSuite(R1).run(skip=['_test_teichmuller', '_test_matrix_smith'])
+    sage: TestSuite(R2).run(skip=['_test_teichmuller', '_test_matrix_smith'])
+    sage: TestSuite(R3).run(skip=['_test_teichmuller', '_test_matrix_smith'])
+    sage: TestSuite(R4).run(skip=['_test_teichmuller', '_test_matrix_smith'])
 """
 
 # ****************************************************************************
@@ -82,7 +83,7 @@ class pAdicLatticeElement(pAdicGenericElement):
 
     - ``x`` -- the newly created element
 
-    - ``prec`` -- an integer; the absolute precision at which this 
+    - ``prec`` -- an integer; the absolute precision at which this
       element has to be capped
 
     - ``dx`` -- a dictionary representing the differential of ``x``
@@ -90,7 +91,7 @@ class pAdicLatticeElement(pAdicGenericElement):
     - ``dx_mode`` -- a string, either ``linear_combination`` (the default)
       or ``values``
 
-    - ``valuation`` -- an integer or ``None`` (default: ``None``), 
+    - ``valuation`` -- an integer or ``None`` (default: ``None``),
       the valuation of this element
 
     - ``check`` -- a boolean (default: ``True``), whether the function
@@ -139,7 +140,7 @@ class pAdicLatticeElement(pAdicGenericElement):
     @abstract_method
     def _declare_new_element(self, dx, prec, dx_mode):
         r"""
-        Declare this element to the precision object and 
+        Declare this element to the precision object and
         return the precision at which this element can be truncated safely.
 
         Only for internal use.
@@ -208,7 +209,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         EXAMPLES::
 
             sage: K = QpLC(7)
-            sage: K.random_element()._is_base_elt(7)
+            sage: K.random_element()._is_base_elt(7)  # not tested, known bug (see :trac:`32126`)
             True
         """
         return p == self._parent.prime()
@@ -233,8 +234,8 @@ class pAdicLatticeElement(pAdicGenericElement):
     def value(self):
         r"""
         Return the actual approximation of this element
-        stored in memory. 
-        In presence of diffused digits of precision, it can 
+        stored in memory.
+        In presence of diffused digits of precision, it can
         have more precision than the absolute precision of
         the element.
 
@@ -326,7 +327,7 @@ class pAdicLatticeElement(pAdicGenericElement):
     def precision_lattice(self):
         r"""
         Return the precision object (which is a lattice in a possibly
-        high-dimensional vector space) that handles the precision of 
+        high-dimensional vector space) that handles the precision of
         this element.
 
         EXAMPLES::
@@ -433,7 +434,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         """
         val = self._value.valuation()
         prec = self.precision_absolute()
-        if val < prec: 
+        if val < prec:
             return val
         elif secure:
             raise PrecisionError("not enough precision")
@@ -501,7 +502,7 @@ class pAdicLatticeElement(pAdicGenericElement):
 
     def is_equal_to(self, other, prec):
         r"""
-        Return ``True`` if this element is indisting
+        Return ``True`` if this element is indistinguishable
         from ``other`` at precision ``prec``
 
         EXAMPLES::
@@ -553,7 +554,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         if self._parent._zero_cap is not None:
             if x.valuation() >= min(self._value.valuation(), other._value.valuation()) + self._parent._zero_cap:
                 x = self._parent._approx_zero
-        dx = [  [self, self._parent._approx_one], 
+        dx = [  [self, self._parent._approx_one],
                [other, self._parent._approx_one] ]
         return self.__class__(self._parent, x, dx=dx, check=False)
 
@@ -575,7 +576,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         if self._parent._zero_cap is not None:
             if x.valuation() >= min(self._value.valuation(), other._value.valuation()) + self._parent._zero_cap:
                 x = self._parent._approx_zero
-        dx = [  [self, self._parent._approx_one], 
+        dx = [  [self, self._parent._approx_one],
                [other, self._parent._approx_minusone] ]
         return self.__class__(self._parent, x, dx=dx, check=False)
 
@@ -617,10 +618,10 @@ class pAdicLatticeElement(pAdicGenericElement):
         r"""
         Return the quotient of this element and ``other``.
 
-        NOTE::
+        .. NOTE::
 
-        The result of division always lives in the fraction field,
-        even if the element to be inverted is a unit.
+            The result of division always lives in the fraction field,
+            even if the element to be inverted is a unit.
 
         EXAMPLES::
 
@@ -629,7 +630,7 @@ class pAdicLatticeElement(pAdicGenericElement):
             18 + 18*19 + 18*19^2 + 18*19^3 + 18*19^4 + O(19^5)
             sage: b = R(-5/2, 5); b
             7 + 9*19 + 9*19^2 + 9*19^3 + 9*19^4 + O(19^5)
- 
+
             sage: c = a / b   # indirect doctest
             sage: c
             8 + 11*19 + 7*19^2 + 11*19^3 + 7*19^4 + O(19^5)
@@ -660,10 +661,10 @@ class pAdicLatticeElement(pAdicGenericElement):
         r"""
         Return the multiplicative inverse of this element.
 
-        NOTE::
+        .. NOTE::
 
-        The result of division always lives in the fraction field,
-        even if the element to be inverted is a unit.
+            The result of division always lives in the fraction field,
+            even if the element to be inverted is a unit.
 
         EXAMPLES::
 
@@ -773,14 +774,14 @@ class pAdicLatticeElement(pAdicGenericElement):
         INPUT:
 
         - ``prec`` -- an integer or ``None`` (default: ``None``), the
-          absolute precision of the result. If ``None``, lifts to the 
+          absolute precision of the result. If ``None``, lifts to the
           maximum precision allowed
 
         - ``infer_precision`` -- a boolean (default: ``False``)
 
         NOTE:
 
-        In the lattice precision model, the precision of all variables is 
+        In the lattice precision model, the precision of all variables is
         handled globally by a unique object, namely a lattice in a certain
         vector space.
 
@@ -791,7 +792,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         When ``infer_precision`` is set to ``False``, the precision on the
         newly created variable is independent as if the variable were created
         by hand by setting independently the value of the absolute precision.
-        In particular, if ``self`` used to share diffused digits of precision 
+        In particular, if ``self`` used to share diffused digits of precision
         with other variables, they are not preserved.
 
         EXAMPLES::
@@ -817,7 +818,7 @@ class pAdicLatticeElement(pAdicGenericElement):
         The gain of precision on ``u + v`` is due to the presence of diffused
         digits of precision between ``u`` and ``v``.
 
-        However, if we call :meth:`lift_to_precision` on one of these variables, 
+        However, if we call :meth:`lift_to_precision` on one of these variables,
         these diffused digits are lost and the precision on the sum is no longer
         sharp::
 
@@ -835,7 +836,7 @@ class pAdicLatticeElement(pAdicGenericElement):
             1 + O(2^10)
 
         Indeed if the absolute precision on ``u = x+y`` (resp. on ``x``)
-        is 20 (resp. 10), we deduce that the absolution precision on 
+        is 20 (resp. 10), we deduce that the absolution precision on
         ``y = u-x`` is 10.
 
         .. SEEALSO::
@@ -1010,7 +1011,7 @@ class pAdicLatticeElement(pAdicGenericElement):
             sage: b.unit_part()
             1 + 16*17 + O(17^3)
 
-        If the element is indistinguishable from zero, an error is raised.
+        If the element is indistinguishable from zero, an error is raised::
 
             sage: c = R(0, 5); c
             O(17^5)
@@ -1024,7 +1025,7 @@ class pAdicLatticeElement(pAdicGenericElement):
 
     def val_unit(self):
         r"""
-        Return the pair `(v, u)`, where this element is 
+        Return the pair `(v, u)`, where this element is
         `p^v u` and `u` is a unit.
 
         EXAMPLES::
@@ -1066,7 +1067,7 @@ class pAdicLatticeElement(pAdicGenericElement):
             sage: y
             1 + O(2^10)
 
-        In the lattice precision model, Sage remembers that ``y`` is 
+        In the lattice precision model, Sage remembers that ``y`` is
         actually equal to ``x``. Therefore, when we compute the difference,
         the `O(2^10)` cancel as well::
 
@@ -1161,14 +1162,14 @@ class pAdicLatticeElement(pAdicGenericElement):
 
         INPUT:
 
-        - ``n`` -- an integer or ``None`` (default ``None``); if given, 
+        - ``n`` -- an integer or ``None`` (default ``None``); if given,
           return the corresponding entry in the expansion.
 
         - ``lift_mode`` -- a string (default: ``simple``); currently
           only ``simple`` is implemented.
 
         - ``start_val`` -- an integer or ``None`` (default: ``None``);
-          start at this valuation rather than the default (`0` or the 
+          start at this valuation rather than the default (`0` or the
           valuation of this element).
 
         EXAMPLES::
@@ -1248,7 +1249,7 @@ class pAdicLatticeElement(pAdicGenericElement):
 class pAdicLatticeCapElement(pAdicLatticeElement):
     def _declare_new_element(self, dx, prec, dx_mode):
         r"""
-        Declare this element to the precision object and 
+        Declare this element to the precision object and
         return the precision at which this element can be truncated safely.
 
         Only for internal use.
@@ -1278,10 +1279,10 @@ class pAdicLatticeCapElement(pAdicLatticeElement):
         r"""
         Return ``True`` if this element is exactly zero.
 
-        NOTE::
+        .. NOTE::
 
-        Since exact zeros are not supported in the precision lattice
-        model, this function always returns ``False``.
+            Since exact zeros are not supported in the precision lattice
+            model, this function always returns ``False``.
 
         EXAMPLES::
 
@@ -1297,7 +1298,7 @@ class pAdicLatticeCapElement(pAdicLatticeElement):
 class pAdicLatticeFloatElement(pAdicLatticeElement):
     def _declare_new_element(self, dx, prec, dx_mode):
         r"""
-        Declare this element to the precision object and 
+        Declare this element to the precision object and
         return the precision at which this element can be truncated safely.
 
         Only for internal use.
