@@ -10,7 +10,10 @@ EXAMPLES::
     sage: from sage.rings.polynomial.flatten import FlatteningMorphism
     sage: phi = FlatteningMorphism(R); phi
     Flattening morphism:
-      From: Univariate Polynomial Ring in X over Multivariate Polynomial Ring in s, t over Univariate Polynomial Ring in y over Univariate Polynomial Ring in x over Rational Field
+      From: Univariate Polynomial Ring in X
+            over Multivariate Polynomial Ring in s, t
+            over Univariate Polynomial Ring in y
+            over Univariate Polynomial Ring in x over Rational Field
       To:   Multivariate Polynomial Ring in x, y, s, t, X over Rational Field
     sage: phi('x*y*s + t*X').parent()
     Multivariate Polynomial Ring in x, y, s, t, X over Rational Field
@@ -108,24 +111,28 @@ class FlatteningMorphism(Morphism):
 
         ::
 
+            sage: # needs sage.rings.number_field
+            sage: x = polygen(ZZ, 'x')
             sage: K.<v> = NumberField(x^3 - 2)
             sage: R = K['x','y']['a','b']
             sage: from sage.rings.polynomial.flatten import FlatteningMorphism
             sage: f = FlatteningMorphism(R)
             sage: f(R('v*a*x^2 + b^2 + 1/v*y'))
-            (v)*x^2*a + b^2 + (1/2*v^2)*y
+            v*x^2*a + b^2 + (1/2*v^2)*y
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: R = QQbar['x','y']['a','b']
             sage: from sage.rings.polynomial.flatten import FlatteningMorphism
             sage: f = FlatteningMorphism(R)
-            sage: f(R('QQbar(sqrt(2))*a*x^2 + b^2 + QQbar(I)*y'))
+            sage: f(R('QQbar(sqrt(2))*a*x^2 + b^2 + QQbar(I)*y'))                       # needs sage.symbolic
             1.414213562373095?*x^2*a + b^2 + I*y
 
         ::
 
-            sage: R.<z> = PolynomialRing(QQbar,1)
+            sage: # needs sage.rings.number_field
+            sage: R.<z> = PolynomialRing(QQbar, 1)
             sage: from sage.rings.polynomial.flatten import FlatteningMorphism
             sage: f = FlatteningMorphism(R)
             sage: f.domain(), f.codomain()
@@ -134,6 +141,7 @@ class FlatteningMorphism(Morphism):
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: R.<z> = PolynomialRing(QQbar)
             sage: from sage.rings.polynomial.flatten import FlatteningMorphism
             sage: f = FlatteningMorphism(R)
@@ -243,7 +251,8 @@ class FlatteningMorphism(Morphism):
             sage: h.section()
             Unflattening morphism:
               From: Multivariate Polynomial Ring in a, b, c, x, y, z over Rational Field
-              To:   Multivariate Polynomial Ring in x, y, z over Multivariate Polynomial Ring in a, b, c over Rational Field
+              To:   Multivariate Polynomial Ring in x, y, z
+                    over Multivariate Polynomial Ring in a, b, c over Rational Field
 
         ::
 
@@ -252,7 +261,8 @@ class FlatteningMorphism(Morphism):
             sage: FlatteningMorphism(R).section()
             Unflattening morphism:
               From: Multivariate Polynomial Ring in a, b, c over Integer Ring
-              To:   Univariate Polynomial Ring in c over Univariate Polynomial Ring in b over Univariate Polynomial Ring in a over Integer Ring
+              To:   Univariate Polynomial Ring in c over Univariate Polynomial Ring in b
+                    over Univariate Polynomial Ring in a over Integer Ring
         """
         return UnflatteningMorphism(self.codomain(), self.domain())
 
@@ -268,7 +278,8 @@ class FlatteningMorphism(Morphism):
             sage: f.inverse()
             Unflattening morphism:
               From: Multivariate Polynomial Ring in x, y, u, v over Rational Field
-              To:   Multivariate Polynomial Ring in u, v over Multivariate Polynomial Ring in x, y over Rational Field
+              To:   Multivariate Polynomial Ring in u, v
+                    over Multivariate Polynomial Ring in x, y over Rational Field
         """
         return self.section()
 
@@ -286,7 +297,8 @@ class UnflatteningMorphism(Morphism):
         sage: g = f(R('x^2 + c*y^2 - z^2'));g
         x^2 + c*y^2 - z^2
         sage: g.parent()
-        Multivariate Polynomial Ring in x, y, z over Univariate Polynomial Ring in c over Rational Field
+        Multivariate Polynomial Ring in x, y, z
+         over Univariate Polynomial Ring in c over Rational Field
 
     ::
 
@@ -296,7 +308,8 @@ class UnflatteningMorphism(Morphism):
         sage: UnflatteningMorphism(R, S)
         Unflattening morphism:
           From: Multivariate Polynomial Ring in a, b, x, y over Rational Field
-          To:   Multivariate Polynomial Ring in x, y over Multivariate Polynomial Ring in a, b over Rational Field
+          To:   Multivariate Polynomial Ring in x, y
+                over Multivariate Polynomial Ring in a, b over Rational Field
     """
 
     def __init__(self, domain, codomain):
@@ -366,8 +379,10 @@ class UnflatteningMorphism(Morphism):
         TESTS::
 
             sage: from sage.rings.polynomial.flatten import FlatteningMorphism
-            sage: for R in [ZZ['x']['y']['a,b,c'], GF(4)['x','y']['a','b'],
-            ....:           AA['x']['a','b']['y'], QQbar['a1','a2']['t']['X','Y']]:
+            sage: rings = [ZZ['x']['y']['a,b,c']]
+            sage: rings += [GF(4)['x','y']['a','b']]                                    # needs sage.rings.finite_rings
+            sage: rings += [AA['x']['a','b']['y'], QQbar['a1','a2']['t']['X','Y']]      # needs sage.rings.number_field
+            sage: for R in rings:
             ....:    f = FlatteningMorphism(R)
             ....:    g = f.section()
             ....:    for _ in range(10):
@@ -423,8 +438,9 @@ class SpecializationMorphism(Morphism):
         sage: from sage.rings.polynomial.flatten import SpecializationMorphism
         sage: xi = SpecializationMorphism(S, {c:0}); xi
         Specialization morphism:
-              From: Univariate Polynomial Ring in z over Univariate Polynomial Ring in c over Rational Field
-              To:   Univariate Polynomial Ring in z over Rational Field
+          From: Univariate Polynomial Ring in z
+                over Univariate Polynomial Ring in c over Rational Field
+          To:   Univariate Polynomial Ring in z over Rational Field
         sage: xi(z^2+c)
         z^2
 
@@ -437,8 +453,11 @@ class SpecializationMorphism(Morphism):
         sage: from sage.rings.polynomial.flatten import SpecializationMorphism
         sage: xi = SpecializationMorphism(S, D); xi
         Specialization morphism:
-          From: Multivariate Polynomial Ring in x, y, z over Multivariate Polynomial Ring in a, b, c over Multivariate Polynomial Ring in u, v over Rational Field
-          To:   Multivariate Polynomial Ring in y, z over Univariate Polynomial Ring in c over Univariate Polynomial Ring in v over Rational Field
+          From: Multivariate Polynomial Ring in x, y, z
+                over Multivariate Polynomial Ring in a, b, c
+                over Multivariate Polynomial Ring in u, v over Rational Field
+          To:   Multivariate Polynomial Ring in y, z over Univariate Polynomial Ring in c
+                over Univariate Polynomial Ring in v over Rational Field
         sage: xi(a*(x*z+y^2)*u+b*v*u*(x*z+y^2)*y^2*c+c*y^2*z^2)
         2*v*c*y^4 + c*y^2*z^2 + y^2
     """
@@ -475,8 +494,9 @@ class SpecializationMorphism(Morphism):
             sage: P.<z> = AffineSpace(R, 1)
             sage: H = End(P)
             sage: f = H([z^2 + c])
-            sage: f.specialization({c:1})
-            Scheme endomorphism of Affine Space of dimension 1 over Real Field with 53 bits of precision
+            sage: f.specialization({c:1})                                               # needs sage.modules
+            Scheme endomorphism of
+             Affine Space of dimension 1 over Real Field with 53 bits of precision
               Defn: Defined on coordinates by sending (z) to
                     (z^2 + 1.00000000000000)
         """
@@ -655,8 +675,10 @@ class FractionSpecializationMorphism(Morphism):
             sage: phi = FractionSpecializationMorphism(Frac(S), {c:3})
             sage: phi
             Fraction Specialization morphism:
-                From: Fraction Field of Multivariate Polynomial Ring in x, y over Multivariate Polynomial Ring in a, c over Rational Field
-                To:   Fraction Field of Multivariate Polynomial Ring in x, y over Univariate Polynomial Ring in a over Rational Field
+              From: Fraction Field of Multivariate Polynomial Ring in x, y
+                    over Multivariate Polynomial Ring in a, c over Rational Field
+              To:   Fraction Field of Multivariate Polynomial Ring in x, y
+                    over Univariate Polynomial Ring in a over Rational Field
         """
         if not is_FractionField(domain):
             raise TypeError("domain must be a fraction field")
