@@ -11,7 +11,7 @@ Interactively, an instance of :class:`RationalField` is available as ``QQ``::
     Rational Field
 
 Values of various types can be converted to rational numbers by using the
-``__call__`` method of ``RationalField`` (that is, by treating ``QQ`` as a
+:meth:`__call__` method of :class:`RationalField` (that is, by treating ``QQ`` as a
 function).
 
 ::
@@ -86,7 +86,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         -930482/9320842317
         sage: QQ([9320842317])
         9320842317
-        sage: QQ(pari(39029384023840928309482842098430284398243982394))
+        sage: QQ(pari(39029384023840928309482842098430284398243982394))                 # optional - sage.libs.pari
         39029384023840928309482842098430284398243982394
         sage: QQ('sage')
         Traceback (most recent call last):
@@ -105,7 +105,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         sage: QQ(RR(1/7)) - 1/7
         0
 
-    If you specify an optional second base argument, then the string
+    If you specify the optional second argument ``base``, then the string
     representation of the float is used.
 
     ::
@@ -304,7 +304,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def construction(self):
         r"""
-        Returns a pair ``(functor, parent)`` such that ``functor(parent)``
+        Return a pair ``(functor, parent)`` such that ``functor(parent)``
         returns ``self``.
 
         This is the construction of `\QQ` as the fraction field of `\ZZ`.
@@ -318,7 +318,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         from . import integer_ring
         return FractionField(), integer_ring.ZZ
 
-    def completion(self, p, prec, extras = {}):
+    def completion(self, p, prec, extras={}):
         r"""
         Return the completion of `\QQ` at `p`.
 
@@ -374,7 +374,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         if S is ZZ:
             return rational.Z_to_Q()
         elif S is int:
-            return rational.long_to_Q()
+            return rational.int_to_Q()
         elif ZZ.has_coerce_map_from(S):
             return rational.Z_to_Q() * ZZ._internal_coerce_map_from(S)
         from sage.rings.localization import Localization
@@ -383,7 +383,6 @@ class RationalField(Singleton, number_field_base.NumberField):
                 from sage.structure.coerce_maps import CallableConvertMap
                 return CallableConvertMap(S, self, lambda x: x._value, parent_as_first_arg=False)
 
-
     def _is_valid_homomorphism_(self, codomain, im_gens, base_map=None):
         """
         Check to see if the map into ``codomain`` determined by ``im_gens`` is
@@ -442,7 +441,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         EXAMPLES::
 
-            sage: QQ / ZZ
+            sage: QQ / ZZ                                                               # optional - sage.groups
             Q/Z
         """
         from sage.rings.ideal import Ideal_generic
@@ -460,9 +459,9 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         Returns a Python generator for the list of rational numbers with
         heights in ``range(start, end)``. Follows the same
-        convention as Python range, see ``range?`` for details.
+        convention as Python :func:`range`, type ``range?`` for details.
 
-        See also ``__iter__()``.
+        See also :meth:`__iter__`.
 
         EXAMPLES:
 
@@ -527,9 +526,9 @@ class RationalField(Singleton, number_field_base.NumberField):
         EXAMPLES::
 
             sage: it = QQ.primes_of_bounded_norm_iter(10)
-            sage: list(it)
+            sage: list(it)                                                              # optional - sage.libs.pari
             [2, 3, 5, 7]
-            sage: list(QQ.primes_of_bounded_norm_iter(1))
+            sage: list(QQ.primes_of_bounded_norm_iter(1))                               # optional - sage.libs.pari
             []
         """
         try:
@@ -541,8 +540,7 @@ class RationalField(Singleton, number_field_base.NumberField):
             return
 
         from sage.arith.misc import primes
-        for p in primes(B+1):
-            yield p
+        yield from primes(B + 1)
 
     def discriminant(self):
         """
@@ -608,14 +606,14 @@ class RationalField(Singleton, number_field_base.NumberField):
 
             sage: QQ.embeddings(QQ)
             [Identity endomorphism of Rational Field]
-            sage: QQ.embeddings(CyclotomicField(5))
+            sage: QQ.embeddings(CyclotomicField(5))                                     # optional - sage.rings.number_field
             [Coercion map:
                From: Rational Field
                To:   Cyclotomic Field of order 5 and degree 4]
 
         `K` must have characteristic 0::
 
-            sage: QQ.embeddings(GF(3))
+            sage: QQ.embeddings(GF(3))                                                  # optional - sage.rings.finite_rings
             Traceback (most recent call last):
             ...
             ValueError: no embeddings of the rational field into K.
@@ -628,9 +626,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         r"""
         Return all Galois automorphisms of ``self``.
 
-        OUTPUT:
-
-        - a sequence containing just the identity morphism
+        OUTPUT: a sequence containing just the identity morphism
 
         EXAMPLES::
 
@@ -645,15 +641,15 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def places(self, all_complex=False, prec=None):
         r"""
-        Return the collection of all infinite places of self, which
-        in this case is just the embedding of self into `\RR`.
+        Return the collection of all infinite places of ``self``, which
+        in this case is just the embedding of ``self`` into `\RR`.
 
         By default, this returns homomorphisms into ``RR``.  If
         ``prec`` is not None, we simply return homomorphisms into
         ``RealField(prec)`` (or ``RDF`` if ``prec=53``).
 
         There is an optional flag ``all_complex``, which defaults to
-        False.  If ``all_complex`` is True, then the real embeddings
+        ``False``.  If ``all_complex`` is ``True``, then the real embeddings
         are returned as embeddings into the corresponding complex
         field.
 
@@ -724,7 +720,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         -  ``p`` - a prime integer.
 
-        -  ``check`` (default True) - if True check the primality of
+        -  ``check`` (default ``True``) - if ``True``, check the primality of
            `p`, else do not.
 
         OUTPUT: The residue field at this prime.
@@ -741,7 +737,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def hilbert_symbol_negative_at_S(self, S, b, check=True):
         r"""
-        Returns an integer that has a negative Hilbert symbol with respect
+        Return an integer that has a negative Hilbert symbol with respect
         to a given rational number and a given set of primes (or places).
 
         The function is algorithm 3.4.1 in [Kir2016]_. It finds an integer `a`
@@ -751,10 +747,10 @@ class RationalField(Singleton, number_field_base.NumberField):
         INPUT:
 
         - ``S`` -- a list of rational primes, the infinite place as real
-          embedding of `\QQ` or as -1
+          embedding of `\QQ` or as `-1`
         - ``b`` -- a non-zero rational number which is a non-square locally
           at every prime in ``S``.
-        - ``check`` -- ``bool`` (default:``True``) perform additional checks on
+        - ``check`` -- ``bool`` (default: ``True``) perform additional checks on
           input and confirm the output.
 
         OUTPUT:
@@ -764,37 +760,37 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         EXAMPLES::
 
-            sage: QQ.hilbert_symbol_negative_at_S([-1,5,3,2,7,11,13,23], -10/7)
+            sage: QQ.hilbert_symbol_negative_at_S([-1,5,3,2,7,11,13,23], -10/7)         # optional - sage.rings.padics
             -9867
-            sage: QQ.hilbert_symbol_negative_at_S([3, 5, QQ.places()[0], 11], -15)
+            sage: QQ.hilbert_symbol_negative_at_S([3, 5, QQ.places()[0], 11], -15)      # optional - sage.rings.padics
             -33
-            sage: QQ.hilbert_symbol_negative_at_S([3, 5], 2)
+            sage: QQ.hilbert_symbol_negative_at_S([3, 5], 2)                            # optional - sage.rings.padics
             15
 
         TESTS::
 
-            sage: QQ.hilbert_symbol_negative_at_S(5/2, -2)
+            sage: QQ.hilbert_symbol_negative_at_S(5/2, -2)                              # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             TypeError: first argument must be a list or integer
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 0)
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 0)                            # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             ValueError: second argument must be nonzero
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([-1, 3, 5], 2)
+            sage: QQ.hilbert_symbol_negative_at_S([-1, 3, 5], 2)                        # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             ValueError: list should be of even cardinality
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 2)
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 2)                            # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             ValueError: all entries in list must be prime or -1 for
@@ -802,7 +798,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([5, 7], 2)
+            sage: QQ.hilbert_symbol_negative_at_S([5, 7], 2)                            # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             ValueError: second argument must be a nonsquare with
@@ -810,14 +806,14 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([1, 3], sqrt(2))
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], sqrt(2))                      # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             TypeError: second argument must be a rational number
 
         ::
 
-            sage: QQ.hilbert_symbol_negative_at_S([-1, 3], 2)
+            sage: QQ.hilbert_symbol_negative_at_S([-1, 3], 2)                           # optional - sage.libs.pari sage.modules
             Traceback (most recent call last):
             ...
             ValueError: if the infinite place is in the list, the second
@@ -891,7 +887,6 @@ class RationalField(Singleton, number_field_base.NumberField):
             v = [(1-hilbert_symbol(x, b, p))//2 for p in P]
             return V(v)
 
-
         M = matrix(GF(2), [phi(p) for p in P+[-1]])
         # We search through all the primes
         for q in Primes():
@@ -911,11 +906,11 @@ class RationalField(Singleton, number_field_base.NumberField):
         a = self.prod([Pq[i]**ZZ(l[i]) for i in range(l.degree())])
         if check:
             assert phi(a) == v, "oops"
-        return  a
+        return a
 
     def gens(self):
         r"""
-        Return a tuple of generators of `\QQ` which is only ``(1,)``.
+        Return a tuple of generators of `\QQ`, which is only ``(1,)``.
 
         EXAMPLES::
 
@@ -928,7 +923,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         r"""
         Return the ``n``-th generator of `\QQ`.
 
-        There is only the 0-th generator which is 1.
+        There is only the 0-th generator, which is 1.
 
         EXAMPLES::
 
@@ -942,7 +937,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def degree(self):
         r"""
-        Return the degree of `\QQ` which is 1.
+        Return the degree of `\QQ`, which is 1.
 
         EXAMPLES::
 
@@ -953,7 +948,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def absolute_degree(self):
         r"""
-        Return the absolute degree of `\QQ` which is 1.
+        Return the absolute degree of `\QQ`, which is 1.
 
         EXAMPLES::
 
@@ -964,7 +959,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def ngens(self):
         r"""
-        Return the number of generators of `\QQ` which is 1.
+        Return the number of generators of `\QQ`, which is 1.
 
         EXAMPLES::
 
@@ -1058,16 +1053,17 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         We make a single absolute extension::
 
-            sage: K.<a> = QQ.extension(x^3 + 5); K
+            sage: x = polygen(QQ, 'x')
+            sage: K.<a> = QQ.extension(x^3 + 5); K                                      # optional - sage.rings.number_field
             Number Field in a with defining polynomial x^3 + 5
 
         We make an extension generated by roots of two polynomials::
 
-            sage: K.<a,b> = QQ.extension([x^3 + 5, x^2 + 3]); K
+            sage: K.<a,b> = QQ.extension([x^3 + 5, x^2 + 3]); K                         # optional - sage.rings.number_field
             Number Field in a with defining polynomial x^3 + 5 over its base field
-            sage: b^2
+            sage: b^2                                                                   # optional - sage.rings.number_field
             -3
-            sage: a^3
+            sage: a^3                                                                   # optional - sage.rings.number_field
             -5
         """
         from sage.rings.number_field.number_field import NumberField
@@ -1075,11 +1071,11 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def algebraic_closure(self):
         r"""
-        Return the algebraic closure of self (which is `\QQbar`).
+        Return the algebraic closure of ``self`` (which is `\QQbar`).
 
         EXAMPLES::
 
-            sage: QQ.algebraic_closure()
+            sage: QQ.algebraic_closure()                                                # optional - sage.rings.number_field
             Algebraic Field
         """
         from sage.rings.qqbar import QQbar
@@ -1087,7 +1083,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def order(self):
         r"""
-        Return the order of `\QQ` which is `\infty`.
+        Return the order of `\QQ`, which is `\infty`.
 
         EXAMPLES::
 
@@ -1101,8 +1097,8 @@ class RationalField(Singleton, number_field_base.NumberField):
         r"""
         Return a defining polynomial of `\QQ`, as for other number fields.
 
-        This is also aliased to :meth:`self.defining_polynomial()`
-        and :meth:`self.absolute_polynomial()`.
+        This is also aliased to :meth:`defining_polynomial`
+        and :meth:`absolute_polynomial`.
 
         EXAMPLES::
 
@@ -1133,9 +1129,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         See :func:`TestSuite` for a typical use case.
 
-        OUTPUT:
-
-        An iterator over 100 elements of `\QQ`.
+        OUTPUT: An iterator over 100 elements of `\QQ`.
 
         EXAMPLES::
 
@@ -1174,7 +1168,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
     def random_element(self, num_bound=None, den_bound=None, *args, **kwds):
         r"""
-        Return an random element of `\QQ`.
+        Return a random element of `\QQ`.
 
         Elements are constructed by randomly choosing integers
         for the numerator and denominator, not necessarily coprime.
@@ -1272,7 +1266,6 @@ class RationalField(Singleton, number_field_base.NumberField):
         else:
             raise ValueError("no n-th root of unity in rational field")
 
-
     def selmer_generators(self, S, m, proof=True, orders=False):
         r"""
         Return generators of the group `\QQ(S,m)`.
@@ -1285,7 +1278,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         - ``proof`` -- ignored
 
-        - ``orders`` (default False) -- if True, output two lists, the
+        - ``orders`` (default ``False``) -- if ``True``, output two lists, the
           generators and their orders
 
         OUTPUT:
@@ -1304,7 +1297,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
             :meth:`RationalField.selmer_space`, which gives additional
             output when `m=p` is prime: as well as generators, it gives an
-            abstract vector space over `GF(p)` isomorphic to `\QQ(S,p)`
+            abstract vector space over `\GF{p}` isomorphic to `\QQ(S,p)`
             and maps implementing the isomorphism between this space and
             `\QQ(S,p)` as a subgroup of `\QQ^*/(\QQ^*)^p`.
 
@@ -1391,7 +1384,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         (tuple) ``QSp``, ``QSp_gens``, ``from_QSp``, ``to_QSp`` where
 
-        - ``QSp`` is an abstract vector space over `GF(p)` isomorphic to `\QQ(S,p)`;
+        - ``QSp`` is an abstract vector space over `\GF{p}` isomorphic to `\QQ(S,p)`;
 
         - ``QSp_gens`` is a list of elements of `\QQ^*` generating `\QQ(S,p)`;
 
@@ -1415,45 +1408,47 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         When `S` is empty, `\QQ(S,p)` is only nontrivial for `p=2`::
 
-            sage: QS2, QS2gens, fromQS2, toQS2 = QQ.selmer_space([], 2)
-            sage: QS2
+            sage: QS2, QS2gens, fromQS2, toQS2 = QQ.selmer_space([], 2)                 # optional - sage.rings.number_field
+            sage: QS2                                                                   # optional - sage.rings.number_field
             Vector space of dimension 1 over Finite Field of size 2
-            sage: QS2gens
+            sage: QS2gens                                                               # optional - sage.rings.number_field
             [-1]
 
-            sage: all(QQ.selmer_space([], p)[0].dimension() == 0 for p in primes(3,10))
+            sage: all(QQ.selmer_space([], p)[0].dimension() == 0                        # optional - sage.libs.pari
+            ....:     for p in primes(3, 10))
             True
 
         In general there is one generator for each `p\in S`, and an
         additional generator of `-1` when `p=2`::
 
-            sage: QS2, QS2gens, fromQS2, toQS2 = QQ.selmer_space([5,7], 2)
-            sage: QS2
+            sage: QS2, QS2gens, fromQS2, toQS2 = QQ.selmer_space([5,7], 2)              # optional - sage.modules
+            sage: QS2                                                                   # optional - sage.modules
             Vector space of dimension 3 over Finite Field of size 2
-            sage: QS2gens
+            sage: QS2gens                                                               # optional - sage.modules
             [5, 7, -1]
-            sage: toQS2(-7)
+            sage: toQS2(-7)                                                             # optional - sage.modules
             (0, 1, 1)
-            sage: fromQS2((0,1,1))
+            sage: fromQS2((0,1,1))                                                      # optional - sage.modules
             -7
 
         The map ``fromQS2`` is only well-defined modulo `p`'th powers
         (in this case, modulo squares)::
 
-            sage: toQS2(-5/7)
+            sage: toQS2(-5/7)                                                           # optional - sage.modules
             (1, 1, 1)
-            sage: fromQS2((1,1,1))
+            sage: fromQS2((1,1,1))                                                      # optional - sage.modules
             -35
-            sage: ((-5/7)/(-35)).is_square()
+            sage: ((-5/7)/(-35)).is_square()                                            # optional - sage.modules
             True
 
         The map ``toQS2`` is not defined on all of `\QQ^*`, only on
         those numbers which are squares away from `5` and `7`::
 
-            sage: toQS2(210)
+            sage: toQS2(210)                                                            # optional - sage.modules
             Traceback (most recent call last):
             ...
-            ValueError: argument 210 should have valuations divisible by 2 at all primes in [5, 7]
+            ValueError: argument 210 should have valuations divisible by 2
+            at all primes in [5, 7]
 
         """
         from sage.rings.number_field.selmer_group import pSelmerGroup
@@ -1519,7 +1514,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         EXAMPLES::
 
-            sage: gap(QQ) # indirect doctest
+            sage: gap(QQ) # indirect doctest                                            # optional - sage.libs.gap
             Rationals
         """
         return 'Rationals'
@@ -1587,7 +1582,7 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         EXAMPLES::
 
-            sage: QQ._sympy_()
+            sage: QQ._sympy_()                                                          # optional - sympy
             Rationals
         """
         from sympy import Rationals
@@ -1633,20 +1628,20 @@ class RationalField(Singleton, number_field_base.NumberField):
         TESTS::
 
             sage: R.<x> = QQ[]
-            sage: QQ._factor_univariate_polynomial( x )
+            sage: QQ._factor_univariate_polynomial(x)                                   # optional - sage.libs.pari
             x
-            sage: QQ._factor_univariate_polynomial( 2*x )
+            sage: QQ._factor_univariate_polynomial(2*x)                                 # optional - sage.libs.pari
             (2) * x
-            sage: QQ._factor_univariate_polynomial( (x^2 - 1/4)^4 )
+            sage: QQ._factor_univariate_polynomial((x^2 - 1/4)^4)                       # optional - sage.libs.pari
             (x - 1/2)^4 * (x + 1/2)^4
-            sage: QQ._factor_univariate_polynomial( (2*x + 1) * (3*x^2 - 5)^2 )
+            sage: QQ._factor_univariate_polynomial((2*x + 1) * (3*x^2 - 5)^2)           # optional - sage.libs.pari
             (18) * (x + 1/2) * (x^2 - 5/3)^2
-            sage: f = prod((k^2*x^k + k)^(k-1) for k in primes(10))
-            sage: QQ._factor_univariate_polynomial(f)
+            sage: f = prod((k^2*x^k + k)^(k-1) for k in primes(10))                     # optional - sage.libs.pari
+            sage: QQ._factor_univariate_polynomial(f)                                   # optional - sage.libs.pari
             (1751787911376562500) * (x^2 + 1/2) * (x^3 + 1/3)^2 * (x^5 + 1/5)^4 * (x^7 + 1/7)^6
-            sage: QQ._factor_univariate_polynomial( 10*x^5 - 1 )
+            sage: QQ._factor_univariate_polynomial(10*x^5 - 1)                          # optional - sage.libs.pari
             (10) * (x^5 - 1/10)
-            sage: QQ._factor_univariate_polynomial( 10*x^5 - 10 )
+            sage: QQ._factor_univariate_polynomial(10*x^5 - 10)                         # optional - sage.libs.pari
             (10) * (x - 1) * (x^4 + x^3 + x^2 + x + 1)
 
         """
@@ -1664,9 +1659,9 @@ class RationalField(Singleton, number_field_base.NumberField):
 
         EXAMPLES::
 
-            sage: v = QQ.valuation(3); v
+            sage: v = QQ.valuation(3); v                                                # optional - sage.rings.padics
             3-adic valuation
-            sage: v(1/3)
+            sage: v(1/3)                                                                # optional - sage.rings.padics
             -1
 
         .. SEEALSO::
