@@ -8,7 +8,7 @@ is known to be modular.  The space is two-dimensional and contains a
 subspace on which complex conjugation acts as multiplication by `+1`
 and one on which it acts by `-1`.
 
-There are three implementations of modular symbols, two within 
+There are three implementations of modular symbols, two within
 ``Sage`` and one in Cremona's ``eclib`` library.
 One can choose here which one is used.
 
@@ -48,9 +48,11 @@ EXAMPLES::
 
     sage: V = E.modular_symbol_space()
     sage: V
-    Modular Symbols subspace of dimension 1 of Modular Symbols space of dimension 2 for Gamma_0(19) of weight 2 with sign 1 over Rational Field
+    Modular Symbols subspace of dimension 1 of Modular Symbols space of dimension 2
+     for Gamma_0(19) of weight 2 with sign 1 over Rational Field
     sage: V.q_eigenform(30)
-    q - 2*q^3 - 2*q^4 + 3*q^5 - q^7 + q^9 + 3*q^11 + 4*q^12 - 4*q^13 - 6*q^15 + 4*q^16 - 3*q^17 + q^19 - 6*q^20 + 2*q^21 + 4*q^25 + 4*q^27 + 2*q^28 + 6*q^29 + O(q^30)
+    q - 2*q^3 - 2*q^4 + 3*q^5 - q^7 + q^9 + 3*q^11 + 4*q^12 - 4*q^13 - 6*q^15 + 4*q^16
+     - 3*q^17 + q^19 - 6*q^20 + 2*q^21 + 4*q^25 + 4*q^27 + 2*q^28 + 6*q^29 + O(q^30)
 
 For more details on modular symbols consult the following
 
@@ -87,19 +89,22 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.structure.sage_object import SageObject
-from sage.modular.modsym.all import ModularSymbols
+from sage.arith.misc import (kronecker as kronecker_symbol,
+                             next_prime,
+                             prime_divisors,
+                             valuation)
 from sage.databases.cremona import parse_cremona_label
-
-from sage.arith.all import next_prime, kronecker_symbol, prime_divisors, valuation
+from sage.misc.verbose import verbose
+from sage.modular.cusps import Cusps
+from sage.modular.modsym.all import ModularSymbols
 from sage.rings.infinity import unsigned_infinity as infinity
 from sage.rings.integer import Integer
-from sage.modular.cusps import Cusps
-from sage.rings.integer_ring import   ZZ
+from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.misc.verbose import verbose
+from sage.structure.sage_object import SageObject
+
+from .constructor import EllipticCurve
 
-from sage.schemes.elliptic_curves.constructor import EllipticCurve
 
 oo = Cusps(infinity)
 zero = Integer(0)
@@ -122,11 +127,12 @@ def modular_symbol_space(E, sign, base_ring, bound=None):
 
     EXAMPLES::
 
-        sage: import sage.schemes.elliptic_curves.ell_modular_symbols
+        sage: from sage.schemes.elliptic_curves.ell_modular_symbols import modular_symbol_space
         sage: E = EllipticCurve('11a1')
-        sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.modular_symbol_space(E,-1,GF(37))
-        sage: M
-        Modular Symbols space of dimension 1 for Gamma_0(11) of weight 2 with sign -1 over Finite Field of size 37
+        sage: M = modular_symbol_space(E, -1, GF(37))                                   # optional - sage.rings.finite_rings
+        sage: M                                                                         # optional - sage.rings.finite_rings
+        Modular Symbols space of dimension 1 for Gamma_0(11) of weight 2 with sign -1
+         over Finite Field of size 37
     """
     if sign not in [-1, 0, 1]:
         raise TypeError('sign must -1, 0 or 1')
@@ -206,12 +212,14 @@ class ModularSymbol(SageObject):
 
             sage: m = EllipticCurve('11a1').modular_symbol()
             sage: m
-            Modular symbol with sign 1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
+            Modular symbol with sign 1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
             sage: m = EllipticCurve('43a1').modular_symbol(sign=-1, implementation="sage")
             sage: m
-            Modular symbol with sign -1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 + x^2 over Rational Field
+            Modular symbol with sign -1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 + x^2 over Rational Field
         """
-        return "Modular symbol with sign %s over %s attached to %s"%(
+        return "Modular symbol with sign %s over %s attached to %s" % (
             self._sign, self._base_ring, self._E)
 
 class ModularSymbolECLIB(ModularSymbol):
@@ -237,22 +245,23 @@ class ModularSymbolECLIB(ModularSymbol):
 
         EXAMPLES::
 
-            sage: import sage.schemes.elliptic_curves.ell_modular_symbols
+            sage: from sage.schemes.elliptic_curves.ell_modular_symbols import ModularSymbolECLIB
             sage: E = EllipticCurve('11a1')
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolECLIB(E,+1)
+            sage: M = ModularSymbolECLIB(E,+1)
             sage: M
-            Modular symbol with sign 1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
+            Modular symbol with sign 1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
             sage: M(0)
             1/5
             sage: E = EllipticCurve('11a2')
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolECLIB(E,+1)
+            sage: M = ModularSymbolECLIB(E,+1)
             sage: M(0)
             1
 
         This is a rank 1 case with vanishing positive twists::
 
             sage: E = EllipticCurve('121b1')
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolECLIB(E,+1)
+            sage: M = ModularSymbolECLIB(E,+1)
             sage: M(0)
             0
             sage: M(1/7)
@@ -270,11 +279,13 @@ class ModularSymbolECLIB(ModularSymbol):
 
             sage: E = EllipticCurve('11a1')
             sage: Mplus = E.modular_symbol(+1); Mplus
-            Modular symbol with sign 1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
+            Modular symbol with sign 1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
             sage: [Mplus(1/i) for i in [1..11]]
             [1/5, -4/5, -3/10, 7/10, 6/5, 6/5, 7/10, -3/10, -4/5, 1/5, 0]
             sage: Mminus = E.modular_symbol(-1); Mminus
-            Modular symbol with sign -1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
+            Modular symbol with sign -1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
             sage: [Mminus(1/i) for i in [1..11]]
             [0, 0, 1/2, 1/2, 0, 0, -1/2, -1/2, 0, 0, 0]
 
@@ -322,11 +333,11 @@ class ModularSymbolECLIB(ModularSymbol):
             raise TypeError('sign must -1 or 1')
         self._sign = ZZ(sign)
         self._E = E
-        self._scaling = 1 if E.discriminant()>0 else ZZ(1)/2
+        self._scaling = 1 if E.discriminant() > 0 else ZZ(1)/2
         self._implementation = "eclib"
         self._base_ring = QQ
         # The ECModularSymbol class must be initialized with sign=0 to compute minus symbols
-        self._modsym = ECModularSymbol(E, int(sign==1), nap)
+        self._modsym = ECModularSymbol(E, int(sign == 1), nap)
         self.cache = {True: {}, False: {}}
 
     def _call_with_caching(self, r, base_at_infinity=True):
@@ -390,17 +401,18 @@ class ModularSymbolSage(ModularSymbol):
         EXAMPLES::
 
             sage: E = EllipticCurve('11a1')
-            sage: import sage.schemes.elliptic_curves.ell_modular_symbols
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolSage(E,+1)
+            sage: from sage.schemes.elliptic_curves.ell_modular_symbols import ModularSymbolSage
+            sage: M = ModularSymbolSage(E, +1)
             sage: M
-            Modular symbol with sign 1 over Rational Field attached to Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
+            Modular symbol with sign 1 over Rational Field attached to
+             Elliptic Curve defined by y^2 + y = x^3 - x^2 - 10*x - 20 over Rational Field
             sage: M(0)
             1/5
             sage: E = EllipticCurve('11a2')
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolSage(E,+1)
+            sage: M = ModularSymbolSage(E, +1)
             sage: M(0)
             1
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolSage(E,-1)
+            sage: M = ModularSymbolSage(E, -1)
             sage: M(1/3)
             1/2
 
@@ -408,7 +420,7 @@ class ModularSymbolSage(ModularSymbol):
         The modular symbol is adjusted by -2::
 
             sage: E = EllipticCurve('121b1')
-            sage: M = sage.schemes.elliptic_curves.ell_modular_symbols.ModularSymbolSage(E,-1,normalize='L_ratio')
+            sage: M = ModularSymbolSage(E, -1, normalize='L_ratio')
             sage: M(1/3)
             1
             sage: M._scaling
@@ -417,16 +429,20 @@ class ModularSymbolSage(ModularSymbol):
             sage: M = EllipticCurve('121d1').modular_symbol(implementation="sage")
             sage: M(0)
             2
-            sage: M = EllipticCurve('121d1').modular_symbol(implementation="sage", normalize='none')
+            sage: M = EllipticCurve('121d1').modular_symbol(implementation="sage",
+            ....:                                           normalize='none')
             sage: M(0)
             1
 
             sage: E = EllipticCurve('15a1')
-            sage: [C.modular_symbol(implementation="sage", normalize='L_ratio')(0) for C in E.isogeny_class()]
+            sage: [C.modular_symbol(implementation="sage", normalize='L_ratio')(0)
+            ....:  for C in E.isogeny_class()]
             [1/4, 1/8, 1/4, 1/2, 1/8, 1/16, 1/2, 1]
-            sage: [C.modular_symbol(implementation="sage", normalize='period')(0) for C in E.isogeny_class()]
+            sage: [C.modular_symbol(implementation="sage", normalize='period')(0)
+            ....:  for C in E.isogeny_class()]
             [1/8, 1/16, 1/8, 1/4, 1/16, 1/32, 1/4, 1/2]
-            sage: [C.modular_symbol(implementation="sage", normalize='none')(0) for C in E.isogeny_class()]
+            sage: [C.modular_symbol(implementation="sage", normalize='none')(0)
+            ....:  for C in E.isogeny_class()]
             [1, 1, 1, 1, 1, 1, 1, 1]
         """
         if sign not in [-1, 1]:
@@ -445,14 +461,14 @@ class ModularSymbolSage(ModularSymbol):
             if self._failed_to_scale:
                 self._find_scaling_period()  # will reset _e and _scaling
             else:
-                self._e  *= self._scaling
+                self._e *= self._scaling
         elif normalize == "period" :
             self._find_scaling_period()      # this will set _e and _scaling
         elif normalize == "none":
             self._scaling = 1
             self._e = self._modsym.dual_eigenvector()
         else :
-            raise ValueError("no normalization %s known for modular symbols"%normalize)
+            raise ValueError("no normalization %s known for modular symbols" % normalize)
 
     def _find_scaling_L_ratio(self):
         r"""
@@ -537,7 +553,7 @@ class ModularSymbolSage(ModularSymbol):
             if at0 != 0 :
                 l1 = self.__lalg__(1)
                 if at0 != l1:
-                    verbose('scale modular symbols by %s'%(l1/at0))
+                    verbose('scale modular symbols by %s' % (l1/at0))
                     self._scaling = l1/at0
             else :
                 # if [0] = 0, we can still hope to scale it correctly by considering twists of E
@@ -549,7 +565,7 @@ class ModularSymbolSage(ModularSymbol):
                     D = Dlist[j]
                     # the following line checks if the twist of the newform of E by D is a newform
                     # this is to avoid that we 'twist back'
-                    if all( valuation(E.conductor(),ell)<= valuation(D,ell) for ell in prime_divisors(D) ) :
+                    if all( valuation(E.conductor(),ell) <= valuation(D,ell) for ell in prime_divisors(D) ) :
                         at0 = sum([kronecker_symbol(D,u) * self(ZZ(u)/D) for u in range(1,abs(D))])
                     j += 1
                 if j == 30 and at0 == 0: # curves like "121b1", "225a1", "225e1", "256a1", "256b1", "289a1", "361a1", "400a1", "400c1", "400h1", "441b1", "441c1", "441d1", "441f1 .. will arrive here
@@ -558,7 +574,7 @@ class ModularSymbolSage(ModularSymbol):
                 else :
                     l1 = self.__lalg__(D)
                     if at0 != l1:
-                        verbose('scale modular symbols by %s found at D=%s '%(l1/at0,D), level=2)
+                        verbose('scale modular symbols by %s found at D=%s ' % (l1/at0,D), level=2)
                         self._scaling = l1/at0
 
         else : # that is when sign = -1
@@ -568,7 +584,7 @@ class ModularSymbolSage(ModularSymbol):
             while j < 30 and at0 == 0 :
                 # computes [0]+ for the twist of E by D until one value is non-zero
                 D = Dlist[j]
-                if all( valuation(E.conductor(),ell)<= valuation(D,ell) for ell in prime_divisors(D) ) :
+                if all( valuation(E.conductor(),ell) <= valuation(D,ell) for ell in prime_divisors(D) ) :
                     at0 = - sum([kronecker_symbol(D,u) * self(ZZ(u)/D) for u in range(1,abs(D))])
                 j += 1
             if j == 30 and at0 == 0: # no more hope for a normalization
@@ -577,7 +593,7 @@ class ModularSymbolSage(ModularSymbol):
             else :
                 l1 = self.__lalg__(D)
                 if at0 != l1:
-                    verbose('scale modular symbols by %s'%(l1/at0))
+                    verbose('scale modular symbols by %s' % (l1/at0))
                     self._scaling = l1/at0
 
     def __lalg__(self, D):
