@@ -9,6 +9,7 @@ and ``non_surjective`` methods of an elliptic curve over a number field.
 
 EXAMPLES::
 
+    sage: x = polygen(ZZ, 'x')
     sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
     sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
     sage: rho = E.galois_representation()
@@ -45,14 +46,17 @@ REFERENCES:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.structure.sage_object import SageObject
-from sage.rings.number_field.number_field import NumberField
+from sage.arith.misc import legendre_symbol, primes
+from sage.misc.functional import cyclotomic_polynomial
 from sage.modules.free_module import VectorSpace
 from sage.rings.finite_rings.finite_field_constructor import GF
-from sage.misc.functional import cyclotomic_polynomial
-from sage.arith.all import legendre_symbol, primes
+from sage.rings.infinity import Infinity
+from sage.rings.integer import Integer
+from sage.rings.integer_ring import ZZ
+from sage.rings.number_field.number_field import NumberField
+from sage.rings.rational_field import QQ
 from sage.sets.set import Set
-from sage.rings.all import Integer, ZZ, QQ, Infinity
+from sage.structure.sage_object import SageObject
 
 
 class GaloisRepresentation(SageObject):
@@ -71,6 +75,7 @@ class GaloisRepresentation(SageObject):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 + 1, 'a')
         sage: E = EllipticCurve('11a1').change_ring(K)
         sage: rho = E.galois_representation()
@@ -84,6 +89,7 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 + 1, 'a')
             sage: E = EllipticCurve('11a1').change_ring(K)
             sage: rho = E.galois_representation()
@@ -100,6 +106,7 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 + 1, 'a')
             sage: E = EllipticCurve('11a1').change_ring(K)
             sage: rho = E.galois_representation()
@@ -116,7 +123,6 @@ class GaloisRepresentation(SageObject):
         else:
             return "Compatible family of Galois representations associated to the " + repr(self.E)
 
-
     def __eq__(self,other):
         r"""
         Compares two Galois representations.
@@ -126,6 +132,7 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 + 1, 'a'); a = K.gen()
             sage: rho1 = EllipticCurve_from_j(1 + a).galois_representation()
             sage: rho2 = EllipticCurve_from_j(2 + a).galois_representation()
@@ -146,6 +153,7 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 + 1, 'a'); a = K.gen()
             sage: E = EllipticCurve_from_j(a)
             sage: rho = E.galois_representation()
@@ -154,7 +162,6 @@ class GaloisRepresentation(SageObject):
         """
         return self.E
 
-
     def non_surjective(self, A=100):
         r"""
         Return a list of primes `p` including all primes for which the mod-`p`
@@ -174,10 +181,11 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
             sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
             sage: rho = E.galois_representation()
-            sage: rho.non_surjective() # See Section 5.10 of [Ser1972].
+            sage: rho.non_surjective() # See Section 5.10 of [Ser1972].  # long time
             [3, 5, 29]
             sage: K = NumberField(x**2 + 3, 'a'); a = K.gen()
             sage: E = EllipticCurve([0, -1, 1, -10, -20]).change_ring(K) # X_0(11)
@@ -224,6 +232,7 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
             sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
             sage: rho = E.galois_representation()
@@ -289,18 +298,22 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
             sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
             sage: rho = E.galois_representation()
-            sage: rho.isogeny_bound() # See Section 5.10 of [Ser1972].
+            sage: rho.isogeny_bound() # See Section 5.10 of [Ser1972].  # long time
             [3, 5]
             sage: K = NumberField(x**2 + 1, 'a')
-            sage: EllipticCurve_from_j(K(1728)).galois_representation().isogeny_bound() # CM over K
+            sage: E = EllipticCurve_from_j(K(1728))             # CM over K
+            sage: E.galois_representation().isogeny_bound()
             [0]
-            sage: EllipticCurve_from_j(K(0)).galois_representation().isogeny_bound() # CM NOT over K
+            sage: E = EllipticCurve_from_j(K(0))                # CM NOT over K
+            sage: E.galois_representation().isogeny_bound()     # long time
             [2, 3]
-            sage: E = EllipticCurve_from_j(K(2268945/128)) # c.f. [Sut2012]
-            sage: E.galois_representation().isogeny_bound() # No 7-isogeny, but...
+            sage: E = EllipticCurve_from_j(K(2268945/128))      # c.f. [Sut2012]
+            sage: rho = E.galois_representation()
+            sage: rho.isogeny_bound()  # No 7-isogeny, but...   # long time
             [7]
 
         For curves with rational CM, there are infinitely many primes
@@ -365,24 +378,25 @@ class GaloisRepresentation(SageObject):
 
         EXAMPLES::
 
+            sage: x = polygen(ZZ, 'x')
             sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
             sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
             sage: rho = E.galois_representation()
-            sage: rho.isogeny_bound() # See Section 5.10 of [Ser1972].
-            [3, 5]
-            sage: rho.reducible_primes()
+            sage: rho.reducible_primes() # See Section 5.10 of [Ser1972].  # long time
             [3, 5]
 
             sage: K = NumberField(x**2 + 1, 'a')
-            sage: EllipticCurve_from_j(K(1728)).galois_representation().isogeny_bound() # CM over K
+            sage: E = EllipticCurve_from_j(K(1728))             # CM over K
+            sage: E.galois_representation().reducible_primes()
             [0]
-            sage: EllipticCurve_from_j(K(0)).galois_representation().reducible_primes() # CM but NOT over K
+            sage: E = EllipticCurve_from_j(K(0))                # CM but NOT over K
+            sage: E.galois_representation().reducible_primes()  # long time
             [2, 3]
-            sage: E = EllipticCurve_from_j(K(2268945/128)) # c.f. [Sut2012]
+            sage: E = EllipticCurve_from_j(K(2268945/128))      # c.f. [Sut2012]
             sage: rho = E.galois_representation()
-            sage: rho.isogeny_bound() # ... but there is no 7-isogeny ...
+            sage: rho.isogeny_bound()  # No 7-isogeny, but...   # long time
             [7]
-            sage: rho.reducible_primes()
+            sage: rho.reducible_primes()                        # long time
             []
 
         For curves with rational CM, there are infinitely many primes
@@ -422,9 +436,10 @@ def _non_surjective(E, patience=100):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
-        sage: sage.schemes.elliptic_curves.gal_reps_number_field._non_surjective(E) # See Section 5.10 of [Ser1972].
+        sage: sage.schemes.elliptic_curves.gal_reps_number_field._non_surjective(E) # See Section 5.10 of [Ser1972].  # long time
         [3, 5, 29]
         sage: E = EllipticCurve_from_j(1728).change_ring(K) # CM
         sage: sage.schemes.elliptic_curves.gal_reps_number_field._non_surjective(E)
@@ -498,7 +513,7 @@ def Frobenius_filter(E, L, patience=100):
     EXAMPLES::
 
         sage: E = EllipticCurve('11a1') # has a 5-isogeny
-        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E,primes(40))
+        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E,primes(40))  # long time
         [5]
 
     Example to show that the output may contain primes where the
@@ -506,7 +521,7 @@ def Frobenius_filter(E, L, patience=100):
     essentially the unique such example by [Sut2012]_::
 
         sage: E = EllipticCurve_from_j(2268945/128)
-        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E, [7, 11])
+        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E, [7, 11])  # long time
         [7]
 
     This curve does possess a 7-isogeny modulo every prime of good
@@ -519,7 +534,7 @@ def Frobenius_filter(E, L, patience=100):
 
         sage: K.<i> = QuadraticField(-1)
         sage: E = EllipticCurve([1+i, -i, i, -399-240*i,  2627+2869*i])
-        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E, primes(20))
+        sage: sage.schemes.elliptic_curves.gal_reps_number_field.Frobenius_filter(E, primes(20))  # long time
         [2, 3]
 
     Here the curve really does possess isogenies of degrees 2 and 3::
@@ -538,7 +553,7 @@ def Frobenius_filter(E, L, patience=100):
         L.remove(2)
         include_2 = not E.division_polynomial(2).is_irreducible()
 
-    K_is_Q = (K==QQ)
+    K_is_Q = (K == QQ)
     from sage.arith.misc import primes
     from sage.rings.infinity import infinity
 
@@ -553,7 +568,7 @@ def Frobenius_filter(E, L, patience=100):
                         yield P
     numP = 0
     for P in primes_iter():
-        if not L or numP==patience:  # stop if no primes are left, or patience is exhausted
+        if not L or numP == patience:  # stop if no primes are left, or patience is exhausted
             break
 
         numP += 1
@@ -596,6 +611,7 @@ def _exceptionals(E, L, patience=1000):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: sage.schemes.elliptic_curves.gal_reps_number_field._exceptionals(E, [29, 31])
@@ -705,7 +721,6 @@ def _exceptionals(E, L, patience=1000):
                 if u not in (1, 2, 4) and u**2 - 3 * u + 1 != 0:
                     D[l][2] = False
 
-
             if D[l] == [False, False, False]:
                 unexc.append(l)
 
@@ -795,7 +810,7 @@ def deg_one_primes_iter(K, principal_only=False):
     # imaginary quadratic fields have no principal primes of norm < disc / 4
     start = K.discriminant().abs() // 4 if principal_only and K.signature() == (0,1) else 2
 
-    K_is_Q = (K==QQ)
+    K_is_Q = (K == QQ)
 
     for p in primes(start=start, stop=Infinity):
         if K_is_Q:
@@ -829,6 +844,7 @@ def _semistable_reducible_primes(E, verbose=False):
     This example, over a quintic field with Galois group `S_5`, took a
     very long time before :trac:`22343`::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^5 - 6*x^3 + 8*x - 1)
         sage: E = EllipticCurve(K, [a^3 - 2*a, a^4 - 2*a^3 - 4*a^2 + 6*a + 1, a + 1, -a^3 + a + 1, -a])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import _semistable_reducible_primes
@@ -856,23 +872,23 @@ def _semistable_reducible_primes(E, verbose=False):
     while len(precomp) < 2:
         P = next(deg_one_primes)
         p = P.norm()
-        if p != last_p and (d==1 or P.ramification_index() == 1) and E.has_good_reduction(P):
+        if p != last_p and (d == 1 or P.ramification_index() == 1) and E.has_good_reduction(P):
             precomp.append(P)
             last_p = p
 
     Px, Py = precomp
     x, y = [PP.gens_reduced()[0] for PP in precomp]
-    EmodPx = E.reduction(Px) if d>1 else E.reduction(x)
-    EmodPy = E.reduction(Py) if d>1 else E.reduction(y)
+    EmodPx = E.reduction(Px) if d > 1 else E.reduction(x)
+    EmodPy = E.reduction(Py) if d > 1 else E.reduction(y)
     fxpol = EmodPx.frobenius_polynomial()
     fypol = EmodPy.frobenius_polynomial()
     fx12pol = fxpol.adams_operator(12) # roots are 12th powers of those of fxpol
     fy12pol = fypol.adams_operator(12)
-    px = x.norm() if d>1 else x
-    py = y.norm() if d>1 else x
+    px = x.norm() if d > 1 else x
+    py = y.norm() if d > 1 else x
     Zx = fxpol.parent()
-    xpol = x.charpoly() if d>1 else Zx([-x,1])
-    ypol = y.charpoly() if d>1 else Zx([-y,1])
+    xpol = x.charpoly() if d > 1 else Zx([-x,1])
+    ypol = y.charpoly() if d > 1 else Zx([-y,1])
 
     if verbose:
         print("Finished precomp, x={} (p={}), y={} (p={})".format(x,px,y,py))
@@ -900,7 +916,6 @@ def _semistable_reducible_primes(E, verbose=False):
             if verbose:
                 print("gx and gy both 0!")
 
-
         ## It is possible that our curve has CM. ##
 
         # Our character must be of the form Nm^K_F for an imaginary
@@ -936,7 +951,7 @@ def _semistable_reducible_primes(E, verbose=False):
         # has CM and computing the set of CM j-invariants of K to check.
         # TODO: Is this the best value for this parameter?
 
-        while div==0 and patience>0:
+        while div == 0 and patience > 0:
             P = next(deg_one_primes) # a prime of K not K_rel
             while E.has_bad_reduction(P):
                 P = next(deg_one_primes)
@@ -952,7 +967,7 @@ def _semistable_reducible_primes(E, verbose=False):
             div2 = Integer(xpol.resultant(fpol.adams_operator(12)) // x.norm()**12)
             if div2:
                 div = div2.isqrt()
-                assert div2==div**2
+                assert div2 == div**2
                 if verbose:
                     print("...div = {}".format(div))
             else:
@@ -1146,14 +1161,15 @@ def Billerey_P_l(E, l):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import Billerey_P_l
         sage: [Billerey_P_l(E,l) for l in primes(10)]
         [x^2 + 8143*x + 16777216,
-        x^2 + 451358*x + 282429536481,
-        x^4 - 664299076*x^3 + 205155493652343750*x^2 - 39595310449600219726562500*x + 3552713678800500929355621337890625,
-        x^4 - 207302404*x^3 - 377423798538689366394*x^2 - 39715249826471656586987520004*x + 36703368217294125441230211032033660188801]
+         x^2 + 451358*x + 282429536481,
+         x^4 - 664299076*x^3 + 205155493652343750*x^2 - 39595310449600219726562500*x + 3552713678800500929355621337890625,
+         x^4 - 207302404*x^3 - 377423798538689366394*x^2 - 39715249826471656586987520004*x + 36703368217294125441230211032033660188801]
     """
     K = E.base_field()
     qq = K.primes_above(l)
@@ -1182,16 +1198,17 @@ def Billerey_B_l(E,l,B=0):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import Billerey_B_l
         sage: [Billerey_B_l(E,l) for l in primes(15)]
         [1123077552537600,
-        227279663773903886745600,
-        0,
-        0,
-        269247154818492941287713746693964214802283882086400,
-        0]
+         227279663773903886745600,
+         0,
+         0,
+         269247154818492941287713746693964214802283882086400,
+         0]
     """
     d = E.base_field().absolute_degree()
     P = Billerey_P_l(E, l)
@@ -1223,6 +1240,7 @@ def Billerey_R_q(E, q, B=0):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import Billerey_R_q
@@ -1283,6 +1301,7 @@ def Billerey_B_bound(E, max_l=200, num_l=8, small_prime_bound=0, debug=False):
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import Billerey_B_bound
@@ -1322,7 +1341,7 @@ def Billerey_B_bound(E, max_l=200, num_l=8, small_prime_bound=0, debug=False):
             B1 = B1.prime_to_m_part(p)
         return B1
     ll = primes(5,max_l) # iterator
-    while B!=1 and len(ells)<num_l:
+    while B != 1 and len(ells) < num_l:
         try:
             l = next(ll)
             while B0.valuation(l):
@@ -1392,6 +1411,7 @@ def Billerey_R_bound(E, max_l=200, num_l=8, small_prime_bound=None, debug=False)
 
     EXAMPLES::
 
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import Billerey_R_bound
@@ -1501,22 +1521,23 @@ def reducible_primes_Billerey(E, num_l=None, max_l=None, verbose=False):
     EXAMPLES::
 
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import reducible_primes_Billerey
+        sage: x = polygen(ZZ, 'x')
         sage: K = NumberField(x**2 - 29, 'a'); a = K.gen()
         sage: E = EllipticCurve([1, 0, ((5 + a)/2)**2, 0, 0])
-        sage: reducible_primes_Billerey(E)
+        sage: reducible_primes_Billerey(E)  # long time
         [3, 5]
         sage: K = NumberField(x**2 + 1, 'a')
         sage: E = EllipticCurve_from_j(K(1728)) # CM over K
-        sage: reducible_primes_Billerey(E)
+        sage: reducible_primes_Billerey(E)  # long time
         [0]
         sage: E = EllipticCurve_from_j(K(0)) # CM but NOT over K
-        sage: reducible_primes_Billerey(E)
+        sage: reducible_primes_Billerey(E)  # long time
         [2, 3]
 
     An example where a prime is not reducible but passes the test::
 
         sage: E = EllipticCurve_from_j(K(2268945/128)).global_minimal_model() # c.f. [Sut2012]
-        sage: reducible_primes_Billerey(E)
+        sage: reducible_primes_Billerey(E)  # long time
         [7]
 
     TESTS:
@@ -1527,8 +1548,8 @@ def reducible_primes_Billerey(E, num_l=None, max_l=None, verbose=False):
         sage: j = 46969655/32768
         sage: E = EllipticCurve(j=K(j))
         sage: EK = E.change_ring(K)
-        sage: C = EK.isogeny_class(minimal_models=False)
-        sage: len(C)
+        sage: C = EK.isogeny_class(minimal_models=False)    # long time
+        sage: len(C)                                        # long time
         4
     """
     #verbose=True
@@ -1610,6 +1631,7 @@ def reducible_primes_naive(E, max_l=None, num_P=None, verbose=False):
     EXAMPLES::
 
         sage: from sage.schemes.elliptic_curves.gal_reps_number_field import reducible_primes_naive
+        sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^4 - 5*x^2 + 3)
         sage: E = EllipticCurve(K, [a^2 - 2, -a^2 + 3, a^2 - 2, -50*a^2 + 35, 95*a^2 - 67])
         sage: reducible_primes_naive(E,num_P=10)
@@ -1618,9 +1640,9 @@ def reducible_primes_naive(E, max_l=None, num_P=None, verbose=False):
         [2, 5, 197, 557, 653, 769]
         sage: reducible_primes_naive(E,num_P=20)
         [2, 5]
-        sage: reducible_primes_naive(E)
+        sage: reducible_primes_naive(E)  # long time
         [2, 5]
-        sage: [phi.degree() for phi in E.isogenies_prime_degree()]
+        sage: [phi.degree() for phi in E.isogenies_prime_degree()]  # long time
         [2, 2, 2, 5]
     """
     if max_l is None:
