@@ -61,27 +61,33 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 ######################################################################
 
-from sage.rings.integer_ring import   ZZ
-from sage.rings.rational_field import QQ
-from sage.rings.padics.factory import Qp
-from sage.rings.infinity import infinity
-from sage.rings.all import LaurentSeriesRing, PowerSeriesRing, PolynomialRing, Integers
-
-from sage.rings.integer import Integer
-from sage.arith.all import valuation, binomial, kronecker_symbol, gcd, prime_divisors, LCM
-
-from sage.structure.sage_object import SageObject
-from sage.structure.richcmp import richcmp_method, richcmp
-
-from sage.misc.functional import denominator
-from sage.misc.verbose import verbose, get_verbose
-
-from sage.modules.free_module_element import vector
-import sage.matrix.all as matrix
+from sage.matrix.constructor import matrix
 import sage.schemes.hyperelliptic_curves.monsky_washnitzer
+
+from sage.arith.functions import lcm as LCM
+from sage.arith.misc import (binomial,
+                             GCD as gcd,
+                             prime_divisors,
+                             kronecker as kronecker_symbol,
+                             valuation)
 from sage.functions.log import log
 from sage.functions.other import floor
 from sage.misc.cachefunc import cached_method
+from sage.misc.functional import denominator
+from sage.misc.verbose import get_verbose, verbose
+from sage.modules.free_module_element import vector
+from sage.rings.finite_rings.integer_mod_ring import IntegerModRing as Integers
+from sage.rings.infinity import infinity
+from sage.rings.integer import Integer
+from sage.rings.integer_ring import ZZ
+from sage.rings.laurent_series_ring import LaurentSeriesRing
+from sage.rings.padics.factory import Qp
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.power_series_ring import PowerSeriesRing
+from sage.rings.rational_field import QQ
+from sage.structure.richcmp import richcmp_method, richcmp
+from sage.structure.sage_object import SageObject
+
 
 @richcmp_method
 class pAdicLseries(SageObject):
@@ -143,7 +149,7 @@ class pAdicLseries(SageObject):
         sage: lp == loads(dumps(lp))
         True
     """
-    def __init__(self, E, p, implementation = 'eclib', normalize='L_ratio'):
+    def __init__(self, E, p, implementation='eclib', normalize='L_ratio'):
         r"""
         INPUT:
 
@@ -218,7 +224,7 @@ class pAdicLseries(SageObject):
             sage: lp1 == lp3
             False
         """
-        if type(self) != type(other):
+        if type(self) is not type(other):
             return NotImplemented
         return richcmp((self._E, self._p), (other._E, other._p), op)
 
@@ -337,7 +343,7 @@ class pAdicLseries(SageObject):
                 return -sum([kronecker_symbol(D, u) * m(r + ZZ(u) / D)
                              for u in range(1, -D)])
 
-    def measure(self, a, n, prec, quadratic_twist=+1, sign = +1):
+    def measure(self, a, n, prec, quadratic_twist=+1, sign=+1):
         r"""
         Return the measure on `\ZZ_p^{\times}` defined by
 
@@ -438,7 +444,7 @@ class pAdicLseries(SageObject):
             if self._E.conductor() % p == 0:
                 mu = chip**n * z * sum([kronecker_symbol(D,u) * f(a/(p*w)+ZZ(u)/D) for u in range(1,D.abs())])
             else:
-                mu = chip**n * z * sum([kronecker_symbol(D,u) *( f(a/(p*w)+ZZ(u)/D) - chip /alpha * f(a/w+ZZ(u)/D) ) for u in range(1,D.abs())])
+                mu = chip**n * z * sum([kronecker_symbol(D,u) * ( f(a/(p*w)+ZZ(u)/D) - chip / alpha * f(a/w+ZZ(u)/D) ) for u in range(1,D.abs())])
             return s*mu
 
     def alpha(self, prec=20):
@@ -862,7 +868,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
             raise ValueError("Insufficient precision (%s)" % prec)
 
         # check if the conditions on quadratic_twist are satisfied
-        eta = ZZ(eta) % (self._p- 1) if self._p != 2 else ZZ(eta) % 2
+        eta = ZZ(eta) % (self._p - 1) if self._p != 2 else ZZ(eta) % 2
         D = ZZ(quadratic_twist)
         if D != 1:
             if eta != 0:
@@ -870,20 +876,20 @@ class pAdicLseriesOrdinary(pAdicLseries):
             if D % 4 == 0:
                 d = D//4
                 if not d.is_squarefree() or d % 4 == 1:
-                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field"%D)
+                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field" % D)
             else:
                 if not D.is_squarefree() or D % 4 != 1:
-                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field"%D)
+                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field" % D)
             if gcd(D,self._p) != 1:
-                raise ValueError("quadratic twist (=%s) must be coprime to p (=%s) "%(D,self._p))
+                raise ValueError("quadratic twist (=%s) must be coprime to p (=%s) " % (D,self._p))
             if gcd(D, self._E.conductor()) != 1:
                 for ell in prime_divisors(D):
                     if valuation(self._E.conductor(), ell) > valuation(D, ell):
-                        raise ValueError("cannot twist a curve of conductor (=%s) by the quadratic twist (=%s)."%(self._E.conductor(),D))
+                        raise ValueError("cannot twist a curve of conductor (=%s) by the quadratic twist (=%s)." % (self._E.conductor(),D))
         p = self._p
         si = 1-2*(eta % 2)
 
-        #verbose("computing L-series for p=%s, n=%s, and prec=%s"%(p,n,prec))
+        # verbose("computing L-series for p=%s, n=%s, and prec=%s" % (p,n,prec))
 
         if prec == 1:
             if eta == 0:
@@ -909,13 +915,13 @@ class pAdicLseriesOrdinary(pAdicLseries):
             bounds = self._prec_bounds(n,prec,sign=si)
             padic_prec = max(bounds[1:]) + 5
 
-        verbose("using p-adic precision of %s"%padic_prec)
+        verbose("using p-adic precision of %s" % padic_prec)
 
         if p == 2:
             res_series_prec = min(p**(n-2), prec)
         else:
             res_series_prec = min(p**(n-1), prec)
-        verbose("using series precision of %s"%res_series_prec)
+        verbose("using series precision of %s" % res_series_prec)
 
         ans = self._get_series_from_cache(n, res_series_prec,D,eta)
         if ans is not None:
@@ -936,17 +942,17 @@ class pAdicLseriesOrdinary(pAdicLseries):
             a_range = 3
         else:
             teich = self.teichmuller(padic_prec)
-            gamma = K(1+ p)
+            gamma = K(1 + p)
             p_power = p**(n-1)
             a_range = p
 
-        verbose("Now iterating over %s summands"%((p-1)*p_power))
+        verbose("Now iterating over %s summands" % ((p-1)*p_power))
         verbose_level = get_verbose()
         count_verb = 0
         for j in range(p_power):
             s = K(0)
             if verbose_level >= 2 and j/p_power*100 > count_verb + 3:
-                verbose("%.2f percent done"%(float(j)/p_power*100))
+                verbose("%.2f percent done" % (float(j)/p_power*100))
                 count_verb += 3
             for a in range(1,a_range):
                 b = teich[a] * gamma_power
@@ -955,7 +961,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
             one_plus_T_factor *= 1+T
             gamma_power *= gamma
 
-        verbose("the series before adjusting the precision is %s"%L)
+        verbose("the series before adjusting the precision is %s" % L)
         # Now create series but with each coefficient truncated
         # so it is proven correct:
         K = Qp(p, padic_prec, print_mode='series')
@@ -1046,7 +1052,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
         if E.galois_representation().is_irreducible(p):
             return 0
 
-        if self._implementation=="sage":
+        if self._implementation == "sage":
             m = E.modular_symbol_space(sign=1)
             b = m.boundary_map().codomain()
             C = b._known_cusps()  # all known, since computed the boundary map
@@ -1064,7 +1070,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
         # else the same reasoning as in _set_denom in numerical
         # modular symbol. We rely on the fact that p is semistable
         from sage.databases.cremona import CremonaDatabase
-        isog =  E.isogeny_class()
+        isog = E.isogeny_class()
         t = 0
         if N <= CremonaDatabase().largest_conductor():
             E0 = E.optimal_curve()
@@ -1089,7 +1095,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
             if p == 2:
                 t += 1
         if p == 2 and E0.real_components() == 1:
-                t += 1 # slanted lattice
+            t += 1  # slanted lattice
 
         # this was the bound for E0 now compare periods
         # to get the bound for E
@@ -1106,7 +1112,7 @@ class pAdicLseriesOrdinary(pAdicLseries):
             if E0.real_components() == 1:
                 om0 *= 2
         m = max(isog.matrix().list())
-        q = (om/om0 *m).round()/m
+        q = (om/om0 * m).round()/m
         t += valuation(q,p)
         return max(t,0)
 
@@ -1221,7 +1227,7 @@ class pAdicLseriesSupersingular(pAdicLseries):
             if D % 4 == 0:
                 d = D//4
                 if not d.is_squarefree() or d % 4 == 1:
-                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field"%D)
+                    raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field" % D)
             else:
                 if not D.is_squarefree() or D % 4 != 1:
                     raise ValueError("quadratic_twist (=%s) must be a fundamental discriminant of a quadratic field" % D)
@@ -1277,18 +1283,18 @@ class pAdicLseriesSupersingular(pAdicLseries):
             a_range = 3
         else:
             teich = self.teichmuller(padic_prec)
-            gamma = 1+ p
+            gamma = 1 + p
             p_power = p**(n-1)
             a_range = p
         si = 1-2*(eta % 2)
 
-        verbose("Now iterating over %s summands"%((p-1)*p_power))
+        verbose("Now iterating over %s summands" % ((p-1)*p_power))
         verbose_level = get_verbose()
         count_verb = 0
         for j in range(p_power):
             s = K(0)
             if verbose_level >= 2 and j/p_power*100 > count_verb + 3:
-                verbose("%.2f percent done"%(float(j)/p_power*100))
+                verbose("%.2f percent done" % (float(j)/p_power*100))
                 count_verb += 3
             for a in range(1,a_range):
                 b = teich[a] * gamma_power
@@ -1369,7 +1375,7 @@ class pAdicLseriesSupersingular(pAdicLseries):
         return [infinity] + [2 * e[j] - c0 for j in range(1, len(e))]
 
     def _poly(self, a):
-        """
+        r"""
         Given an element a in Qp[alpha] this returns the list
         containing the two coordinates in Qp.
 
@@ -1387,15 +1393,15 @@ class pAdicLseriesSupersingular(pAdicLseries):
         # this should be implemented in elements of Eisenstein rings at some point trac 20248
 
         if a.is_zero():
-            return [0,0]
+            return [0, 0]
         v, k = a._ntl_rep_abs()
         K = a.base_ring()
         pi = K.uniformiser()
-        v0 =  K(v[0]._sage_()) * pi**k
-        v1 =  K(v[1]._sage_()) * pi**k
+        v0 = K(v[0]._sage_()) * pi**k
+        v1 = K(v[1]._sage_()) * pi**k
         alpha = a.parent().gen()
-        assert v0 + v1*alpha == a
-        return [ v0, v1 ]
+        assert v0 + v1 * alpha == a
+        return [v0, v1]
 
     def Dp_valued_series(self, n=3, quadratic_twist=+1, prec=5):
         r"""
@@ -1431,8 +1437,8 @@ class pAdicLseriesSupersingular(pAdicLseries):
         lps = self.series(n, quadratic_twist=quadratic_twist, prec=prec)
 
         # now split up the series in two lps = G + H * alpha
-        R = lps.base_ring().base_ring() # Qp
-        QpT , T = PowerSeriesRing(R, 'T', prec).objgen()
+        R = lps.base_ring().base_ring()  # Qp
+        QpT, T = PowerSeriesRing(R, 'T', prec).objgen()
         Gli = []
         Hli = []
         for n in range(lps.prec()):
@@ -1443,10 +1449,10 @@ class pAdicLseriesSupersingular(pAdicLseries):
         H = QpT(Hli, prec)
 
         # now compute phi
-        phi = matrix.matrix([[0,-1/p],[1,E.ap(p)/p]])
-        lpv = vector([G  + (E.ap(p))*H  , - R(p) * H ])  # this is L_p
-        eps = (1-phi)**(-2)
-        resu = lpv*eps.transpose()
+        phi = matrix([[0, -1 / p], [1, E.ap(p) / p]])
+        lpv = vector([G + (E.ap(p)) * H, - R(p) * H])  # this is L_p
+        eps = (1 - phi)**(-2)
+        resu = lpv * eps.transpose()
         return resu
 
     def frobenius(self, prec=20, algorithm="mw"):
@@ -1478,8 +1484,8 @@ class pAdicLseriesSupersingular(pAdicLseries):
         """
         E = self._E
         p = self._p
-        if algorithm != "mw" and algorithm !="approx":
-            raise ValueError("Unknown algorithm %s."%algorithm)
+        if algorithm != "mw" and algorithm != "approx":
+            raise ValueError("Unknown algorithm %s." % algorithm)
         if algorithm == "approx":
             return self.__phi_bpr(prec=prec)
         if p < 4 and algorithm == "mw":
@@ -1492,28 +1498,27 @@ class pAdicLseriesSupersingular(pAdicLseries):
         Q = x**3 + modprecring(Ew.a4()) * x + modprecring(Ew.a6())
         trace = Ew.ap(p)
         fr = sage.schemes.hyperelliptic_curves.monsky_washnitzer.matrix_of_frobenius(Q, p, adjusted_prec, trace)
-        fr = matrix.matrix(output_ring,2,2,fr)
+        fr = matrix(output_ring,2,2,fr)
 
         # return a vector for PARI's ellchangecurve to pass from e1 to e2
-        def isom(e1,e2):
+        def isom(e1, e2):
             if not e1.is_isomorphic(e2):
                 raise ValueError("Curves must be isomorphic.")
-            usq = (e1.discriminant()/e2.discriminant()).nth_root(6)
+            usq = (e1.discriminant() / e2.discriminant()).nth_root(6)
             u = usq.sqrt()
-            s = (u   *  e2.a1() - e1.a1() )/ZZ(2)
-            r = (usq *  e2.a2() - e1.a2() + s**2 + e1.a1()*s)/ZZ(3)
-            t = (u**3 * e2.a3() - e1.a3() - e1.a1()*r)/ZZ(2)
-            return [u,r,s,t]
+            s = (u * e2.a1() - e1.a1()) / ZZ(2)
+            r = (usq * e2.a2() - e1.a2() + s**2 + e1.a1()*s) / ZZ(3)
+            t = (u**3 * e2.a3() - e1.a3() - e1.a1()*r) / ZZ(2)
+            return [u, r, s, t]
 
-        v = isom(E,Ew)
+        v = isom(E, Ew)
         u = v[0]
         r = v[1]
 
         # change basis
-        A = matrix.matrix([[u,-r/u],[0,1/u]])
+        A = matrix([[u, -r/u], [0, 1/u]])
         frn = A * fr * A**(-1)
-        return 1/p*frn
-
+        return 1 / p*frn
 
     def __phi_bpr(self, prec=0):
         r"""
@@ -1550,9 +1555,9 @@ class pAdicLseriesSupersingular(pAdicLseries):
             print("Warning: Very large value for the precision.")
         if prec == 0:
             prec = floor((log(10000)/log(p)))
-            verbose("prec set to %s"%prec)
+            verbose("prec set to %s" % prec)
         eh = E.formal()
-        om = eh.differential(prec = p**prec+3)
+        om = eh.differential(prec=p**prec+3)
         verbose("differential computed")
         xt = eh.x(prec=p**prec + 3)
         et = xt*om
@@ -1566,31 +1571,33 @@ class pAdicLseriesSupersingular(pAdicLseries):
         for k in range(1,prec+1):
             # this is the equation eq[0]*x+eq[1]*y+eq[2] == 0
             # such that delta_ = delta + d^dpr*x ...
-            eq = [(p**dpr*cs[k]) % p**k,(-p**dga*ds[k]) % p**k , (delta*cs[k]-gamma*ds[k]-cs[k-1]) % p**k ]
+            eq = [(p**dpr*cs[k]) % p**k,
+                  (-p**dga*ds[k]) % p**k,
+                  (delta*cs[k]-gamma*ds[k]-cs[k-1]) % p**k]
             verbose("valuations : %s" % ([x.valuation(p) for x in eq]))
-            v = min([x.valuation(p) for x in eq])
+            v = min(x.valuation(p) for x in eq)
             if v == infinity:
-                verbose("no new information at step k=%s"%k)
+                verbose("no new information at step k=%s" % k)
             else:
                 eq = [ZZ(x/p**v) for x in eq]
-                verbose("renormalised eq mod p^%s is now %s"%(k-v,eq))
+                verbose("renormalised eq mod p^%s is now %s" % (k-v,eq))
                 if eq[0].valuation(p) == 0:
                     l = min(eq[1].valuation(p),k-v)
                     if l == 0:
-                        verbose("not uniquely determined at step k=%s"%k)
+                        verbose("not uniquely determined at step k=%s" % k)
                     else:
                         ainv = eq[0].inverse_mod(p**l)
                         delta = delta - eq[2]*ainv*p**dpr
                         dpr = dpr + l
                         delta = delta % p**dpr
-                        verbose("delta_prec increased to %s\n delta is now %s"%(dpr,delta))
+                        verbose("delta_prec increased to %s\n delta is now %s" % (dpr,delta))
                 elif eq[1].valuation(p) == 0:
                     l = min(eq[0].valuation(p),k-v)
                     ainv = eq[1].inverse_mod(p**l)
                     gamma = gamma - eq[2]*ainv*p**dga
                     dga = dga + l
                     gamma = gamma % p**dga
-                    verbose("gamma_prec increased to %s\n gamma is now %s"%(dga,gamma))
+                    verbose("gamma_prec increased to %s\n gamma is now %s" % (dga,gamma))
                 else:
                     raise RuntimeError("Bug: no delta or gamma can exist")
 
@@ -1598,12 +1605,12 @@ class pAdicLseriesSupersingular(pAdicLseries):
         R = Qp(p,max(dpr,dga)+1)
         delta = R(delta,absprec=dpr)
         gamma = R(gamma,absprec=dga)
-        verbose("result delta = %s\n      gamma = %s\n check : %s"%(delta,gamma, [Qp(p,k)(delta * cs[k] - gamma * ds[k] - cs[k-1]) for k in range(1,prec+1)] ))
+        verbose("result delta = %s\n      gamma = %s\n check : %s" % (delta,gamma, [Qp(p,k)(delta * cs[k] - gamma * ds[k] - cs[k-1]) for k in range(1,prec+1)] ))
         a = delta
         c = -gamma
         d = E.ap(p) - a
         b = (-1/p+a*d)/c
-        phi = matrix.matrix([[a,b],[c,d]])
+        phi = matrix([[a,b],[c,d]])
         return phi
 
     def bernardi_sigma_function(self, prec=20):
@@ -1665,7 +1672,9 @@ class pAdicLseriesSupersingular(pAdicLseries):
         elog = Ehat.log(prec + Integer(3))
 
         # we will have to do it properly with David Harvey's _multiply_point()
-        n = LCM(E.tamagawa_numbers())
+        # import here to avoid circular import
+        from sage.schemes.elliptic_curves.padics import _multiple_to_make_good_reduction
+        n = _multiple_to_make_good_reduction(E)
         n = LCM(n, E.Np(p)) # allowed here because E has good reduction at p
 
         def height(P,check=True):
@@ -1680,15 +1689,15 @@ class pAdicLseriesSupersingular(pAdicLseries):
             tt = R(tt)
             zz = elog(tt)
 
-            homega = -zz**2/n**2
+            homega = -zz**2 / n**2
 
-            eQ = denominator(Q[1])/denominator(Q[0])
+            eQ = denominator(Q[1]) / denominator(Q[0])
             si = self.bernardi_sigma_function(prec=prec+4)
-            heta =  2 * log(si(zz)/eQ) / n**2
+            heta = 2 * log(si(zz)/eQ) / n**2
 
-            R = Qp(p,prec)
+            R = Qp(p, prec)
 
-            return vector([-R(heta),R(homega)])
+            return vector([-R(heta), R(homega)])
 
         return height
 
@@ -1715,12 +1724,12 @@ class pAdicLseriesSupersingular(pAdicLseries):
         p = self._p
         E = self._E
 
-        h =  self.Dp_valued_height(prec=prec)
+        h = self.Dp_valued_height(prec=prec)
 
         # this is the height_{v} (P) for a v in D_p
-        def hv(vec,P):
+        def hv(vec, P):
             hP = h(P)
-            return - vec[0]*hP[1] +vec[1]*hP[0]
+            return - vec[0]*hP[1] + vec[1]*hP[0]
 
         #    def hvpairing(vec,P,Q):
         #        return (hv(vec,    P+Q) - hv(vec,P)-hv(vec,Q))/2
@@ -1739,11 +1748,11 @@ class pAdicLseriesSupersingular(pAdicLseries):
         basis = E.gens()
 
         def regv(vec):
-            M = matrix.matrix(K, rk, rk, 0)
+            M = matrix(K, rk, rk, 0)
             point_height = [hv(vec, P) for P in basis]
             for i in range(rk):
                 for j in range(i+1, rk):
-                    M[i, j] = M[j, i] = (hv(vec,basis[i] + basis[j])- point_height[i] - point_height[j] )/2
+                    M[i, j] = M[j, i] = (hv(vec,basis[i] + basis[j]) - point_height[i] - point_height[j] )/2
             for i in range(rk):
                 M[i, i] = point_height[i]
 
