@@ -2,7 +2,7 @@
 #
 # All these methods are imported in EllipticCurve_rational_field,
 # so there is no reason to add this module to the documentation.
-"""
+r"""
 Miscellaneous `p`-adic methods
 """
 
@@ -21,25 +21,31 @@ Miscellaneous `p`-adic methods
 #                  https://www.gnu.org/licenses/
 ######################################################################
 
-
-import sage.rings.all as rings
-from . import padic_lseries as plseries
-import sage.arith.all as arith
-from sage.rings.all import (
-    Qp, Zp,
-    Integers,
-    Integer,
-    O,
-    PowerSeriesRing,
-    LaurentSeriesRing,
-    RationalField)
 import math
-import sage.misc.misc as misc
-import sage.matrix.all as matrix
-sqrt = math.sqrt
-import sage.schemes.hyperelliptic_curves.monsky_washnitzer
+
+from sage.arith.functions import lcm as LCM
+from sage.arith.misc import valuation
+from sage.matrix.constructor import matrix
+from sage.misc.misc import newton_method_sizes
+from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
+from sage.rings.padics.factory import Qp as pAdicField
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 import sage.schemes.hyperelliptic_curves.hypellfrob
+import sage.schemes.hyperelliptic_curves.monsky_washnitzer
+
 from sage.misc.cachefunc import cached_method
+from sage.rings.big_oh import O
+from sage.rings.finite_rings.integer_mod_ring import IntegerModRing as Integers
+from sage.rings.integer import Integer
+from sage.rings.laurent_series_ring import LaurentSeriesRing
+from sage.rings.padics.factory import Qp, Zp
+from sage.rings.power_series_ring import PowerSeriesRing
+from sage.rings.rational_field import RationalField
+
+from . import padic_lseries as plseries
+
+sqrt = math.sqrt
+
 
 def __check_padic_hypotheses(self, p):
     r"""
@@ -58,7 +64,7 @@ def __check_padic_hypotheses(self, p):
         ArithmeticError: p must be a good ordinary prime
 
     """
-    p = rings.Integer(p)
+    p = Integer(p)
     if not p.is_prime():
         raise ValueError("p = (%s) must be prime" % p)
     if p == 2:
@@ -98,8 +104,10 @@ def _normalize_padic_lseries(self, p, normalize, implementation, precision):
         raise ValueError("Implementation should be one of  'sage', 'eclib', 'num' or 'pollackstevens'")
     return (p, normalize, implementation, precision)
 
+
 @cached_method(key=_normalize_padic_lseries)
-def padic_lseries(self, p, normalize = None, implementation = 'eclib', precision = None):
+def padic_lseries(self, p, normalize=None, implementation='eclib',
+                  precision=None):
     r"""
     Return the `p`-adic `L`-series of self at
     `p`, which is an object whose approx method computes
@@ -176,10 +184,10 @@ def padic_lseries(self, p, normalize = None, implementation = 'eclib', precision
         sage: L = e.padic_lseries(3, implementation = 'sage')
         sage: L.series(5,prec=10)
         2 + 3 + 3^2 + 2*3^3 + 2*3^5 + 3^6 + O(3^7) + (1 + 3 + 2*3^2 + 3^3 + O(3^4))*T + (1 + 2*3 + O(3^4))*T^2 + (3 + 2*3^2 + O(3^3))*T^3 + (2*3 + 3^2 + O(3^3))*T^4 + (2 + 2*3 + 2*3^2 + O(3^3))*T^5 + (1 + 3^2 + O(3^3))*T^6 + (2 + 3^2 + O(3^3))*T^7 + (2 + 2*3 + 2*3^2 + O(3^3))*T^8 + (2 + O(3^2))*T^9 + O(T^10)
-        
+
     Also the numerical modular symbols can be used.
-    This may allow for much larger conductor in some instances::   
-    
+    This may allow for much larger conductor in some instances::
+
         sage: E = EllipticCurve([101,103])
         sage: L = E.padic_lseries(5, implementation="num")
         sage: L.series(2)
@@ -203,22 +211,22 @@ def padic_lseries(self, p, normalize = None, implementation = 'eclib', precision
         sage: L[3]
         O(11^0)
     """
-    p, normalize, implementation, precision = self._normalize_padic_lseries(p,\
-                             normalize, implementation, precision)
+    p, normalize, implementation, precision = self._normalize_padic_lseries(p,
+        normalize, implementation, precision)
 
     if implementation in ['sage', 'eclib', 'num']:
         if self.ap(p) % p != 0:
             Lp = plseries.pAdicLseriesOrdinary(self, p,
-                                  normalize = normalize, implementation = implementation)
+                                  normalize=normalize, implementation=implementation)
         else:
             Lp = plseries.pAdicLseriesSupersingular(self, p,
-                                  normalize = normalize, implementation = implementation)
+                                  normalize=normalize, implementation=implementation)
     else:
         phi = self.pollack_stevens_modular_symbol(sign=0)
         if phi.parent().level() % p == 0:
-            Phi = phi.lift(p, precision, eigensymbol = True)
+            Phi = phi.lift(p, precision, eigensymbol=True)
         else:
-            Phi = phi.p_stabilize_and_lift(p, precision, eigensymbol = True)
+            Phi = phi.p_stabilize_and_lift(p, precision, eigensymbol=True)
         Lp = Phi.padic_lseries()  #mm TODO should this pass precision on too ?
         Lp._cinf = self.real_components()
     return Lp
@@ -227,6 +235,8 @@ def padic_lseries(self, p, normalize = None, implementation = 'eclib', precision
 def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
     r"""
     Compute the cyclotomic `p`-adic regulator of this curve.
+    The model of the curve needs to be integral and minimal at `p`.
+    Moreover the reduction at `p` should not be additive.
 
     INPUT:
 
@@ -241,16 +251,11 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
     - ``check_hypotheses`` -- boolean, whether to check
       that this is a curve for which the p-adic height makes sense
 
-    OUTPUT: The p-adic cyclotomic regulator of this curve, to the
+    OUTPUT: The `p`-adic cyclotomic regulator of this curve, to the
     requested precision.
 
     If the rank is 0, we output 1.
 
-    .. TODO::
-
-        Remove restriction that curve must be in minimal
-        Weierstrass form. This is currently required for E.gens().
-
     AUTHORS:
 
     - Liang Xiao: original implementation at the 2006 MSRI
@@ -287,7 +292,7 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
         sage: max_prec = 30    # make sure we get past p^2    # long time
         sage: full = E.padic_regulator(5, max_prec)           # long time
         sage: for prec in range(1, max_prec):                 # long time
-        ....:     assert E.padic_regulator(5, prec) == full   # long time
+        ....:     assert E.padic_regulator(5, prec) == full
 
     A case where the generator belongs to the formal group already
     (:trac:`3632`)::
@@ -303,7 +308,7 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
         sage: E.padic_regulator(7) == Em.padic_regulator(7)
         True
 
-    Allow a Python int as input::
+    Allow a python int as input::
 
         sage: E = EllipticCurve('37a')
         sage: E.padic_regulator(int(5))
@@ -312,7 +317,7 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
     p = Integer(p)  # this is assumed in code below
     if check_hypotheses:
         if not p.is_prime():
-            raise ValueError("p = (%s) must be prime"%p)
+            raise ValueError("p = (%s) must be prime" % p)
         if p == 2:
             raise ValueError("p must be odd")   # todo
         if self.conductor() % (p**2) == 0:
@@ -338,9 +343,10 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
 def padic_height_pairing_matrix(self, p, prec=20, height=None, check_hypotheses=True):
     r"""
     Computes the cyclotomic `p`-adic height pairing matrix of
-    this curve with respect to the basis self.gens() for the
-    Mordell-Weil group for a given odd prime p of good ordinary
+    this curve with respect to the basis ``self.gens()`` for the
+    Mordell-Weil group for a given odd prime `p` of good ordinary
     reduction.
+    The model needs to be integral and minimal at `p`.
 
     INPUT:
 
@@ -355,14 +361,9 @@ def padic_height_pairing_matrix(self, p, prec=20, height=None, check_hypotheses=
     - ``check_hypotheses`` -- boolean, whether to check
       that this is a curve for which the p-adic height makes sense
 
-    OUTPUT: The p-adic cyclotomic height pairing matrix of this curve
+    OUTPUT: The `p`-adic cyclotomic height pairing matrix of this curve
     to the given precision.
 
-    .. TODO::
-
-        remove restriction that curve must be in minimal
-        Weierstrass form. This is currently required for E.gens().
-
     AUTHORS:
 
     - David Harvey, Liang Xiao, Robert Bradshaw, Jennifer
@@ -401,7 +402,7 @@ def padic_height_pairing_matrix(self, p, prec=20, height=None, check_hypotheses=
     K = Qp(p, prec=prec)
 
     rank = self.rank()
-    M = matrix.matrix(K, rank, rank, 0)
+    M = matrix(K, rank, rank, 0)
     if rank == 0:
         return M
 
@@ -423,14 +424,14 @@ def padic_height_pairing_matrix(self, p, prec=20, height=None, check_hypotheses=
 
 def _multiply_point(E, R, P, m):
     r"""
-    Computes coordinates of a multiple of P with entries in a ring.
+    Computes coordinates of a multiple of `P` with entries in a ring.
 
     INPUT:
 
-    - ``E`` -- elliptic curve over Q with integer
+    - ``E`` -- elliptic curve over `\QQ` with integer
       coefficients
 
-    - ``P`` -- a rational point on P that reduces to a
+    - ``P`` -- a rational point on `P` that reduces to a
       non-singular point at all primes
 
     - ``R`` -- a ring in which 2 is invertible (typically
@@ -450,8 +451,7 @@ def _multiply_point(E, R, P, m):
     that the sign for `b'` will match the sign for
     `d'`.
 
-    ALGORITHM: Proposition 9 of "Efficient Computation of p-adic
-    Heights" (David Harvey, to appear in LMS JCM).
+    ALGORITHM: Proposition 9 in [Har2009]_.
 
     Complexity is soft-`O(\log L \log m + \log^2 m)`.
 
@@ -579,12 +579,89 @@ def _multiply_point(E, R, P, m):
 
     return theta, omega, psi_m * d
 
+def _multiple_to_make_good_reduction(E):
+    r"""
+    Return the integer `n_2` such that for all points `P` in `E(\QQ)`
+    `n_2*P` has good reduction at all primes.
+    If the model is globally minimal the lcm of the
+    Tamagawa numbers will do, otherwise we have to take into
+    account the change of the model.
+
+    INPUT:
+
+    - ``E`` -- an elliptic curve over `\QQ`
+
+    OUTPUT:
+
+    - a positive integer ``n2``
+
+    EXAMPLE (:trac:`34790`)::
+
+        sage: from sage.schemes.elliptic_curves.padics import _multiple_to_make_good_reduction
+        sage: E = EllipticCurve([-1728,-100656])
+        sage: _multiple_to_make_good_reduction(E)
+        30
+
+    The number ``n_2`` is not always optimal but it is in this example.
+    The first multiple of the generator `P` with good reduction in this
+    non-minimal model is `30 P`.
+
+    TESTS::
+
+        sage: from sage.schemes.elliptic_curves.padics import _multiple_to_make_good_reduction
+        sage: E = EllipticCurve([1/2,1/3])
+        sage: _multiple_to_make_good_reduction(E)
+        Traceback (most recent call last):
+        ...
+        NotImplementedError: This only implemented for integral models. Please change the model first.
+        sage: E = EllipticCurve([0,3])
+        sage: _multiple_to_make_good_reduction(E)
+        1
+        sage: E = EllipticCurve([0,5^7]) # min eq is additive
+        sage: _multiple_to_make_good_reduction(E)
+        5
+        sage: E = EllipticCurve([7,0,0,0,7^7]) # min eq is split mult
+        sage: _multiple_to_make_good_reduction(E)
+        6
+        sage: E = EllipticCurve([0,-3^2,0,0,3^7]) # min eq is non-split mult
+        sage: _multiple_to_make_good_reduction(E)
+        4
+
+    """
+    if not E.is_integral():
+        st = ("This only implemented for integral models. "
+              "Please change the model first.")
+        raise NotImplementedError(st)
+    if E.is_minimal():
+        n2 = LCM(E.tamagawa_numbers())
+    else:
+        # generalising to number fields one can get the u from local_data
+        Emin = E.global_minimal_model()
+        iota = E.isomorphism_to(Emin)
+        u = Integer(iota.u)
+        ps = u.prime_divisors()
+        li = []
+        for p in ps:
+            np = u.valuation(p)
+            if Emin.discriminant() %p != 0:
+                li.append(Emin.Np(p) * p**(np-1))
+            elif Emin.has_additive_reduction(p):
+                li.append(E.tamagawa_number(p) * p**np)
+            elif E.has_split_multiplicative_reduction(p):
+                li.append(E.tamagawa_number(p) * (p-1) * p**(np-1))
+            else: # non split
+                li.append(E.tamagawa_number(p) * (p+1) * p**(np-1))
+        otherbad = Integer(Emin.discriminant()).prime_divisors()
+        otherbad = [p for p in otherbad if u%p != 0 ]
+        li += [E.tamagawa_number(p) for p in otherbad]
+        n2 = LCM(li)
+    return n2
 
 def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
     r"""
-    Compute the cyclotomic p-adic height.
+    Compute the cyclotomic `p`-adic height.
 
-    The equation of the curve must be minimal at `p`.
+    The equation of the curve must be integral and minimal at `p`.
 
     INPUT:
 
@@ -601,7 +678,7 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
 
     OUTPUT: A function that accepts two parameters:
 
-    - a Q-rational point on the curve whose height should be computed
+    - a `\QQ`-rational point on the curve whose height should be computed
 
     - optional boolean flag 'check': if False, it skips some input
       checking, and returns the p-adic height of that point to the
@@ -609,8 +686,8 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
 
     - The normalization (sign and a factor 1/2 with respect to some other
       normalizations that appear in the literature) is chosen in such a way
-      as to make the p-adic Birch Swinnerton-Dyer conjecture hold as stated
-      in [Mazur-Tate-Teitelbaum].
+      as to make the `p`-adic Birch Swinnerton-Dyer conjecture hold as stated
+      in [MTT1986]_.
 
     AUTHORS:
 
@@ -658,7 +735,7 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
         sage: max_prec = 30    # make sure we get past p^2    # long time
         sage: full = E.padic_height(5, max_prec)(P)           # long time
         sage: for prec in range(1, max_prec):                 # long time
-        ....:     assert E.padic_height(5, prec)(P) == full   # long time
+        ....:     assert E.padic_height(5, prec)(P) == full
 
     A supersingular prime for a curve::
 
@@ -698,7 +775,7 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
 
     TESTS:
 
-    Check that ticket :trac:`20798` is solved::
+    Check that issue :trac:`20798` is solved::
 
         sage: E = EllipticCurve("91b")
         sage: h = E.padic_height(7,10)
@@ -710,7 +787,7 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
     """
     if check_hypotheses:
         if not p.is_prime():
-            raise ValueError("p = (%s) must be prime"%p)
+            raise ValueError("p = (%s) must be prime" % p)
         if p == 2:
             raise ValueError("p must be odd")   # todo
         if self.conductor() % (p**2) == 0:
@@ -729,16 +806,15 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
 
     # else good ordinary case
 
-    # For notation and definitions, see "Efficient Computation of
-    # p-adic Heights", David Harvey (unpublished)
+    # For notation and definitions, see [Har2009]_.
 
-    n1 = self.change_ring(rings.GF(p)).cardinality()
-    n2 = arith.LCM(self.tamagawa_numbers())
-    n = arith.LCM(n1, n2)
+    n1 = self.change_ring(GF(p)).cardinality()
+    n2 = _multiple_to_make_good_reduction(self)
+    n = LCM(n1, n2)
     m = int(n / n2)
 
-    adjusted_prec = prec + 2 * arith.valuation(n, p)   # this is M'
-    R = rings.Integers(p ** adjusted_prec)
+    adjusted_prec = prec + 2 * valuation(n, p)   # this is M'
+    R = Integers(p ** adjusted_prec)
 
     if sigma is None:
         sigma = self.padic_sigma(p, adjusted_prec, check_hypotheses=False)
@@ -781,15 +857,13 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
                    "answer with precision at least prec, but we didn't."
         return K(answer)
 
-
     # (man... I love python's local function definitions...)
     return height
 
 
-
 def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
     r"""
-    Computes the cyclotomic p-adic height.
+    Computes the cyclotomic `p`-adic height.
 
     The equation of the curve must be minimal at `p`.
 
@@ -802,7 +876,7 @@ def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
 
     - ``E2`` -- precomputed value of E2. If not supplied,
       this function will call padic_E2 to compute it. The value supplied
-      must be correct mod `p^(prec-2)` (or slightly higher in the
+      must be correct mod `p^{prec-2}` (or slightly higher in the
       anomalous case; see the code for details).
 
     - ``check_hypotheses`` -- boolean, whether to check
@@ -810,22 +884,21 @@ def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
 
     OUTPUT: A function that accepts two parameters:
 
-    - a Q-rational point on the curve whose height should be computed
+    - a `\QQ`-rational point on the curve whose height should be computed
 
     - optional boolean flag 'check': if False, it skips some input
-      checking, and returns the p-adic height of that point to the
+      checking, and returns the `p`-adic height of that point to the
       desired precision.
 
     - The normalization (sign and a factor 1/2 with respect to some other
       normalizations that appear in the literature) is chosen in such a way
       as to make the p-adic Birch Swinnerton-Dyer conjecture hold as stated
-      in [Mazur-Tate-Teitelbaum].
+      in [MTT1986]_.
 
     AUTHORS:
 
     - David Harvey (2008-01): based on the padic_height() function,
-      using the algorithm of"Computing p-adic heights via
-      point multiplication"
+      using the algorithm of [Har2009]_.
 
     EXAMPLES::
 
@@ -860,11 +933,11 @@ def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
         sage: max_prec = 30    # make sure we get past p^2    # long time
         sage: full = E.padic_height(5, max_prec)(P)           # long time
         sage: for prec in range(2, max_prec):                 # long time
-        ....:     assert E.padic_height_via_multiply(5, prec)(P) == full   # long time
+        ....:     assert E.padic_height_via_multiply(5, prec)(P) == full
     """
     if check_hypotheses:
         if not p.is_prime():
-            raise ValueError("p = (%s) must be prime"%p)
+            raise ValueError("p = (%s) must be prime" % p)
         if p == 2:
             raise ValueError("p must be odd")   # todo
         if self.conductor() % p == 0:
@@ -876,18 +949,17 @@ def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
     if prec < 1:
         raise ValueError("prec (=%s) must be at least 1" % prec)
 
-    # For notation and definitions, see ``Computing p-adic heights via point
-    # multiplication'' (David Harvey, still in draft form)
+    # For notation and definitions, [Har2009]_
 
-    n1 = self.change_ring(rings.GF(p)).cardinality()
-    n2 = arith.LCM(self.tamagawa_numbers())
-    n = arith.LCM(n1, n2)
+    n1 = self.change_ring(GF(p)).cardinality()
+    n2 = _multiple_to_make_good_reduction(self)
+    n = LCM(n1, n2)
     m = int(n / n2)
 
     lamb = int(math.floor(math.sqrt(prec)))
 
-    adjusted_prec = prec + 2 * arith.valuation(n, p)   # this is M'
-    R = rings.Integers(p ** (adjusted_prec + 2*lamb))
+    adjusted_prec = prec + 2 * valuation(n, p)   # this is M'
+    R = Integers(p ** (adjusted_prec + 2*lamb))
 
     sigma = self.padic_sigma_truncated(p, N=adjusted_prec, E2=E2, lamb=lamb)
 
@@ -929,16 +1001,15 @@ def padic_height_via_multiply(self, p, prec=20, E2=None, check_hypotheses=True):
                    "answer with precision at least prec, but we didn't."
         return K(answer)
 
-
     # (man... I love python's local function definitions...)
     return height
 
 
 def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
     r"""
-    Computes the p-adic sigma function with respect to the standard
+    Computes the `p`-adic sigma function with respect to the standard
     invariant differential `dx/(2y + a_1 x + a_3)`, as
-    defined by Mazur and Tate, as a power series in the usual
+    defined by Mazur and Tate in [MT1991]_, as a power series in the usual
     uniformiser `t` at the origin.
 
     The equation of the curve must be minimal at `p`.
@@ -961,7 +1032,7 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
 
     - ``differential equation`` -- note that this does NOT
       guarantee correctness of all the returned digits, but it comes
-      pretty close :-))
+      pretty close.
 
     - ``check_hypotheses`` -- boolean, whether to check
       that this is a curve for which the p-adic sigma function makes
@@ -982,9 +1053,9 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
     `p`-adic digits).
 
     ALGORITHM: Described in "Efficient Computation of p-adic Heights"
-    (David Harvey), which is basically an optimised version of the
+    (David Harvey) [Har2009]_ which is basically an optimised version of the
     algorithm from "p-adic Heights and Log Convergence" (Mazur, Stein,
-    Tate).
+    Tate) [MST2006]_.
 
     Running time is soft-`O(N^2 \log p)`, plus whatever time is
     necessary to compute `E_2`.
@@ -1042,7 +1113,7 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
         sage: E2 = E.padic_E2(5, max_N)                     # long time
         sage: max_sigma = E.padic_sigma(p, max_N, E2=E2)    # long time
         sage: for N in range(3, max_N):                     # long time
-        ....:    sigma = E.padic_sigma(p, N, E2=E2)         # long time
+        ....:    sigma = E.padic_sigma(p, N, E2=E2)
         ....:    assert sigma == max_sigma
     """
     if check_hypotheses:
@@ -1082,7 +1153,7 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
 
     QQt = LaurentSeriesRing(RationalField(), "x")
 
-    R = rings.Integers(p**(N-2))
+    R = Integers(p**(N-2))
     X = self.change_ring(R)
     c = (X.a1()**2 + 4*X.a2() - R(E2)) / 12
 
@@ -1091,7 +1162,7 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
 
     Rt = x.parent()
 
-    A  = (x + c) * f
+    A = (x + c) * f
     # do integral over QQ, to avoid divisions by p
     A = Rt(QQt(A).integral())
     A = (-X.a1()/2 - A) * f
@@ -1103,7 +1174,7 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
     assert A.valuation() == -1 and A[-1] == 1
     A = A - A.parent().gen() ** (-1)
     A = A.power_series().list()
-    R = rings.Integers(p**(N-1))
+    R = Integers(p**(N-1))
     A = [R(u) for u in A]
     A[0] = self.change_ring(R).a1()/2     # fix constant term
     A = PowerSeriesRing(R, "x")(A, len(A))
@@ -1116,22 +1187,22 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
     # [Note: there are actually more digits available, but it's a bit
     # tricky to figure out exactly how many, and we only need p^(N-k+1)
     # for p-adic height purposes anyway]
-    K = rings.pAdicField(p, N + 1)
+    K = pAdicField(p, N + 1)
 
     sigma = sigma.padded_list(N+1)
 
-    sigma[0] = K(0, N +1)
+    sigma[0] = K(0, N + 1)
     sigma[1] = K(1, N)
     for n in range(2, N+1):
         sigma[n] = K(sigma[n].lift(), N - n + 1)
 
-    S = rings.PowerSeriesRing(K, "t", N+1)
+    S = PowerSeriesRing(K, "t", N+1)
     sigma = S(sigma, N+1)
 
     # if requested, check that sigma satisfies the appropriate
     # differential equation
     if check:
-        R = rings.Integers(p**N)
+        R = Integers(p**N)
         X = self.change_ring(R)
         x = X.formal_group().x(N+5)       # few extra terms for safety
         f = X.formal_group().differential(N+5)
@@ -1157,7 +1228,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
     r"""
     Compute the p-adic sigma function with respect to the standard
     invariant differential `dx/(2y + a_1 x + a_3)`, as
-    defined by Mazur and Tate, as a power series in the usual
+    defined by Mazur and Tate in [MT1991]_, as a power series in the usual
     uniformiser `t` at the origin.
 
     The equation of the curve must be minimal at `p`.
@@ -1191,10 +1262,9 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
     correct to precision `O(p^{N - 2 + (3 - j)(lamb + 1)})`.
 
     ALGORITHM: Described in "Efficient Computation of p-adic Heights"
-    (David Harvey, to appear in LMS JCM), which is basically an
+    [Har2009]_, which is basically an
     optimised version of the algorithm from "p-adic Heights and Log
-    Convergence" (Mazur, Stein, Tate), and "Computing p-adic heights
-    via point multiplication" (David Harvey, still draft form).
+    Convergence" (Mazur, Stein, Tate) [MST2006]_.
 
     Running time is soft-`O(N^2 \lambda^{-1} \log p)`, plus
     whatever time is necessary to compute `E_2`.
@@ -1224,10 +1294,10 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
         sage: E = EllipticCurve([1, 2, 3, 4, 7])                            # long time
         sage: E2 = E.padic_E2(5, 50)                                        # long time
         sage: for N in range(2, 10):                                        # long time
-        ....:    for lamb in range(10):                                     # long time
-        ....:       correct = E.padic_sigma(5, N + 3*lamb, E2=E2)           # long time
-        ....:       compare = E.padic_sigma_truncated(5, N=N, lamb=lamb, E2=E2)    # long time
-        ....:       assert compare == correct                               # long time
+        ....:    for lamb in range(10):
+        ....:       correct = E.padic_sigma(5, N + 3*lamb, E2=E2)
+        ....:       compare = E.padic_sigma_truncated(5, N=N, lamb=lamb, E2=E2)
+        ....:       assert compare == correct
     """
     if check_hypotheses:
         p = __check_padic_hypotheses(self, p)
@@ -1270,7 +1340,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
 
     QQt = LaurentSeriesRing(RationalField(), "x")
 
-    R = rings.Integers(p**(N-2))
+    R = Integers(p**(N-2))
     X = self.change_ring(R)
     c = (X.a1()**2 + 4*X.a2() - R(E2)) / 12
 
@@ -1279,7 +1349,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
 
     Rt = x.parent()
 
-    A  = (x + c) * f
+    A = (x + c) * f
     # do integral over QQ, to avoid divisions by p
     A = Rt(QQt(A).integral())
     A = (-X.a1()/2 - A) * f
@@ -1291,7 +1361,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
     assert A.valuation() == -1 and A[-1] == 1
     A = A - A.parent().gen() ** (-1)
     A = A.power_series().list()
-    R = rings.Integers(p**(N-1+lamb))
+    R = Integers(p**(N-1+lamb))
     A = [R(u) for u in A]
     A[0] = self.change_ring(R).a1()/2     # fix constant term
     A = PowerSeriesRing(R, "x")(A, len(A))
@@ -1301,7 +1371,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
 
     # Convert the answer to power series over p-adics; drop the precision
     # of the t^j coefficient to p^{N - 2 + (3 - j)(lamb + 1)}).
-    K = rings.pAdicField(p, N - 2 + 3*(lamb+1))
+    K = pAdicField(p, N - 2 + 3*(lamb+1))
 
     sigma = sigma.padded_list(trunc+1)
 
@@ -1310,7 +1380,7 @@ def padic_sigma_truncated(self, p, N=20, lamb=0, E2=None, check_hypotheses=True)
     for j in range(2, trunc+1):
         sigma[j] = K(sigma[j].lift(), N - 2 + (3 - j)*(lamb+1))
 
-    S = rings.PowerSeriesRing(K, "t", trunc + 1)
+    S = PowerSeriesRing(K, "t", trunc + 1)
     sigma = S(sigma, trunc+1)
 
     return sigma
@@ -1376,7 +1446,7 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
     trick.
 
     EXAMPLES: Here is the example discussed in the paper "Computation
-    of p-adic Heights and Log Convergence" (Mazur, Stein, Tate)::
+    of p-adic Heights and Log Convergence" (Mazur, Stein, Tate) [MST2006]_::
 
         sage: EllipticCurve([-1, 1/4]).padic_E2(5)
         2 + 4*5 + 2*5^3 + 5^4 + 3*5^5 + 2*5^6 + 5^8 + 3*5^9 + 4*5^10 + 2*5^11 + 2*5^12 + 2*5^14 + 3*5^15 + 3*5^16 + 3*5^17 + 4*5^18 + 2*5^19 + O(5^20)
@@ -1476,7 +1546,7 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
     if self.conductor() % p == 0:
         if not self.conductor() % (p**2) == 0:
             eq = self.tate_curve(p)
-            return  eq.E2(prec=prec)
+            return eq.E2(prec=prec)
 
     X = self.minimal_model().short_weierstrass_model()
     frob_p = X.matrix_of_frobenius(p, prec, check, check_hypotheses, algorithm).change_ring(Integers(p**prec))
@@ -1484,7 +1554,7 @@ def padic_E2(self, p, prec=20, check=False, check_hypotheses=True, algorithm="au
     frob_p_n = frob_p**prec
 
     # todo: think about the sign of this. Is it correct?
-    output_ring = rings.pAdicField(p, prec)
+    output_ring = pAdicField(p, prec)
 
     E2_of_X = output_ring( (-12 * frob_p_n[0,1] / frob_p_n[1,1]).lift() ) \
               + O(p**prec)
@@ -1619,16 +1689,16 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
         else:
             trace = self.ap(p)
 
-        base_ring = rings.Integers(p**adjusted_prec)
+        base_ring = Integers(p**adjusted_prec)
 
-        R, x = rings.PolynomialRing(base_ring, 'x').objgen()
+        R, x = PolynomialRing(base_ring, 'x').objgen()
         Q = x**3 + base_ring(X.a4()) * x + base_ring(X.a6())
         frob_p = sage.schemes.hyperelliptic_curves.monsky_washnitzer.matrix_of_frobenius(
                          Q, p, adjusted_prec, trace)
 
     else:   # algorithm == "sqrtp"
         p_to_prec = p**prec
-        R = rings.PolynomialRing(Integers(), "x")
+        R = PolynomialRing(Integers(), "x")
         Q = R([X.a6() % p_to_prec, X.a4() % p_to_prec, 0, 1])
         frob_p = sage.schemes.hyperelliptic_curves.hypellfrob.hypellfrob(p, prec, Q)
 
@@ -1671,7 +1741,7 @@ def _brent(F, p, N):
     some log-log factors.
 
     For more information, and a proof of the precision guarantees, see
-    Lemma 4 in "Efficient Computation of p-adic Heights" (David Harvey).
+    Lemma 4 in [Har2009]_.
 
     AUTHORS:
 
@@ -1709,7 +1779,7 @@ def _brent(F, p, N):
     G = Rx.one()
 
     # loop over an appropriate increasing sequence of lengths s
-    for s in misc.newton_method_sizes(N):
+    for s in newton_method_sizes(N):
         # zero-extend to s terms
         # todo: there has to be a better way in Sage to do this...
         G = Rx(G.list(), s)
