@@ -27,35 +27,36 @@ AUTHORS:
 - Ben Hutz (2018): add numerical point support
 """
 
-
-#*****************************************************************************
-#       Copyright (C) 2011 Volker Braun <vbraun.name@gmail.com>
-#       Copyright (C) 2006 William Stein <wstein@gmail.com>
+# *****************************************************************************
+#        Copyright (C) 2011 Volker Braun <vbraun.name@gmail.com>
+#        Copyright (C) 2006 William Stein <wstein@gmail.com>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
-#  as published by the Free Software Foundation; either version 2 of
-#  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#   Distributed under the terms of the GNU General Public License (GPL)
+#   as published by the Free Software Foundation; either version 2 of
+#   the License, or (at your option) any later version.
+#                   http://www.gnu.org/licenses/
+# *****************************************************************************
 
 from sage.rings.integer_ring import ZZ
 from sage.rings.real_mpfr import RR
 from sage.rings.cc import CC
-from sage.schemes.generic.homset import SchemeHomset_points
+from sage.schemes.generic.homset import SchemeHomset_points, SchemeHomset_generic
 
 from sage.misc.verbose import verbose
 
 from sage.rings.rational_field import is_RationalField
 from sage.categories.fields import Fields
 from sage.categories.number_fields import NumberFields
-from sage.rings.finite_rings.finite_field_constructor import is_FiniteField
+from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.schemes.generic.algebraic_scheme import AlgebraicScheme_subscheme
 from copy import copy
 
-#*******************************************************************
-# Projective varieties
-#*******************************************************************
+
+# *******************************************************************
+#  Projective varieties
+# *******************************************************************
+
 class SchemeHomset_points_projective_field(SchemeHomset_points):
     """
     Set of rational points of a projective variety over a field.
@@ -82,17 +83,17 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
 
         kwds:
 
-        - ``bound`` - real number (optional, default=0). The bound for the coordinates for
+        - ``bound`` - real number (optional, default: 0). The bound for the coordinates for
           subschemes with dimension at least 1.
 
-        - ``precision`` - integer (optional, default=53). The precision to use to
+        - ``precision`` - integer (optional, default: 53). The precision to use to
           compute the elements of bounded height for number fields.
 
-        - ``point_tolerance`` - positive real number (optional, default=10^(-10)).
+        - ``point_tolerance`` - positive real number (optional, default: `10^{-10}`).
           For numerically inexact fields, two points are considered the same
           if their coordinates are within tolerance.
 
-        - ``zero_tolerance`` - positive real number (optional, default=10^(-10)).
+        - ``zero_tolerance`` - positive real number (optional, default: `10^{-10}`).
           For numerically inexact fields, points are on the subscheme if they
           satisfy the equations to within tolerance.
 
@@ -111,48 +112,49 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
 
         EXAMPLES::
 
-            sage: P.<x,y> = ProjectiveSpace(QQ,1)
+            sage: P.<x,y> = ProjectiveSpace(QQ, 1)
             sage: P(QQ).points(bound=4)
             [(-4 : 1), (-3 : 1), (-2 : 1), (-3/2 : 1), (-4/3 : 1), (-1 : 1),
-            (-3/4 : 1), (-2/3 : 1), (-1/2 : 1), (-1/3 : 1), (-1/4 : 1), (0 : 1),
-            (1/4 : 1), (1/3 : 1), (1/2 : 1), (2/3 : 1), (3/4 : 1), (1 : 0), (1 : 1),
-            (4/3 : 1), (3/2 : 1), (2 : 1), (3 : 1), (4 : 1)]
+             (-3/4 : 1), (-2/3 : 1), (-1/2 : 1), (-1/3 : 1), (-1/4 : 1), (0 : 1),
+             (1/4 : 1), (1/3 : 1), (1/2 : 1), (2/3 : 1), (3/4 : 1), (1 : 0), (1 : 1),
+             (4/3 : 1), (3/2 : 1), (2 : 1), (3 : 1), (4 : 1)]
 
         ::
 
             sage: u = QQ['u'].0
-            sage: K.<v> = NumberField(u^2 + 3)
-            sage: P.<x,y,z> = ProjectiveSpace(K,2)
-            sage: len(P(K).points(bound=1.8))
-            381
+            sage: K.<v> = NumberField(u^2 + 3)                                                      # optional - sage.rings.number_field
+            sage: P.<x,y,z> = ProjectiveSpace(K, 2)                                                 # optional - sage.rings.number_field
+            sage: len(P(K).points(bound=1.8))                                                       # optional - sage.rings.number_field
+            309
 
         ::
 
-            sage: P1 = ProjectiveSpace(GF(2),1)
-            sage: F.<a> = GF(4,'a')
-            sage: P1(F).points()
+            sage: P1 = ProjectiveSpace(GF(2), 1)                                                    # optional - sage.rings.finite_rings
+            sage: F.<a> = GF(4, 'a')                                                                # optional - sage.rings.finite_rings
+            sage: P1(F).points()                                                                    # optional - sage.rings.finite_rings
             [(0 : 1), (1 : 0), (1 : 1), (a : 1), (a + 1 : 1)]
 
         ::
 
-            sage: P.<x,y,z> = ProjectiveSpace(QQ,2)
-            sage: E = P.subscheme([(y^3-y*z^2) - (x^3-x*z^2),(y^3-y*z^2) + (x^3-x*z^2)])
+            sage: P.<x,y,z> = ProjectiveSpace(QQ, 2)
+            sage: E = P.subscheme([(y^3-y*z^2) - (x^3-x*z^2), (y^3-y*z^2) + (x^3-x*z^2)])
             sage: E(P.base_ring()).points()
-            [(-1 : -1 : 1), (-1 : 0 : 1), (-1 : 1 : 1), (0 : -1 : 1), (0 : 0 : 1), (0 : 1 : 1),
-            (1 : -1 : 1), (1 : 0 : 1), (1 : 1 : 1)]
+            [(-1 : -1 : 1), (-1 : 0 : 1), (-1 : 1 : 1), (0 : -1 : 1), (0 : 0 : 1),
+             (0 : 1 : 1), (1 : -1 : 1), (1 : 0 : 1), (1 : 1 : 1)]
 
         ::
 
             sage: P.<x,y,z> = ProjectiveSpace(CC, 2)
             sage: E = P.subscheme([y^3 - x^3 - x*z^2, x*y*z])
-            sage: L=E(P.base_ring()).points(); sorted(L, key=str)
-            verbose 0 (...: projective_homset.py, points) Warning: computations in the numerical fields are inexact;points may be computed partially or incorrectly.
+            sage: L = E(P.base_ring()).points(); sorted(L, key=str)
+            verbose 0 (...: projective_homset.py, points) Warning: computations in
+            the numerical fields are inexact;points may be computed partially or incorrectly.
             [(-0.500000000000000 + 0.866025403784439*I : 1.00000000000000 : 0.000000000000000),
-            (-0.500000000000000 - 0.866025403784439*I : 1.00000000000000 : 0.000000000000000),
-            (-1.00000000000000*I : 0.000000000000000 : 1.00000000000000),
-            (0.000000000000000 : 0.000000000000000 : 1.00000000000000),
-            (1.00000000000000 : 1.00000000000000 : 0.000000000000000),
-            (1.00000000000000*I : 0.000000000000000 : 1.00000000000000)]
+             (-0.500000000000000 - 0.866025403784439*I : 1.00000000000000 : 0.000000000000000),
+             (-1.00000000000000*I : 0.000000000000000 : 1.00000000000000),
+             (0.000000000000000 : 0.000000000000000 : 1.00000000000000),
+             (1.00000000000000 : 1.00000000000000 : 0.000000000000000),
+             (1.00000000000000*I : 0.000000000000000 : 1.00000000000000)]
             sage: L[0].codomain()
             Projective Space of dimension 2 over Complex Field with 53 bits of precision
 
@@ -161,7 +163,8 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
             sage: P.<x,y,z> = ProjectiveSpace(CDF, 2)
             sage: E = P.subscheme([y^2 + x^2 + z^2, x*y*z])
             sage: len(E(P.base_ring()).points())
-            verbose 0 (...: projective_homset.py, points) Warning: computations in the numerical fields are inexact;points may be computed partially or incorrectly.
+            verbose 0 (...: projective_homset.py, points) Warning: computations in
+            the numerical fields are inexact;points may be computed partially or incorrectly.
             6
         """
         from sage.schemes.projective.projective_space import is_ProjectiveSpace
@@ -283,7 +286,7 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
                 raise TypeError("a positive bound B (= %s) must be specified"%B)
             from sage.schemes.projective.projective_rational_point import enum_projective_number_field
             return enum_projective_number_field(self, bound=B, tolerance=tol, precision=prec)
-        elif is_FiniteField(R):
+        elif isinstance(R, FiniteField):
             from sage.schemes.projective.projective_rational_point import enum_projective_finite_field
             return enum_projective_finite_field(self.extended_codomain())
         else:
@@ -304,11 +307,11 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
 
         kwds:
 
-        - ``point_tolerance`` - positive real number (optional, default=10^(-10)).
+        - ``point_tolerance`` - positive real number (optional, default: `10^{-10}`).
           For numerically inexact fields, two points are considered the same
           if their coordinates are within tolerance.
 
-        - ``zero_tolerance`` - positive real number (optional, default=10^(-10)).
+        - ``zero_tolerance`` - positive real number (optional, default: `10^{-10}`).
           For numerically inexact fields, points are on the subscheme if they
           satisfy the equations to within tolerance.
 
@@ -332,10 +335,10 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
         ::
 
             sage: S.<a> = QQ[]
-            sage: K.<v> = NumberField(a^5 - 7, embedding=CC((7)**(1/5)))
-            sage: P.<x,y,z> = ProjectiveSpace(K,2)
-            sage: X = P.subscheme([x^2 - v^2*z^2, y-v*z])
-            sage: len(X(K).numerical_points(F=CDF))
+            sage: K.<v> = NumberField(a^5 - 7, embedding=CC((7)**(1/5)))                            # optional - sage.rings.number_field
+            sage: P.<x,y,z> = ProjectiveSpace(K, 2)                                                 # optional - sage.rings.number_field
+            sage: X = P.subscheme([x^2 - v^2*z^2, y - v*z])                                         # optional - sage.rings.number_field
+            sage: len(X(K).numerical_points(F=CDF))                                                 # optional - sage.rings.number_field
             2
 
         ::
@@ -459,6 +462,7 @@ class SchemeHomset_points_projective_field(SchemeHomset_points):
                 return rat_points
             raise NotImplementedError('numerical approximation of points only for dimension 0 subschemes')
 
+
 class SchemeHomset_points_projective_ring(SchemeHomset_points):
     """
     Set of rational points of a projective variety over a commutative ring.
@@ -486,36 +490,35 @@ class SchemeHomset_points_projective_ring(SchemeHomset_points):
         EXAMPLES::
 
             sage: from sage.schemes.projective.projective_homset import SchemeHomset_points_projective_ring
-            sage: H = SchemeHomset_points_projective_ring(Spec(ZZ), ProjectiveSpace(ZZ,2))
+            sage: H = SchemeHomset_points_projective_ring(Spec(ZZ), ProjectiveSpace(ZZ, 2))
             sage: H.points(3)
-            [(0 : 0 : 1), (0 : 1 : -3), (0 : 1 : -2), (0 : 1 : -1), (0 : 1 : 0), (0
-            : 1 : 1), (0 : 1 : 2), (0 : 1 : 3), (0 : 2 : -3), (0 : 2 : -1), (0 : 2 :
-            1), (0 : 2 : 3), (0 : 3 : -2), (0 : 3 : -1), (0 : 3 : 1), (0 : 3 : 2),
-            (1 : -3 : -3), (1 : -3 : -2), (1 : -3 : -1), (1 : -3 : 0), (1 : -3 : 1),
-            (1 : -3 : 2), (1 : -3 : 3), (1 : -2 : -3), (1 : -2 : -2), (1 : -2 : -1),
-            (1 : -2 : 0), (1 : -2 : 1), (1 : -2 : 2), (1 : -2 : 3), (1 : -1 : -3),
-            (1 : -1 : -2), (1 : -1 : -1), (1 : -1 : 0), (1 : -1 : 1), (1 : -1 : 2),
-            (1 : -1 : 3), (1 : 0 : -3), (1 : 0 : -2), (1 : 0 : -1), (1 : 0 : 0), (1
-            : 0 : 1), (1 : 0 : 2), (1 : 0 : 3), (1 : 1 : -3), (1 : 1 : -2), (1 : 1 :
-            -1), (1 : 1 : 0), (1 : 1 : 1), (1 : 1 : 2), (1 : 1 : 3), (1 : 2 : -3),
-            (1 : 2 : -2), (1 : 2 : -1), (1 : 2 : 0), (1 : 2 : 1), (1 : 2 : 2), (1 :
-            2 : 3), (1 : 3 : -3), (1 : 3 : -2), (1 : 3 : -1), (1 : 3 : 0), (1 : 3 :
-            1), (1 : 3 : 2), (1 : 3 : 3), (2 : -3 : -3), (2 : -3 : -2), (2 : -3 :
-            -1), (2 : -3 : 0), (2 : -3 : 1), (2 : -3 : 2), (2 : -3 : 3), (2 : -2 :
-            -3), (2 : -2 : -1), (2 : -2 : 1), (2 : -2 : 3), (2 : -1 : -3), (2 : -1 :
-            -2), (2 : -1 : -1), (2 : -1 : 0), (2 : -1 : 1), (2 : -1 : 2), (2 : -1 :
-            3), (2 : 0 : -3), (2 : 0 : -1), (2 : 0 : 1), (2 : 0 : 3), (2 : 1 : -3),
-            (2 : 1 : -2), (2 : 1 : -1), (2 : 1 : 0), (2 : 1 : 1), (2 : 1 : 2), (2 :
-            1 : 3), (2 : 2 : -3), (2 : 2 : -1), (2 : 2 : 1), (2 : 2 : 3), (2 : 3 :
-            -3), (2 : 3 : -2), (2 : 3 : -1), (2 : 3 : 0), (2 : 3 : 1), (2 : 3 : 2),
-            (2 : 3 : 3), (3 : -3 : -2), (3 : -3 : -1), (3 : -3 : 1), (3 : -3 : 2),
-            (3 : -2 : -3), (3 : -2 : -2), (3 : -2 : -1), (3 : -2 : 0), (3 : -2 : 1),
-            (3 : -2 : 2), (3 : -2 : 3), (3 : -1 : -3), (3 : -1 : -2), (3 : -1 : -1),
-            (3 : -1 : 0), (3 : -1 : 1), (3 : -1 : 2), (3 : -1 : 3), (3 : 0 : -2), (3
-            : 0 : -1), (3 : 0 : 1), (3 : 0 : 2), (3 : 1 : -3), (3 : 1 : -2), (3 : 1
-            : -1), (3 : 1 : 0), (3 : 1 : 1), (3 : 1 : 2), (3 : 1 : 3), (3 : 2 : -3),
-            (3 : 2 : -2), (3 : 2 : -1), (3 : 2 : 0), (3 : 2 : 1), (3 : 2 : 2), (3 :
-            2 : 3), (3 : 3 : -2), (3 : 3 : -1), (3 : 3 : 1), (3 : 3 : 2)]
+            [(0 : 0 : 1), (0 : 1 : -3), (0 : 1 : -2), (0 : 1 : -1), (0 : 1 : 0), (0 : 1 : 1),
+             (0 : 1 : 2), (0 : 1 : 3), (0 : 2 : -3), (0 : 2 : -1), (0 : 2 : 1), (0 : 2 : 3),
+             (0 : 3 : -2), (0 : 3 : -1), (0 : 3 : 1), (0 : 3 : 2), (1 : -3 : -3),
+             (1 : -3 : -2), (1 : -3 : -1), (1 : -3 : 0), (1 : -3 : 1), (1 : -3 : 2),
+             (1 : -3 : 3), (1 : -2 : -3), (1 : -2 : -2), (1 : -2 : -1), (1 : -2 : 0),
+             (1 : -2 : 1), (1 : -2 : 2), (1 : -2 : 3), (1 : -1 : -3), (1 : -1 : -2),
+             (1 : -1 : -1), (1 : -1 : 0), (1 : -1 : 1), (1 : -1 : 2), (1 : -1 : 3),
+             (1 : 0 : -3), (1 : 0 : -2), (1 : 0 : -1), (1 : 0 : 0), (1 : 0 : 1), (1 : 0 : 2),
+             (1 : 0 : 3), (1 : 1 : -3), (1 : 1 : -2), (1 : 1 : -1), (1 : 1 : 0), (1 : 1 : 1),
+             (1 : 1 : 2), (1 : 1 : 3), (1 : 2 : -3), (1 : 2 : -2), (1 : 2 : -1), (1 : 2 : 0),
+             (1 : 2 : 1), (1 : 2 : 2), (1 : 2 : 3), (1 : 3 : -3), (1 : 3 : -2), (1 : 3 : -1),
+             (1 : 3 : 0), (1 : 3 : 1), (1 : 3 : 2), (1 : 3 : 3), (2 : -3 : -3),
+             (2 : -3 : -2), (2 : -3 : -1), (2 : -3 : 0), (2 : -3 : 1), (2 : -3 : 2),
+             (2 : -3 : 3), (2 : -2 : -3), (2 : -2 : -1), (2 : -2 : 1), (2 : -2 : 3),
+             (2 : -1 : -3), (2 : -1 : -2), (2 : -1 : -1), (2 : -1 : 0), (2 : -1 : 1),
+             (2 : -1 : 2), (2 : -1 : 3), (2 : 0 : -3), (2 : 0 : -1), (2 : 0 : 1),
+             (2 : 0 : 3), (2 : 1 : -3), (2 : 1 : -2), (2 : 1 : -1), (2 : 1 : 0), (2 : 1 : 1),
+             (2 : 1 : 2), (2 : 1 : 3), (2 : 2 : -3), (2 : 2 : -1), (2 : 2 : 1), (2 : 2 : 3),
+             (2 : 3 : -3), (2 : 3 : -2), (2 : 3 : -1), (2 : 3 : 0), (2 : 3 : 1), (2 : 3 : 2),
+             (2 : 3 : 3), (3 : -3 : -2), (3 : -3 : -1), (3 : -3 : 1), (3 : -3 : 2),
+             (3 : -2 : -3), (3 : -2 : -2), (3 : -2 : -1), (3 : -2 : 0), (3 : -2 : 1),
+             (3 : -2 : 2), (3 : -2 : 3), (3 : -1 : -3), (3 : -1 : -2), (3 : -1 : -1),
+             (3 : -1 : 0), (3 : -1 : 1), (3 : -1 : 2), (3 : -1 : 3), (3 : 0 : -2),
+             (3 : 0 : -1), (3 : 0 : 1), (3 : 0 : 2), (3 : 1 : -3), (3 : 1 : -2),
+             (3 : 1 : -1), (3 : 1 : 0), (3 : 1 : 1), (3 : 1 : 2), (3 : 1 : 3), (3 : 2 : -3),
+             (3 : 2 : -2), (3 : 2 : -1), (3 : 2 : 0), (3 : 2 : 1), (3 : 2 : 2), (3 : 2 : 3),
+             (3 : 3 : -2), (3 : 3 : -1), (3 : 3 : 1), (3 : 3 : 2)]
         """
         R = self.value_ring()
         if R == ZZ:
@@ -527,9 +530,43 @@ class SchemeHomset_points_projective_ring(SchemeHomset_points):
             raise TypeError("unable to enumerate points over %s"%R)
 
 
-#*******************************************************************
-# Abelian varieties
-#*******************************************************************
+class SchemeHomset_polynomial_projective_space(SchemeHomset_generic):
+    """
+    Set of morphisms of a projective space.
+
+    EXAMPLES::
+
+        sage: P.<x,y,z> = ProjectiveSpace(2, QQ)
+        sage: Hom(P, P)
+        Set of morphisms
+          From: Projective Space of dimension 2 over Rational Field
+          To:   Projective Space of dimension 2 over Rational Field
+    """
+    def identity(self):
+        """
+        Return the identity morphism of this hom-set.
+
+        EXAMPLES::
+
+            sage: P.<x,y,z> = ProjectiveSpace(2, QQ)
+            sage: Hom(P, P)
+            Set of morphisms
+              From: Projective Space of dimension 2 over Rational Field
+              To:   Projective Space of dimension 2 over Rational Field
+            sage: _.identity()
+            Scheme endomorphism of Projective Space of dimension 2 over Rational Field
+              Defn: Identity map
+        """
+        if self.is_endomorphism_set():
+            from sage.schemes.generic.morphism import SchemeMorphism_polynomial_id
+            return SchemeMorphism_polynomial_id(self.domain())
+        raise TypeError("identity map is only defined for endomorphisms")
+
+
+# *******************************************************************
+#  Abelian varieties
+# *******************************************************************
+
 class SchemeHomset_points_abelian_variety_field(SchemeHomset_points_projective_field):
     r"""
     Set of rational points of an Abelian variety.
@@ -542,23 +579,24 @@ class SchemeHomset_points_abelian_variety_field(SchemeHomset_points_projective_f
 
     The bug reported at :trac:`1785` is fixed::
 
-        sage: K.<a> = NumberField(x^2 + x - (3^3-3))
-        sage: E = EllipticCurve('37a')
-        sage: X = E(K)
-        sage: X
-        Abelian group of points on Elliptic Curve defined by
-        y^2 + y = x^3 + (-1)*x over Number Field in a with
-        defining polynomial x^2 + x - 24
-        sage: P = X([3,a])
-        sage: P
+        sage: x = polygen(ZZ, 'x')
+        sage: K.<a> = NumberField(x^2 + x - (3^3-3))                                    # optional - sage.rings.number_field
+        sage: E = EllipticCurve('37a')                                                  # optional - sage.rings.number_field
+        sage: X = E(K)                                                                  # optional - sage.rings.number_field
+        sage: X                                                                         # optional - sage.rings.number_field
+        Abelian group of points on
+         Elliptic Curve defined by y^2 + y = x^3 + (-1)*x
+          over Number Field in a with defining polynomial x^2 + x - 24
+        sage: P = X([3,a])                                                                          # optional - sage.rings.number_field
+        sage: P                                                                                     # optional - sage.rings.number_field
         (3 : a : 1)
-        sage: P in E
+        sage: P in E                                                                                # optional - sage.rings.number_field
         False
-        sage: P in E.base_extend(K)
+        sage: P in E.base_extend(K)                                                                 # optional - sage.rings.number_field
         True
-        sage: P in X.codomain()
+        sage: P in X.codomain()                                                                     # optional - sage.rings.number_field
         False
-        sage: P in X.extended_codomain()
+        sage: P in X.extended_codomain()                                                            # optional - sage.rings.number_field
         True
 
     Check for :trac:`11982`::
@@ -641,7 +679,7 @@ class SchemeHomset_points_abelian_variety_field(SchemeHomset_points_projective_f
             sage: E = EllipticCurve('37a')
             sage: Hom = E.point_homset();  Hom
             Abelian group of points on Elliptic Curve defined
-            by y^2 + y = x^3 - x over Rational Field
+             by y^2 + y = x^3 - x over Rational Field
             sage: Hom.base_ring()
             Rational Field
             sage: Hom.base_extend(QQ)
