@@ -15,8 +15,8 @@ EXAMPLES:
 Projective, over `\QQ`::
 
     sage: from sage.schemes.projective.projective_rational_point import enum_projective_rational_field
-    sage: P.<X,Y,Z> = ProjectiveSpace(2,QQ)
-    sage: C = P.subscheme([X+Y-Z])
+    sage: P.<X,Y,Z> = ProjectiveSpace(2, QQ)
+    sage: C = P.subscheme([X + Y - Z])
     sage: enum_projective_rational_field(C, 3)
     [(-2 : 3 : 1), (-1 : 1 : 0), (-1 : 2 : 1), (-1/2 : 3/2 : 1),
      (0 : 1 : 1), (1/3 : 2/3 : 1), (1/2 : 1/2 : 1), (2/3 : 1/3 : 1),
@@ -26,8 +26,8 @@ Projective, over `\QQ`::
 Projective over a finite field::
 
     sage: from sage.schemes.projective.projective_rational_point import enum_projective_finite_field
-    sage: E = EllipticCurve('72').change_ring(GF(19))
-    sage: enum_projective_finite_field(E)
+    sage: E = EllipticCurve('72').change_ring(GF(19))                                               # optional - sage.rings.finite_rings
+    sage: enum_projective_finite_field(E)                                                           # optional - sage.rings.finite_rings
     [(0 : 1 : 0), (1 : 0 : 1), (3 : 0 : 1), (4 : 9 : 1), (4 : 10 : 1),
      (6 : 6 : 1), (6 : 13 : 1), (7 : 6 : 1), (7 : 13 : 1), (9 : 4 : 1),
      (9 : 15 : 1), (12 : 8 : 1), (12 : 11 : 1), (13 : 8 : 1), (13 : 11 : 1),
@@ -89,7 +89,7 @@ def enum_projective_rational_field(X, B):
     EXAMPLES::
 
         sage: P.<X,Y,Z> = ProjectiveSpace(2, QQ)
-        sage: C = P.subscheme([X+Y-Z])
+        sage: C = P.subscheme([X + Y - Z])
         sage: from sage.schemes.projective.projective_rational_point import enum_projective_rational_field
         sage: enum_projective_rational_field(C(QQ), 6)
         [(-5 : 6 : 1), (-4 : 5 : 1), (-3 : 4 : 1), (-2 : 3 : 1),
@@ -110,15 +110,15 @@ def enum_projective_rational_field(X, B):
         sage: P3.<W,X,Y,Z> = ProjectiveSpace(3, QQ)
         sage: enum_projective_rational_field(P3, 1)
         [(-1 : -1 : -1 : 1), (-1 : -1 : 0 : 1), (-1 : -1 : 1 : 0), (-1 : -1 : 1 : 1),
-        (-1 : 0 : -1 : 1), (-1 : 0 : 0 : 1), (-1 : 0 : 1 : 0), (-1 : 0 : 1 : 1),
-        (-1 : 1 : -1 : 1), (-1 : 1 : 0 : 0), (-1 : 1 : 0 : 1), (-1 : 1 : 1 : 0),
-        (-1 : 1 : 1 : 1), (0 : -1 : -1 : 1), (0 : -1 : 0 : 1), (0 : -1 : 1 : 0),
-        (0 : -1 : 1 : 1), (0 : 0 : -1 : 1), (0 : 0 : 0 : 1), (0 : 0 : 1 : 0),
-        (0 : 0 : 1 : 1), (0 : 1 : -1 : 1), (0 : 1 : 0 : 0), (0 : 1 : 0 : 1),
-        (0 : 1 : 1 : 0), (0 : 1 : 1 : 1), (1 : -1 : -1 : 1), (1 : -1 : 0 : 1),
-        (1 : -1 : 1 : 0), (1 : -1 : 1 : 1), (1 : 0 : -1 : 1), (1 : 0 : 0 : 0),
-        (1 : 0 : 0 : 1), (1 : 0 : 1 : 0), (1 : 0 : 1 : 1), (1 : 1 : -1 : 1),
-        (1 : 1 : 0 : 0), (1 : 1 : 0 : 1), (1 : 1 : 1 : 0), (1 : 1 : 1 : 1)]
+         (-1 : 0 : -1 : 1), (-1 : 0 : 0 : 1), (-1 : 0 : 1 : 0), (-1 : 0 : 1 : 1),
+         (-1 : 1 : -1 : 1), (-1 : 1 : 0 : 0), (-1 : 1 : 0 : 1), (-1 : 1 : 1 : 0),
+         (-1 : 1 : 1 : 1), (0 : -1 : -1 : 1), (0 : -1 : 0 : 1), (0 : -1 : 1 : 0),
+         (0 : -1 : 1 : 1), (0 : 0 : -1 : 1), (0 : 0 : 0 : 1), (0 : 0 : 1 : 0),
+         (0 : 0 : 1 : 1), (0 : 1 : -1 : 1), (0 : 1 : 0 : 0), (0 : 1 : 0 : 1),
+         (0 : 1 : 1 : 0), (0 : 1 : 1 : 1), (1 : -1 : -1 : 1), (1 : -1 : 0 : 1),
+         (1 : -1 : 1 : 0), (1 : -1 : 1 : 1), (1 : 0 : -1 : 1), (1 : 0 : 0 : 0),
+         (1 : 0 : 0 : 1), (1 : 0 : 1 : 0), (1 : 0 : 1 : 1), (1 : 1 : -1 : 1),
+         (1 : 1 : 0 : 0), (1 : 1 : 0 : 1), (1 : 1 : 1 : 0), (1 : 1 : 1 : 1)]
 
     ALGORITHM:
 
@@ -167,7 +167,7 @@ def enum_projective_number_field(X, **kwds):
 
     This is an implementation of the revised algorithm (Algorithm 4) in
     [DK2013]_. Algorithm 5 is used for imaginary quadratic fields.
-    
+
     INPUT:
 
     kwds:
@@ -187,21 +187,20 @@ def enum_projective_number_field(X, **kwds):
 
         sage: from sage.schemes.projective.projective_rational_point import enum_projective_number_field
         sage: u = QQ['u'].0
-        sage: K = NumberField(u^3 - 5,'v')
-        sage: P.<x,y,z> = ProjectiveSpace(K, 2)
-        sage: X = P.subscheme([x - y])
-        sage: enum_projective_number_field(X(K), bound=RR(5^(1/3)), prec=2^10)
-        [(0 : 0 : 1), (-1 : -1 : 1), (1 : 1 : 1), (-1/5*v^2 : -1/5*v^2 : 1), (-v : -v : 1),
-        (1/5*v^2 : 1/5*v^2 : 1), (v : v : 1), (1 : 1 : 0)]
+        sage: K = NumberField(u^3 - 5, 'v')                                                         # optional - sage.rings.number_field
+        sage: P.<x,y,z> = ProjectiveSpace(K, 2)                                                     # optional - sage.rings.number_field
+        sage: X = P.subscheme([x - y])                                                              # optional - sage.rings.number_field
+        sage: enum_projective_number_field(X(K), bound=RR(5^(1/3)), prec=2^10)                      # optional - sage.rings.number_field
+        [(0 : 0 : 1), (1 : 1 : 0), (-1 : -1 : 1), (1 : 1 : 1)]
 
     ::
 
         sage: u = QQ['u'].0
-        sage: K = NumberField(u^2 + 3, 'v')
-        sage: A.<x,y> = ProjectiveSpace(K,1)
-        sage: X = A.subscheme(x-y)
+        sage: K = NumberField(u^2 + 3, 'v')                                                         # optional - sage.rings.number_field
+        sage: A.<x,y> = ProjectiveSpace(K, 1)                                                       # optional - sage.rings.number_field
+        sage: X = A.subscheme(x - y)                                                                # optional - sage.rings.number_field
         sage: from sage.schemes.projective.projective_rational_point import enum_projective_number_field
-        sage: enum_projective_number_field(X, bound=2)
+        sage: enum_projective_number_field(X, bound=2)                                              # optional - sage.rings.number_field
         [(1 : 1)]
     """
     B = kwds.pop('bound')
@@ -245,35 +244,35 @@ def enum_projective_finite_field(X):
 
     EXAMPLES::
 
-        sage: F = GF(53)
-        sage: P.<X,Y,Z> = ProjectiveSpace(2,F)
+        sage: F = GF(53)                                                                            # optional - sage.rings.finite_rings
+        sage: P.<X,Y,Z> = ProjectiveSpace(2, F)                                                     # optional - sage.rings.finite_rings
         sage: from sage.schemes.projective.projective_rational_point import enum_projective_finite_field
-        sage: len(enum_projective_finite_field(P(F)))
+        sage: len(enum_projective_finite_field(P(F)))                                               # optional - sage.rings.finite_rings
         2863
-        sage: 53^2+53+1
+        sage: 53^2 + 53 + 1
         2863
 
     ::
 
-        sage: F = GF(9,'a')
-        sage: P.<X,Y,Z> = ProjectiveSpace(2,F)
-        sage: C = Curve(X^3-Y^3+Z^2*Y)
-        sage: enum_projective_finite_field(C(F))
+        sage: F = GF(9, 'a')                                                                        # optional - sage.rings.finite_rings
+        sage: P.<X,Y,Z> = ProjectiveSpace(2,F)                                                      # optional - sage.rings.finite_rings
+        sage: C = Curve(X^3 - Y^3 + Z^2*Y)                                                          # optional - sage.rings.finite_rings
+        sage: enum_projective_finite_field(C(F))                                                    # optional - sage.rings.finite_rings
         [(0 : 0 : 1), (0 : 1 : 1), (0 : 2 : 1), (1 : 1 : 0), (a + 1 : 2*a : 1),
-        (a + 1 : 2*a + 1 : 1), (a + 1 : 2*a + 2 : 1), (2*a + 2 : a : 1),
-        (2*a + 2 : a + 1 : 1), (2*a + 2 : a + 2 : 1)]
+         (a + 1 : 2*a + 1 : 1), (a + 1 : 2*a + 2 : 1), (2*a + 2 : a : 1),
+         (2*a + 2 : a + 1 : 1), (2*a + 2 : a + 2 : 1)]
 
     ::
 
-        sage: F = GF(5)
-        sage: P2F.<X,Y,Z> = ProjectiveSpace(2,F)
-        sage: enum_projective_finite_field(P2F)
+        sage: F = GF(5)                                                                             # optional - sage.rings.finite_rings
+        sage: P2F.<X,Y,Z> = ProjectiveSpace(2, F)                                                   # optional - sage.rings.finite_rings
+        sage: enum_projective_finite_field(P2F)                                                     # optional - sage.rings.finite_rings
         [(0 : 0 : 1), (0 : 1 : 0), (0 : 1 : 1), (0 : 2 : 1), (0 : 3 : 1), (0 : 4 : 1),
-        (1 : 0 : 0), (1 : 0 : 1), (1 : 1 : 0), (1 : 1 : 1), (1 : 2 : 1), (1 : 3 : 1),
-        (1 : 4 : 1), (2 : 0 : 1), (2 : 1 : 0), (2 : 1 : 1), (2 : 2 : 1), (2 : 3 : 1),
-        (2 : 4 : 1), (3 : 0 : 1), (3 : 1 : 0), (3 : 1 : 1), (3 : 2 : 1), (3 : 3 : 1),
-        (3 : 4 : 1), (4 : 0 : 1), (4 : 1 : 0), (4 : 1 : 1), (4 : 2 : 1), (4 : 3 : 1),
-        (4 : 4 : 1)]
+         (1 : 0 : 0), (1 : 0 : 1), (1 : 1 : 0), (1 : 1 : 1), (1 : 2 : 1), (1 : 3 : 1),
+         (1 : 4 : 1), (2 : 0 : 1), (2 : 1 : 0), (2 : 1 : 1), (2 : 2 : 1), (2 : 3 : 1),
+         (2 : 4 : 1), (3 : 0 : 1), (3 : 1 : 0), (3 : 1 : 1), (3 : 2 : 1), (3 : 3 : 1),
+         (3 : 4 : 1), (4 : 0 : 1), (4 : 1 : 0), (4 : 1 : 1), (4 : 2 : 1), (4 : 3 : 1),
+         (4 : 4 : 1)]
 
     ALGORITHM:
 
@@ -308,16 +307,15 @@ def enum_projective_finite_field(X):
     return pts
 
 
-
 def sieve(X, bound):
     r"""
     Returns the list of all projective, rational points on scheme ``X`` of
     height up to ``bound``.
 
-    Height of a projective point X = (x_1, x_2,..., x_n) is given by
-    H_X = max(y_1, y_2,..., y_n), where H_X is height of point X and y_i's
-    are the normalized coordinates such that all y_i are integers and
-    gcd(y_1, y_2,..., y_n) = 1.
+    Height of a projective point `X = (x_1, x_2,\dots, x_n)` is given by
+    `H_X = \max(y_1, y_2,\dots, y_n)`, where the values `y_i`
+    are the normalized coordinates such that all `y_i` are integers and
+    `\gcd(y_1, y_2,\dots, y_n) = 1`.
 
     ALGORITHM:
 
@@ -344,8 +342,8 @@ def sieve(X, bound):
     EXAMPLES::
 
         sage: from sage.schemes.projective.projective_rational_point import sieve
-        sage: P.<x,y,z,q>=ProjectiveSpace(QQ,3)
-        sage: Y=P.subscheme([x^2-3^2*y^2+z*q,x+z+4*q])
+        sage: P.<x,y,z,q> = ProjectiveSpace(QQ, 3)
+        sage: Y = P.subscheme([x^2 - 3^2*y^2 + z*q, x + z + 4*q])
         sage: sorted(sieve(Y, 12))  # long time
         [(-4 : -4/3 : 0 : 1), (-4 : 4/3 : 0 : 1),
          (-1 : -1/3 : 1 : 0), (-1 : 1/3 : 1 : 0)]
@@ -365,7 +363,7 @@ def sieve(X, bound):
     Algorithm works even if coefficients are fraction::
 
         sage: from sage.schemes.projective.projective_rational_point import sieve
-        sage: P.<x,y,z> = ProjectiveSpace(2,QQ)
+        sage: P.<x,y,z> = ProjectiveSpace(2, QQ)
         sage: X = P.subscheme(3*x - 3/2*y)
         sage: sieve(X, 3)
         [(-1 : -2 : 1), (-1/2 : -1 : 1), (-1/3 : -2/3 : 1), (0 : 0 : 1),
@@ -446,7 +444,7 @@ def sieve(X, bound):
         best_size = 2
         best_time = (N**2)*M[2][-1]**(N) + (N**5 * RR(prod(M[2])**dim_scheme / M[2][-1]) )
         for i in range(2, max_length + 1):
-            current_time = (N**2)*M[i][-1]**(N) + (N**5 * RR(prod(M[i])**dim_scheme  / M[i][-1]) )
+            current_time = (N**2)*M[i][-1]**(N) + (N**5 * RR(prod(M[i])**dim_scheme / M[i][-1]) )
             if current_time < best_time:
                 best_size = i
                 best_time = current_time
