@@ -48,12 +48,11 @@ First, consider the following embedding of `\mathbb{P}^1` into
 
     sage: P2.<x,y,z> = toric_varieties.P2()
     sage: P1.<u,v> = toric_varieties.P1()
-    sage: P1.hom([0,u^2+v^2,u*v], P2)
+    sage: P1.hom([0, u^2 + v^2, u*v], P2)
     Scheme morphism:
       From: 1-d CPR-Fano toric variety covered by 2 affine patches
       To:   2-d CPR-Fano toric variety covered by 3 affine patches
-      Defn: Defined on coordinates by sending [u : v] to
-            [0 : u^2 + v^2 : u*v]
+      Defn: Defined on coordinates by sending [u : v] to [0 : u^2 + v^2 : u*v]
 
 This is a well-defined morphism of algebraic varieties because
 homogeneously rescaled coordinates of a point of `\mathbb{P}^1` map to the same
@@ -78,8 +77,7 @@ difficulty. For example, consider ::
     Scheme morphism:
       From: 1-d CPR-Fano toric variety covered by 2 affine patches
       To:   2-d CPR-Fano toric variety covered by 3 affine patches
-      Defn: Defined on coordinates by sending [u : v] to
-            [0 : u : v]
+      Defn: Defined on coordinates by sending [u : v] to [0 : u : v]
 
 This map is actually the embedding of the
 :meth:`~sage.schemes.toric.variety.ToricVariety_field.orbit_closure`
@@ -93,7 +91,7 @@ z\not=0 \}` of `\mathbb{P}^2`.
 
 Consider instead the following morphism of fans::
 
-    sage: fm = FanMorphism( matrix(ZZ,[[1,0]]), P1.fan(), P2.fan() );  fm
+    sage: fm = FanMorphism(matrix(ZZ, [[1,0]]), P1.fan(), P2.fan());  fm
     Fan morphism defined by the matrix
     [1 0]
     Domain fan: Rational polyhedral fan in 1-d lattice N
@@ -114,8 +112,7 @@ The fan morphism map is equivalent to the following polynomial map::
     Scheme morphism:
       From: 1-d CPR-Fano toric variety covered by 2 affine patches
       To:   2-d CPR-Fano toric variety covered by 3 affine patches
-      Defn: Defined on coordinates by sending [u : v] to
-            [u : v : v]
+      Defn: Defined on coordinates by sending [u : v] to [u : v : v]
 
 Finally, here is an example of a fan morphism that cannot be written
 using homogeneous polynomials. Consider the blowup `O_{\mathbb{P}^1}(2)
@@ -131,7 +128,7 @@ using homogeneous polynomials. Consider the blowup `O_{\mathbb{P}^1}(2)
     sage: blowup.as_polynomial_map()
     Traceback (most recent call last):
     ...
-    TypeError: The fan morphism cannot be written in homogeneous polynomials.
+    TypeError: the fan morphism cannot be written in homogeneous polynomials
 
 If we denote the homogeneous coordinates of `O_{\mathbb{P}^1}(2)` by
 `x`, `t`, `y` corresponding to the rays `(1,2)`, `(1,1)`, and `(1,0)`
@@ -158,7 +155,7 @@ otherwise (however, note that you can always
 that is dominant over the image or its closure).
 
 For example, consider the blow-up restricted to one of the two
-coordinate charts of $O_{\mathbb{P}^1}(2)$ ::
+coordinate charts of `O_{\mathbb{P}^1}(2)` ::
 
 
     sage: O2_P1_chart = ToricVariety(Fan([O2_P1.fan().generating_cones()[0]]))
@@ -174,8 +171,7 @@ coordinate charts of $O_{\mathbb{P}^1}(2)$ ::
     Scheme morphism:
       From: 0-d affine toric variety
       To:   2-d affine toric variety
-      Defn: Defined on coordinates by sending [] to
-            [1 : 1]
+      Defn: Defined on coordinates by sending [] to [1 : 1]
 
 The fibers are labeled by torus orbits in the base, that is, cones of
 the codomain fan. In this case, the fibers over lower-dimensional
@@ -217,7 +213,8 @@ already encountered. The interesting fiber is the one over the
 2-dimensional cone, which represents the exceptional set of the
 blow-up in this single coordinate chart. Lets investigate further::
 
-    sage: exceptional_cones = single_chart.fan_morphism().primitive_preimage_cones(A2_Z2.fan(2)[0])
+    sage: fm = single_chart.fan_morphism()
+    sage: exceptional_cones = fm.primitive_preimage_cones(A2_Z2.fan(2)[0])
     sage: exceptional_set = single_chart.fiber_component(exceptional_cones[0])
     sage: exceptional_set
     1-d affine toric variety
@@ -225,19 +222,18 @@ blow-up in this single coordinate chart. Lets investigate further::
     Scheme morphism:
       From: 1-d affine toric variety
       To:   2-d affine toric variety
-      Defn: Defined on coordinates by sending [z0] to
-            [z0 : 0]
+      Defn: Defined on coordinates by sending [z0] to [z0 : 0]
 
 So we see that the fiber over this point is an affine line. Together
 with another affine line in the other coordinate patch, this covers
-the exceptional $\mathbb{P}^1$ of the blowup $O_{\mathbb{P}^1}(2) \to
-\CC^2/\ZZ_2$.
+the exceptional `\mathbb{P}^1` of the blowup `O_{\mathbb{P}^1}(2) \to
+\CC^2/\ZZ_2`.
 
 Here is an example with higher dimensional varieties involved::
 
     sage: A3 = toric_varieties.A(3)
     sage: P3 = toric_varieties.P(3)
-    sage: m = matrix([(2,0,0), (1,1,0), (3, 1, 0)])
+    sage: m = matrix([(2,0,0), (1,1,0), (3,1,0)])
     sage: phi = A3.hom(m, P3)
     sage: phi.as_polynomial_map()
     Scheme morphism:
@@ -348,7 +344,7 @@ fan::
     1 connected components over (1, 2), each with 2 irreducible components.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2011 Volker Braun <vbraun.name@gmail.com>
 #       Copyright (C) 2010 Andrey Novoseltsev <novoselt@gmail.com>
 #       Copyright (C) 2006 William Stein <wstein@gmail.com>
@@ -357,8 +353,8 @@ fan::
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 # For now, the scheme morphism base class cannot derive from Morphism
 # since this would clash with elliptic curves. So we derive only on
@@ -369,12 +365,13 @@ from sage.categories.morphism import Morphism
 from sage.structure.richcmp import richcmp_not_equal, richcmp
 
 from sage.structure.sequence import Sequence
-from sage.rings.all import ZZ
-from sage.arith.all import gcd
-from sage.misc.all import cached_method
+from sage.rings.integer_ring import ZZ
+from sage.arith.misc import GCD as gcd
+from sage.misc.cachefunc import cached_method
 from sage.matrix.constructor import matrix, identity_matrix
 from sage.modules.free_module_element import vector
-from sage.geometry.all import Cone, Fan
+from sage.geometry.cone import Cone
+from sage.geometry.fan import Fan
 
 from sage.schemes.generic.scheme import is_Scheme
 from sage.schemes.generic.morphism import (
@@ -407,9 +404,7 @@ class SchemeMorphism_point_toric_field(SchemeMorphism_point, Morphism):
     - ``check`` -- if ``True`` (default), the input will be checked for
       correctness.
 
-    OUTPUT:
-
-    A :class:`SchemeMorphism_point_toric_field`.
+    OUTPUT: A :class:`SchemeMorphism_point_toric_field`.
 
     TESTS::
 
@@ -431,7 +426,7 @@ class SchemeMorphism_point_toric_field(SchemeMorphism_point, Morphism):
         # Convert scheme to its set of points over the base ring
         if is_Scheme(X):
             X = X(X.base_ring())
-        super(SchemeMorphism_point_toric_field, self).__init__(X)
+        super().__init__(X)
         if check:
             # Verify that there are the right number of coords
             # Why is it not done in the parent?
@@ -439,10 +434,10 @@ class SchemeMorphism_point_toric_field(SchemeMorphism_point, Morphism):
                 coordinates = list(coordinates)
             if not isinstance(coordinates, (list, tuple)):
                 raise TypeError("coordinates must be a scheme point, list, "
-                                "or tuple. Got %s" % coordinates)
+                                "or tuple; got %s" % coordinates)
             d = X.codomain().ambient_space().ngens()
             if len(coordinates) != d:
-                raise ValueError("there must be %d coordinates! Got only %d: "
+                raise ValueError("there must be %d coordinates; got only %d: "
                                  "%s" % (d, len(coordinates), coordinates))
             # Make sure the coordinates all lie in the appropriate ring
             coordinates = Sequence(coordinates, X.value_ring())
@@ -451,7 +446,6 @@ class SchemeMorphism_point_toric_field(SchemeMorphism_point, Morphism):
         self._coords = coordinates
 
 
-
 ############################################################################
 # A morphism of toric varieties determined by homogeneous polynomials.
 class SchemeMorphism_polynomial_toric_variety(SchemeMorphism_polynomial, Morphism):
@@ -471,16 +465,14 @@ class SchemeMorphism_polynomial_toric_variety(SchemeMorphism_polynomial, Morphis
     Same as for
     :class:`~sage.schemes.toric.morphism.SchemeMorphism_polynomial`.
 
-    OUTPUT:
-
-    A :class:`~sage.schemes.toric.morphism.SchemeMorphism_polynomial_toric_variety`.
+    OUTPUT: A :class:`~sage.schemes.toric.morphism.SchemeMorphism_polynomial_toric_variety`.
 
     TESTS::
 
         sage: P1xP1 = toric_varieties.P1xP1()
         sage: P1xP1.inject_variables()
         Defining s, t, x, y
-        sage: P1 = P1xP1.subscheme(s-t)
+        sage: P1 = P1xP1.subscheme(s - t)
         sage: H = P1xP1.Hom(P1)
         sage: import sage.schemes.toric.morphism as MOR
         sage: MOR.SchemeMorphism_polynomial_toric_variety(H, [s, s, x, y])
@@ -502,7 +494,7 @@ class SchemeMorphism_polynomial_toric_variety(SchemeMorphism_polynomial, Morphis
             sage: P1xP1 = toric_varieties.P1xP1()
             sage: P1xP1.inject_variables()
             Defining s, t, x, y
-            sage: P1 = P1xP1.subscheme(s-t)
+            sage: P1 = P1xP1.subscheme(s - t)
             sage: H = P1xP1.Hom(P1)
             sage: import sage.schemes.toric.morphism as MOR
             sage: MOR.SchemeMorphism_polynomial_toric_variety(H, [s, s, x, y])
@@ -520,16 +512,15 @@ class SchemeMorphism_polynomial_toric_variety(SchemeMorphism_polynomial, Morphis
             # different if the target uses weighted coordinates)
             for p in self.defining_polynomials():
                 if not self.domain().ambient_space().is_homogeneous(p):
-                    raise ValueError("%s is not homogeneous!" % p)
+                    raise ValueError("%s is not homogeneous" % p)
 
     def as_fan_morphism(self):
         """
         Express the morphism as a map defined by a fan morphism.
 
-        OUTPUT:
+        OUTPUT: A :class:`SchemeMorphism_polynomial_toric_variety`.
 
-        A :class:`SchemeMorphism_polynomial_toric_variety`. Raises a
-        ``TypeError`` if the morphism cannot be written in such a way.
+        Raises a ``TypeError`` if the morphism cannot be written in such a way.
 
         EXAMPLES::
 
@@ -540,10 +531,10 @@ class SchemeMorphism_polynomial_toric_variety(SchemeMorphism_polynomial, Morphis
             Traceback (most recent call last):
             ...
             NotImplementedError: expressing toric morphisms as fan morphisms is
-            not implemented yet!
+            not implemented yet
         """
         raise NotImplementedError("expressing toric morphisms as fan "
-                                  "morphisms is not implemented yet!")
+                                  "morphisms is not implemented yet")
 
 
 ############################################################################
@@ -612,9 +603,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
         r"""
         Return the cone corresponding to the torus orbit.
 
-        OUTPUT:
-
-        A cone of the fan of the ambient toric variety.
+        OUTPUT: A cone of the fan of the ambient toric variety.
 
         EXAMPLES::
 
@@ -635,8 +624,8 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
 
         OUTPUT:
 
-        Return a dictionary `{orbit ray generator : preimage ray
-        index}`. Note that the orbit ray generator need not be
+        A dictionary ``{orbit ray generator: preimage ray
+        index}``. Note that the orbit ray generator need not be
         primitive. Also, the preimage ray is not necessarily unique.
 
         EXAMPLES::
@@ -651,7 +640,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
         """
         orbit = self.parent().domain()
         codomain_fan = self.parent().codomain().fan()
-        reverse_ray_dict = dict()
+        reverse_ray_dict = {}
         for n1, n2 in self._ray_map.items():
             ray_index = codomain_fan.rays().index(n1)
             if n2.is_zero():
@@ -679,7 +668,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
             'Defined by embedding the torus closure associated to the 1-d cone of
              Rational polyhedral fan in 2-d lattice N.'
         """
-        s  = 'Defined by embedding the torus closure associated to the '
+        s = 'Defined by embedding the torus closure associated to the '
         s += str(self._defining_cone)
         s += '.'
         return s
@@ -711,8 +700,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
             Scheme morphism:
               From: 1-d toric variety covered by 2 affine patches
               To:   2-d CPR-Fano toric variety covered by 3 affine patches
-              Defn: Defined on coordinates by sending [z0 : z1] to
-                    [0 : z1 : z0]
+              Defn: Defined on coordinates by sending [z0 : z1] to [0 : z1 : z0]
 
         If the toric variety is singular, then some orbit closure
         embeddings cannot be written with homogeneous polynomials::
@@ -722,7 +710,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
             sage: P1.embedding_morphism().as_polynomial_map()
             Traceback (most recent call last):
             ...
-            TypeError: The embedding cannot be written with homogeneous polynomials.
+            TypeError: the embedding cannot be written with homogeneous polynomials
         """
         orbit = self.domain()
         codomain_fan = self.codomain().fan()
@@ -735,7 +723,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
             try:
                 ray_index = ray_index_map[ray]
             except KeyError:
-                raise TypeError('The embedding cannot be written with homogeneous polynomials.')
+                raise TypeError('the embedding cannot be written with homogeneous polynomials')
             polys[ray_index] = R.gen(i)
         return SchemeMorphism_polynomial_toric_variety(self.parent(), polys)
 
@@ -745,7 +733,7 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
 
         INPUT:
 
-        - ``divisor`` -- a torus-invariant QQ-Cartier divisor on the
+        - ``divisor`` -- a torus-invariant `\QQ`-Cartier divisor on the
           codomain of the embedding map.
 
         OUTPUT:
@@ -766,13 +754,13 @@ class SchemeMorphism_orbit_closure_toric_variety(SchemeMorphism, Morphism):
         """
         from sage.schemes.toric.divisor import is_ToricDivisor
         if not (is_ToricDivisor(divisor) and divisor.is_QQ_Cartier()):
-            raise ValueError('The divisor must be torus-invariant and QQ-Cartier.')
+            raise ValueError('the divisor must be torus-invariant and QQ-Cartier')
         m = divisor.m(self._defining_cone)
         values = []
         codomain_rays = self.codomain().fan().rays()
         for ray in self.domain().fan().rays():
             ray = codomain_rays[self._reverse_ray_map()[ray]]
-            value = divisor.function_value(ray) - m*ray
+            value = divisor.function_value(ray) - m * ray
             values.append(value)
         return self.domain().divisor(values)
 
@@ -812,9 +800,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         :class:`SchemeMorphism_fan_toric_variety_dominant` for
         additional functionality for fibrations.
 
-    OUTPUT:
-
-    A :class:`~sage.schemes.toric.morphism.SchemeMorphism_fan_toric_variety`.
+    OUTPUT: A :class:`~sage.schemes.toric.morphism.SchemeMorphism_fan_toric_variety`.
 
     EXAMPLES::
 
@@ -834,13 +820,13 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         sage: P1xP1 = toric_varieties.P1xP1()
         sage: P1 = toric_varieties.P1()
         sage: hom_set = P1xP1.Hom(P1)
-        sage: fm = FanMorphism( matrix(ZZ,[[1],[0]]), P1xP1.fan(), P1.fan() )
+        sage: fm = FanMorphism(matrix(ZZ, [[1],[0]]), P1xP1.fan(), P1.fan())
         sage: hom_set(fm)
         Scheme morphism:
           From: 2-d CPR-Fano toric variety covered by 4 affine patches
           To:   1-d CPR-Fano toric variety covered by 2 affine patches
           Defn: Defined by sending Rational polyhedral fan in 2-d lattice N
-               to Rational polyhedral fan in 1-d lattice N.
+                to Rational polyhedral fan in 1-d lattice N.
 
         sage: P1xP1.hom(fm, P1)
         Scheme morphism:
@@ -859,7 +845,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             sage: P1xP1 = toric_varieties.P1xP1()
             sage: P1 = toric_varieties.P1()
             sage: hom_set = P1xP1.Hom(P1)
-            sage: fan_morphism = FanMorphism( matrix(ZZ,[[1],[0]]), P1xP1.fan(), P1.fan() )
+            sage: fan_morphism = FanMorphism(matrix(ZZ, [[1],[0]]), P1xP1.fan(), P1.fan())
             sage: from sage.schemes.toric.morphism import SchemeMorphism_fan_toric_variety
             sage: SchemeMorphism_fan_toric_variety(hom_set, fan_morphism)
             Scheme morphism:
@@ -869,10 +855,10 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
                     to Rational polyhedral fan in 1-d lattice N.
         """
         SchemeMorphism.__init__(self, parent)
-        if check and self.domain().fan()!=fan_morphism.domain_fan():
-            raise ValueError('The fan morphism domain must be the fan of the domain.')
-        if check and self.codomain().fan()!=fan_morphism.codomain_fan():
-            raise ValueError('The fan morphism codomain must be the fan of the codomain.')
+        if check and self.domain().fan() != fan_morphism.domain_fan():
+            raise ValueError('the fan morphism domain must be the fan of the domain')
+        if check and self.codomain().fan() != fan_morphism.codomain_fan():
+            raise ValueError('the fan morphism codomain must be the fan of the codomain')
         self._fan_morphism = fan_morphism
 
     def _richcmp_(self, right, op):
@@ -883,9 +869,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
 
         - ``right`` -- another toric morphism
 
-        OUTPUT:
-
-        - boolean
+        OUTPUT: A boolean.
 
         Comparison is done first by domain, then by codomain, then by
         fan morphism.
@@ -926,9 +910,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
 
         - ``right`` -- a toric morphism defined by a fan morphism.
 
-        OUTPUT:
-
-        - a toric morphism.
+        OUTPUT: A toric morphism.
 
         EXAMPLES::
 
@@ -965,7 +947,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             sage: f._repr_defn()
             'Defined by sending Rational polyhedral fan in 2-d lattice N to Rational polyhedral fan in 1-d lattice N.'
         """
-        s  = 'Defined by sending '
+        s = 'Defined by sending '
         s += str(self.domain().fan())
         s += ' to '
         s += str(self.codomain().fan())
@@ -1035,8 +1017,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             Scheme morphism:
               From: 2-d affine toric variety
               To:   2-d affine toric variety
-              Defn: Defined on coordinates by sending [x : y] to
-                    [x^2 : y]
+              Defn: Defined on coordinates by sending [x : y] to [x^2 : y]
 
         Blowup chart (birational)::
 
@@ -1044,8 +1025,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             Scheme morphism:
               From: 2-d affine toric variety
               To:   2-d toric variety covered by 3 affine patches
-              Defn: Defined on coordinates by sending [z0 : z1] to
-                    [1 : z1 : z0*z1]
+              Defn: Defined on coordinates by sending [z0 : z1] to [1 : z1 : z0*z1]
 
         Coordinate plane inclusion (injective)::
 
@@ -1053,11 +1033,10 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             Scheme morphism:
               From: 2-d toric variety covered by 3 affine patches
               To:   3-d CPR-Fano toric variety covered by 4 affine patches
-              Defn: Defined on coordinates by sending [z0 : z1 : z2] to
-                    [z2 : z1 : z0 : z0]
+              Defn: Defined on coordinates by sending [z0 : z1 : z2] to [z2 : z1 : z0 : z0]
         """
         phi_i, phi_b, phi_s = self.fan_morphism().factor()
-        from sage.schemes.toric.all import ToricVariety
+        from sage.schemes.toric.variety import ToricVariety
         X = self.domain()
         X_s = ToricVariety(phi_s.codomain_fan())
         X_i = ToricVariety(phi_i.domain_fan())
@@ -1068,9 +1047,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         """
         Return the defining fan morphism.
 
-        OUTPUT:
-
-        A :class:`~sage.geometry.fan_morphism.FanMorphism`.
+        OUTPUT: A :class:`~sage.geometry.fan_morphism.FanMorphism`.
 
         EXAMPLES::
 
@@ -1090,10 +1067,9 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         """
         Express the morphism via homogeneous polynomials.
 
-        OUTPUT:
+        OUTPUT: A :class:`SchemeMorphism_polynomial_toric_variety`.
 
-        A :class:`SchemeMorphism_polynomial_toric_variety`. Raises a
-        ``TypeError`` if the morphism cannot be written in terms of
+        Raises a ``TypeError`` if the morphism cannot be written in terms of
         homogeneous polynomials.
 
         EXAMPLES::
@@ -1102,8 +1078,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             sage: square = A1.hom(matrix([[2]]), A1)
             sage: square.as_polynomial_map()
             Scheme endomorphism of 1-d affine toric variety
-              Defn: Defined on coordinates by sending [z] to
-                    [z^2]
+              Defn: Defined on coordinates by sending [z] to [z^2]
 
             sage: P1 = toric_varieties.P1()
             sage: patch = A1.hom(matrix([[1]]), P1)
@@ -1111,8 +1086,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
             Scheme morphism:
               From: 1-d affine toric variety
               To:   1-d CPR-Fano toric variety covered by 2 affine patches
-              Defn: Defined on coordinates by sending [z] to
-                    [z : 1]
+              Defn: Defined on coordinates by sending [z] to [z : 1]
         """
         R = self.domain().coordinate_ring()
         phi = self.fan_morphism()
@@ -1125,8 +1099,8 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
                 try:
                     d = ZZ(d)
                 except TypeError:
-                    raise TypeError('The fan morphism cannot be written in '
-                                    'homogeneous polynomials.')
+                    raise TypeError('the fan morphism cannot be written in '
+                                    'homogeneous polynomials')
                 polys[i] *= x**d
         if phi.domain_fan().virtual_rays():
             raise NotImplementedError("polynomial representations for fans "
@@ -1301,7 +1275,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
 
         INPUT:
 
-        - ``divisor`` -- a torus-invariant QQ-Cartier divisor on the
+        - ``divisor`` -- a torus-invariant `\QQ`-Cartier divisor on the
           codomain of ``self``.
 
         OUTPUT:
@@ -1312,7 +1286,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
 
             sage: A2_Z2 = toric_varieties.A2_Z2()
             sage: A2 = toric_varieties.A2()
-            sage: f = A2.hom( matrix([[1,0],[1,2]]), A2_Z2)
+            sage: f = A2.hom(matrix([[1,0], [1,2]]), A2_Z2)
             sage: f.pullback_divisor(A2_Z2.divisor(0))
             V(x)
 
@@ -1325,7 +1299,7 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         """
         from sage.schemes.toric.divisor import is_ToricDivisor
         if not (is_ToricDivisor(divisor) and divisor.is_QQ_Cartier()):
-            raise ValueError('The divisor must be torus-invariant and QQ-Cartier.')
+            raise ValueError('the divisor must be torus-invariant and QQ-Cartier')
         fm = self.fan_morphism()
         values = []
         for ray in self.domain().fan().rays():
@@ -1334,7 +1308,6 @@ class SchemeMorphism_fan_toric_variety(SchemeMorphism, Morphism):
         return self.domain().divisor(values)
 
 
-
 ############################################################################
 # A morphism of toric varieties determined by a dominant fan morphism
 class SchemeMorphism_fan_toric_variety_dominant(SchemeMorphism_fan_toric_variety):
@@ -1359,9 +1332,7 @@ class SchemeMorphism_fan_toric_variety_dominant(SchemeMorphism_fan_toric_variety
     morphism :meth:`must be dominant
     <sage.geometry.fan_morphism.FanMorphism.is_dominant>`.
 
-    OUTPUT:
-
-    A :class:`~sage.schemes.toric.morphism.SchemeMorphism_fan_toric_variety_dominant`.
+    OUTPUT: A :class:`~sage.schemes.toric.morphism.SchemeMorphism_fan_toric_variety_dominant`.
 
     EXAMPLES::
 
@@ -1421,11 +1392,10 @@ class SchemeMorphism_fan_toric_variety_dominant(SchemeMorphism_fan_toric_variety
             Scheme morphism:
               From: 1-d toric variety covered by 2 affine patches
               To:   2-d CPR-Fano toric variety covered by 4 affine patches
-              Defn: Defined on coordinates by sending [z0 : z1] to
-                    [1 : 1 : z0 : z1]
+              Defn: Defined on coordinates by sending [z0 : z1] to [1 : 1 : z0 : z1]
 
             sage: A1 = toric_varieties.A1()
-            sage: fan = Fan([(0,1,2)], [(1,1,0),(1,0,1),(1,-1,-1)])
+            sage: fan = Fan([(0,1,2)], [(1,1,0), (1,0,1), (1,-1,-1)])
             sage: fan = fan.subdivide(new_rays=[(1,0,0)])
             sage: f = ToricVariety(fan).hom(matrix([[1],[0],[0]]), A1)
             sage: f.fiber_generic()
@@ -1480,10 +1450,11 @@ class SchemeMorphism_fan_toric_variety_dominant(SchemeMorphism_fan_toric_variety
             ....:      (0,1,0,0),(0,2,-1,-1),(1,0,0,0),(2,0,-1,-1)])
             sage: coarse_fan = FaceFan(polytope)
             sage: P2 = toric_varieties.P2()
-            sage: proj24 = matrix([[0,0],[1,0],[0,0],[0,1]])
+            sage: proj24 = matrix([[0,0], [1,0], [0,0], [0,1]])
             sage: fm = FanMorphism(proj24, coarse_fan, P2.fan(), subdivide=True)
             sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
-            sage: primitive_cones = fibration.fan_morphism().primitive_preimage_cones(P2.fan(1)[0])
+            sage: ffm = fibration.fan_morphism()
+            sage: primitive_cones = ffm.primitive_preimage_cones(P2.fan(1)[0])
             sage: primitive_cone = primitive_cones[0]
             sage: fibration.fiber_component(primitive_cone)
             2-d toric variety covered by 4 affine patches
@@ -1599,11 +1570,12 @@ class SchemeMorphism_fan_toric_variety_dominant(SchemeMorphism_fan_toric_variety
             sage: coarse_fan = FaceFan(polytope, lattice=ToricLattice(4))
 
             sage: P2 = toric_varieties.P2()
-            sage: proj34 = block_matrix(2,1,[zero_matrix(2,2), identity_matrix(2)])
+            sage: proj34 = block_matrix(2, 1, [zero_matrix(2,2),
+            ....:                              identity_matrix(2)])
             sage: fm = FanMorphism(proj34, coarse_fan, P2.fan(), subdivide=True)
             sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
 
-            sage: fibration.fiber_graph( P2.fan(0)[0] )
+            sage: fibration.fiber_graph(P2.fan(0)[0])
             Graph on 1 vertex
             sage: for c1 in P2.fan(1):
             ....:     fibration.fiber_graph(c1)
@@ -1676,7 +1648,8 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
         sage: proj24 = matrix([[0,0],[1,0],[0,0],[0,1]])
         sage: fm = FanMorphism(proj24, coarse_fan, P2.fan(), subdivide=True)
         sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
-        sage: primitive_cones = fibration.fan_morphism().primitive_preimage_cones(P2.fan(1)[0])
+        sage: ffm = fibration.fan_morphism()
+        sage: primitive_cones = ffm.primitive_preimage_cones(P2.fan(1)[0])
         sage: primitive_cone = primitive_cones[0]
         sage: fiber_component = fibration.fiber_component(primitive_cone)
         sage: fiber_component
@@ -1708,7 +1681,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             ....:      (0,1,0,0),(0,2,-1,-1),(1,0,0,0),(2,0,-1,-1)])
             sage: coarse_fan = FaceFan(polytope, lattice=ToricLattice(4))
             sage: P2 = toric_varieties.P2()
-            sage: proj24 = matrix([[0,0],[1,0],[0,0],[0,1]])
+            sage: proj24 = matrix([[0,0], [1,0], [0,0], [0,1]])
             sage: fm = FanMorphism(proj24, coarse_fan, P2.fan(), subdivide=True)
             sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
             sage: primitive_cone = Cone([(-1, 2, -1, 0)])
@@ -1764,7 +1737,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             ....:      (0,1,0,0),(0,2,-1,-1),(1,0,0,0),(2,0,-1,-1)])
             sage: coarse_fan = FaceFan(polytope, lattice=ToricLattice(4))
             sage: P2 = toric_varieties.P2()
-            sage: proj24 = matrix([[0,0],[1,0],[0,0],[0,1]])
+            sage: proj24 = matrix([[0,0], [1,0], [0,0], [0,1]])
             sage: fm = FanMorphism(proj24, coarse_fan, P2.fan(), subdivide=True)
             sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
 
@@ -1782,7 +1755,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             sage: f.as_polynomial_map()
             Traceback (most recent call last):
             ...
-            ValueError: The morphism cannot be written using homogeneous polynomials.
+            ValueError: the morphism cannot be written using homogeneous polynomials
         """
         fc = self.domain()
         toric_variety = self.codomain()
@@ -1794,7 +1767,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             try:
                 ray_index = self._ray_index_map[ray]
             except KeyError:
-                raise ValueError('The morphism cannot be written using homogeneous polynomials.')
+                raise ValueError('the morphism cannot be written using homogeneous polynomials')
             polys[ray_index] = x
         return SchemeMorphism_polynomial_toric_variety(self.parent(), polys)
 
@@ -1843,7 +1816,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
         ker = fm.kernel().basis()
         m = fm.matrix() * base_cone.lattice().basis_matrix()
         base_cone_preimg = [m.solve_left(r) for r in base_cone.rays()]
-        L = fm.domain_fan().lattice().span(ker+base_cone_preimg).saturation()
+        L = fm.domain_fan().lattice().span(ker + base_cone_preimg).saturation()
 
         cone_L = Cone([L.coordinates(r) for r in defining_cone.rays()])
         L_quotient = cone_L.sublattice_quotient()
@@ -1860,7 +1833,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             cones.append(Cone(projected_rays))
         fiber_fan = Fan(cones)
 
-        ray_index_map = dict()
+        ray_index_map = {}
         for ray in star_rays:
             ray_index = fm.domain_fan().rays().index(ray)
             projected_ray = fiber_fan.lattice()(projection(ray))
@@ -1941,7 +1914,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             ....:      (0,1,0,0),(0,2,-1,-1),(1,0,0,0),(2,0,-1,-1)])
             sage: coarse_fan = FaceFan(polytope, lattice=ToricLattice(4))
             sage: P2 = toric_varieties.P2()
-            sage: proj24 = matrix([[0,0],[1,0],[0,0],[0,1]])
+            sage: proj24 = matrix([[0,0], [1,0], [0,0], [0,1]])
             sage: fm = FanMorphism(proj24, coarse_fan, P2.fan(), subdivide=True)
             sage: fibration = ToricVariety(fm.domain_fan()).hom(fm, P2)
             sage: primitive_cone = Cone([(-1, 2, -1, 0)])
@@ -1966,7 +1939,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
             d = gcd(ray)
             if d * fiber_ray != ray:
                 continue
-            if multiplicity is not None and d>multiplicity:
+            if multiplicity is not None and d > multiplicity:
                 continue
             multiplicity = d
             image_ray_index = index
@@ -1978,7 +1951,7 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
 
         INPUT:
 
-        - ``divisor`` -- a torus-invariant QQ-Cartier divisor on the
+        - ``divisor`` -- a torus-invariant `\QQ`-Cartier divisor on the
           codomain of the embedding map.
 
         OUTPUT:
@@ -2004,16 +1977,14 @@ class SchemeMorphism_fan_fiber_component_toric_variety(SchemeMorphism):
         """
         from sage.schemes.toric.divisor import is_ToricDivisor
         if not (is_ToricDivisor(divisor) and divisor.is_QQ_Cartier()):
-            raise ValueError('The divisor must be torus-invariant and QQ-Cartier.')
+            raise ValueError('the divisor must be torus-invariant and QQ-Cartier')
         m = divisor.m(self.defining_cone())
         values = []
         codomain_rays = self.codomain().fan().rays()
         for ray in self.domain().fan().rays():
             image_ray_index, multiplicity = self._image_ray_multiplicity(ray)
             image_ray = codomain_rays[image_ray_index]
-            value = divisor.function_value(image_ray) - m*image_ray
+            value = divisor.function_value(image_ray) - m * image_ray
             value /= multiplicity
             values.append(value)
         return self.domain().divisor(values)
-
-
