@@ -337,7 +337,7 @@ class Set_base():
         if set_self is not self:
             from sage.misc.sage_unittest import TestSuite
             tester.info("\n  Running the test suite of Set(self)")
-            TestSuite(set_self).run(skip="_test_pickling",  # see Trac #32025
+            TestSuite(set_self).run(skip="_test_pickling",  # see Issue #32025
                                     verbose=tester._verbose,
                                     prefix=tester._prefix + "  ")
             tester.info(tester._prefix + " ", newline=False)
@@ -616,7 +616,7 @@ class Set_object(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_opera
             False
 
         Finite fields better illustrate the difference between
-        ``__contains__`` for objects and their underlying sets.
+        ``__contains__`` for objects and their underlying sets::
 
             sage: X = Set(GF(7))
             sage: X
@@ -1061,10 +1061,20 @@ class Set_object_enumerated(Set_object):
             False
             sage: Set([1]) == set([1])
             True
+
+        Test set equality and inequality::
+
+            sage: L = {0}
+            sage: S = Set(L)
+            sage: S == L
+            True
+            sage: S != L
+            False
         """
         if not isinstance(other, Set_object_enumerated):
             if isinstance(other, (set, frozenset)):
-                return self.set() == other
+                if self.set() == other:
+                    return rich_to_bool(op, 0)
             return NotImplemented
         if self.set() == other.set():
             return rich_to_bool(op, 0)
