@@ -387,7 +387,7 @@ sage class. In this case the class is specified using the arguments to
 
 Here is an example to test the pickling of a :class:`GlobalOptions` instance::
 
-    sage: TestSuite(Partitions.options).run()
+    sage: TestSuite(Partitions.options).run()                                           # optional - sage.combinat
 
 TESTS:
 
@@ -526,15 +526,15 @@ class Option():
 
     EXAMPLES::
 
-        sage: Partitions.options.display
+        sage: Partitions.options.display                                                # optional - sage.combinat
         list
-        sage: Partitions.options.display='compact'
-        sage: Partitions.options.display('list')
-        sage: Partitions.options._reset()
+        sage: Partitions.options.display = 'compact'                                    # optional - sage.combinat
+        sage: Partitions.options.display('list')                                        # optional - sage.combinat
+        sage: Partitions.options._reset()                                               # optional - sage.combinat
 
     TESTS::
 
-        sage: TestSuite(Partitions.options.display).run()
+        sage: TestSuite(Partitions.options.display).run()                               # optional - sage.combinat
     """
     __name__ = 'Option class'
 
@@ -545,7 +545,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: type(Partitions.options.display)    # indirect doctest
+            sage: type(Partitions.options.display)    # indirect doctest                # optional - sage.combinat
             <class 'sage.structure.global_options.Option'>
         """
         self._name = name
@@ -559,7 +559,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: Partitions.options.display # indirect doctest
+            sage: Partitions.options.display # indirect doctest                         # optional - sage.combinat
             list
         """
         # NOTE: we intentionally use str() instead of repr()
@@ -572,7 +572,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: Tableaux.options.convention +' is good'
+            sage: Tableaux.options.convention + ' is good'                              # optional - sage.combinat
             'English is good'
         """
         return self._options[self._name] + other
@@ -584,7 +584,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: 'Good '+Tableaux.options.convention
+            sage: 'Good ' + Tableaux.options.convention                                 # optional - sage.combinat
             'Good English'
         """
         return other + self._options[self._name]
@@ -596,7 +596,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: Tableaux.options.convention +' is good'
+            sage: Tableaux.options.convention + ' is good'                              # optional - sage.combinat
             'English is good'
         """
         return self._options[self._name] * other
@@ -608,43 +608,40 @@ class Option():
 
         EXAMPLES::
 
-            sage: 'Good '+Tableaux.options.convention
+            sage: 'Good ' + Tableaux.options.convention                                 # optional - sage.combinat
             'Good English'
         """
         return other * self._options[self._name]
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         r"""
         Return the value of this option interpreted as a boolean.
 
         EXAMPLES::
 
-            sage: RiggedConfigurations.options.half_width_boxes_type_B
+            sage: RiggedConfigurations.options.half_width_boxes_type_B                          # optional - sage.combinat
             True
-            sage: 'yes' if RiggedConfigurations.options.half_width_boxes_type_B else  'no'
+            sage: 'yes' if RiggedConfigurations.options.half_width_boxes_type_B else 'no'       # optional - sage.combinat
             'yes'
-            sage: RiggedConfigurations.options.half_width_boxes_type_B=False
-            sage: 'yes' if RiggedConfigurations.options.half_width_boxes_type_B else  'no'
+            sage: RiggedConfigurations.options.half_width_boxes_type_B = False                  # optional - sage.combinat
+            sage: 'yes' if RiggedConfigurations.options.half_width_boxes_type_B else 'no'       # optional - sage.combinat
             'no'
-            sage: RiggedConfigurations.options._reset()
+            sage: RiggedConfigurations.options._reset()                                         # optional - sage.combinat
         """
         return bool(self._options[self._name])
 
-    # for the less sensibly named python 2 family
-    
-
     def __call__(self, *args, **kwds):
         r"""
         Get or set value of the option ``self``.
 
         EXAMPLES::
 
-            sage: Partitions.options.display() # indirect doctest
+            sage: Partitions.options.display()       # indirect doctest                         # optional - sage.combinat
             'list'
-            sage: Partitions.options.display('exp') # indirect doctest
-            sage: Partitions.options.display() # indirect doctest
+            sage: Partitions.options.display('exp')  # indirect doctest                         # optional - sage.combinat
+            sage: Partitions.options.display()       # indirect doctest                         # optional - sage.combinat
             'exp_low'
-            sage: Partitions.options._reset()
+            sage: Partitions.options._reset()                                                   # optional - sage.combinat
 
         TESTS:
 
@@ -666,7 +663,7 @@ class Option():
 
             sage: config.size(value=None)
             doctest:...: DeprecationWarning: keyword argument "value" should be replaced by positional argument
-            See https://trac.sagemath.org/30763 for details.
+            See https://github.com/sagemath/sage/issues/30763 for details.
             sage: config.size() is None
             True
             sage: config.size(1, 2)
@@ -699,11 +696,11 @@ class Option():
 
         EXAMPLES::
 
-            sage: Tableaux.options.convention
+            sage: Tableaux.options.convention                                           # optional - sage.combinat
             English
-            sage: Tableaux.options.convention == "English"
+            sage: Tableaux.options.convention == "English"                              # optional - sage.combinat
             True
-            sage: Tableaux.options.convention == "French"
+            sage: Tableaux.options.convention == "French"                               # optional - sage.combinat
             False
         """
         return self._options[self._name] == other
@@ -715,11 +712,11 @@ class Option():
 
         EXAMPLES::
 
-            sage: Tableaux.options.convention
+            sage: Tableaux.options.convention                                           # optional - sage.combinat
             English
-            sage: Tableaux.options.convention != "English"
+            sage: Tableaux.options.convention != "English"                              # optional - sage.combinat
             False
-            sage: Tableaux.options.convention != "French"
+            sage: Tableaux.options.convention != "French"                               # optional - sage.combinat
             True
         """
         return self._options[self._name] != other
@@ -731,7 +728,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: hash(Tableaux.options.convention) == hash(Tableaux.options('convention'))
+            sage: hash(Tableaux.options.convention) == hash(Tableaux.options('convention'))     # optional - sage.combinat
             True
         """
         return hash(self._options[self._name])
@@ -743,7 +740,7 @@ class Option():
 
         EXAMPLES::
 
-            sage: str(Tableaux.options.convention)
+            sage: str(Tableaux.options.convention)                                      # optional - sage.combinat
             'English'
         """
         return str(self._options[self._name])
@@ -1235,7 +1232,7 @@ class GlobalOptions(metaclass=GlobalOptionsMeta):
 
         EXAMPLES::
 
-            sage: print(Partitions.options.__doc__)
+            sage: print(Partitions.options.__doc__)                                     # optional - sage.combinat
             <BLANKLINE>
             Sets and displays the global options for elements of the partition,
             skew partition, and partition tuple classes.  If no parameters are
@@ -1276,12 +1273,12 @@ class GlobalOptions(metaclass=GlobalOptionsMeta):
 
         EXAMPLES::
 
-            sage: Partitions.options.display = 'exp'
-            sage: Partitions.options.dispplay = 'list'
+            sage: Partitions.options.display = 'exp'                                    # optional - sage.combinat
+            sage: Partitions.options.dispplay = 'list'                                  # optional - sage.combinat
             Traceback (most recent call last):
             ...
             ValueError: dispplay is not an option for Partitions
-            sage: Partitions.options._reset()
+            sage: Partitions.options._reset()                                           # optional - sage.combinat
         """
         # Underscore, and "special", attributes are set using type.__setattr__
         if name[0] == '_' or name in ['reset', 'dispatch', 'default_value']:
@@ -1301,24 +1298,24 @@ class GlobalOptions(metaclass=GlobalOptionsMeta):
 
         EXAMPLES::
 
-            sage: Partitions.options()
+            sage: Partitions.options()                                                  # optional - sage.combinat
             Current options for Partitions
               - convention:        English
               - diagram_str:       *
               - display:           list
               - latex:             young_diagram
               - latex_diagram_str: \ast
-            sage: Partitions.options.convention="French"
-            sage: pickle = dumps(Partitions.options)
-            sage: Partitions.options._reset()        # reset options
-            sage: loads(pickle)                      # indirect doctest
+            sage: Partitions.options.convention = "French"                              # optional - sage.combinat
+            sage: pickle = dumps(Partitions.options)                                    # optional - sage.combinat
+            sage: Partitions.options._reset()        # reset options                    # optional - sage.combinat
+            sage: loads(pickle)                      # indirect doctest                 # optional - sage.combinat
             Current options for Partitions
               - convention:        French
               - diagram_str:       *
               - display:           list
               - latex:             young_diagram
               - latex_diagram_str: \ast
-            sage: Partitions.options._reset()
+            sage: Partitions.options._reset()                                           # optional - sage.combinat
         """
         # open the options for the corresponding "parent" and copy all of
         # the data from its options class into unpickle
@@ -1353,8 +1350,8 @@ class GlobalOptions(metaclass=GlobalOptionsMeta):
 
         EXAMPLES::
 
-            sage: Partitions.options._reset()
-            sage: Partitions.options.__getstate__()
+            sage: Partitions.options._reset()                                           # optional - sage.combinat
+            sage: Partitions.options.__getstate__()                                     # optional - sage.combinat
              {'convention': 'English',
              'option_class': 'Partitions',
              'options_module': 'sage.combinat.partition'}
@@ -1388,12 +1385,12 @@ class GlobalOptions(metaclass=GlobalOptionsMeta):
 
         EXAMPLES::
 
-            sage: Partitions.options == PartitionsGreatestLE.options # indirect doctest
+            sage: Partitions.options == PartitionsGreatestLE.options # indirect doctest # optional - sage.combinat
             True
-            sage: Partitions.options == Tableaux.options
+            sage: Partitions.options == Tableaux.options                                # optional - sage.combinat
             False
         """
-        return self.__getstate__() == other.__getstate__()
+        return isinstance(other, GlobalOptions) and self.__getstate__() == other.__getstate__()
 
     def _add_option(self, option, specifications):
         r"""
