@@ -24,8 +24,6 @@ using monospace fonts. The difference is that one is restricted to
 #
 #                  https://www.gnu.org/licenses/
 # ******************************************************************************
-
-import os
 import sys
 from sage.structure.sage_object import SageObject
 
@@ -135,8 +133,7 @@ class CharacterArt(SageObject):
              * *
             *****
         """
-        for elem in self._matrix:
-            yield elem
+        yield from self._matrix
 
     def _repr_(self):
         r"""
@@ -164,10 +161,10 @@ class CharacterArt(SageObject):
 
         EXAMPLES::
 
-            sage: M = matrix([[1,2],[3,4]])
-            sage: format(ascii_art(M))
+            sage: M = matrix([[1,2],[3,4]])                                             # needs sage.modules
+            sage: format(ascii_art(M))                                                  # needs sage.modules
             '[1 2]\n[3 4]'
-            sage: format(unicode_art(M))
+            sage: format(unicode_art(M))                                                # needs sage.modules
             '\u239b1 2\u239e\n\u239d3 4\u23a0'
         """
         return format(self._string_type(self), fmt)
@@ -230,7 +227,7 @@ class CharacterArt(SageObject):
             sage: aa = ascii_art([p3, p5])
             sage: aa.get_breakpoints()
             doctest:...: DeprecationWarning: get_breakpoints() is deprecated
-            See https://trac.sagemath.org/29204 for details.
+            See https://github.com/sagemath/sage/issues/29204 for details.
             [6]
         """
         from sage.misc.superseded import deprecation
